#!perl

use strict;
use warnings;
$|=1;
use Test::More tests => 1;
use DBI;
#use DBD::SQLite;
use File::Spec;
use File::Path;
use File::Basename;

# rebuild cpanstats db

my $f = File::Spec->catfile('t','_DBDIR','test.db');
unlink $f if -f $f;
mkpath( dirname($f) );

my $dbh = DBI->connect("dbi:SQLite:dbname=$f", '', '', {AutoCommit=>1});
$dbh->do(q{
  CREATE TABLE cpanstats (
                          id            INTEGER PRIMARY KEY,
                          guid          TEXT,
                          state         TEXT,
                          postdate      TEXT,
                          tester        TEXT,
                          dist          TEXT,
                          version       TEXT,
                          platform      TEXT,
                          perl          TEXT,
                          osname        TEXT,
                          osvers        TEXT,
                          fulldate      TEXT
  )
});

while(<DATA>){
  chomp;
  $dbh->do('INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate ) VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )', {}, split(/\|/,$_) );
}

$dbh->do(q{ CREATE INDEX distverstate ON cpanstats (dist, version, state) });
$dbh->do(q{ CREATE INDEX ixdate ON cpanstats (postdate) });
$dbh->do(q{ CREATE INDEX ixperl ON cpanstats (perl) });
$dbh->do(q{ CREATE INDEX ixplat ON cpanstats (platform) });

my ($ct) = $dbh->selectrow_array('select count(*) from cpanstats');

$dbh->disconnect;

is($ct, 10976, "row count for cpanstats");

#select * from cpanstats where state='cpan' and dist in ('AEAE', 'AI-NeuralNet-BackProp', 'AI-NeuralNet-Mesh', 'AI-NeuralNet-SOM', 'AOL-TOC', 'Abstract-Meta-Class', 'Acme', 'Acme-Anything', 'Acme-BOPE', 'Acme-Brainfuck', 'Acme-Buffy', 'Acme-CPANAuthors-Canadian', 'Acme-CPANAuthors-CodeRepos', 'Acme-CPANAuthors-French', 'Acme-CPANAuthors-Japanese');
# sqlite> select * from cpanstats where postdate=200901 order by dist limit 20;
# id|guid|state|postdate|tester|dist|version|platform|perl|osname|osvers|date
__DATA__
4769141|4769141-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907250807
4768761|4768761-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907250645
4768746|4768746-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907250643
4766868|4766868-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241805
4766801|4766801-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241803
4766786|4766786-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241803
4766403|4766403-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100rc1@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241753
4766103|4766103-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker1@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241744
4766061|4766061-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241743
4765898|4765898-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker1@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241739
4765868|4765868-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241738
4765251|4765251-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241720
4764927|4764927-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241711
4764914|4764914-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241710
4764659|4764659-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241703
4764609|4764609-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241702
4764421|4764421-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241657
4764354|4764354-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241656
4763897|4763897-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241645
4763676|4763676-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241638
4763621|4763621-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241636
4763613|4763613-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241636
4763542|4763542-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241634
4762584|4762584-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241609
4762464|4762464-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241607
4762393|4762393-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker4@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241606
4762347|4762347-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241605
4762041|4762041-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241600
4762008|4762008-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241600
4761762|4761762-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris|5.8.8|solaris|2.10|200907242024
4761682|4761682-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241554
4760155|4760155-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907241627
4756952|4756952-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907240354
4756950|4756950-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907240353
4756165|4756165-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907240025
4755922|4755922-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907240018
4755852|4755852-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100rc1@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907240016
4755743|4755743-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker1@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907240010
4754970|4754970-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker9@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907231932
4754831|4754831-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker3@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907231926
4754597|4754597-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907231913
4754377|4754377-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker4@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907231902
4754291|4754291-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907231858
4753804|4753804-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232249
4753583|4753583-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Mail-File|0.08|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232155
4753443|4753443-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|GD-Chart-Radial|0.07|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232117
4753442|4753442-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232117
4753414|4753414-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232115
4753154|4753154-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232020
4753153|4753153-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232020
4753150|4753150-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232020
4753146|4753146-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232019
4753145|4753145-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232019
4753138|4753138-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232018
4753070|4753070-b19f-3f77-b713-d32bba55d77f|fail|200907|bingos@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232005
4753063|4753063-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232004
4753036|4753036-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231959
4753031|4753031-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231959
4753028|4753028-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231958
4753025|4753025-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231958
4753018|4753018-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231956
4753016|4753016-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231956
4753008|4753008-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231954
4753007|4753007-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231955
4753006|4753006-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231954
4752911|4752911-b19f-3f77-b713-d32bba55d77f|pass|200907|woody@2143.net|Test-YAML-Meta|0.12|i686-linux|5.8.8|linux|2.6.27-gentoo-r8|200907231842
4752887|4752887-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Calendar-List|0.21|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231938
4752635|4752635-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231851
4752626|4752626-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231850
4752050|4752050-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907231816
4750475|4750475-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200907231355
4749847|4749847-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200907231204
4749845|4749845-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200907231204
4749843|4749843-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200907231203
4748817|4748817-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907230904
4748811|4748811-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907230902
4748175|4748175-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907230505
4747966|4747966-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907230311
4747831|4747831-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907230304
4747512|4747512-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907230257
4747503|4747503-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907230257
4747293|4747293-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907230253
4747096|4747096-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907230250
4746987|4746987-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907230248
4746594|4746594-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907230240
4746497|4746497-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907230238
4744652|4744652-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|Test-JSON-Meta|0.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907222351
4743941|4743941-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris|5.8.7|solaris|2.10|200907221924
4743355|4743355-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221809
4743019|4743019-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris|5.8.7|solaris|2.10|200907221641
4742638|4742638-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907221724
4742629|4742629-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907221722
4742396|4742396-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221549
4742019|4742019-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220946
4741950|4741950-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220944
4741803|4741803-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221427
4741801|4741801-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i86pc-solaris|5.8.7|solaris|2.10|200907221403
4741754|4741754-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221425
4741749|4741749-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221425
4741729|4741729-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221425
4741637|4741637-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris|5.8.7|solaris|2.10|200907221355
4741609|4741609-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|i86pc-solaris|5.8.7|solaris|2.10|200907221354
4741603|4741603-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris|5.8.7|solaris|2.10|200907221354
4741501|4741501-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220916
4740659|4740659-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220840
4739689|4739689-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|Test-JSON-Meta|0.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200907221336
4739282|4739282-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-Data-Release|0.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907221304
4739099|4739099-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-Data-Release|0.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200907221242
4737204|4737204-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220001
4736615|4736615-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220351
4736406|4736406-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220347
4736276|4736276-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220344
4736271|4736271-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220344
4736083|4736083-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220341
4735903|4735903-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220337
4735866|4735866-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220337
4735847|4735847-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220336
4734594|4734594-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211931
4733422|4733422-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211908
4732528|4732528-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211846
4732484|4732484-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211844
4731521|4731521-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211806
4731235|4731235-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211758
4731180|4731180-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211756
4731063|4731063-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211752
4730766|4730766-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211737
4730600|4730600-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211739
4729977|4729977-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211723
4729746|4729746-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211716
4729733|4729733-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211715
4729323|4729323-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211704
4729094|4729094-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211658
4729063|4729063-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211658
4728791|4728791-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211650
4727799|4727799-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211740
4727785|4727785-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211739
4727781|4727781-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211739
4727767|4727767-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211736
4727009|4727009-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211511
4727007|4727007-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211510
4726695|4726695-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Test-YAML-Meta|0.12|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200907211420
4724251|4724251-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907210627
4722716|4722716-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200907210110
4722667|4722667-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907210059
4722507|4722507-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris|5.8.6|solaris|2.10|200907202310
4721610|4721610-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201739
4721175|4721175-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201729
4720349|4720349-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201708
4719799|4719799-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907202254
4718903|4718903-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201633
4718061|4718061-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201938
4717977|4717977-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201608
4717971|4717971-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201608
4717841|4717841-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201604
4717840|4717840-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201604
4717650|4717650-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201559
4717523|4717523-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201555
4717414|4717414-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201552
4717354|4717354-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201550
4717210|4717210-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201545
4716961|4716961-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201539
4716884|4716884-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201538
4716291|4716291-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201524
4716121|4716121-b19f-3f77-b713-d32bba55d77f|pass|200907|justin.d.hunter@gmail.com|Regexp-Log-Common|0.05|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200907201204
4715956|4715956-b19f-3f77-b713-d32bba55d77f|pass|200907|justin.d.hunter@gmail.com|Test-JSON-Meta|0.01|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200907201138
4715946|4715946-b19f-3f77-b713-d32bba55d77f|pass|200907|justin.d.hunter@gmail.com|CPAN-Testers-Data-Release|0.02|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200907201137
4715881|4715881-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris|5.8.6|solaris|2.10|200907201905
4715146|4715146-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201606
4715137|4715137-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907201838
4715036|4715036-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907201825
4714761|4714761-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i86pc-solaris|5.8.6|solaris|2.10|200907201625
4714727|4714727-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris|5.8.6|solaris|2.10|200907201622
4714725|4714725-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|i86pc-solaris|5.8.6|solaris|2.10|200907201621
4714719|4714719-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris|5.8.6|solaris|2.10|200907201621
4714550|4714550-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200907201726
4714238|4714238-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907201656
4714112|4714112-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201406
4714106|4714106-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201404
4714096|4714096-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201403
4714091|4714091-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201403
4713794|4713794-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907201615
4713502|4713502-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Release|0.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907202328
4713493|4713493-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Uploads|0.07|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907202327
4712770|4712770-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200907201326
4712529|4712529-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907201248
4712402|4712402-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200907201229
4711987|4711987-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200907201135
4711623|4711623-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPAN-Testers-Data-Uploads|0.07|i686-linux|5.10.0|linux|2.6.24-24-generic|200907200946
4711622|4711622-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPAN-Testers-Data-Release|0.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200907200946
4711257|4711257-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200907200956
4710624|4710624-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200907200812
4710570|4710570-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200907200801
4710561|4710561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200907200759
4710334|4710334-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200907200713
4710276|4710276-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200907200705
4709196|4709196-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200334
4709166|4709166-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907200334
4709053|4709053-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200907200531
4708666|4708666-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200325
4708510|4708510-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907200323
4708507|4708507-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200323
4707788|4707788-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907200311
4707722|4707722-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200310
4707593|4707593-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200907200503
4706860|4706860-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200907200317
4706677|4706677-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200907200246
4706564|4706564-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Regexp-Log-Common|0.05|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200033
4705646|4705646-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200907200004
4705157|4705157-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907192255
4704623|4704623-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200907192124
4704613|4704613-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200907192122
4704602|4704602-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha-Plugin-PingFM|0.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200520
4704247|4704247-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907192019
4703956|4703956-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200907191928
4703803|4703803-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200256
4703399|4703399-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200907191740
4703369|4703369-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200907191737
4703173|4703173-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Mail-Outlook|0.15|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200110
4703072|4703072-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200907191655
4703064|4703064-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200907191653
4703043|4703043-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200907191647
4702627|4702627-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191015
4702290|4702290-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907191009
4701521|4701521-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907190958
4701469|4701469-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190951
4700908|4700908-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907191548
4700904|4700904-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190948
4700614|4700614-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.07|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907191544
4700190|4700190-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190938
4699966|4699966-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190934
4699667|4699667-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190930
4699363|4699363-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200907191525
4698678|4698678-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190916
4698599|4698599-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190856
4698493|4698493-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190913
4698354|4698354-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190910
4698270|4698270-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190909
4697695|4697695-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190900
4697278|4697278-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190852
4697076|4697076-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907191437
4696678|4696678-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907191334
4696602|4696602-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.07|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907191329
4696103|4696103-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200907191221
4695948|4695948-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200907191202
4695911|4695911-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.07|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200907191158
4695795|4695795-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907191141
4695761|4695761-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.07|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907191137
4695391|4695391-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200907191053
4695251|4695251-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200907191033
4694869|4694869-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200907190908
4694865|4694865-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200907190907
4694789|4694789-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200907190841
4694764|4694764-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907190835
4694734|4694734-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200907190829
4694566|4694566-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907190754
4694543|4694543-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200907190749
4694363|4694363-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200907190718
4694300|4694300-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200907190701
4693851|4693851-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907190637
4693690|4693690-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190034
4693587|4693587-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907190631
4693532|4693532-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190030
4692997|4692997-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190017
4692958|4692958-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190016
4691279|4691279-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Test-JSON-Meta|0.01|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200907190527
4691192|4691192-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190324
4691136|4691136-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190323
4691117|4691117-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190322
4691059|4691059-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190320
4690944|4690944-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190317
4690606|4690606-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190308
4690575|4690575-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190307
4690423|4690423-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190302
4690163|4690163-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190255
4689962|4689962-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190249
4689882|4689882-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190247
4689760|4689760-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190244
4689620|4689620-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190240
4689519|4689519-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190237
4689332|4689332-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190232
4688456|4688456-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190207
4688273|4688273-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190202
4688265|4688265-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190202
4688141|4688141-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190158
4687942|4687942-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190152
4686813|4686813-b19f-3f77-b713-d32bba55d77f|pass|200907|barthex@linux.e-cen.pl ("Bartosz Talaga")|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.2.26|200907182305
4685176|4685176-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris|5.8.5|solaris|2.10|200907182043
4684775|4684775-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris|5.8.5|solaris|2.10|200907181939
4684759|4684759-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181853
4684564|4684564-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181810
4684107|4684107-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.07|alpha-netbsd|5.10.0|netbsd|4.0.1|200907181656
4684054|4684054-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|alpha-netbsd|5.10.0|netbsd|4.0.1|200907181650
4683824|4683824-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|IP35-irix-64int|5.8.8|irix|6.5|200907181821
4683778|4683778-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181615
4683762|4683762-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181613
4683755|4683755-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181612
4683753|4683753-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181612
4683651|4683651-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Release|0.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907190203
4683640|4683640-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Uploads|0.07|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907190202
4683604|4683604-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i86pc-solaris|5.8.5|solaris|2.10|200907181642
4683576|4683576-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris|5.8.5|solaris|2.10|200907181639
4683567|4683567-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.02|i86pc-solaris|5.8.5|solaris|2.10|200907181638
4683565|4683565-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris|5.8.5|solaris|2.10|200907181638
4683375|4683375-b19f-3f77-b713-d32bba55d77f|pass|200907|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200907181724
4683178|4683178-b19f-3f77-b713-d32bba55d77f|pass|200907|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Uploads|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200907182300
4683137|4683137-b19f-3f77-b713-d32bba55d77f|pass|200907|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Release|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200907182256
4682844|4682844-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.07|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200907180918
4682791|4682791-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200907180911
4682630|4682630-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.07|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200907181439
4682621|4682621-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.07|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200907181438
4682617|4682617-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.07|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200907181437
4682612|4682612-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200907181437
4682608|4682608-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200907181436
4682607|4682607-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200907181436
4682605|4682605-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200907181436
4682596|4682596-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.07|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200907181434
4682590|4682590-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200907181432
4681890|4681890-b19f-3f77-b713-d32bba55d77f|fail|200907|castaway@desert-island.demon.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.20.1insel|200907172316
4679711|4679711-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907180121
4679350|4679350-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180115
4679184|4679184-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180112
4678934|4678934-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180108
4678275|4678275-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180057
4678274|4678274-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907180057
4678204|4678204-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180055
4677274|4677274-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180039
4677074|4677074-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180036
4676667|4676667-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180029
4675557|4675557-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180010
4675477|4675477-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180009
4675269|4675269-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180005
4674911|4674911-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180359
4674783|4674783-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180357
4674753|4674753-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180356
4674717|4674717-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180356
4674666|4674666-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180355
4674440|4674440-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180351
4674032|4674032-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Test-CPAN-Meta|0.13|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907180305
4669811|4669811-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171915
4669797|4669797-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171913
4669691|4669691-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171858
4669685|4669685-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171857
4669671|4669671-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171856
4668932|4668932-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Test-JSON-Meta|0.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200907171639
4667381|4667381-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170959
4667374|4667374-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907171004
4667357|4667357-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker9@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907171004
4667309|4667309-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|CPAN-Testers-WWW-Reports-Mailer|0.17|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907170703
4667239|4667239-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907171001
4667218|4667218-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|CPAN-Testers-WWW-Statistics|0.65|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907170700
4667182|4667182-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171559
4666899|4666899-b19f-3f77-b713-d32bba55d77f|pass|200907|mw487.yahoo.com@gmail.com|Test-JSON-Meta|0.01|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200907170853
4666873|4666873-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170953
4666863|4666863-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker9@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170952
4666842|4666842-b19f-3f77-b713-d32bba55d77f|pass|200907|mw487.yahoo.com@gmail.com|CPAN-Testers-Data-Release|0.02|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200907170852
4666049|4666049-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170934
4665946|4665946-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170931
4665882|4665882-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170930
4665459|4665459-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|CPAN-Testers-Data-Generator|0.37|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907170619
4665318|4665318-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170916
4665187|4665187-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170913
4664905|4664905-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170906
4664867|4664867-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|CPAN-Testers-Data-Release|0.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907170606
4664559|4664559-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170859
4664289|4664289-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170855
4664230|4664230-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170854
4664046|4664046-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170850
4663991|4663991-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170849
4663445|4663445-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170840
4663114|4663114-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170834
4663094|4663094-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170833
4663084|4663084-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170833
4662815|4662815-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170829
4662756|4662756-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170828
4662346|4662346-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|CPAN-Testers-WWW-Reports-Parser|0.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907170521
4662333|4662333-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170821
4662090|4662090-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170817
4661943|4661943-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Release|0.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170814
4661576|4661576-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Uploads|0.07|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170808
4661408|4661408-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200907171154
4661377|4661377-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200907170650
4661326|4661326-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|IP35-irix-64int|5.8.8|irix|6.5|200907171346
4661308|4661308-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200907171244
4661303|4661303-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200907171244
4661297|4661297-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200907171243
4661292|4661292-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200907171243
4661268|4661268-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|Test-JSON-Meta|0.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200907171241
4661045|4661045-b19f-3f77-b713-d32bba55d77f|pass|200907|mw487.yahoo.com@gmail.com|Test-JSON-Meta|0.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200907170609
4660521|4660521-b19f-3f77-b713-d32bba55d77f|pass|200907|imacat@mail.imacat.idv.tw|Test-JSON-Meta|0.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200907171757
4660214|4660214-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Release|0.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200907171115
4660210|4660210-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Uploads|0.07|i86pc-solaris-64int|5.10.0|solaris|2.11|200907171114
4659809|4659809-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Release|0.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200907171025
4659447|4659447-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|WWW-UsePerl-Journal|0.22|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907170049
4659393|4659393-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907170845
4659059|4659059-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|CPAN-Testers-Data-Release|0.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200907170806
4659057|4659057-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|CPAN-Testers-Data-Release|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200907170806
4659028|4659028-b19f-3f77-b713-d32bba55d77f|pass|200907|rbo@cpan.org|CPAN-Testers-Data-Uploads|0.07|i86pc-solaris|5.10.0|solaris|2.11|200907170857
4659000|4659000-b19f-3f77-b713-d32bba55d77f|pass|200907|rbo@cpan.org|CPAN-Testers-Data-Release|0.02|i86pc-solaris|5.10.0|solaris|2.11|200907170851
4658892|4658892-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.07|amd64-freebsd|5.8.8|freebsd|7.0-release|200907170806
4658886|4658886-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.07|amd64-freebsd|5.8.9|freebsd|7.0-release|200907170806
4658072|4658072-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170324
4658069|4658069-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170324
4657959|4657959-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170317
4657584|4657584-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker7@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170311
4657290|4657290-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170306
4657288|4657288-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170306
4657087|4657087-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100rc1@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170302
4656829|4656829-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170258
4655950|4655950-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170243
4655720|4655720-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170239
4655542|4655542-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker6@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170236
4655436|4655436-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170234
4655174|4655174-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170230
4655170|4655170-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170230
4655087|4655087-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170228
4655059|4655059-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170228
4654990|4654990-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170227
4654503|4654503-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170219
4654394|4654394-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170217
4653528|4653528-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100rc1@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170202
4653415|4653415-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170200
4653248|4653248-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170157
4653224|4653224-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170157
4652897|4652897-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker1@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170151
4652871|4652871-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170150
4652248|4652248-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170140
4652130|4652130-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170138
4652030|4652030-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170136
4649799|4649799-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|CPAN-Testers-Data-Release|0.02|i86pc-solaris|5.10.0|solaris|2.10|200907162118
4649790|4649790-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|CPAN-Testers-Data-Uploads|0.07|i86pc-solaris|5.10.0|solaris|2.10|200907162116
4649787|4649787-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|CPAN-Testers-Common-Article|0.36|i86pc-solaris|5.10.0|solaris|2.10|200907162115
4649786|4649786-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris|5.10.0|solaris|2.10|200907162115
4648750|4648750-b19f-3f77-b713-d32bba55d77f|cpan|200907|BARBIE|CPAN-Testers-Data-Uploads|0.07||0|||200907162011
4648605|4648605-b19f-3f77-b713-d32bba55d77f|cpan|200907|BARBIE|CPAN-Testers-Data-Release|0.02||0|||200907161947
4648160|4648160-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Uploads|0.06|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170259
4648043|4648043-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris|5.8.4|solaris|2.10|200907161738
4647731|4647731-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha-Plugin-PingFM|0.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170216
4647463|4647463-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris|5.8.4|solaris|2.10|200907161634
4647422|4647422-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161641
4647023|4647023-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161544
4645959|4645959-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|i86pc-solaris|5.8.4|solaris|2.10|200907161335
4645949|4645949-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200907161345
4645862|4645862-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Regexp-Log-Common|0.05|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907162236
4645674|4645674-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161311
4645621|4645621-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Test-JSON-Meta|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907162207
4644592|4644592-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-JSON-Meta|0.01|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200907161104
4644539|4644539-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|Test-JSON-Meta|0.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200907161157
4643340|4643340-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|Test-JSON-Meta|0.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200907160955
4643132|4643132-b19f-3f77-b713-d32bba55d77f|pass|200907|rbo@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris|5.10.0|solaris|2.11|200907160934
4642844|4642844-b19f-3f77-b713-d32bba55d77f|pass|200907|rbo@cpan.org|Test-JSON-Meta|0.01|i86pc-solaris|5.10.0|solaris|2.11|200907160855
4642166|4642166-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Test-JSON-Meta|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907161514
4641996|4641996-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160021
4641151|4641151-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160008
4641011|4641011-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160005
4639451|4639451-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160337
4639197|4639197-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160332
4639185|4639185-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160332
4639175|4639175-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160332
4638324|4638324-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160315
4638128|4638128-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907160310
4637656|4637656-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160259
4637598|4637598-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160258
4637176|4637176-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160247
4636300|4636300-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160227
4636135|4636135-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160223
4635947|4635947-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160218
4635798|4635798-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Test-JSON-Meta|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160213
4632851|4632851-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|Test-JSON-Meta|0.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200907152123
4632807|4632807-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|Test-JSON-Meta|0.01|i86pc-solaris|5.10.0|solaris|2.10|200907152054
4632560|4632560-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|Test-JSON-Meta|0.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200907152123
4630963|4630963-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151437
4630959|4630959-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151437
4630583|4630583-b19f-3f77-b713-d32bba55d77f|cpan|200907|BARBIE|Test-JSON-Meta|0.01||0|||200907152028
4630224|4630224-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151420
4630172|4630172-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151419
4628980|4628980-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker3@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151350
4628861|4628861-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907151347
4628846|4628846-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907151347
4628217|4628217-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907151030
4627063|4627063-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151259
4626824|4626824-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151252
4625965|4625965-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151223
4625718|4625718-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151213
4625640|4625640-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151211
4625562|4625562-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151208
4625260|4625260-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151200
4624907|4624907-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|GD-Chart-Radial|0.07|i686-linux|5.10.0|linux|2.6.24-24-generic|200907151650
4624796|4624796-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151147
4624507|4624507-b19f-3f77-b713-d32bba55d77f|pass|200907|brian@minton.name|Test-CPAN-Meta|0.13|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200907151126
4621697|4621697-b19f-3f77-b713-d32bba55d77f|pass|200907|paul@mystery-land.net|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.30.1-dsa-ia32|200907150950
4618242|4618242-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150320
4617961|4617961-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150309
4617690|4617690-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907150258
4617351|4617351-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150246
4617298|4617298-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150244
4615167|4615167-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker8@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150153
4614742|4614742-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150145
4612617|4612617-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907141850
4612005|4612005-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker3@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141824
4610946|4610946-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker7@gmail.com|Mail-File|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141726
4610682|4610682-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141704
4610490|4610490-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris|5.10.0|solaris|2.10|200907142145
4610263|4610263-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907141640
4609584|4609584-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141602
4608233|4608233-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141511
4608020|4608020-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141505
4607915|4607915-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150503
4607512|4607512-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141452
4607409|4607409-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141449
4607056|4607056-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141441
4607011|4607011-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141440
4606996|4606996-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141440
4606715|4606715-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150433
4606706|4606706-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150433
4606490|4606490-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150413
4605401|4605401-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|WWW-UsePerl-Journal|0.22|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150219
4599553|4599553-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140232
4599400|4599400-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907140734
4598320|4598320-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907140122
4597681|4597681-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907140109
4597466|4597466-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907140058
4597323|4597323-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907140103
4595599|4595599-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140321
4592972|4592972-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140107
4591587|4591587-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.13|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140041
4591489|4591489-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907140040
4591180|4591180-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.589@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140034
4591132|4591132-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140032
4590478|4590478-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140020
4589586|4589586-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140005
4589061|4589061-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker9@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907131955
4586905|4586905-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907131913
4585439|4585439-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907131836
4585399|4585399-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907131835
4584237|4584237-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131633
4584113|4584113-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.13|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131623
4581015|4581015-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131242
4580545|4580545-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200907131659
4577843|4577843-b19f-3f77-b713-d32bba55d77f|pass|200907|artur+cpan@niif.spb.su (ARTO)|Test-YAML-Meta|0.12|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200907131508
4576334|4576334-b19f-3f77-b713-d32bba55d77f|pass|200907|rlane10@wi.rr.com|Test-YAML-Meta|0.12|darwin-2level-ld|5.10.0|darwin|8.11.0|200907130247
4575414|4575414-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Mail-Outlook|0.15|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131903
4573772|4573772-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130357
4573626|4573626-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130345
4573555|4573555-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907130340
4573192|4573192-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker1@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130321
4571869|4571869-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130233
4571653|4571653-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130225
4571649|4571649-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130225
4570787|4570787-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131156
4570760|4570760-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Test-CPAN-Meta|0.13|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131155
4569062|4569062-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Regexp-Log-Common|0.05|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130804
4568323|4568323-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.17|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130556
4568310|4568310-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Statistics|0.65|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130554
4568064|4568064-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.37|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130513
4568061|4568061-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-Article|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130513
4564442|4564442-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907120147
4564175|4564175-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907120141
4563902|4563902-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120133
4563758|4563758-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120129
4563756|4563756-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120129
4563551|4563551-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120123
4563540|4563540-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120123
4563445|4563445-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120120
4563442|4563442-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120120
4563119|4563119-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907120110
4562836|4562836-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120102
4562797|4562797-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120101
4562686|4562686-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120058
4562457|4562457-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907120051
4562445|4562445-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907120051
4562219|4562219-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120045
4561923|4561923-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907120036
4561415|4561415-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907120024
4561229|4561229-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.12|i86pc-solaris|5.10.0|solaris|2.10|200907120117
4561084|4561084-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120014
4560862|4560862-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120008
4560756|4560756-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120005
4560746|4560746-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907120005
4560633|4560633-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907120002
4560549|4560549-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907120000
4560432|4560432-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907111957
4559999|4559999-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907111950
4559717|4559717-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907111944
4559659|4559659-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907111943
4559457|4559457-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907111940
4559268|4559268-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907111935
4559202|4559202-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907111933
4559183|4559183-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907111933
4558952|4558952-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907111929
4558903|4558903-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907111928
4558894|4558894-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907111928
4558734|4558734-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907111925
4558675|4558675-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907111924
4558674|4558674-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907111924
4558191|4558191-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907111913
4558185|4558185-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907111913
4557581|4557581-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907112330
4557487|4557487-b19f-3f77-b713-d32bba55d77f|pass|200907|alexchorny@gmail.com|Test-YAML-Meta|0.12|i686-linux|5.8.8|linux|2.4.20-8smp|200907111420
4552834|4552834-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200907110425
4552543|4552543-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111822
4552538|4552538-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Test-CPAN-Meta|0.13|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111821
4550682|4550682-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907110138
4550681|4550681-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907110138
4549731|4549731-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907110118
4548529|4548529-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907110055
4548070|4548070-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907110044
4546828|4546828-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110006
4546533|4546533-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.17|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111249
4546528|4546528-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Statistics|0.65|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111247
4546418|4546418-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.37|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111227
4546415|4546415-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-Article|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111226
4546377|4546377-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111221
4546376|4546376-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111221
4546285|4546285-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111202
4545909|4545909-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|WWW-UsePerl-Journal|0.22|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907110959
4544511|4544511-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200907102025
4543322|4543322-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Mail-File|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101429
4543257|4543257-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101427
4543212|4543212-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101426
4542992|4542992-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker1@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101421
4542817|4542817-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101417
4542614|4542614-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101411
4542505|4542505-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101407
4536496|4536496-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.24-24-generic|200907101310
4529474|4529474-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907100027
4528637|4528637-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907100011
4527364|4527364-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907091947
4527022|4527022-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Mail-File|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907091937
4526811|4526811-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907091933
4526171|4526171-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907091921
4521156|4521156-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker3@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907091105
4520988|4520988-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907091059
4519735|4519735-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907091019
4519561|4519561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907091015
4519232|4519232-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907091007
4518807|4518807-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|Regexp-Log-Common|0.05|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907091658
4518305|4518305-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Mail-File|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907090945
4516058|4516058-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907090846
4515129|4515129-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907090824
4510939|4510939-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907090213
4510289|4510289-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Parse-CPAN-Distributions|0.05|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907090000
4509825|4509825-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Mail-File|0.08|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907082217
4509359|4509359-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|GD-Chart-Radial|0.07|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907082106
4509356|4509356-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Games-Trackword|1.06|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907082105
4508683|4508683-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100rc1@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081534
4508155|4508155-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907082018
4507310|4507310-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker6@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081324
4505671|4505671-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907081241
4503070|4503070-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100rc1@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081132
4502958|4502958-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907081129
4502877|4502877-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081128
4502365|4502365-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081112
4502059|4502059-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907081105
4501996|4501996-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081103
4501948|4501948-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081102
4501600|4501600-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907081056
4501575|4501575-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081055
4501438|4501438-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081554
4501395|4501395-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-XML|0.12|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081553
4501377|4501377-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-Ini|0.10|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081553
4501361|4501361-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook-Loader-DBI|0.11|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081552
4501329|4501329-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081551
4501246|4501246-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081548
4501097|4501097-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-WWW-Testers-Generator|0.30|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081526
4501081|4501081-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081523
4501068|4501068-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081521
4501045|4501045-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081518
4501042|4501042-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081518
4500723|4500723-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Calendar-List|0.21|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907081430
4496380|4496380-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-CPAN-Meta|0.13|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907080459
4495796|4495796-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907072351
4494665|4494665-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071321
4494659|4494659-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071320
4494612|4494612-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker6@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071319
4494556|4494556-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071318
4493643|4493643-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker7@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071247
4493618|4493618-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907071246
4492509|4492509-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071219
4492471|4492471-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907071219
4491482|4491482-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907071156
4490876|4490876-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071138
4490384|4490384-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071122
4490164|4490164-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907071114
4489982|4489982-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071108
4489939|4489939-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907071107
4489838|4489838-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907071102
4489833|4489833-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907071102
4489740|4489740-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Calendar-List|0.21|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071058
4489418|4489418-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071541
4489412|4489412-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071541
4488086|4488086-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907071252
4481321|4481321-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061907
4481275|4481275-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061906
4481267|4481267-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061905
4481026|4481026-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061858
4480270|4480270-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-Data-Release|0.01|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907070133
4480192|4480192-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061829
4479988|4479988-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061822
4479512|4479512-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-WWW-Testers|0.41|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907070110
4479482|4479482-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-WWW-Testers|0.40|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907070109
4479458|4479458-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-WWW-Testers|0.39|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907070109
4479344|4479344-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907070106
4479215|4479215-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-Data-Release|0.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907070103
4479198|4479198-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-Data-Generator|0.37|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907070102
4479182|4479182-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061802
4479161|4479161-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061801
4478920|4478920-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker7@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061756
4476450|4476450-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907061626
4476356|4476356-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907062033
4475734|4475734-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061310
4475032|4475032-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.589@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061252
4474842|4474842-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker3@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061247
4474533|4474533-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061239
4474504|4474504-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061238
4474472|4474472-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061238
4473985|4473985-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061226
4473963|4473963-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061225
4473832|4473832-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061221
4473655|4473655-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061217
4472851|4472851-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061157
4471558|4471558-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061129
4471179|4471179-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061121
4470325|4470325-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061101
4469889|4469889-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061049
4469600|4469600-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Calendar-List|0.21|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061042
4463152|4463152-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.589@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060122
4462467|4462467-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060110
4462429|4462429-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker9@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907060109
4462145|4462145-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060103
4462068|4462068-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907060101
4461298|4461298-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker7@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907060047
4461270|4461270-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060046
4461259|4461259-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907060046
4460925|4460925-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060037
4460729|4460729-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060033
4459461|4459461-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060007
4459272|4459272-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907060003
4457184|4457184-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907052008
4455642|4455642-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050944
4455402|4455402-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050947
4455327|4455327-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050946
4454885|4454885-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050938
4454201|4454201-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050927
4454077|4454077-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050925
4454032|4454032-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050924
4453727|4453727-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050918
4453505|4453505-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050914
4453458|4453458-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050913
4452927|4452927-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050905
4452552|4452552-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050859
4452525|4452525-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050858
4452471|4452471-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050857
4452369|4452369-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050855
4452133|4452133-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050851
4452089|4452089-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050850
4451892|4451892-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050847
4451818|4451818-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050846
4451671|4451671-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050844
4451659|4451659-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050843
4451504|4451504-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050841
4451209|4451209-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050837
4451045|4451045-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050834
4450945|4450945-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050832
4450804|4450804-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050830
4450788|4450788-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050829
4450761|4450761-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050829
4450535|4450535-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050824
4445851|4445851-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041800
4445053|4445053-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041739
4444771|4444771-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041746
4444734|4444734-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041746
4444040|4444040-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041733
4443918|4443918-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041730
4443341|4443341-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041718
4442641|4442641-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041706
4442500|4442500-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041703
4442232|4442232-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041658
4441745|4441745-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041649
4440034|4440034-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041616
4439845|4439845-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041611
4439592|4439592-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041606
4437862|4437862-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041158
4437626|4437626-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041152
4437558|4437558-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041151
4437548|4437548-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041151
4437214|4437214-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Mail-File|0.08|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041145
4437200|4437200-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907041644
4436762|4436762-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041137
4436693|4436693-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041136
4436689|4436689-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041136
4436425|4436425-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041131
4436151|4436151-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041126
4435557|4435557-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041115
4435462|4435462-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041114
4435241|4435241-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041110
4435042|4435042-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041104
4434404|4434404-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041047
4433966|4433966-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041036
4433900|4433900-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041034
4433855|4433855-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041033
4433775|4433775-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041032
4433731|4433731-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041031
4433549|4433549-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041007
4433366|4433366-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041008
4433202|4433202-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907040957
4433127|4433127-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041012
4433101|4433101-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker9@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041011
4432604|4432604-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907040958
4432600|4432600-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907040958
4432479|4432479-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907040953
4432468|4432468-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907040953
4431877|4431877-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907040930
4431680|4431680-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907040925
4426667|4426667-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031429
4426025|4426025-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031458
4425979|4425979-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031457
4425721|4425721-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031451
4425694|4425694-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031450
4423672|4423672-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907031410
4423225|4423225-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031400
4421911|4421911-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031333
4421657|4421657-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031327
4421561|4421561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031325
4421445|4421445-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907031322
4421346|4421346-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031319
4416909|4416909-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907030600
4413860|4413860-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021949
4413672|4413672-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021946
4413464|4413464-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021942
4413106|4413106-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021933
4412295|4412295-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021912
4412069|4412069-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021904
4412003|4412003-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.589@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021903
4410942|4410942-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021835
4410785|4410785-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021831
4410361|4410361-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021821
4410175|4410175-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021815
4409381|4409381-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021755
4409338|4409338-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021753
4409281|4409281-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021752
4408944|4408944-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker5@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021744
4407533|4407533-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907021951
4405338|4405338-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.24-24-generic|200907021132
4405050|4405050-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.6.24-24-generic|200907021048
4405049|4405049-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.24-24-generic|200907021048
4404883|4404883-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.10.0|linux|2.6.24-24-generic|200907021036
4403276|4403276-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020049
4402952|4402952-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020043
4402931|4402931-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020043
4401841|4401841-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020022
4401462|4401462-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker3@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907020011
4401296|4401296-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020006
4401048|4401048-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907020358
4400995|4400995-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020357
4400931|4400931-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker3@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020355
4400638|4400638-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Mail-File|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020345
4400364|4400364-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907020337
4397499|4397499-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011737
4397031|4397031-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907011716
4396578|4396578-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011653
4396101|4396101-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker1@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011628
4395363|4395363-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907011547
4395054|4395054-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907011533
4394617|4394617-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907011512
4393471|4393471-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200907011622
4393098|4393098-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.589@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011145
4392793|4392793-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011129
4392664|4392664-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907011122
4392342|4392342-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907011102
4392312|4392312-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907011101
4390853|4390853-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907010959
4390667|4390667-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010950
4388838|4388838-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010845
4384554|4384554-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-19-server|200907010943
4382674|4382674-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200907010318
4382175|4382175-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907010044
4381786|4381786-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907010028
4381429|4381429-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907010019
4380911|4380911-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907010008
4380839|4380839-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907010007
4380833|4380833-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010007
4380582|4380582-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907010004
4380535|4380535-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907010004
4380061|4380061-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906301958
4380052|4380052-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906301958
4379935|4379935-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker4@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906301956
4379607|4379607-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker4@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906301952
4378558|4378558-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906301937
4378151|4378151-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Mail-File|0.08|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301931
4377851|4377851-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906301927
4377626|4377626-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux|5.8.9|linux|2.6.24-16-generic|200906301923
4377558|4377558-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.65|i686-linux|5.8.9|linux|2.6.24-16-generic|200906301922
4376856|4376856-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.37|i686-linux|5.8.9|linux|2.6.24-16-generic|200906301848
4376699|4376699-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Release|0.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200906301844
4375353|4375353-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200906301818
4374781|4374781-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906302301
4374530|4374530-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200906301608
4374446|4374446-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906302141
4368619|4368619-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906300443
4368262|4368262-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906300427
4367273|4367273-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300246
4367073|4367073-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300237
4366342|4366342-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300212
4365587|4365587-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Calendar-List|0.21|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300158
4364372|4364372-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Mail-File|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300140
4364119|4364119-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300136
4363834|4363834-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300131
4363611|4363611-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300128
4363416|4363416-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300125
4362782|4362782-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300113
4362469|4362469-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|App-Maisha|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300108
4362421|4362421-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300108
4358790|4358790-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291525
4358561|4358561-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291519
4358064|4358064-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906291508
4356620|4356620-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291428
4356427|4356427-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291423
4356403|4356403-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906291423
4356251|4356251-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker5@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906291420
4355554|4355554-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906291904
4355148|4355148-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Mail-File|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291354
4353771|4353771-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906291320
4352141|4352141-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.13|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906291001
4348577|4348577-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906291006
4348569|4348569-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906291003
4348552|4348552-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906291000
4348373|4348373-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290940
4348368|4348368-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290939
4348362|4348362-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290938
4347362|4347362-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906290058
4347359|4347359-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906290056
4347100|4347100-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906290008
4347078|4347078-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290602
4347077|4347077-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906290002
4346982|4346982-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-NNTP|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290537
4346937|4346937-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906290336
4346591|4346591-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906290329
4345121|4345121-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906290029
4341042|4341042-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906281008
4340546|4340546-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906280921
4340246|4340246-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280927
4339709|4339709-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906280946
4339618|4339618-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280948
4339429|4339429-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280957
4339364|4339364-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280956
4339225|4339225-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker9@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280953
4338978|4338978-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280949
4338541|4338541-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906280940
4338447|4338447-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906280938
4337610|4337610-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.5100@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280921
4337529|4337529-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280919
4336723|4336723-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker8@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280904
4335572|4335572-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906280842
4335333|4335333-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906280824
4335315|4335315-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280837
4335299|4335299-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280837
4334617|4334617-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906280824
4334211|4334211-b19f-3f77-b713-d32bba55d77f|pass|200906|joerg.meltzer@tngtech.com|Test-CPAN-Meta|0.13|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200906271510
4331867|4331867-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906280922
4330025|4330025-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906280401
4328677|4328677-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.13|i686-linux|5.10.0|linux|2.6.24-16-generic|200906280022
4326863|4326863-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906272030
4322583|4322583-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200906271053
4322515|4322515-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200906271043
4322389|4322389-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200906271022
4315389|4315389-b19f-3f77-b713-d32bba55d77f|pass|200906|lists.perl.cpan-testers@csjewell.fastmail.us (Curtis Jewell)|Test-CPAN-Meta|0.13|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200906260055
4315228|4315228-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906261527
4309814|4309814-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260130
4307066|4307066-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251757
4306816|4306816-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251751
4306793|4306793-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251750
4306388|4306388-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251739
4303835|4303835-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251221
4303196|4303196-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251129
4302780|4302780-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906251205
4302741|4302741-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251202
4301969|4301969-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906251227
4301868|4301868-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251223
4301346|4301346-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251217
4301208|4301208-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251227
4300801|4300801-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251218
4300629|4300629-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251214
4300550|4300550-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251213
4300512|4300512-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251153
4300135|4300135-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251204
4299694|4299694-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251058
4299440|4299440-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251130
4299336|4299336-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251146
4299016|4299016-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251139
4298992|4298992-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251139
4298875|4298875-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251117
4298812|4298812-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251133
4298775|4298775-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251133
4298754|4298754-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251133
4298749|4298749-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251132
4298568|4298568-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251117
4298173|4298173-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251121
4298127|4298127-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251120
4297560|4297560-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251106
4297425|4297425-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251103
4296349|4296349-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.24-24-generic|200906251416
4296345|4296345-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-24-generic|200906251416
4295189|4295189-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-Data-Generator|0.35|i686-linux|5.10.0|linux|2.6.24-24-generic|200906251120
4293003|4293003-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906250525
4291803|4291803-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.smoker5@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250035
4290990|4290990-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.589@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250016
4290984|4290984-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker5@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250016
4290668|4290668-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Calendar-List|0.21|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906250410
4290275|4290275-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250001
4289970|4289970-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.smoker4@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250355
4288718|4288718-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906250327
4288696|4288696-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250326
4288694|4288694-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906250326
4288539|4288539-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250323
4288341|4288341-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906250318
4288304|4288304-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250317
4288299|4288299-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250317
4287961|4287961-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906250310
4287749|4287749-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker6@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250305
4287507|4287507-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250300
4287225|4287225-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.smoker1@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250254
4286871|4286871-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.smoker3@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250246
4286867|4286867-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.smoker3@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250245
4283773|4283773-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906241648
4283771|4283771-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906241648
4283177|4283177-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240840
4282885|4282885-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906240837
4282871|4282871-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.5100rc1@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240836
4282818|4282818-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906240831
4282113|4282113-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240845
4282057|4282057-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906240843
4281273|4281273-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240829
4280025|4280025-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240810
4280009|4280009-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker7@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240809
4279892|4279892-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker8@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240807
4279617|4279617-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240759
4279424|4279424-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906240754
4279014|4279014-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240744
4278573|4278573-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906241235
4278406|4278406-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906241206
4278050|4278050-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-Data-Uploads|0.06|i686-linux|5.10.0|linux|2.6.24-24-generic|200906240915
4277793|4277793-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906231037
4277702|4277702-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906240815
4277657|4277657-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906240758
4277603|4277603-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906240735
4277480|4277480-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240511
4277363|4277363-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906240641
4277349|4277349-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240437
4277178|4277178-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906240618
4276519|4276519-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240352
4276486|4276486-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906231050
4276452|4276452-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240350
4276315|4276315-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240345
4276209|4276209-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker7@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240341
4275905|4275905-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240332
4275831|4275831-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240330
4275514|4275514-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240321
4274953|4274953-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker8@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240308
4274868|4274868-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240306
4274644|4274644-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker5@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240300
4274526|4274526-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906240456
4274133|4274133-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240246
4273998|4273998-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker6@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240243
4273827|4273827-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker2@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240239
4273694|4273694-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231037
4272846|4272846-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231340
4272110|4272110-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231359
4271921|4271921-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|App-Maisha|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231349
4271822|4271822-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231339
4271712|4271712-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231041
4271393|4271393-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906231038
4270521|4270521-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906240031
4269944|4269944-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906232317
4268764|4268764-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231355
4267685|4267685-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221724
4267519|4267519-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|App-Maisha-Plugin-PingFM|0.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200906231640
4266514|4266514-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200906231539
4265809|4265809-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|App-Maisha|0.12|i686-linux|5.10.0|linux|2.6.24-24-generic|200906231417
4265622|4265622-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221827
4265055|4265055-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221716
4264109|4264109-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221732
4263918|4263918-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221820
4263729|4263729-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221812
4263514|4263514-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221655
4262983|4262983-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221701
4262712|4262712-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906230015
4262393|4262393-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221811
4261051|4261051-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221655
4260919|4260919-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221702
4259671|4259671-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906230406
4258952|4258952-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221356
4258366|4258366-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221509
4257470|4257470-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221531
4257310|4257310-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221505
4257280|4257280-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221357
4257099|4257099-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221531
4256796|4256796-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221524
4256554|4256554-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221517
4255743|4255743-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221524
4255158|4255158-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221520
4254791|4254791-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221517
4254553|4254553-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221507
4254393|4254393-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221502
4253740|4253740-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221347
4253602|4253602-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221355
4253342|4253342-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221345
4251426|4251426-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@tenzobox.net ("Axel Bourgeois")|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906220142
4250919|4250919-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Mail-Outlook|0.15|i686-linux|5.10.0|linux|2.6.24-24-generic|200906221208
4247755|4247755-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906211927
4247514|4247514-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906211908
4247383|4247383-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906211917
4244498|4244498-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux|5.10.0|linux|2.6.18-92.el5|200906212028
4244376|4244376-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux|5.10.0|linux|2.6.18-92.el5|200906212003
4242465|4242465-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906211325
4239925|4239925-b19f-3f77-b713-d32bba55d77f|pass|200906|emer@emer.net|Test-YAML-Meta|0.12|darwin-2level|5.10.0|darwin|9.6.0|200906201237
4239465|4239465-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906210736
4232094|4232094-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210138
4232023|4232023-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.65|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210137
4231033|4231033-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.37|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210058
4230902|4230902-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Release|0.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210050
4230661|4230661-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210018
4230337|4230337-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210913
4230335|4230335-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Test-CPAN-Meta|0.13|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210912
4230017|4230017-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200906201822
4228951|4228951-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906202020
4226827|4226827-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.17|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210126
4226813|4226813-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Statistics|0.65|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210123
4226615|4226615-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.37|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210057
4226497|4226497-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210045
4226226|4226226-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210013
4224124|4224124-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906201303
4224034|4224034-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Data-Release|0.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906201245
4224023|4224023-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Data-Generator|0.37|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906201244
4221766|4221766-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906201124
4220468|4220468-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906192232
4214510|4214510-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906190708
4214505|4214505-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906190707
4212577|4212577-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906190117
4212572|4212572-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906190116
4212508|4212508-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906190103
4212497|4212497-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906190100
4212494|4212494-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906190059
4212475|4212475-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906190055
4212474|4212474-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906190054
4212426|4212426-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906190041
4212424|4212424-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906190040
4212421|4212421-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906190040
4211968|4211968-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906182245
4211961|4211961-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd|5.8.9|netbsd|5.0|200906182138
4211911|4211911-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906182234
4211863|4211863-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-NNTP|0.05|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906182218
4211372|4211372-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906182043
4210034|4210034-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|WWW-UsePerl-Journal|0.22|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200906181513
4207546|4207546-b19f-3f77-b713-d32bba55d77f|pass|200906|mmlange@cpan.org (Matthew Lange)|Test-YAML-Meta|0.12|x86_64-linux|5.8.8|linux|2.6.25-gentoo-r7a1|200906171153
4205974|4205974-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200906180651
4205871|4205871-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200906180635
4205435|4205435-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906180426
4201729|4201729-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|WWW-UsePerl-Journal|0.22|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906171820
4198671|4198671-b19f-3f77-b713-d32bba55d77f|pass|200906|brian@minton.name|Parse-CPAN-Distributions|0.05|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161610
4198654|4198654-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-64int|5.10.0|netbsd|5.0|200906171317
4198391|4198391-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906171300
4197688|4197688-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|WWW-UsePerl-Journal|0.22|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906170333
4197388|4197388-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906171144
4194253|4194253-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-64int-2level|5.8.9|darwin|8.11.0|200906162339
4192949|4192949-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|darwin-64int-2level|5.8.9|darwin|8.11.0|200906162039
4191229|4191229-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161608
4188189|4188189-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160829
4188179|4188179-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160827
4188167|4188167-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160823
4188084|4188084-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160807
4188077|4188077-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160806
4188067|4188067-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160805
4187636|4187636-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd|5.8.9|netbsd|5.0|200906160559
4187082|4187082-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160556
4186817|4186817-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906160407
4185957|4185957-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906160202
4184573|4184573-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd|5.8.9|netbsd|5.0|200906152345
4183884|4183884-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Test-YAML-Meta|0.12|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906151441
4183718|4183718-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd|5.8.9|netbsd|5.0|200906152210
4183714|4183714-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd|5.8.9|netbsd|5.0|200906152209
4183697|4183697-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd|5.8.9|netbsd|5.0|200906152207
4183672|4183672-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd|5.8.9|netbsd|5.0|200906152203
4183281|4183281-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906151256
4183280|4183280-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Data-Release|0.01|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906151255
4183277|4183277-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906151255
4183276|4183276-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-Article|0.36|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906151255
4179027|4179027-b19f-3f77-b713-d32bba55d77f|pass|200906|mw487.yahoo.com@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200906150600
4178074|4178074-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906151159
4175718|4175718-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|WWW-UsePerl-Journal|0.22|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906150315
4173895|4173895-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd|5.10.0|netbsd|5.0|200906142132
4172381|4172381-b19f-3f77-b713-d32bba55d77f|pass|200906|l.mai@web.de|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.22-gentoo-r9|200906131705
4172057|4172057-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd|5.10.0|netbsd|5.0|200906140057
4171666|4171666-b19f-3f77-b713-d32bba55d77f|pass|200906|bernt.guldbrandtsen@agrsci.dk|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200906132217
4171325|4171325-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-64int-2level|5.8.8|darwin|8.11.0|200906132358
4170942|4170942-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i386-netbsd|5.10.0|netbsd|5.0|200906132301
4170939|4170939-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.64|i386-netbsd|5.10.0|netbsd|5.0|200906132300
4170892|4170892-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd|5.10.0|netbsd|5.0|200906132254
4170889|4170889-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-netbsd|5.10.0|netbsd|5.0|200906132254
4170867|4170867-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd|5.10.0|netbsd|5.0|200906132249
4170857|4170857-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd|5.10.0|netbsd|5.0|200906132247
4170837|4170837-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd|5.10.0|netbsd|5.0|200906132242
4170179|4170179-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|darwin-64int-2level|5.8.8|darwin|8.11.0|200906132035
4170169|4170169-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|darwin-64int-2level|5.8.8|darwin|8.11.0|200906132034
4170149|4170149-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-64int-2level|5.8.8|darwin|8.11.0|200906132030
4170101|4170101-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-64int-2level|5.8.8|darwin|8.11.0|200906132022
4169912|4169912-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131148
4169362|4169362-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131009
4169356|4169356-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131009
4169353|4169353-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131008
4169352|4169352-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-Article|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131008
4169027|4169027-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906131711
4168404|4168404-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|WWW-UsePerl-Journal|0.22|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906121554
4168217|4168217-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906131417
4168215|4168215-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906131416
4168175|4168175-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906131411
4168167|4168167-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906131410
4168166|4168166-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906131409
4167296|4167296-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906131207
4166146|4166146-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906130611
4165797|4165797-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906130548
4165607|4165607-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|WWW-UsePerl-Journal|0.22|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130303
4165574|4165574-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906130356
4165084|4165084-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906130335
4165036|4165036-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130125
4165033|4165033-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130125
4165032|4165032-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Data-Generator|0.37|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130124
4165031|4165031-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-Article|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130124
4165030|4165030-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130124
4164564|4164564-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906130043
4164561|4164561-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906130042
4164557|4164557-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906130041
4164519|4164519-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Reports-Mailer|0.17|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120439
4164510|4164510-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110249
4164474|4164474-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Statistics|0.65|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120440
4164280|4164280-b19f-3f77-b713-d32bba55d77f|pass|200906|davidp@preshweb.co.uk ("David Precious")|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.25-arch|200906122128
4164181|4164181-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120438
4164134|4164134-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-Article|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120437
4163817|4163817-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Statistics|0.64|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906121343
4163715|4163715-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120500
4163667|4163667-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120439
4163665|4163665-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Data-Generator|0.37|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120438
4163664|4163664-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120437
4161283|4161283-b19f-3f77-b713-d32bba55d77f|pass|200906|MKUTTER@cpan.org ("Martin Kutter")|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906121618
4161273|4161273-b19f-3f77-b713-d32bba55d77f|pass|200906|MKUTTER@cpan.org ("Martin Kutter")|Test-CPAN-Meta|0.13|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906121617
4161223|4161223-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121505
4160603|4160603-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121310
4160599|4160599-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.64|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121309
4160574|4160574-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121304
4160572|4160572-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121303
4160546|4160546-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121259
4160543|4160543-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121258
4160542|4160542-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121258
4156532|4156532-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906120052
4155758|4155758-b19f-3f77-b713-d32bba55d77f|pass|200906|vpit@cpan.org|Test-YAML-Meta|0.12|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200906112305
4155523|4155523-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906112056
4155521|4155521-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906112056
4155492|4155492-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906112051
4155487|4155487-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906112050
4155486|4155486-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906112050
4154538|4154538-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906111650
4153018|4153018-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200906111036
4153017|4153017-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-64int-2level|5.8.7|darwin|8.11.0|200906111036
4153015|4153015-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200906111035
4153012|4153012-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200906111034
4152971|4152971-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110657
4152332|4152332-b19f-3f77-b713-d32bba55d77f|fail|200906|martin.evans@easysoft.com|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.24-24-generic|200906110925
4149298|4149298-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110056
4149292|4149292-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.64|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110054
4149275|4149275-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110050
4149271|4149271-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110049
4149259|4149259-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110045
4149251|4149251-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110044
4149249|4149249-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110044
4148594|4148594-b19f-3f77-b713-d32bba55d77f|pass|200906|vpit@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-20-eeepc|200906102307
4148342|4148342-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906102205
4147875|4147875-b19f-3f77-b713-d32bba55d77f|pass|200906|vpit@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200906102033
4147874|4147874-b19f-3f77-b713-d32bba55d77f|pass|200906|vpit@cpan.org|CPAN-Testers-Data-Release|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200906102032
4147462|4147462-b19f-3f77-b713-d32bba55d77f|pass|200906|mw487.yahoo.com@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200906101208
4145813|4145813-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906101522
4145808|4145808-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906101522
4145641|4145641-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Test-YAML-Meta|0.12|i686-linux|5.8.8|linux|2.4.27-2-386|200906101550
4145638|4145638-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Test-CPAN-Meta|0.13|i686-linux|5.8.8|linux|2.4.27-2-386|200906101549
4145248|4145248-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200906101411
4145180|4145180-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906101406
4145173|4145173-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906101406
4145135|4145135-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906101403
4144807|4144807-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200906101342
4144704|4144704-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906101332
4144584|4144584-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906101304
4144571|4144571-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906101302
4144507|4144507-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906101251
4144504|4144504-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906101251
4144371|4144371-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906101240
4144243|4144243-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200906101230
4144048|4144048-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906101217
4144044|4144044-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906101217
4144042|4144042-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200906101117
4144034|4144034-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906101216
4144025|4144025-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200906101116
4144015|4144015-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200906101116
4144008|4144008-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200906101116
4143957|4143957-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906101212
4143490|4143490-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200906101126
4143472|4143472-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906101123
4143294|4143294-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906101108
4142986|4142986-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200906101047
4142981|4142981-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906101047
4142622|4142622-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200906101018
4142409|4142409-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200906100959
4141877|4141877-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906100920
4141659|4141659-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200906100854
4141599|4141599-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906100846
4141551|4141551-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906100837
4141496|4141496-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906100828
4141387|4141387-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906100815
4141316|4141316-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200906100804
4141280|4141280-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.37|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906100757
4141209|4141209-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906100747
4141177|4141177-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200906100741
4141168|4141168-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906100739
4141071|4141071-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906100720
4141038|4141038-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200906100710
4141037|4141037-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906100710
4140816|4140816-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Release|0.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200906100621
4140372|4140372-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906100444
4140354|4140354-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906100338
4140352|4140352-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906100338
4140341|4140341-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906100436
4140323|4140323-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906100332
4140316|4140316-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906100329
4140314|4140314-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906100328
4140281|4140281-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200906100422
4140274|4140274-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200906100421
4140263|4140263-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906100420
4140208|4140208-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906100410
4140153|4140153-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906100401
4140144|4140144-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906100359
4140100|4140100-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906100350
4140082|4140082-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200906100348
4140064|4140064-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906100345
4139994|4139994-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200906100336
4139846|4139846-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906100321
4139637|4139637-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906100308
4139466|4139466-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906100258
4139453|4139453-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906100256
4139451|4139451-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200906100256
4139403|4139403-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906100253
4139388|4139388-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200906100252
4139296|4139296-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200906100245
4139279|4139279-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200906100242
4139066|4139066-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux|5.10.0|linux|2.6.26-2-686|200906100019
4138990|4138990-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200906100229
4138860|4138860-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200906100219
4138440|4138440-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906100120
4138437|4138437-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906100120
4138392|4138392-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906100115
4138300|4138300-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200906100103
4137926|4137926-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200906100016
4137901|4137901-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906100013
4137793|4137793-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906100001
4137779|4137779-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906100000
4137773|4137773-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906100000
4137737|4137737-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Parser|0.01|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906092353
4137714|4137714-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906092344
4136377|4136377-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|darwin-64int-2level|5.8.7|darwin|8.11.0|200906091703
4136374|4136374-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-64int-2level|5.8.7|darwin|8.11.0|200906091703
4136372|4136372-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-64int-2level|5.8.7|darwin|8.11.0|200906091702
4136364|4136364-b19f-3f77-b713-d32bba55d77f|fail|200906|ivan.wills@gmail.com ("Ivan Wills")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906100159
4136360|4136360-b19f-3f77-b713-d32bba55d77f|fail|200906|ivan.wills@gmail.com ("Ivan Wills")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906100158
4135489|4135489-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200906091351
4135467|4135467-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200906090849
4135338|4135338-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|IP35-irix-64int|5.8.8|irix|6.5|200906091532
4135304|4135304-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200906091426
4135248|4135248-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200906091416
4135244|4135244-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200906091416
4135231|4135231-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200906091414
4135223|4135223-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Parser|0.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200906091413
4135098|4135098-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-Data-Generator|0.37|i686-linux|5.10.0|linux|2.6.24-24-generic|200906091326
4135097|4135097-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-Common-Article|0.36|i686-linux|5.10.0|linux|2.6.24-24-generic|200906091326
4135062|4135062-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906091315
4135060|4135060-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.64|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906091315
4135056|4135056-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906091313
4135053|4135053-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906091312
4135048|4135048-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-Data-Release|0.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200906091311
4135047|4135047-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.24-24-generic|200906091311
4135045|4135045-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906091311
4135044|4135044-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906091311
4134992|4134992-b19f-3f77-b713-d32bba55d77f|pass|200906|vpit@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200906091356
4134591|4134591-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200906091101
4134520|4134520-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-64int-2level|5.8.6|darwin|8.11.0|200906091042
4134516|4134516-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Parser|0.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200906091140
4134319|4134319-b19f-3f77-b713-d32bba55d77f|pass|200906|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Parser|0.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200906091632
4134215|4134215-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Parser|0.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200906090956
4133789|4133789-b19f-3f77-b713-d32bba55d77f|pass|200906|rbo@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|i86pc-solaris|5.10.0|solaris|2.11|200906090834
4133662|4133662-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Generator|0.37|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906090810
4133603|4133603-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.26-2-686|200906090829
4133601|4133601-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.26-2-686|200906090829
4133600|4133600-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.26-2-686|200906090829
4133596|4133596-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.26-2-686|200906090828
4133371|4133371-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.10.0|linux|2.6.26-2-686|200906090722
4133370|4133370-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.10.0|linux|2.6.26-2-686|200906090722
4133369|4133369-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.10.0|linux|2.6.26-2-686|200906090722
4132886|4132886-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.17|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906091316
4132878|4132878-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Statistics|0.65|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906091314
4132851|4132851-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906090301
4132627|4132627-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906090416
4132620|4132620-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.37|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906091215
4132522|4132522-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Release|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906091154
4132447|4132447-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906090229
4132422|4132422-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Data-Release|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906090222
4132414|4132414-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906090221
4132411|4132411-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906090221
4132345|4132345-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906090313
4132310|4132310-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Parser|0.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906091110
4132068|4132068-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Parser|0.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906091030
4131833|4131833-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Release|0.01|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906090134
4131469|4131469-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.17|i86pc-solaris-64int|5.8.9|solaris|2.11|200906090006
4131442|4131442-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200906082325
4131415|4131415-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.65|i86pc-solaris-64int|5.8.9|solaris|2.11|200906090001
4131251|4131251-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Reports-Parser|0.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200906082325
4131230|4131230-b19f-3f77-b713-d32bba55d77f|pass|200906|mw487.yahoo.com@gmail.com|CPAN-Testers-Data-Release|0.01|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200906081629
4131150|4131150-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.37|i86pc-solaris-64int|5.8.9|solaris|2.11|200906082320
4131083|4131083-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Release|0.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200906082308
4129686|4129686-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906081841
4129101|4129101-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|GD-Chart-Radial|0.07|i686-linux|5.10.0|linux|2.6.26-2-686|200906082256
4128792|4128792-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Data-Release|0.01|i686-linux|5.8.9|linux|2.6.26-2-686|200906082235
4128752|4128752-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Data-Generator|0.37|i686-linux|5.8.9|linux|2.6.26-2-686|200906082232
4128667|4128667-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i686-linux|5.8.9|linux|2.6.26-2-686|200906082227
4128656|4128656-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux|5.8.9|linux|2.6.26-2-686|200906082227
4128321|4128321-b19f-3f77-b713-d32bba55d77f|pass|200906|schwern@pobox.com|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200906080158
4127676|4127676-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.17|i86pc-solaris-64int|5.10.0|solaris|2.11|200906081738
4127665|4127665-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.65|i86pc-solaris-64int|5.10.0|solaris|2.11|200906081737
4127186|4127186-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.37|i86pc-solaris-64int|5.10.0|solaris|2.11|200906081647
4127138|4127138-b19f-3f77-b713-d32bba55d77f|pass|200906|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Release|0.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200906081628
4127078|4127078-b19f-3f77-b713-d32bba55d77f|cpan|200906|BARBIE|CPAN-Testers-WWW-Reports-Parser|0.01||0|||200906081617
4126695|4126695-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.26-2-686|200906081947
4126461|4126461-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.26-2-686|200906081936
4125616|4125616-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Data-Release|0.01|i686-linux|5.10.0|linux|2.6.26-2-686|200906081851
4125319|4125319-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200906081237
4125316|4125316-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200906080737
4125306|4125306-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.37|alpha-netbsd|5.10.0|netbsd|4.0.1|200906081236
4125301|4125301-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.37|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200906080736
4125185|4125185-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.26-2-686|200906081825
4125184|4125184-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.26-2-686|200906081825
4125101|4125101-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.01|IP35-irix-64int|5.8.8|irix|6.5|200906081421
4125094|4125094-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.37|IP35-irix-64int|5.8.8|irix|6.5|200906081421
4125053|4125053-b19f-3f77-b713-d32bba55d77f|pass|200906|rafl@debian.org|Test-CPAN-Meta|0.13|i686-linux|5.10.0|linux|2.6.28.7|200906081417
4124989|4124989-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200906081313
4124987|4124987-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200906081313
4124984|4124984-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.37|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200906081313
4124947|4124947-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Release|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200906081310
4124945|4124945-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.37|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200906081309
4124781|4124781-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@rail.org.ua|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.6.26-2-686|200906081751
4124780|4124780-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.6.26-2-686|200906081751
4124496|4124496-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|amd64-freebsd|5.10.0|freebsd|7.0-release|200906081223
4124494|4124494-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.65|amd64-freebsd|5.10.0|freebsd|7.0-release|200906081221
4124182|4124182-b19f-3f77-b713-d32bba55d77f|pass|200906|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Release|0.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200906081714
4124180|4124180-b19f-3f77-b713-d32bba55d77f|pass|200906|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Generator|0.37|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200906081712
4123770|4123770-b19f-3f77-b713-d32bba55d77f|pass|200906|rbo@cpan.org|CPAN-Testers-Data-Release|0.01|i86pc-solaris|5.10.0|solaris|2.11|200906080834
4123766|4123766-b19f-3f77-b713-d32bba55d77f|pass|200906|rbo@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris|5.10.0|solaris|2.11|200906080833
4122290|4122290-b19f-3f77-b713-d32bba55d77f|pass|200906|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.65|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200906080932
4121213|4121213-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906072357
4121008|4121008-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Generator|0.37|amd64-freebsd|5.10.0|freebsd|7.0-release|200906072304
4120844|4120844-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Release|0.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200906072159
4120659|4120659-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Release|0.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200906072159
4120082|4120082-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906071955
4119998|4119998-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906071925
4119823|4119823-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906071858
4119606|4119606-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Release|0.01|amd64-freebsd|5.10.0|freebsd|7.0-release|200906071817
4119473|4119473-b19f-3f77-b713-d32bba55d77f|cpan|200906|BARBIE|CPAN-Testers-Data-Release|0.01||0|||200906071747
4119082|4119082-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906071637
4119006|4119006-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.26-2-686|200906071854
4119001|4119001-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Generator|0.37|amd64-freebsd|5.8.8|freebsd|7.0-release|200906071626
4118991|4118991-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-Data-Generator|0.37|amd64-freebsd|5.8.9|freebsd|7.0-release|200906071626
4118870|4118870-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.6.26-2-686|200906071838
4118843|4118843-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.10.0|linux|2.6.26-2-686|200906071835
4118713|4118713-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906071559
4117970|4117970-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200906071449
4117931|4117931-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-64int-2level|5.10.0|darwin|8.11.0|200906071344
4117911|4117911-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906071442
4117817|4117817-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@rail.org.ua|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.10.0|linux|2.6.26-2-686|200906071702
4117816|4117816-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@rail.org.ua|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux|5.10.0|linux|2.6.26-2-686|200906071702
4117652|4117652-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906071425
4117441|4117441-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906071408
4117377|4117377-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|GD-Chart-Radial|0.07|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906071402
4116939|4116939-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906071327
4116695|4116695-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906071312
4116474|4116474-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux|5.8.8|linux|2.4.27-2-386|200906071336
4116404|4116404-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.65|i686-linux|5.8.8|linux|2.4.27-2-386|200906071331
4116369|4116369-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.8.8|linux|2.4.27-2-386|200906071328
4116342|4116342-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.17|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906071248
4116290|4116290-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|CPAN-Testers-WWW-Statistics|0.55|i686-linux|5.10.0|linux|2.6.26-2-686|200906071511
4116252|4116252-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.26-2-686|200906071508
4116251|4116251-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.26-2-686|200906071508
4115938|4115938-b19f-3f77-b713-d32bba55d77f|pass|200906|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Generator|0.37|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200906071218
4115671|4115671-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux|5.10.0|linux|2.6.26-2-686|200906071425
4115588|4115588-b19f-3f77-b713-d32bba55d77f|pass|200906|wiml@hhhh.org ("Wim Lewis")|Regexp-Log-Common|0.05|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200906070136
4115535|4115535-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|App-Maisha-Plugin-PingFM|0.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906071408
4115239|4115239-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|App-Maisha|0.12|i686-linux|5.10.0|linux|2.6.26-2-686|200906071345
4115105|4115105-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.65|alpha-netbsd|5.10.0|netbsd|4.0.1|200906070858
4115046|4115046-b19f-3f77-b713-d32bba55d77f|cpan|200906|BARBIE|CPAN-Testers-Data-Generator|0.37||0|||200906071055
4115040|4115040-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.64|alpha-netbsd|5.10.0|netbsd|4.0.1|200906070854
4115018|4115018-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.65|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200906070352
4114991|4114991-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.64|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200906070350
4114827|4114827-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.65|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200906070922
4114821|4114821-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.65|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200906070920
4114817|4114817-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.65|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200906070919
4114811|4114811-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.64|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200906070919
4114786|4114786-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.65|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200906070916
4114776|4114776-b19f-3f77-b713-d32bba55d77f|pass|200906|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.64|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200906070915
4114148|4114148-b19f-3f77-b713-d32bba55d77f|pass|200906|rbo@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris|5.10.0|solaris|2.11|200906070827
4113848|4113848-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906070724
4113842|4113842-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906070722
4113831|4113831-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906070719
4113768|4113768-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906070705
4113763|4113763-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906070704
4113754|4113754-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906070703
4113284|4113284-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906070332
4112502|4112502-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.26-2-686|200906070519
4111918|4111918-b19f-3f77-b713-d32bba55d77f|pass|200906|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.17|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200906070035
4111899|4111899-b19f-3f77-b713-d32bba55d77f|pass|200906|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.65|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200906070031
4111524|4111524-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.65|amd64-freebsd|5.8.9|freebsd|7.0-release|200906062229
4111306|4111306-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|amd64-freebsd|5.8.8|freebsd|7.0-release|200906062229
4111297|4111297-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.17|amd64-freebsd|5.8.9|freebsd|7.0-release|200906062229
4111160|4111160-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.26-2-686|200906070242
4111000|4111000-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.65|amd64-freebsd|5.8.8|freebsd|7.0-release|200906062229
4110730|4110730-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.26-2-686|200906070131
4107364|4107364-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.26-2-686|200906062140
4107361|4107361-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Test-CPAN-Meta|0.13|i686-linux|5.10.0|linux|2.6.26-2-686|200906062140
4107202|4107202-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060819
4106458|4106458-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060814
4106453|4106453-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060814
4106451|4106451-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060814
4105413|4105413-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060808
4105410|4105410-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060808
4105408|4105408-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060808
4103101|4103101-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060755
4102696|4102696-b19f-3f77-b713-d32bba55d77f|cpan|200906|BARBIE|CPAN-Testers-WWW-Statistics|0.65||0|||200906061312
4102235|4102235-b19f-3f77-b713-d32bba55d77f|cpan|200906|BARBIE|CPAN-Testers-WWW-Statistics|0.64||0|||200906061230
4101842|4101842-b19f-3f77-b713-d32bba55d77f|cpan|200906|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.17||0|||200906061159
4100734|4100734-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906060805
4099946|4099946-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906060642
4098933|4098933-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060434
4097763|4097763-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906060232
4097506|4097506-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Calendar-List|0.21|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906060207
4097492|4097492-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060205
4097490|4097490-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060205
4095180|4095180-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906060118
4095175|4095175-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906060118
4095090|4095090-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051433
4092975|4092975-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200906051402
4092922|4092922-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-WWW-Testers-Generator|0.30|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200906051400
4092686|4092686-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906051417
4092613|4092613-b19f-3f77-b713-d32bba55d77f|pass|200906|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-WWW-Reports-Mailer|0.16|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200906051246
4092607|4092607-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906051417
4092474|4092474-b19f-3f77-b713-d32bba55d77f|pass|200906|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-Common-DBUtils|0.03|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200906051239
4092036|4092036-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906051359
4091798|4091798-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906051412
4091795|4091795-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906051412
4091081|4091081-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091078|4091078-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091076|4091076-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091073|4091073-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4090051|4090051-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906051359
4088957|4088957-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Test-CPAN-Meta|0.13|i686-linux|5.10.0|linux|2.6.24-24-generic|200906051618
4088956|4088956-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.24-24-generic|200906051618
4087366|4087366-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|Test-CPAN-Meta|0.13|amd64-freebsd|5.6.2|freebsd|7.0-release|200906051046
4086545|4086545-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906050751
4085940|4085940-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Test-YAML-Meta|0.12|darwin-2level|5.8.8|darwin|8.11.0|200906050551
4085677|4085677-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906050320
4085212|4085212-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906050419
4085193|4085193-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906050418
4084664|4084664-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Calendar-List|0.21|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906050114
4084542|4084542-b19f-3f77-b713-d32bba55d77f|pass|200906|wiml@hhhh.org ("Wim Lewis")|WWW-UsePerl-Journal|0.22|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200906050103
4083995|4083995-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906050013
4083876|4083876-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906050201
4083866|4083866-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906050200
4083628|4083628-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906041406
4083627|4083627-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041406
4083597|4083597-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Test-YAML-Meta|0.12|darwin-2level|5.10.0|darwin|8.11.0|200906050138
4083402|4083402-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Calendar-List|0.21|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041403
4082533|4082533-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906042234
4082324|4082324-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906042221
4082297|4082297-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906042219
4080407|4080407-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041406
4080054|4080054-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Calendar-List|0.21|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041403
4079845|4079845-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906041401
4079376|4079376-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040721
4079369|4079369-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040721
4078926|4078926-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040713
4078676|4078676-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906041838
4078675|4078675-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906040637
4078043|4078043-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040641
4077456|4077456-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040721
4077454|4077454-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040721
4076524|4076524-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906040713
4075853|4075853-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040637
4075851|4075851-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906040637
4075531|4075531-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|WWW-UsePerl-Journal|0.22|amd64-freebsd|5.6.2|freebsd|7.0-release|200906041508
4074193|4074193-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040641
4073601|4073601-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040637
4073599|4073599-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040637
4073595|4073595-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040637
4073594|4073594-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040637
4069864|4069864-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906040043
4069726|4069726-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040023
4069299|4069299-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906032349
4069068|4069068-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906031705
4068379|4068379-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906031658
4068275|4068275-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906032237
4068091|4068091-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906031705
4068087|4068087-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906031705
4067252|4067252-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906031658
4066714|4066714-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906032019
4066645|4066645-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906032013
4065222|4065222-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030644
4064964|4064964-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030641
4063027|4063027-b19f-3f77-b713-d32bba55d77f|pass|200906|bminton@integ.com (Brian Minton)|Parse-CPAN-Distributions|0.05|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200906031047
4061345|4061345-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030638
4060692|4060692-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030644
4060216|4060216-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030641
4059563|4059563-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030638
4059562|4059562-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030638
4059560|4059560-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030638
4059558|4059558-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030638
4059338|4059338-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906031023
4059304|4059304-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906031018
4059290|4059290-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906031116
4059157|4059157-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906031005
4058541|4058541-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030915
4058482|4058482-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030910
4058140|4058140-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030845
4058116|4058116-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030843
4057776|4057776-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@tenzobox.net ("Axel Bourgeois")|Test-YAML-Meta|0.12|i386-openbsd|5.10.0|openbsd|4.5|200906022342
4056591|4056591-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030712
4056584|4056584-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030711
4056463|4056463-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030702
4056441|4056441-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030701
4055960|4055960-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030623
4055389|4055389-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030545
4054073|4054073-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030354
4053435|4053435-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030306
4053434|4053434-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030305
4053431|4053431-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030305
4053427|4053427-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030305
4053163|4053163-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030244
4053162|4053162-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030244
4053160|4053160-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030244
4053159|4053159-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030244
4053157|4053157-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030244
4053156|4053156-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030243
4053004|4053004-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030231
4052633|4052633-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030201
4052164|4052164-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030125
4051298|4051298-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030031
4050393|4050393-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021412
4049160|4049160-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021418
4048643|4048643-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021420
4048409|4048409-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|GD-Chart-Radial|0.07|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906022319
4047583|4047583-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906021412
4047581|4047581-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021412
4047219|4047219-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906022145
4046415|4046415-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021401
4046413|4046413-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906021401
4046410|4046410-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021401
4046409|4046409-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021401
4046406|4046406-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021401
4046403|4046403-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021401
4046399|4046399-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021401
4045828|4045828-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020641
4044757|4044757-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020639
4044742|4044742-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020639
4043537|4043537-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020621
4043532|4043532-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020621
4043303|4043303-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Test-YAML-Meta|0.12|i686-linux|5.8.6|linux|2.4.18|200906021600
4042450|4042450-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906020641
4042220|4042220-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020639
4042218|4042218-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020639
4039610|4039610-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020621
4039607|4039607-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020621
4039602|4039602-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020621
4036092|4036092-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Parse-CPAN-Distributions|0.05|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906021312
4035275|4035275-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020200
4034837|4034837-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|WWW-UsePerl-Journal-Thread|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906021130
4034457|4034457-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-WWW-Testers-Generator|0.30|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906021103
4033198|4033198-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011820
4032133|4032133-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906011509
4030579|4030579-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906011509
4029512|4029512-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011501
4024998|4024998-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-2level|5.10.0|darwin|8.11.0|200906011454
4024980|4024980-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-CPAN-Meta|0.13|darwin-2level|5.10.0|darwin|8.11.0|200906011453
4024656|4024656-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011418
4024650|4024650-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Test-CPAN-Meta|0.13|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011418
4023357|4023357-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906011129
4022717|4022717-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Test-YAML-Meta|0.12|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200906010953
4022223|4022223-b19f-3f77-b713-d32bba55d77f|fail|200906|ivan.wills@gmail.com ("Ivan Wills")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906011718
4022215|4022215-b19f-3f77-b713-d32bba55d77f|fail|200906|ivan.wills@gmail.com ("Ivan Wills")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906011717
4019842|4019842-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905311551
4019841|4019841-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905311551
4019761|4019761-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int|5.10.0|linux|2.6.23.1-42.fc8|200906010040
4018489|4018489-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905312158
4018487|4018487-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905312158
4018312|4018312-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200905312022
4018078|4018078-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905311146
4018076|4018076-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905311146
4017978|4017978-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906010432
4017588|4017588-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906010309
4017587|4017587-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906010308
4017088|4017088-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906010126
4016194|4016194-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.8.9|linux|2.6.26-2-686|200905311848
4016193|4016193-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.8.9|linux|2.6.26-2-686|200905311848
4016189|4016189-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Mail-File|0.08|i686-linux|5.8.9|linux|2.6.26-2-686|200905311847
4016132|4016132-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.8.9|linux|2.6.26-2-686|200905311843
4016130|4016130-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@rail.org.ua|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.8.9|linux|2.6.26-2-686|200905311843
4016129|4016129-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.8.9|linux|2.6.26-2-686|200905311843
4016127|4016127-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.8.9|linux|2.6.26-2-686|200905311842
4013044|4013044-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310548
4013043|4013043-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310548
4012808|4012808-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311502
4012739|4012739-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311451
4012681|4012681-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310446
4012679|4012679-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310446
4012678|4012678-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Phrasebook|0.29|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310446
4012676|4012676-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Phrasebook|0.29|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310446
4012459|4012459-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311417
4012137|4012137-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Data-Generator|0.35|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310340
4012132|4012132-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Data-Generator|0.35|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310340
4009180|4009180-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Data-Uploads|0.06|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301517
4008681|4008681-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Mail-Outlook|0.15|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310713
4008486|4008486-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Data-Uploads|0.06|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301356
4008479|4008479-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Data-Generator|0.36|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301356
4008476|4008476-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Common-Article|0.36|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301356
4008454|4008454-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Data-Generator|0.36|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301355
4008452|4008452-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Common-Article|0.36|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301355
4008122|4008122-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Test-YAML-Meta|0.12|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301625
4008117|4008117-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Test-CPAN-Meta|0.13|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301625
4008041|4008041-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Test-YAML-Meta|0.12|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301617
4008037|4008037-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Test-CPAN-Meta|0.13|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301616
4007943|4007943-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Test-YAML-Meta|0.12|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301604
4007939|4007939-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Test-CPAN-Meta|0.13|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301604
4007869|4007869-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905301057
4005984|4005984-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|App-Maisha|0.12|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301043
4005854|4005854-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905301057
4005841|4005841-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905301057
4004514|4004514-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905301057
4004512|4004512-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905301057
4002201|4002201-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200905301856
4001524|4001524-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905302124
4001518|4001518-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905302123
4001174|4001174-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301952
4000495|4000495-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|GD-Chart-Radial|0.07|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905301005
3999764|3999764-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905301711
3999759|3999759-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Test-CPAN-Meta|0.13|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905301710
3999748|3999748-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301707
3999742|3999742-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Test-CPAN-Meta|0.13|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301706
3999195|3999195-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux|5.8.9|linux|2.6.26-2-686|200905300502
3999090|3999090-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.8.9|linux|2.6.26-2-686|200905300451
3997732|3997732-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905300131
3997717|3997717-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905300128
3997522|3997522-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|i386-freebsd|5.10.0|freebsd|6.4-release|200905300046
3997510|3997510-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|i386-freebsd|5.10.0|freebsd|6.4-release|200905300045
3995793|3995793-b19f-3f77-b713-d32bba55d77f|pass|200905|jafelds@gmail.com|Test-YAML-Meta|0.12|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200905281253
3995488|3995488-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300157
3995451|3995451-b19f-3f77-b713-d32bba55d77f|pass|200905|gardnerm@gsicommerce.com|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-53.el5|200905281324
3995389|3995389-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|i686-linux|5.8.6|linux|2.4.20|200905291634
3995000|3995000-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Games-Trackword|1.06|i686-linux|5.8.9|linux|2.6.26-2-686|200905291454
3994999|3994999-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Calendar-List|0.21|i686-linux|5.8.9|linux|2.6.26-2-686|200905291454
3994351|3994351-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@rail.org.ua|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.8.9|linux|2.6.26-2-686|200905291332
3994349|3994349-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.8.9|linux|2.6.26-2-686|200905291332
3993933|3993933-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Test-YAML-Meta|0.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200905291358
3993930|3993930-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Test-CPAN-Meta|0.13|i86pc-solaris-64int|5.10.0|solaris|2.11|200905291357
3993096|3993096-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux|5.8.9|linux|2.6.26-2-686|200905291126
3992825|3992825-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Test-YAML-Meta|0.12|i386-freebsd-64int|5.8.8|freebsd|6.2-release|200905291033
3992051|3992051-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.8.9|linux|2.6.26-2-686|200905290832
3992021|3992021-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.8.9|linux|2.6.26-2-686|200905290829
3991895|3991895-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.12|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200905291128
3991886|3991886-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.13|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200905291125
3990404|3990404-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.8.9|linux|2.6.26-2-686|200905290223
3990402|3990402-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux|5.8.9|linux|2.6.26-2-686|200905290223
3990047|3990047-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905290043
3990043|3990043-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905290042
3988787|3988787-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905282130
3988786|3988786-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-CPAN-Meta|0.13|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905282130
3988632|3988632-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.12|armv5tejl-linux|5.10.0|linux|2.6.17.14|200905282202
3988600|3988600-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.13|armv5tejl-linux|5.10.0|linux|2.6.17.14|200905282158
3987341|3987341-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905281704
3987337|3987337-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905281704
3986122|3986122-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905280645
3985952|3985952-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905280639
3985406|3985406-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPAN-Testers-WWW-Statistics|0.55|i686-linux|5.8.9|linux|2.6.26-2-686|200905281822
3985345|3985345-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.9|linux|2.6.26-2-686|200905281819
3985343|3985343-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Data-Phrasebook|0.29|i686-linux|5.8.9|linux|2.6.26-2-686|200905281819
3985193|3985193-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPAN-Testers-Data-Generator|0.35|i686-linux|5.8.9|linux|2.6.26-2-686|200905281810
3985044|3985044-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Test-YAML-Meta|0.12|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905280738
3985031|3985031-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Test-CPAN-Meta|0.13|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905280737
3984744|3984744-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Mail-Outlook|0.15|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280526
3984310|3984310-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|CPAN-Testers-Data-Uploads|0.06|i686-linux|5.8.9|linux|2.6.26-2-686|200905281725
3984283|3984283-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|CPAN-Testers-Data-Generator|0.36|i686-linux|5.8.9|linux|2.6.26-2-686|200905281723
3984281|3984281-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|CPAN-Testers-Common-Article|0.36|i686-linux|5.8.9|linux|2.6.26-2-686|200905281723
3983793|3983793-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905280644
3983736|3983736-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Mail-Outlook|0.15|i686-linux|5.8.9|linux|2.6.26-2-686|200905281656
3983434|3983434-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Statistics|0.55|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282116
3982946|3982946-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Phrasebook-Loader-YAML|0.09|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282056
3982940|3982940-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Phrasebook|0.29|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282056
3982850|3982850-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905280640
3982818|3982818-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.12|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280352
3982816|3982816-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.13|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280351
3982694|3982694-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905280639
3982410|3982410-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.35|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282006
3982038|3982038-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200905280932
3982034|3982034-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200905280931
3981743|3981743-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.12|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280039
3980024|3980024-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-YAML-Meta|0.12|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905280141
3980022|3980022-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-CPAN-Meta|0.13|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905280140
3978967|3978967-b19f-3f77-b713-d32bba55d77f|pass|200905|rafl@debian.org|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.28.7|200905272234
3978912|3978912-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Regexp-Log-Common|0.05|i686-linux|5.8.9|linux|2.6.26-2-686|200905271626
3978775|3978775-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|WWW-UsePerl-Journal|0.22|i686-linux|5.8.9|linux|2.6.26-2-686|200905271505
3978325|3978325-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.13|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905271140
3977857|3977857-b19f-3f77-b713-d32bba55d77f|pass|200905|brian@minton.name|Test-YAML-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.2-dsa-dl380-oldxeon|200905271224
3977752|3977752-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|App-Maisha|0.12|i686-linux|5.8.9|linux|2.6.26-2-686|200905271100
3977628|3977628-b19f-3f77-b713-d32bba55d77f|pass|200905|overlordq@gmail.com|Test-YAML-Meta|0.12|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.18-xen-3.1-1-amd64|200905270910
3977431|3977431-b19f-3f77-b713-d32bba55d77f|pass|200905|mjg@phoenixtrap.com|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|9.6.0|200905270116
3976913|3976913-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Test-YAML-Meta|0.12|i686-linux|5.8.9|linux|2.6.26-2-686|200905271113
3976905|3976905-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Test-CPAN-Meta|0.13|i686-linux|5.8.9|linux|2.6.26-2-686|200905271113
3976783|3976783-b19f-3f77-b713-d32bba55d77f|pass|200905|mjg@phoenixtrap.com|Test-CPAN-Meta|0.13|darwin-thread-multi-2level|5.10.0|darwin|9.6.0|200905270116
3975407|3975407-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux|5.8.9|linux|2.6.26-2-686|200905271024
3975406|3975406-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.8.9|linux|2.6.26-2-686|200905271024
3975007|3975007-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Test-YAML-Meta|0.12|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200905271211
3974521|3974521-b19f-3f77-b713-d32bba55d77f|pass|200905|rbo@cpan.org|Test-CPAN-Meta|0.13|i86pc-solaris|5.8.9|solaris|2.11|200905271223
3974048|3974048-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905271008
3974043|3974043-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905271008
3973676|3973676-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905270929
3973516|3973516-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Test-CPAN-Meta|0.13|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905270153
3973465|3973465-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Test-YAML-Meta|0.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905270153
3972476|3972476-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.11|armv5tejl-linux|5.10.0|linux|2.6.17.14|200905270556
3972145|3972145-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905270403
3971628|3971628-b19f-3f77-b713-d32bba55d77f|pass|200905|cpanuser@oeuftete.com|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.18.8-linode16|200905260241
3971182|3971182-b19f-3f77-b713-d32bba55d77f|pass|200905|hholz@mcs.csueastbay.edu ((Hilary Holz))|Test-YAML-Meta|0.12|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200905261401
3971027|3971027-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.62|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261548
3971008|3971008-b19f-3f77-b713-d32bba55d77f|pass|200905|arto+test@cpan.org|Test-YAML-Meta|0.12|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200905260106
3970891|3970891-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.62|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261536
3970478|3970478-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905261402
3970464|3970464-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Test-CPAN-Meta|0.13|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905262237
3970065|3970065-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905262208
3970052|3970052-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905262208
3969850|3969850-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905261612
3969847|3969847-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-CPAN-Meta|0.13|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905261612
3969381|3969381-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905261403
3968981|3968981-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905261359
3966564|3966564-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|WWW-UsePerl-Journal|0.22|amd64-freebsd|5.10.0|freebsd|7.0-release|200905261433
3965405|3965405-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200905261027
3965401|3965401-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200905261026
3965299|3965299-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200905261052
3965298|3965298-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.13|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200905261052
3965282|3965282-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905260949
3965279|3965279-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905260947
3965069|3965069-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905260900
3965067|3965067-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905260858
3965041|3965041-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200905260854
3965036|3965036-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200905260852
3964985|3964985-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200905260842
3964972|3964972-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200905260840
3964800|3964800-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200905260812
3964794|3964794-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200905260811
3964736|3964736-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905260802
3964731|3964731-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905260800
3964723|3964723-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905260759
3964713|3964713-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905260757
3964649|3964649-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905260745
3964610|3964610-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905260739
3964589|3964589-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905260733
3964584|3964584-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905260732
3964512|3964512-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905260713
3964500|3964500-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905260709
3964175|3964175-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905260604
3964159|3964159-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905260559
3964088|3964088-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905260546
3964064|3964064-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905260541
3964042|3964042-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905260538
3964028|3964028-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905260536
3963989|3963989-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905260527
3963971|3963971-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905260522
3963909|3963909-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200905260508
3963892|3963892-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200905260506
3963801|3963801-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905260449
3963787|3963787-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905260445
3963703|3963703-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905260430
3963672|3963672-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905260425
3963668|3963668-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905260424
3963651|3963651-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905260419
3963573|3963573-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905260304
3963265|3963265-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905260109
3963117|3963117-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905260056
3962897|3962897-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200905260204
3962892|3962892-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200905260202
3962886|3962886-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Test-YAML-Meta|0.12|i686-linux|5.10.0|linux|2.6.23.11.20071215-bcm203x|200905260202
3962770|3962770-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200905260133
3962667|3962667-b19f-3f77-b713-d32bba55d77f|pass|200905|perl@galumph.com|Test-YAML-Meta|0.12|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200905251818
3962583|3962583-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200905260102
3962579|3962579-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200905260101
3962426|3962426-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905260030
3962327|3962327-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905260021
3962316|3962316-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905260020
3962089|3962089-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905252353
3962030|3962030-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200905252345
3962026|3962026-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200905252344
3960457|3960457-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-CPAN-Meta|0.13|amd64-freebsd|5.8.8|freebsd|7.0-release|200905251136
3960450|3960450-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-YAML-Meta|0.12|amd64-freebsd|5.10.0|freebsd|7.0-release|200905251146
3960133|3960133-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-YAML-Meta|0.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200905251136
3960049|3960049-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-YAML-Meta|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200905251848
3960048|3960048-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-CPAN-Meta|0.13|amd64-freebsd|5.8.9|freebsd|7.0-release|200905251848
3960010|3960010-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Test-CPAN-Meta|0.13|amd64-freebsd|5.10.0|freebsd|7.0-release|200905250859
3960002|3960002-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Test-YAML-Meta|0.12|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905251132
3959999|3959999-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Test-CPAN-Meta|0.13|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905251131
3959761|3959761-b19f-3f77-b713-d32bba55d77f|pass|200905|jayfrombkk@gmail.com ("Jay from BKK")|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.8.8|darwin|9.0|200905251222
3959639|3959639-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Test-YAML-Meta|0.12|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200905251927
3959635|3959635-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Test-YAML-Meta|0.12|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200905251926
3959632|3959632-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200905251926
3959625|3959625-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Test-YAML-Meta|0.12|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200905251922
3959619|3959619-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Test-YAML-Meta|0.12|i586-linux-thread-multi|5.8.8|linux|2.6.16|200905251916
3959501|3959501-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|alpha-netbsd|5.10.0|netbsd|4.0.1|200905251601
3959491|3959491-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|alpha-netbsd|5.10.0|netbsd|4.0.1|200905251555
3959182|3959182-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.9-5.elsmp|200905251446
3958811|3958811-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Test-YAML-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200905251218
3958637|3958637-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905251251
3958616|3958616-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905251248
3958596|3958596-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.12|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200905251245
3958581|3958581-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200905251241
3958567|3958567-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905250536
3958559|3958559-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|IP35-irix-64int|5.8.8|irix|6.5|200905251234
3958547|3958547-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|IP35-irix-64int|5.8.8|irix|6.5|200905251233
3958546|3958546-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905250532
3958542|3958542-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905251832
3958534|3958534-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.13|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905251831
3958422|3958422-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905251105
3958421|3958421-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905251105
3958420|3958420-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905251104
3958419|3958419-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905251104
3958415|3958415-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200905251204
3958414|3958414-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905251103
3958411|3958411-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905251103
3958410|3958410-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905251103
3958408|3958408-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905251103
3958382|3958382-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Test-CPAN-Meta|0.13|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905251058
3957811|3957811-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Test-CPAN-Meta|0.13|i86pc-solaris-64int|5.8.9|solaris|2.11|200905251000
3957795|3957795-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905251002
3957792|3957792-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Test-YAML-Meta|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200905251000
3957760|3957760-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905250955
3957656|3957656-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.13|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200905250938
3957142|3957142-b19f-3f77-b713-d32bba55d77f|pass|200905|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Test-CPAN-Meta|0.13|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200905251518
3957138|3957138-b19f-3f77-b713-d32bba55d77f|pass|200905|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Test-YAML-Meta|0.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200905251517
3957137|3957137-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905250712
3956993|3956993-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250625
3956308|3956308-b19f-3f77-b713-d32bba55d77f|pass|200905|cpanuser@oeuftete.com|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.18.8-linode16|200905241642
3955237|3955237-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905241830
3955222|3955222-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905241830
3955217|3955217-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Regexp-Log-Common|0.05|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241544
3954719|3954719-b19f-3f77-b713-d32bba55d77f|pass|200905|stsc@refcnt.org ("Steven Schubiger")|Test-YAML-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200905242324
3954718|3954718-b19f-3f77-b713-d32bba55d77f|pass|200905|stsc@refcnt.org ("Steven Schubiger")|Test-CPAN-Meta|0.13|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200905242323
3954676|3954676-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-YAML-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905242318
3954672|3954672-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-CPAN-Meta|0.13|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905242318
3954592|3954592-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Test-YAML-Meta|0.12|x86_64-linux-ld|5.10.0|linux|2.6.26.5-fuuka.profvince.com|200905242303
3953783|3953783-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.12|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241144
3953519|3953519-b19f-3f77-b713-d32bba55d77f|cpan|200905|BARBIE|Test-CPAN-Meta|0.13||0|||200905242008
3953511|3953511-b19f-3f77-b713-d32bba55d77f|cpan|200905|BARBIE|Test-YAML-Meta|0.12||0|||200905242007
3953282|3953282-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241012
3953276|3953276-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241012
3953231|3953231-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Regexp-Log-Common|0.05|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241003
3951935|3951935-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-CPAN-Meta|0.12|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905240452
3951628|3951628-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905240306
3951624|3951624-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905240306
3951400|3951400-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|WWW-UsePerl-Journal|0.22|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905240156
3950732|3950732-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Calendar-List|0.21|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240338
3950522|3950522-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240233
3945854|3945854-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200905231138
3945554|3945554-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Uploads|0.06|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231856
3945511|3945511-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Data-Generator|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231841
3945510|3945510-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-Article|0.36|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231841
3945415|3945415-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha-Plugin-PingFM|0.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231754
3944846|3944846-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|App-Maisha|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231500
3944267|3944267-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905230318
3943636|3943636-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905230219
3943516|3943516-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Mail-Outlook|0.15|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231158
3942372|3942372-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905222156
3942303|3942303-b19f-3f77-b713-d32bba55d77f|pass|200905|pjacklam@cpan.org|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905221907
3937351|3937351-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Regexp-Log-Common|0.05|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221708
3935861|3935861-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905220043
3935472|3935472-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905211843
3935125|3935125-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905211843
3935124|3935124-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905211843
3934864|3934864-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Test-CPAN-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220831
3934476|3934476-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-WWW-Reports-Mailer|0.16|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220707
3934466|3934466-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220706
3933811|3933811-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|WWW-UsePerl-Journal|0.22|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220440
3933090|3933090-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905211800
3932370|3932370-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905210621
3932243|3932243-b19f-3f77-b713-d32bba55d77f|pass|200905|james@mastros.biz|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200905202155
3932088|3932088-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905210632
3931517|3931517-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905210621
3931436|3931436-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905210619
3931426|3931426-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905210619
3931239|3931239-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905210632
3929976|3929976-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905210621
3929744|3929744-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905210619
3929743|3929743-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905210619
3929742|3929742-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905210619
3928037|3928037-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905210257
3926499|3926499-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200905201831
3926066|3926066-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200905201723
3922794|3922794-b19f-3f77-b713-d32bba55d77f|pass|200905|bobtfish@bobtfish.net|Test-CPAN-Meta|0.12|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.24-16-server|200905191844
3921646|3921646-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905200306
3920901|3920901-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200905192258
3920336|3920336-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905192147
3920279|3920279-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905192131
3918651|3918651-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905191417
3915543|3915543-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905190141
3914889|3914889-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|WWW-UsePerl-Journal|0.22|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905181504
3911308|3911308-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180741
3910881|3910881-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180741
3910260|3910260-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180740
3908677|3908677-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180653
3908253|3908253-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905180548
3908224|3908224-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905180543
3907965|3907965-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180433
3907713|3907713-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905180327
3907187|3907187-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180226
3907185|3907185-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180225
3907100|3907100-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905180217
3907099|3907099-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180217
3906466|3906466-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905171815
3906299|3906299-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905171815
3906123|3906123-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905171815
3905121|3905121-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.11|armv5tejl-linux|5.8.8|linux|2.6.17.14|200905172240
3903123|3903123-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3902553|3902553-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3902478|3902478-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3901638|3901638-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3901545|3901545-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3901542|3901542-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3901541|3901541-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3899730|3899730-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170523
3899424|3899424-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170345
3899408|3899408-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170343
3899186|3899186-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170317
3899184|3899184-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170317
3899182|3899182-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170317
3899004|3899004-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905170153
3898654|3898654-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905161823
3898468|3898468-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905161823
3898211|3898211-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905161823
3898200|3898200-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905161823
3897926|3897926-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Regexp-Log-Common|0.05|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905161053
3897731|3897731-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-2level|5.8.8|darwin|8.11.0|200905162134
3897063|3897063-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905161959
3896760|3896760-b19f-3f77-b713-d32bba55d77f|pass|200905|rafl@debian.org|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.28.7|200905161834
3896169|3896169-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905161534
3895916|3895916-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905161422
3894690|3894690-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905160935
3894495|3894495-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905160853
3894473|3894473-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905160643
3894200|3894200-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905160513
3893359|3893359-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|App-Maisha|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905160308
3893019|3893019-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905160226
3893018|3893018-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905160226
3892939|3892939-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Data-Generator|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905160218
3891334|3891334-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|WWW-UsePerl-Journal|0.22|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905150828
3890295|3890295-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.11|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905150823
3887999|3887999-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905150634
3887441|3887441-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905150634
3887415|3887415-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|App-Maisha|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905150634
3885337|3885337-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905150358
3883137|3883137-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905141850
3882908|3882908-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905142304
3882226|3882226-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Test-YAML-Meta|0.11|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905141318
3877814|3877814-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140637
3877582|3877582-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140522
3877162|3877162-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Mail-Outlook|0.15|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905140359
3876636|3876636-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905140310
3875759|3875759-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|GD-Chart-Radial|0.07|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905140119
3875003|3875003-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905132033
3874674|3874674-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905131946
3871590|3871590-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905131055
3868617|3868617-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905121302
3868330|3868330-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905121242
3868298|3868298-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905121302
3868297|3868297-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121302
3868210|3868210-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121301
3867820|3867820-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121302
3867519|3867519-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121923
3867504|3867504-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121922
3867377|3867377-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121908
3867369|3867369-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121907
3867363|3867363-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121906
3867324|3867324-b19f-3f77-b713-d32bba55d77f|pass|200905|robin@smidsrod.no ("Robin Smidsrd")|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-19-server|200905121237
3867180|3867180-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905121242
3866843|3866843-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121747
3866683|3866683-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-Ini|0.10|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121708
3866676|3866676-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-XML|0.12|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121707
3866630|3866630-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-File|0.08|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121656
3866629|3866629-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121655
3866627|3866627-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121654
3866255|3866255-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-YACSmoke-Plugin-Outlook|0.06|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121541
3863734|3863734-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905120157
3863679|3863679-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905120146
3863363|3863363-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905120114
3862960|3862960-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111703
3862520|3862520-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905111712
3862324|3862324-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111713
3861739|3861739-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111432
3861580|3861580-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111422
3861395|3861395-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905111430
3860772|3860772-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111409
3860080|3860080-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-2level|5.8.6|darwin|8.11.0|200905111543
3859662|3859662-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905110653
3859418|3859418-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905110653
3859417|3859417-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905110654
3858690|3858690-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905110652
3856488|3856488-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905110137
3856422|3856422-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905110130
3856232|3856232-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905110232
3852690|3852690-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905100701
3844448|3844448-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905090354
3843007|3843007-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905081935
3843003|3843003-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905081933
3842807|3842807-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-2level|5.8.9|darwin|8.11.0|200905082340
3841868|3841868-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905081516
3841065|3841065-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd|5.8.9|netbsd|5.0|200905081745
3829058|3829058-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd|5.10.0|netbsd|5.0|200905070317
3827273|3827273-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-2level|5.10.0|darwin|8.11.0|200905061834
3822179|3822179-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051820
3821180|3821180-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905052034
3818580|3818580-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050700
3814742|3814742-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905042338
3813269|3813269-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905041625
3811049|3811049-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905041011
3808094|3808094-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040210
3808090|3808090-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040207
3808085|3808085-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040205
3808081|3808081-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Pearson_Driver|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040202
3808070|3808070-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-ORA_Driver|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040159
3808063|3808063-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040156
3808054|3808054-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Regexp-Log-Common|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040153
3808050|3808050-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Parse-CPAN-Distributions|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040153
3808049|3808049-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Mail-File|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040152
3808047|3808047-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Games-Trackword|1.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040152
3808045|3808045-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040151
3808043|3808043-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040151
3808037|3808037-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040148
3808035|3808035-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040147
3808034|3808034-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040146
3808032|3808032-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040145
3808031|3808031-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040144
3808030|3808030-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Calendar-List|0.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040144
3808029|3808029-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-WebList|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040143
3808022|3808022-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-Outlook|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040137
3808014|3808014-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040136
3807985|3807985-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTP|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040123
3807978|3807978-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers-Generator|0.30|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040121
3807906|3807906-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040054
3807881|3807881-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040048
3807874|3807874-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Uploads|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040043
3807869|3807869-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Generator|0.35|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040037
3807864|3807864-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040033
3807854|3807854-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040031
3807832|3807832-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|App-Maisha|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040027
3806026|3806026-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905031026
3805356|3805356-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Mail-Outlook|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905031413
3805026|3805026-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905031300
3801570|3801570-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905021813
3801498|3801498-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@tenzobox.net ("Axel Bourgeois")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.27-11-server|200905021714
3801344|3801344-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905022338
3801334|3801334-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200905021633
3799946|3799946-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905021229
3799732|3799732-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905021150
3799358|3799358-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905021036
3798773|3798773-b19f-3f77-b713-d32bba55d77f|pass|200905|amiri@metalabel.com (Amiri Barksdale)|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200905010052
3798553|3798553-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905020503
3797985|3797985-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905020251
3797000|3797000-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905012020
3796795|3796795-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905011626
3795868|3795868-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Test-CPAN-Meta|0.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905010636
3792828|3792828-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-DBUtils|0.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200904301748
3791836|3791836-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302023
3791497|3791497-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904301910
3788422|3788422-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904300238
3788052|3788052-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300059
3787605|3787605-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904292350
3786708|3786708-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291808
3786517|3786517-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291730
3786218|3786218-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291626
3786016|3786016-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291532
3785011|3785011-b19f-3f77-b713-d32bba55d77f|pass|200904|bobtfisg@bobtfish.net|Test-CPAN-Meta|0.12|darwin-thread-multi-2level|5.8.6|darwin|8.0|200904282318
3784766|3784766-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904290710
3783948|3783948-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290428
3783686|3783686-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290253
3782315|3782315-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Test-YAML-Meta|0.11|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904282227
3778505|3778505-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281104
3778324|3778324-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281018
3777038|3777038-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904280622
3776828|3776828-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904280344
3776119|3776119-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904272249
3774510|3774510-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271535
3774240|3774240-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271442
3772230|3772230-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904270516
3770154|3770154-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904262127
3769775|3769775-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904261857
3769620|3769620-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904261813
3768426|3768426-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904261352
3768425|3768425-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904261351
3767428|3767428-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904260847
3767415|3767415-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260344
3766595|3766595-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904260615
3766324|3766324-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260419
3766320|3766320-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260418
3765528|3765528-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904260224
3765525|3765525-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904260224
3765474|3765474-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904260215
3764304|3764304-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252115
3763929|3763929-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252011
3763459|3763459-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251359
3761834|3761834-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.16|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904250808
3760892|3760892-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904251141
3760804|3760804-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|Test-CPAN-Meta|0.12|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250919
3760714|3760714-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904251104
3760214|3760214-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904250828
3760088|3760088-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904250856
3758756|3758756-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-WWW-Reports-Mailer|0.16|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250214
3758546|3758546-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250139
3757921|3757921-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250050
3757651|3757651-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904250106
3757581|3757581-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Test-CPAN-Meta|0.12|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904250055
3757357|3757357-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904250021
3757262|3757262-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904250008
3756976|3756976-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904242318
3756246|3756246-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904242140
3756076|3756076-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904242113
3755249|3755249-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904241747
3755237|3755237-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904241744
3754222|3754222-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|amd64-freebsd|5.8.9|freebsd|7.0-release|200904241627
3754069|3754069-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.16|i86pc-solaris-64int|5.8.9|solaris|2.11|200904241614
3753490|3753490-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.16|i86pc-solaris-64int|5.10.0|solaris|2.11|200904241444
3753115|3753115-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904241355
3752649|3752649-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux|5.10.0|linux|2.6.24-16-generic|200904240718
3752626|3752626-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.16|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904241316
3752207|3752207-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.16|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904241145
3752191|3752191-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|CPAN-Testers-WWW-Reports-Mailer|0.16|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904241144
3752161|3752161-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904241140
3752137|3752137-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.16|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904241137
3752069|3752069-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904241124
3752067|3752067-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904241124
3751862|3751862-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904241042
3751550|3751550-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Mailer|0.16|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904241647
3751409|3751409-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904240926
3749666|3749666-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.16|amd64-freebsd|5.8.8|freebsd|7.0-release|200904240023
3748821|3748821-b19f-3f77-b713-d32bba55d77f|cpan|200904|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.16||0|||200904232016
3748463|3748463-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904231752
3747116|3747116-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904221850
3745035|3745035-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904230703
3744877|3744877-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904230705
3744876|3744876-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904230704
3744829|3744829-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904230647
3744826|3744826-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904230647
3743463|3743463-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222328
3743049|3743049-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904222328
3741697|3741697-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221803
3741531|3741531-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904221836
3741440|3741440-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904221811
3740929|3740929-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904221638
3740518|3740518-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221418
3739964|3739964-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Test-CPAN-Meta|0.12|amd64-freebsd|5.10.0|freebsd|7.0-release|200904221114
3738633|3738633-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904220736
3738164|3738164-b19f-3f77-b713-d32bba55d77f|pass|200904|rafl@debian.org|Test-CPAN-Meta|0.12|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904220523
3738075|3738075-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220354
3737526|3737526-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904220222
3737392|3737392-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220034
3737173|3737173-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904220036
3736707|3736707-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904212158
3735943|3735943-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net ("GRAHAMC")|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904202214
3733597|3733597-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211314
3732593|3732593-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211005
3731624|3731624-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904210733
3731616|3731616-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904210731
3730001|3730001-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Test-CPAN-Meta|0.12|alpha-netbsd|5.10.0|netbsd|4.0.1|200904202257
3729630|3729630-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904202328
3729623|3729623-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904202327
3728788|3728788-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202053
3728748|3728748-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904202147
3728505|3728505-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904202103
3728022|3728022-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904201945
3727633|3727633-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904201841
3727481|3727481-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904201719
3727363|3727363-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904201704
3727351|3727351-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904201703
3726997|3726997-b19f-3f77-b713-d32bba55d77f|pass|200904|pjacklam@online.no|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904201707
3726919|3726919-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904201648
3724957|3724957-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904201103
3724533|3724533-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904200838
3724293|3724293-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200757
3723292|3723292-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904200434
3723259|3723259-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200320
3722970|3722970-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904200222
3722688|3722688-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904192339
3722053|3722053-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Regexp-Log-Common|0.05|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904192114
3721532|3721532-b19f-3f77-b713-d32bba55d77f|pass|200904|mjg@phoenixtrap.com|Test-CPAN-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|9.6.0|200904181058
3721383|3721383-b19f-3f77-b713-d32bba55d77f|pass|200904|doug@peaches.acomp.usf.edu ("Douglas Christopher Wilson")|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release-p7|200904190042
3721021|3721021-b19f-3f77-b713-d32bba55d77f|pass|200904|mjg@phoenixtrap.com|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|9.6.0|200904190209
3720934|3720934-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Test-CPAN-Meta|0.12|i86pc-solaris|5.8.9|solaris|2.11|200904182101
3720456|3720456-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904191049
3719789|3719789-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Test-CPAN-Meta|0.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904191604
3719595|3719595-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904190646
3716100|3716100-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904181940
3714948|3714948-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904181729
3714681|3714681-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904181642
3714577|3714577-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904181627
3714287|3714287-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904181543
3714278|3714278-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904181543
3713785|3713785-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904181441
3713371|3713371-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904181356
3713301|3713301-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181247
3712635|3712635-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904181213
3711461|3711461-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904180555
3710701|3710701-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904180120
3710689|3710689-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904180118
3710633|3710633-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904180103
3710390|3710390-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904180105
3708826|3708826-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171814
3705713|3705713-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904170759
3705405|3705405-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904170507
3705017|3705017-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170344
3704966|3704966-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904170425
3703511|3703511-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904162230
3703062|3703062-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|alpha-netbsd|5.10.0|netbsd|4.0.1|200904161944
3702959|3702959-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904162121
3702934|3702934-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904162114
3702578|3702578-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904161955
3701645|3701645-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904161644
3701303|3701303-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904161547
3700565|3700565-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904161343
3700085|3700085-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904161226
3699487|3699487-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904161027
3698180|3698180-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904160407
3698046|3698046-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|WWW-UsePerl-Journal|0.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904160225
3697302|3697302-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200904160003
3693468|3693468-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904151258
3692233|3692233-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904151043
3691663|3691663-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904150756
3691498|3691498-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150606
3691447|3691447-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904150651
3690856|3690856-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904150410
3690279|3690279-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904150140
3690277|3690277-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904150140
3690193|3690193-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904150120
3690187|3690187-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904150119
3687026|3687026-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.35|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904141341
3686923|3686923-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904141309
3686561|3686561-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|WWW-UsePerl-Journal|0.22|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904141051
3685866|3685866-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904140833
3685805|3685805-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904140813
3683373|3683373-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132039
3683129|3683129-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904132024
3682875|3682875-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904131921
3680868|3680868-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904130630
3680117|3680117-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904130018
3679943|3679943-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.15|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904122238
3679940|3679940-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904122237
3679817|3679817-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904122142
3679356|3679356-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904121903
3678986|3678986-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904121702
3678602|3678602-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904121443
3678146|3678146-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904121425
3678037|3678037-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904121256
3677786|3677786-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904121147
3676954|3676954-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904120853
3676050|3676050-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904120628
3675847|3675847-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904120538
3675339|3675339-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904120313
3675202|3675202-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904120236
3674198|3674198-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.15|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904112218
3672225|3672225-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904111503
3672193|3672193-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904111557
3671784|3671784-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904111353
3670714|3670714-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904110935
3670678|3670678-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Regexp-Log-Common|0.05|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200904110124
3669896|3669896-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904110626
3669827|3669827-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904110610
3669670|3669670-b19f-3f77-b713-d32bba55d77f|pass|200904|justin.hunter@asu.edu|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200904100308
3669158|3669158-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904110354
3667900|3667900-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|WWW-UsePerl-Journal|0.22|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200904101352
3666282|3666282-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904101611
3665914|3665914-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904101442
3665773|3665773-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904101408
3665217|3665217-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904101130
3664710|3664710-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904101000
3663079|3663079-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|WWW-UsePerl-Journal|0.22|i86pc-solaris|5.8.9|solaris|2.11|200904092000
3662012|3662012-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904092229
3661531|3661531-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-64int-2level|5.11.0|darwin|8.11.0|200904092040
3660794|3660794-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904091730
3660793|3660793-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904091730
3660776|3660776-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-64int-2level|5.11.0|darwin|8.11.0|200904091727
3660481|3660481-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904091747
3660462|3660462-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904091645
3659944|3659944-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@consol.de|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris|5.8.9|solaris|2.11|200904091326
3659512|3659512-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@consol.de|Regexp-Log-Common|0.05|i86pc-solaris|5.8.9|solaris|2.11|200904091406
3658482|3658482-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904091119
3658227|3658227-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904091020
3658124|3658124-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Regexp-Log-Common|0.05|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904090302
3658024|3658024-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904090936
3657337|3657337-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904090644
3656237|3656237-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904090253
3655586|3655586-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904090111
3655224|3655224-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904082316
3654557|3654557-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904082319
3654361|3654361-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904082157
3653977|3653977-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Regexp-Log-Common|0.05|alpha-netbsd|5.10.0|netbsd|4.0.1|200904082009
3653387|3653387-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081915
3652738|3652738-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081734
3652623|3652623-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904081823
3651665|3651665-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904081409
3651379|3651379-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.15|amd64-freebsd|5.10.0|freebsd|7.0-release|200904081414
3650952|3650952-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904081226
3650489|3650489-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081102
3649660|3649660-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.15|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904080925
3647159|3647159-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080011
3644953|3644953-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904071924
3644797|3644797-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Regexp-Log-Common|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904072000
3644710|3644710-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904071844
3644474|3644474-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.15|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904071741
3643225|3643225-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071333
3642443|3642443-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071142
3641521|3641521-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904070932
3641139|3641139-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904070826
3639192|3639192-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Regexp-Log-Common|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904070014
3639181|3639181-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Regexp-Log-Common|0.05|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904070013
3637178|3637178-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904062008
3636640|3636640-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Regexp-Log-Common|0.05|amd64-freebsd|5.10.0|freebsd|7.0-release|200904061910
3635724|3635724-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904061505
3634252|3634252-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904061021
3634153|3634153-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904060903
3633771|3633771-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-WWW-Reports-Mailer|0.15|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904060623
3633295|3633295-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904060514
3633282|3633282-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904060510
3633271|3633271-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904060506
3633256|3633256-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904060503
3631922|3631922-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060019
3631741|3631741-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.15|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904052342
3631739|3631739-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.15|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904052342
3631424|3631424-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904052300
3630851|3630851-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.15|i86pc-solaris-64int|5.8.9|solaris|2.11|200904052124
3630768|3630768-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.15|i86pc-solaris-64int|5.10.0|solaris|2.11|200904052102
3628944|3628944-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904051358
3628111|3628111-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051147
3627123|3627123-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.15|amd64-freebsd|5.8.9|freebsd|7.0-release|200904050646
3627120|3627120-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.15|amd64-freebsd|5.8.8|freebsd|7.0-release|200904050646
3626066|3626066-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904050239
3623857|3623857-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904041932
3622782|3622782-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904041716
3622111|3622111-b19f-3f77-b713-d32bba55d77f|cpan|200904|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.15||0|||200904041549
3621387|3621387-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904041402
3621371|3621371-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904041359
3618906|3618906-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904040355
3618100|3618100-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904032310
3615755|3615755-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031419
3614326|3614326-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031035
3612627|3612627-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904030308
3612329|3612329-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030112
3611639|3611639-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904022324
3611634|3611634-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904022323
3611007|3611007-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904022031
3611004|3611004-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904022031
3610701|3610701-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904021832
3608837|3608837-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021305
3608490|3608490-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021155
3608367|3608367-b19f-3f77-b713-d32bba55d77f|pass|200904|robertl@apnic.net ("Robert Loomans")|Test-YAML-Meta|0.11|darwin-2level|5.8.9|darwin|9.6.0|200904021313
3607255|3607255-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904020910
3605564|3605564-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020147
3605482|3605482-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020134
3604730|3604730-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904012307
3604726|3604726-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904012306
3604448|3604448-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904012151
3604442|3604442-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904012150
3604096|3604096-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904012006
3603324|3603324-b19f-3f77-b713-d32bba55d77f|pass|200904|schwern@pobox.com|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200904011345
3599222|3599222-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200903312028
3598463|3598463-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903311753
3596980|3596980-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903311203
3594836|3594836-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.62|i86pc-solaris-64int|5.8.9|solaris|2.11|200903310119
3594733|3594733-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310001
3594464|3594464-b19f-3f77-b713-d32bba55d77f|pass|200903|woody@2143.net|Test-YAML-Meta|0.11|i686-linux|5.8.8|linux|2.6.24-gentoo-r4|200903302215
3593561|3593561-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903302141
3593558|3593558-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903302140
3593537|3593537-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903302133
3589751|3589751-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300039
3587757|3587757-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.62|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903291636
3586929|3586929-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903291315
3586781|3586781-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903291222
3586772|3586772-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903291218
3586768|3586768-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903291217
3585445|3585445-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903290857
3584148|3584148-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-WWW-Statistics|0.62|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290128
3583995|3583995-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903290057
3583904|3583904-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903290132
3582839|3582839-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903282124
3582493|3582493-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.62|i86pc-solaris-64int|5.10.0|solaris|2.11|200903281957
3582191|3582191-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903281839
3582189|3582189-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903281838
3582046|3582046-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.62|amd64-freebsd|5.10.0|freebsd|7.0-release|200903281716
3580876|3580876-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903281401
3580751|3580751-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903281334
3580401|3580401-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281224
3580392|3580392-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Test-CPAN-Meta|0.12|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903280623
3580327|3580327-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903281211
3580325|3580325-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903281210
3580262|3580262-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903281156
3577617|3577617-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903280347
3576650|3576650-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.62|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903272320
3576301|3576301-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903272211
3575772|3575772-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903271907
3575098|3575098-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903271511
3574745|3574745-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.62|amd64-freebsd|5.8.8|freebsd|7.0-release|200903271240
3574375|3574375-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.62|amd64-freebsd|5.8.9|freebsd|7.0-release|200903271139
3574097|3574097-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903271013
3574036|3574036-b19f-3f77-b713-d32bba55d77f|cpan|200903|BARBIE|CPAN-Testers-WWW-Statistics|0.62||0|||200903270956
3573276|3573276-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903270454
3573101|3573101-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903270329
3570724|3570724-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|GD-Chart-Radial|0.07|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903261149
3569987|3569987-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903260651
3568455|3568455-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903260105
3568027|3568027-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903251815
3565712|3565712-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.14|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903251038
3565709|3565709-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903251037
3564410|3564410-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.61|i86pc-solaris-64int|5.10.0|solaris|2.11|200903251053
3563932|3563932-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250433
3563861|3563861-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250425
3563657|3563657-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers|0.49|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250351
3563579|3563579-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250332
3563573|3563573-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250331
3562015|3562015-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.15|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250236
3560642|3560642-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.61|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903242305
3558450|3558450-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.61|amd64-freebsd|5.8.9|freebsd|7.0-release|200903241838
3558445|3558445-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.61|amd64-freebsd|5.8.8|freebsd|7.0-release|200903241838
3556396|3556396-b19f-3f77-b713-d32bba55d77f|cpan|200903|BARBIE|CPAN-Testers-WWW-Statistics|0.61||0|||200903241353
3554299|3554299-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903240901
3553828|3553828-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903240803
3553541|3553541-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903240718
3552315|3552315-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903240336
3549531|3549531-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903231235
3549518|3549518-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903231235
3549515|3549515-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.55|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903231237
3549360|3549360-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903231932
3549121|3549121-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903231525
3549003|3549003-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903231340
3548764|3548764-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232105
3548762|3548762-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232104
3548755|3548755-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232104
3548690|3548690-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232102
3548312|3548312-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232046
3546284|3546284-b19f-3f77-b713-d32bba55d77f|pass|200903|yary@pinky.yary.ack.org ((Yary Hluchan IV))|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi|5.10.0|openbsd|3.9|200903201500
3544917|3544917-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903232004
3544224|3544224-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903231948
3540697|3540697-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|GD-Chart-Radial|0.07|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903221237
3539376|3539376-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903220804
3537472|3537472-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211845
3537078|3537078-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211748
3535225|3535225-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211115
3535224|3535224-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211115
3534524|3534524-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210850
3534522|3534522-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210850
3534519|3534519-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210849
3533501|3533501-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.37|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211116
3533441|3533441-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.36|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211109
3533159|3533159-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|App-Maisha-Plugin-PingFM|0.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211034
3532994|3532994-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.37|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211012
3532954|3532954-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.36|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211003
3532920|3532920-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.35|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903210955
3532869|3532869-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.34|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903210950
3532852|3532852-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-WWW-Testers|0.33|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903210945
3532846|3532846-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903210944
3531694|3531694-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210044
3531332|3531332-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210002
3531330|3531330-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.22|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210002
3531224|3531224-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210349
3530840|3530840-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|CPAN-Testers-WWW-Statistics|0.55|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903210245
3529237|3529237-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201838
3528805|3528805-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201739
3528799|3528799-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201738
3528602|3528602-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|CPAN-Testers-WWW-Reports-Mailer|0.14|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903201625
3528590|3528590-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|CPAN-Testers-Data-Generator|0.35|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903201623
3527350|3527350-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|App-Maisha-Plugin-PingFM|0.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903202024
3524790|3524790-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903201423
3524702|3524702-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.55|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200911
3524517|3524517-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.11|i86pc-solaris-64int|5.8.9|solaris|2.11|200903201348
3524516|3524516-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.10|i86pc-solaris-64int|5.8.9|solaris|2.11|200903201347
3524512|3524512-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200903201347
3524498|3524498-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200845
3524496|3524496-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200845
3524007|3524007-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.14|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200743
3523994|3523994-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.35|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200742
3521854|3521854-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903200129
3521850|3521850-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903200129
3521845|3521845-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903200128
3521830|3521830-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903200125
3521346|3521346-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903200349
3520662|3520662-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903200246
3520657|3520657-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903200246
3519778|3519778-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200000
3519777|3519777-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200000
3519774|3519774-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200000
3519763|3519763-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Mail-File|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192357
3519393|3519393-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192238
3519392|3519392-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192238
3519387|3519387-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192236
3519384|3519384-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192236
3519298|3519298-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903192215
3518275|3518275-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Mail-File|0.08|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191857
3517785|3517785-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-Outlook|0.06|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191739
3517780|3517780-b19f-3f77-b713-d32bba55d77f|fail|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-WebList|0.05|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191739
3517768|3517768-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTP|0.05|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191737
3517758|3517758-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191737
3516000|3516000-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903191406
3515999|3515999-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903191406
3515314|3515314-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190753
3513814|3513814-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Uploads|0.06|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190425
3513751|3513751-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-Article|0.36|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190418
3513637|3513637-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers|0.49|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190400
3513625|3513625-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190358
3513548|3513548-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|App-Maisha-Plugin-PingFM|0.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190350
3510751|3510751-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|App-Maisha|0.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200903181733
3510366|3510366-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903182131
3506643|3506643-b19f-3f77-b713-d32bba55d77f|pass|200903|jafelds@gmail.com|Test-YAML-Meta|0.11|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200903172037
3506276|3506276-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903180919
3506275|3506275-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903180919
3505391|3505391-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903180615
3504877|3504877-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903180423
3503906|3503906-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903180101
3503267|3503267-b19f-3f77-b713-d32bba55d77f|fail|200903|JOST@cpan.org ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.15|i86pc-solaris-64int|5.8.9|solaris|2.11|200903172247
3502813|3502813-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200903172136
3501223|3501223-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Games-Trackword|1.06|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171807
3501221|3501221-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Calendar-List|0.21|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171807
3500826|3500826-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.15|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171240
3499516|3499516-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171542
3499503|3499503-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171541
3495328|3495328-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903170345
3493547|3493547-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903162140
3492946|3492946-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903161940
3492348|3492348-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903161836
3492341|3492341-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903161835
3491221|3491221-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903161605
3489651|3489651-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.06|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903161052
3488907|3488907-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903160815
3488756|3488756-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903160753
3488667|3488667-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160731
3488567|3488567-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160707
3488566|3488566-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160707
3488549|3488549-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903160700
3488253|3488253-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160534
3488068|3488068-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903160436
3487655|3487655-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160318
3486362|3486362-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-WWW-Statistics|0.55|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903151410
3486213|3486213-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152231
3486146|3486146-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152225
3486111|3486111-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers|0.49|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152220
3486105|3486105-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152219
3486069|3486069-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152206
3485314|3485314-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|App-Maisha|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151939
3484069|3484069-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Mail-Outlook|0.15|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151522
3483815|3483815-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Data-Phrasebook-Loader-YAML|0.09|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903150558
3483811|3483811-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Data-Phrasebook|0.29|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903150557
3481955|3481955-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-WWW-Reports-Mailer|0.14|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903150026
3481937|3481937-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-Data-Generator|0.35|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903150021
3477122|3477122-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903150002
3477105|3477105-b19f-3f77-b713-d32bba55d77f|pass|200903|alceu.freitas.jr@gmail.com|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903141200
3477101|3477101-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142359
3477078|3477078-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142357
3477023|3477023-b19f-3f77-b713-d32bba55d77f|fail|200903|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Pearson_Driver|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142354
3476994|3476994-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-ORA_Driver|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142350
3476946|3476946-b19f-3f77-b713-d32bba55d77f|fail|200903|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142347
3476916|3476916-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142343
3476910|3476910-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Regexp-Log-Common|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142343
3476903|3476903-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Parse-CPAN-Distributions|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142343
3476896|3476896-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Mail-File|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142342
3476893|3476893-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Games-Trackword|1.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142342
3476888|3476888-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142341
3476885|3476885-b19f-3f77-b713-d32bba55d77f|fail|200903|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142341
3476867|3476867-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142338
3476864|3476864-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142338
3476855|3476855-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142337
3476851|3476851-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142336
3476825|3476825-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142334
3476817|3476817-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142334
3476813|3476813-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Calendar-List|0.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142334
3476806|3476806-b19f-3f77-b713-d32bba55d77f|fail|200903|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-WebList|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142333
3476758|3476758-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-Outlook|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142326
3476753|3476753-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142325
3476715|3476715-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTP|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903142319
3474985|3474985-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903141529
3474892|3474892-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903141511
3473875|3473875-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903141042
3473871|3473871-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|App-Maisha-Plugin-PingFM|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903141041
3473855|3473855-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|App-Maisha|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903141036
3467328|3467328-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903130148
3466915|3466915-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Mail-Outlook|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903131845
3466266|3466266-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903131637
3465706|3465706-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903130621
3465677|3465677-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903130459
3465296|3465296-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903130506
3461210|3461210-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121540
3459998|3459998-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Games-Trackword|1.06|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121244
3459994|3459994-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Calendar-List|0.21|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121244
3459655|3459655-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121207
3458191|3458191-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Test-CPAN-Meta|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120900
3458188|3458188-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.09|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120859
3458185|3458185-b19f-3f77-b713-d32bba55d77f|fail|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120859
3453831|3453831-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Parse-CPAN-Distributions|0.05|i86pc-solaris-64int|5.8.9|solaris|2.11|200903111723
3453414|3453414-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200903111637
3453413|3453413-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal|0.22|i86pc-solaris-64int|5.8.9|solaris|2.11|200903111637
3452959|3452959-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.30|i86pc-solaris-64int|5.8.9|solaris|2.11|200903111538
3449420|3449420-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Regexp-Log-Common|0.05|i86pc-solaris-64int|5.8.9|solaris|2.11|200903110650
3449072|3449072-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i86pc-solaris-64int|5.8.9|solaris|2.11|200903110559
3449068|3449068-b19f-3f77-b713-d32bba55d77f|fail|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i86pc-solaris-64int|5.8.9|solaris|2.11|200903110559
3443769|3443769-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.55|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101818
3443557|3443557-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101712
3443556|3443556-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook|0.29|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101712
3442091|3442091-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.14|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101249
3442082|3442082-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.35|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101248
3440670|3440670-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903101017
3440661|3440661-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903101016
3440252|3440252-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100933
3440249|3440249-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100933
3440238|3440238-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100932
3440233|3440233-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100931
3439185|3439185-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Mail-Outlook|0.15|amd64-freebsd|5.10.0|freebsd|7.0-release|200903100750
3439119|3439119-b19f-3f77-b713-d32bba55d77f|pass|200903|peter.kerrigan@gmail.com|Test-CPAN-Meta|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903090852
3438176|3438176-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Test-YAML-Meta|0.11|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903100448
3436730|3436730-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|GD-Chart-Radial|0.07|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100307
3435981|3435981-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Test-YAML-Meta|0.11|i86pc-solaris-64int|5.8.9|solaris|2.11|200903100126
3435409|3435409-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Uploads|0.06|i86pc-solaris-64int|5.8.9|solaris|2.11|200903100009
3435303|3435303-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Common-Article|0.36|i86pc-solaris-64int|5.8.9|solaris|2.11|200903092357
3435221|3435221-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200903092349
3434995|3434995-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|App-Maisha-Plugin-PingFM|0.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903092313
3434569|3434569-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-Data-Uploads|0.06|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903091351
3434202|3434202-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-Common-Article|0.36|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903091305
3433976|3433976-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091614
3433975|3433975-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091614
3433972|3433972-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091614
3433952|3433952-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091612
3433787|3433787-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091559
3433333|3433333-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|CPAN-Testers-Common-DBUtils|0.03|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903091126
3433162|3433162-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|App-Maisha|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091942
3432859|3432859-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|App-Maisha-Plugin-PingFM|0.02|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903091025
3431139|3431139-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Mail-Outlook|0.15|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091508
3427200|3427200-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903090737
3427198|3427198-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903090737
3425833|3425833-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903090001
3424113|3424113-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090015
3423404|3423404-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081921
3418406|3418406-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081317
3418402|3418402-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081317
3418162|3418162-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903081801
3417618|3417618-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903081722
3416602|3416602-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081100
3416596|3416596-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081100
3412647|3412647-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080316
3412457|3412457-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080132
3412455|3412455-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080132
3412396|3412396-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080121
3411870|3411870-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903080546
3411136|3411136-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|App-Maisha|0.12|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903080244
3411116|3411116-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080241
3410158|3410158-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071813
3409782|3409782-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071659
3409781|3409781-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071658
3408859|3408859-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903071932
3407196|3407196-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070825
3407091|3407091-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070802
3407090|3407090-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070802
3406770|3406770-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.14|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070654
3406767|3406767-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.35|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070653
3406159|3406159-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070450
3405964|3405964-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Mail-Outlook|0.15|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903070045
3405389|3405389-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.15|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070222
3404983|3404983-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903070124
3404980|3404980-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903070123
3404957|3404957-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Uploads|0.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070120
3404887|3404887-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070113
3404857|3404857-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers|0.49|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070109
3404853|3404853-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070108
3404775|3404775-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070054
3403886|3403886-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070156
3403768|3403768-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070317
3400529|3400529-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|Mail-Outlook|0.15|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903061135
3398457|3398457-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903060947
3398424|3398424-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd|0|OpenBSD|4.4|200903060537
3397318|3397318-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|CPAN-Testers-Data-Uploads|0.06|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903060336
3397032|3397032-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903060253
3394174|3394174-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903052231
3393772|3393772-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903051908
3393771|3393771-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903051908
3392602|3392602-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903051337
3391955|3391955-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903051124
3391954|3391954-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903051124
3391864|3391864-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903051051
3391607|3391607-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050828
3390787|3390787-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903050518
3389683|3389683-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903050242
3387630|3387630-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903042040
3387619|3387619-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903042039
3386698|3386698-b19f-3f77-b713-d32bba55d77f|pass|200903|alfreitas@deloitte.com ("Freitas, Alceu Rodrigues de \\(BR - Sao Paulo\\)")|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903041155
3386624|3386624-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041759
3386620|3386620-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041759
3383286|3383286-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040850
3380733|3380733-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903032339
3379418|3379418-b19f-3f77-b713-d32bba55d77f|pass|200903|MKUTTER@cpan.org ("Martin Kutter")|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200903032102
3378755|3378755-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031706
3376850|3376850-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|CPAN-WWW-Testers|0.49|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200903031149
3376419|3376419-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903030929
3376407|3376407-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903030926
3375934|3375934-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|App-Maisha|0.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200903030841
3375282|3375282-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030007
3375280|3375280-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030006
3375277|3375277-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030006
3375265|3375265-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030003
3375131|3375131-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030415
3374193|3374193-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903022341
3373877|3373877-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Maisha|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200903022347
3373669|3373669-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903022317
3372521|3372521-b19f-3f77-b713-d32bba55d77f|pass|200903|davidrw@cpan.org|CPAN-WWW-Testers|0.49|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200903021435
3371915|3371915-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|App-Maisha|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903021840
3370801|3370801-b19f-3f77-b713-d32bba55d77f|pass|200903|mithaldu@yahoo.de ("Christian Walde")|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903021530
3370677|3370677-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903021406
3370367|3370367-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|App-Maisha|0.12|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903020807
3369549|3369549-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|App-Maisha|0.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200903021119
3366141|3366141-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200903012342
3365991|3365991-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903011811
3365925|3365925-b19f-3f77-b713-d32bba55d77f|pass|200903|alexchorny@gmail.com|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200903011758
3365539|3365539-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903012110
3365402|3365402-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Maisha|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903012053
3365268|3365268-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200903011519
3363704|3363704-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010634
3363702|3363702-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010634
3362089|3362089-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903010613
3361087|3361087-b19f-3f77-b713-d32bba55d77f|pass|200902|alexchorny@gmail.com|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902281506
3360385|3360385-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.24-16-generic|200902281217
3360000|3360000-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200902281044
3359999|3359999-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.24-16-generic|200902281043
3359895|3359895-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.10.0|linux|2.6.24-16-generic|200902281023
3359207|3359207-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|alpha-netbsd|5.10.0|netbsd|4.0.1|200902281336
3359143|3359143-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902281424
3359038|3359038-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902281404
3359008|3359008-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|App-Maisha|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902282059
3358998|3358998-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902281357
3358955|3358955-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902281346
3358921|3358921-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902281340
3358805|3358805-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902281316
3358799|3358799-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902281315
3358744|3358744-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|App-Maisha|0.12|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281306
3358693|3358693-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902281301
3358292|3358292-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902280500
3358225|3358225-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|IP35-irix-64int|5.8.8|irix|6.5|200902281150
3358166|3358166-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902281041
3358160|3358160-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902281039
3358142|3358142-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902281038
3358136|3358136-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902281038
3357831|3357831-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280433
3357384|3357384-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280248
3356813|3356813-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|App-Maisha|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280454
3354476|3354476-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.12||0|||200902271414
3348752|3348752-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200902252333
3348739|3348739-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200902252330
3347622|3347622-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902251932
3347369|3347369-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902251644
3346286|3346286-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250710
3346285|3346285-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250710
3345892|3345892-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.14|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250531
3345883|3345883-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.35|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250530
3345358|3345358-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250339
3343517|3343517-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902250212
3343508|3343508-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902250209
3343504|3343504-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902250207
3343502|3343502-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902250206
3343495|3343495-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902250206
3343493|3343493-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902250205
3343395|3343395-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902250139
3343383|3343383-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902250135
3343378|3343378-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902250134
3343369|3343369-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902250133
3343363|3343363-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902250132
3343359|3343359-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902250131
3342018|3342018-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241917
3341976|3341976-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902241806
3341961|3341961-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902241804
3341960|3341960-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902241804
3341958|3341958-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902241804
3341956|3341956-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902241803
3341953|3341953-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902241803
3341873|3341873-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.15|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241249
3341198|3341198-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Uploads|0.06|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241052
3340992|3340992-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-Article|0.36|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241018
3340924|3340924-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers|0.49|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241006
3340915|3340915-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241005
3340720|3340720-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|App-Maisha-Plugin-PingFM|0.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200902240934
3340624|3340624-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|App-Maisha|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200902240912
3339950|3339950-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902240558
3339948|3339948-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.22|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902240558
3339851|3339851-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902240523
3338679|3338679-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902240427
3337408|3337408-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232257
3337407|3337407-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232256
3337404|3337404-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232255
3337399|3337399-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232255
3337396|3337396-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232254
3337391|3337391-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232253
3337387|3337387-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232252
3337384|3337384-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232252
3337381|3337381-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232251
3337379|3337379-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232251
3337377|3337377-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232250
3337375|3337375-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232250
3337374|3337374-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232250
3337373|3337373-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232249
3337372|3337372-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232249
3337371|3337371-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232248
3337370|3337370-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902232248
3337367|3337367-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232248
3337364|3337364-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232247
3337362|3337362-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902232246
3336906|3336906-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200902231929
3336819|3336819-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902231919
3336358|3336358-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902231655
3335837|3335837-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|App-Maisha-Plugin-PingFM|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902232232
3335769|3335769-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|App-Maisha|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902232227
3335312|3335312-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902231351
3335175|3335175-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902231312
3335053|3335053-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|x86_64-linux-ld|5.10.0|linux|2.6.27-9-generic|200902230643
3335031|3335031-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902231235
3334800|3334800-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902231128
3334517|3334517-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230912
3334513|3334513-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230910
3334511|3334511-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230909
3334503|3334503-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230907
3334501|3334501-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230906
3334498|3334498-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230905
3334495|3334495-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230904
3334490|3334490-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230903
3334482|3334482-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230902
3334477|3334477-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200902230901
3333766|3333766-b19f-3f77-b713-d32bba55d77f|pass|200902|rafl@debian.org|Test-YAML-Meta|0.11|i686-linux|5.10.0 patch 35117|linux|2.6.26|200902230816
3332943|3332943-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902230311
3332755|3332755-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230203
3332751|3332751-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230202
3332748|3332748-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230201
3332740|3332740-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230159
3332738|3332738-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230158
3332736|3332736-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230157
3332734|3332734-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230156
3332733|3332733-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230156
3332729|3332729-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230155
3332725|3332725-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230154
3332721|3332721-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200902230153
3332456|3332456-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200902230040
3332454|3332454-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200902230039
3332321|3332321-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200902222352
3332202|3332202-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha-Plugin-PingFM|0.02|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221830
3332195|3332195-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha-Plugin-PingFM|0.01|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221829
3332178|3332178-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221826
3332173|3332173-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.10|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221826
3332172|3332172-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.09|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221826
3332170|3332170-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.08|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221825
3332168|3332168-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.07|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221825
3332166|3332166-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.06|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221825
3332165|3332165-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.05|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221824
3332163|3332163-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.04|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902221824
3331895|3331895-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Uploads|0.06|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902222247
3331710|3331710-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|App-Maisha|0.11|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902222203
3331555|3331555-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Common-Article|0.36|amd64-freebsd|5.6.2|freebsd|7.0-release|200902222123
3329175|3329175-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200902221047
3329078|3329078-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221019
3329077|3329077-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221019
3329074|3329074-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221017
3329073|3329073-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221017
3329070|3329070-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221016
3329069|3329069-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221016
3329065|3329065-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221014
3329064|3329064-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221013
3329063|3329063-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221012
3329062|3329062-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221012
3329061|3329061-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221011
3329060|3329060-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221011
3329059|3329059-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221010
3329058|3329058-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221010
3329057|3329057-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221009
3329056|3329056-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221009
3329055|3329055-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221008
3329053|3329053-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221008
3329052|3329052-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221007
3329051|3329051-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221007
3329050|3329050-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902221007
3329049|3329049-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200902221006
3327465|3327465-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200902212347
3327169|3327169-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902212242
3327074|3327074-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902212207
3326511|3326511-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902211920
3326437|3326437-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902211924
3326089|3326089-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211524
3326083|3326083-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211523
3326077|3326077-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211522
3326064|3326064-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211519
3326063|3326063-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211518
3326058|3326058-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211517
3326053|3326053-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211516
3326049|3326049-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211515
3326044|3326044-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211514
3326041|3326041-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211513
3326037|3326037-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211512
3326034|3326034-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211511
3326033|3326033-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902211510
3325666|3325666-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902211459
3325648|3325648-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200902211454
3325617|3325617-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902211310
3323902|3323902-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902210117
3323901|3323901-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902210117
3323900|3323900-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902210116
3323896|3323896-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902210115
3323618|3323618-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202220
3323604|3323604-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202218
3323589|3323589-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202217
3323583|3323583-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202215
3323578|3323578-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202214
3323573|3323573-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202214
3323568|3323568-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202213
3323559|3323559-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202211
3323554|3323554-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202211
3323547|3323547-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202209
3323541|3323541-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202208
3323537|3323537-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202207
3323533|3323533-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202206
3323530|3323530-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202206
3323526|3323526-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202205
3323523|3323523-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202205
3323518|3323518-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202204
3323515|3323515-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202204
3323512|3323512-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202203
3323511|3323511-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202203
3323507|3323507-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202202
3323506|3323506-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202202
3323502|3323502-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202201
3323500|3323500-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202201
3323499|3323499-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902202200
3323492|3323492-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202200
3323487|3323487-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202159
3323482|3323482-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202158
3323475|3323475-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202157
3323472|3323472-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902202156
3323455|3323455-b19f-3f77-b713-d32bba55d77f|pass|200902|shlomif@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.29-desktop-0.rc5.1mnb|200902210033
3323453|3323453-b19f-3f77-b713-d32bba55d77f|pass|200902|shlomif@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux|5.10.0|linux|2.6.29-desktop-0.rc5.1mnb|200902210033
3322730|3322730-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902201405
3322421|3322421-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.06|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902201835
3321950|3321950-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|alpha-netbsd|5.10.0|netbsd|4.0.1|200902201528
3321947|3321947-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|IP35-irix-64int|5.8.8|irix|6.5|200902201628
3321913|3321913-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902200917
3321872|3321872-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902201503
3321870|3321870-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902201503
3321863|3321863-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902201503
3321862|3321862-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902201502
3321303|3321303-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.06|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902201211
3321301|3321301-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.05|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902201210
3321300|3321300-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902201209
3321298|3321298-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.06|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902201208
3321296|3321296-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.05|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902201207
3321294|3321294-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902201206
3321293|3321293-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902201206
3321287|3321287-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902201204
3321193|3321193-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200902201102
3321191|3321191-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200902201101
3320605|3320605-b19f-3f77-b713-d32bba55d77f|pass|200902|jeff@zeroclue.com|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200902200031
3320604|3320604-b19f-3f77-b713-d32bba55d77f|pass|200902|jeff@zeroclue.com|Data-Phrasebook|0.29|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200902200030
3320177|3320177-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Generator|0.36|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902200037
3320176|3320176-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Common-Article|0.36|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902200037
3320086|3320086-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|Test-YAML-Meta|0.11|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200902200019
3318966|3318966-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191236
3318960|3318960-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191234
3318957|3318957-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191233
3318954|3318954-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191232
3318950|3318950-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191231
3318948|3318948-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191230
3318944|3318944-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191229
3318942|3318942-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191229
3318941|3318941-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191228
3318940|3318940-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191227
3318938|3318938-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191227
3318936|3318936-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191226
3318933|3318933-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191226
3318931|3318931-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191225
3318930|3318930-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902191225
3318529|3318529-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200902191503
3318523|3318523-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200902191459
3318490|3318490-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902191434
3318486|3318486-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902191431
3318357|3318357-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha-Plugin-PingFM|0.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902190621
3318354|3318354-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha-Plugin-PingFM|0.02|alpha-netbsd|5.10.0|netbsd|4.0.1|200902191220
3318337|3318337-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902191217
3318288|3318288-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902190554
3318285|3318285-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902190553
3318280|3318280-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902190552
3318278|3318278-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902190551
3318248|3318248-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902191109
3318246|3318246-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902191109
3318245|3318245-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902191109
3318244|3318244-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902191109
3318229|3318229-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|alpha-netbsd|5.10.0|netbsd|4.0.1|200902191059
3318226|3318226-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|alpha-netbsd|5.10.0|netbsd|4.0.1|200902191058
3318223|3318223-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|IP35-irix-64int|5.8.8|irix|6.5|200902191158
3318215|3318215-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|alpha-netbsd|5.10.0|netbsd|4.0.1|200902191057
3318213|3318213-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|IP35-irix-64int|5.8.8|irix|6.5|200902191157
3318210|3318210-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|IP35-irix-64int|5.8.8|irix|6.5|200902191156
3318207|3318207-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|IP35-irix-64int|5.8.8|irix|6.5|200902191155
3318196|3318196-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha-Plugin-PingFM|0.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902191054
3318194|3318194-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha-Plugin-PingFM|0.02|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902191054
3318023|3318023-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902190914
3318022|3318022-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902190914
3318020|3318020-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902190914
3318019|3318019-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902190914
3318018|3318018-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902190913
3318016|3318016-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902190913
3318015|3318015-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902190913
3318014|3318014-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902190913
3318008|3318008-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.10|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902190912
3318006|3318006-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.09|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902190911
3318004|3318004-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.08|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902190911
3318003|3318003-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902190911
3317921|3317921-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|App-Maisha|0.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200902190929
3317643|3317643-b19f-3f77-b713-d32bba55d77f|fail|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.04|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902190441
3317472|3317472-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902190404
3317435|3317435-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902190336
3317068|3317068-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902190134
3317008|3317008-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902190125
3316960|3316960-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902190110
3316906|3316906-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902190058
3316879|3316879-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902190057
3316776|3316776-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902190041
3316774|3316774-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902190037
3316772|3316772-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902190033
3316730|3316730-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902190020
3316722|3316722-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902190016
3316652|3316652-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902182352
3316641|3316641-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902182346
3316617|3316617-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902182334
3316612|3316612-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.10|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902182328
3316321|3316321-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200902182229
3316092|3316092-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200902182121
3315786|3315786-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200902181824
3315776|3315776-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200902181821
3315702|3315702-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181738
3315700|3315700-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181737
3315693|3315693-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181733
3315691|3315691-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181733
3315690|3315690-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181733
3315688|3315688-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181731
3315687|3315687-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181731
3315685|3315685-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181729
3315683|3315683-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181727
3315681|3315681-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181727
3315680|3315680-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181726
3315679|3315679-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181725
3315678|3315678-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181725
3315677|3315677-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181724
3315676|3315676-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181724
3315673|3315673-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.07|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181723
3315672|3315672-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181722
3315671|3315671-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181722
3315670|3315670-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181721
3315668|3315668-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181721
3315667|3315667-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181720
3315666|3315666-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181720
3315665|3315665-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181719
3315664|3315664-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181719
3315663|3315663-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181718
3315662|3315662-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181718
3315659|3315659-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181717
3315656|3315656-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181716
3315594|3315594-b19f-3f77-b713-d32bba55d77f|pass|200902|office@darac.org.uk|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200902171029
3315530|3315530-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.11||0|||200902181649
3315524|3315524-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|App-Maisha-Plugin-PingFM|0.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200902181647
3315522|3315522-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|App-Maisha|0.10|i86pc-solaris-64int|5.10.0|solaris|2.11|200902181646
3314683|3314683-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|App-Maisha|0.08|i86pc-solaris-64int|5.10.0|solaris|2.11|200902181121
3313968|3313968-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180139
3313950|3313950-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180134
3313947|3313947-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha-Plugin-PingFM|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180133
3313945|3313945-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180132
3313938|3313938-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180129
3313936|3313936-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180128
3313935|3313935-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180127
3313932|3313932-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180127
3313930|3313930-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180126
3313613|3313613-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Data-Uploads|0.04|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171811
3313602|3313602-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171810
3313600|3313600-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171810
3313597|3313597-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|App-Maisha-Plugin-PingFM|0.01|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171810
3313589|3313589-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|App-Maisha|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171809
3313584|3313584-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|App-Maisha|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171809
3313579|3313579-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|App-Maisha|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171809
3313577|3313577-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|App-Maisha|0.04|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171808
3313575|3313575-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|App-Maisha|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171808
3313572|3313572-b19f-3f77-b713-d32bba55d77f|fail|200902|DCOLLINS@cpan.org|App-Maisha|0.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171808
3313570|3313570-b19f-3f77-b713-d32bba55d77f|fail|200902|DCOLLINS@cpan.org|App-Maisha|0.01|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902171808
3312806|3312806-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Generator|0.36|amd64-freebsd|5.10.0|freebsd|7.0-release|200902172112
3312768|3312768-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-WWW-Testers|0.49|amd64-freebsd|5.10.0|freebsd|7.0-release|200902172103
3312733|3312733-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.10|amd64-freebsd|5.8.8|freebsd|7.0-release|200902172038
3312687|3312687-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha-Plugin-PingFM|0.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200902172038
3312673|3312673-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha-Plugin-PingFM|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200902172037
3312671|3312671-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.10|amd64-freebsd|5.8.9|freebsd|7.0-release|200902172037
3312133|3312133-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171724
3312119|3312119-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171719
3312105|3312105-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|App-Maisha|0.08|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171716
3312099|3312099-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171714
3312097|3312097-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171713
3312094|3312094-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171713
3312089|3312089-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171712
3312086|3312086-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171711
3312069|3312069-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171709
3312064|3312064-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171707
3311935|3311935-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha-Plugin-PingFM|0.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171646
3311846|3311846-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902171029
3311786|3311786-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha-Plugin-PingFM|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902171719
3311781|3311781-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902171017
3311780|3311780-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.08|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902171719
3311779|3311779-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|App-Maisha|0.07|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171616
3311777|3311777-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.06|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902171718
3311776|3311776-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171616
3311772|3311772-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902171717
3311667|3311667-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171550
3311642|3311642-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.10||0|||200902171647
3311637|3311637-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|alpha-netbsd|5.10.0|netbsd|4.0.1|200902171547
3311615|3311615-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha-Plugin-PingFM|0.02||0|||200902171643
3311567|3311567-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.09||0|||200902171638
3311511|3311511-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902171525
3311510|3311510-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902171525
3311458|3311458-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902171512
3311454|3311454-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902171512
3311452|3311452-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902171512
3311444|3311444-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902171510
3311439|3311439-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902170910
3311304|3311304-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200902171434
3311303|3311303-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902171434
3311285|3311285-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902171428
3311283|3311283-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200902171428
3311015|3311015-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.08||0|||200902171407
3310770|3310770-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Uploads|0.06|i86pc-solaris-64int|5.10.0|solaris|2.11|200902171301
3310697|3310697-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.36|i86pc-solaris-64int|5.10.0|solaris|2.11|200902171249
3310695|3310695-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Common-Article|0.36|i86pc-solaris-64int|5.10.0|solaris|2.11|200902171249
3310658|3310658-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171141
3310650|3310650-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171139
3310644|3310644-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|App-Maisha-Plugin-PingFM|0.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200902171238
3310643|3310643-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.06|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171138
3310642|3310642-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|App-Maisha|0.06|i86pc-solaris-64int|5.10.0|solaris|2.11|200902171237
3310640|3310640-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171137
3310637|3310637-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171137
3310634|3310634-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171136
3310632|3310632-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171136
3310629|3310629-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171135
3310527|3310527-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.07||0|||200902171212
3310525|3310525-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|IP35-irix-64int|5.8.8|irix|6.5|200902171212
3310511|3310511-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|IP35-irix-64int|5.8.8|irix|6.5|200902171210
3310423|3310423-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902170457
3310422|3310422-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.06|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902171057
3310419|3310419-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.05|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902171056
3310418|3310418-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902170456
3310241|3310241-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902171119
3310211|3310211-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|IP35-irix-64int|5.8.8|irix|6.5|200902171114
3310210|3310210-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902171013
3310208|3310208-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902171014
3310207|3310207-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|IP35-irix-64int|5.8.8|irix|6.5|200902171113
3310204|3310204-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902171012
3310203|3310203-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902171012
3310171|3310171-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902171104
3310170|3310170-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902171104
3310164|3310164-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902170935
3310113|3310113-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902171052
3310106|3310106-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902171050
3310081|3310081-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.04|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902171043
3310067|3310067-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|IP35-irix-64int|5.8.8|irix|6.5|200902171038
3310065|3310065-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902170937
3310063|3310063-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902170938
3310062|3310062-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902170937
3310059|3310059-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902170937
3310057|3310057-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902170937
3310055|3310055-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902171036
3310033|3310033-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.04|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902171029
3309991|3309991-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.04|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902171016
3309972|3309972-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.06|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902170913
3309971|3309971-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.05|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902170912
3309956|3309956-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.04|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902170910
3309921|3309921-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|App-Maisha-Plugin-PingFM|0.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902171704
3309891|3309891-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|App-Maisha|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902171659
3309833|3309833-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902170949
3309810|3309810-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902170938
3309807|3309807-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902170935
3309806|3309806-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902170934
3309803|3309803-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902170934
3309802|3309802-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902170933
3309783|3309783-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.04|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902170930
3309582|3309582-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha-Plugin-PingFM|0.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902170858
3309571|3309571-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.06|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902170854
3309548|3309548-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha-Plugin-PingFM|0.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200902170839
3309546|3309546-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha-Plugin-PingFM|0.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200902170839
3308015|3308015-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902162336
3308009|3308009-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902162336
3308008|3308008-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902162335
3308001|3308001-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902162335
3307999|3307999-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902162335
3307994|3307994-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902162334
3307905|3307905-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902162317
3307903|3307903-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902162316
3307900|3307900-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902162316
3307896|3307896-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.05|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902162315
3307509|3307509-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902162225
3307240|3307240-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902162109
3306923|3306923-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.06|amd64-freebsd|5.8.8|freebsd|7.0-release|200902161906
3306921|3306921-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Generator|0.36|amd64-freebsd|5.8.8|freebsd|7.0-release|200902161906
3306845|3306845-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Generator|0.36|amd64-freebsd|5.8.9|freebsd|7.0-release|200902161906
3306842|3306842-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.06|amd64-freebsd|5.8.9|freebsd|7.0-release|200902161906
3306773|3306773-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902161847
3306447|3306447-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha-Plugin-PingFM|0.01||0|||200902161716
3306379|3306379-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|App-Maisha|0.04|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902162355
3306087|3306087-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.06||0|||200902161530
3305952|3305952-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.05||0|||200902161422
3305780|3305780-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161238
3305775|3305775-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161237
3305773|3305773-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161236
3305768|3305768-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161235
3305764|3305764-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161234
3305760|3305760-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161234
3305751|3305751-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161231
3305745|3305745-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161229
3305743|3305743-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161228
3305735|3305735-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161228
3305732|3305732-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161227
3305730|3305730-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161226
3305692|3305692-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-WWW-Testers|0.49||0|||200902161317
3305663|3305663-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-Testers-Data-Generator|0.36||0|||200902161309
3305477|3305477-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|CPAN-WWW-Testers|0.48|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200902161212
3305185|3305185-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161019
3305180|3305180-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161018
3305179|3305179-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161017
3305174|3305174-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161016
3305173|3305173-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161015
3305170|3305170-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161015
3305167|3305167-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161014
3304867|3304867-b19f-3f77-b713-d32bba55d77f|fail|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Data-Uploads|0.04|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160419
3304864|3304864-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-Article|0.36|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160418
3304861|3304861-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-DBUtils|0.03|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160418
3304856|3304856-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|Mail-Outlook|0.15|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902160418
3304413|3304413-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160721
3304405|3304405-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160720
3304399|3304399-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160718
3304394|3304394-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160718
3304390|3304390-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160717
3304389|3304389-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160716
3303942|3303942-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.03|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160359
3303633|3303633-b19f-3f77-b713-d32bba55d77f|fail|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Data-Uploads|0.04|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.25(0.15642)|200902160142
3303629|3303629-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.03|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160141
3303624|3303624-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.02|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160141
3303508|3303508-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902160053
3303507|3303507-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902160052
3303506|3303506-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902160052
3303505|3303505-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.04|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902160051
3302990|3302990-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.06|amd64-freebsd|5.8.9|freebsd|7.0-release|200902152236
3302980|3302980-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.06|amd64-freebsd|5.8.8|freebsd|7.0-release|200902152236
3302808|3302808-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.04|amd64-freebsd|5.8.9|freebsd|7.0-release|200902152236
3302790|3302790-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.04|amd64-freebsd|5.8.8|freebsd|7.0-release|200902152236
3302643|3302643-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.06|amd64-freebsd|5.10.0|freebsd|7.0-release|200902152207
3302624|3302624-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Common-Article|0.36|amd64-freebsd|5.10.0|freebsd|7.0-release|200902152207
3302256|3302256-b19f-3f77-b713-d32bba55d77f|pass|200902|sanko@cpan.org ("Sanko Robinson")|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.11.0 patch blead 2009-02-05.22:06:19 c8f794576f0d940fc66e0fc10236a1b54a7e40a3 GitLive-blead-510-gc8f7945|MSWin32|5.1|200902141340
3302160|3302160-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151807
3302154|3302154-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151805
3302152|3302152-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151805
3302150|3302150-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151804
3302148|3302148-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151804
3302125|3302125-b19f-3f77-b713-d32bba55d77f|pass|200902|mithaldu@yahoo.de ("Christian Walde")|CPAN-Testers-Common-DBUtils|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200902142242
3301739|3301739-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.04||0|||200902151742
3301669|3301669-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-Testers-Data-Uploads|0.06||0|||200902151731
3301290|3301290-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.03|alpha-netbsd|5.10.0|netbsd|4.0.1|200902151441
3301096|3301096-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.02|alpha-netbsd|5.10.0|netbsd|4.0.1|200902151339
3301095|3301095-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.03|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902150739
3300979|3300979-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902150709
3300784|3300784-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902151203
3300783|3300783-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.03|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902151204
3300782|3300782-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.03|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902151204
3300781|3300781-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902151204
3300763|3300763-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902151159
3300762|3300762-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902151159
3300761|3300761-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902151159
3300760|3300760-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.02|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902151159
3300758|3300758-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151157
3300745|3300745-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151155
3300743|3300743-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151153
3300741|3300741-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151153
3300736|3300736-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151152
3300667|3300667-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151140
3300662|3300662-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151138
3300660|3300660-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151138
3300659|3300659-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151137
3300657|3300657-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151136
3300567|3300567-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902151058
3300457|3300457-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|App-Maisha|0.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902151117
3300291|3300291-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902151026
3300290|3300290-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902151026
3300269|3300269-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-Testers-Data-Uploads|0.05||0|||200902150959
3299845|3299845-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902150258
3299843|3299843-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902150257
3299842|3299842-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902150257
3299840|3299840-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902150256
3299614|3299614-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902150125
3298972|3298972-b19f-3f77-b713-d32bba55d77f|fail|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Data-Uploads|0.04|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902141742
3298962|3298962-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-Article|0.36|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902141740
3298952|3298952-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902142236
3298948|3298948-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902142235
3298947|3298947-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902142234
3298556|3298556-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|Mail-Outlook|0.15|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902141633
3298554|3298554-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-DBUtils|0.03|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902141633
3298529|3298529-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-Article|0.36|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902141630
3298419|3298419-b19f-3f77-b713-d32bba55d77f|fail|200902|mw487.yahoo.com@gmail.com|App-Maisha|0.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902141600
3298346|3298346-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902142025
3298343|3298343-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902142024
3298342|3298342-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902142024
3298337|3298337-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902142023
3298178|3298178-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|App-Maisha|0.02|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902142040
3297991|3297991-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.03||0|||200902141945
3297758|3297758-b19f-3f77-b713-d32bba55d77f|fail|200902|imacat@mail.imacat.idv.tw|CPAN-Testers-Data-Uploads|0.04|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902150145
3297744|3297744-b19f-3f77-b713-d32bba55d77f|fail|200902|imacat@mail.imacat.idv.tw|App-Maisha|0.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902150142
3297386|3297386-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200902141733
3297385|3297385-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200902141733
3296725|3296725-b19f-3f77-b713-d32bba55d77f|fail|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Uploads|0.04|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902140914
3296710|3296710-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|alpha-netbsd|5.10.0|netbsd|4.0.1|200902141413
3296703|3296703-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-Article|0.36|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902140912
3296658|3296658-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141402
3296652|3296652-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141401
3296529|3296529-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141346
3296517|3296517-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141345
3296510|3296510-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902140744
3296425|3296425-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|IP35-irix-64int|5.8.8|irix|6.5|200902141429
3296415|3296415-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200902141327
3296362|3296362-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902141321
3296359|3296359-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902140721
3296357|3296357-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902141321
3296356|3296356-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902141321
3296355|3296355-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-Data-Uploads|0.04|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902141321
3296284|3296284-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200902141310
3296273|3296273-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200902141308
3296260|3296260-b19f-3f77-b713-d32bba55d77f|fail|200902|vpit@cpan.org|CPAN-Testers-Data-Uploads|0.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902141409
3296257|3296257-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902141409
3296255|3296255-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|App-Maisha|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902141409
3296123|3296123-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.02||0|||200902141315
3296122|3296122-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902141215
3296121|3296121-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902141215
3296118|3296118-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902141214
3296112|3296112-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|App-Maisha|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902141213
3295977|3295977-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141144
3295963|3295963-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141142
3295959|3295959-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141141
3295906|3295906-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141130
3295902|3295902-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141127
3295900|3295900-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141126
3295756|3295756-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.04|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902141148
3295750|3295750-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902141145
3295664|3295664-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.04|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902141120
3295631|3295631-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902141113
3295570|3295570-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Uploads|0.04|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902141102
3295485|3295485-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902141044
3295406|3295406-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan@sourcentral.org ("Oliver Paukstadt")|App-Maisha|0.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902141018
3293390|3293390-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902140345
3292493|3292493-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902140136
3292479|3292479-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902140135
3292467|3292467-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902140134
3292459|3292459-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|App-Maisha|0.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902140133
3290605|3290605-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Uploads|0.04|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902132305
3290439|3290439-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|App-Maisha|0.01|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902132250
3290158|3290158-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902131621
3289641|3289641-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902132039
3289635|3289635-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902132039
3289624|3289624-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902132038
3289614|3289614-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-Data-Uploads|0.04|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902132037
3289453|3289453-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902131328
3289324|3289324-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200902132116
3289262|3289262-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|App-Maisha|0.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200902132109
3289039|3289039-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131446
3287570|3287570-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131228
3286379|3286379-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.04|amd64-freebsd|5.8.9|freebsd|7.0-release|200902131633
3286284|3286284-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|App-Maisha|0.01||0|||200902131648
3286173|3286173-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Uploads|0.04|amd64-freebsd|5.8.8|freebsd|7.0-release|200902131633
3285769|3285769-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Common-Article|0.36|amd64-freebsd|5.8.9|freebsd|7.0-release|200902131540
3285589|3285589-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Common-Article|0.36|amd64-freebsd|5.8.8|freebsd|7.0-release|200902131540
3283955|3283955-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131250
3283539|3283539-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-Testers-Data-Uploads|0.04||0|||200902131317
3283159|3283159-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902131253
3283100|3283100-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902131950
3282781|3282781-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|alpha-netbsd|5.10.0|netbsd|4.0.1|200902131131
3282755|3282755-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902131129
3282748|3282748-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902131129
3282527|3282527-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902131110
3282505|3282505-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902131208
3282482|3282482-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902131206
3282469|3282469-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902131106
3282266|3282266-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902131150
3282178|3282178-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902131142
3282046|3282046-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|IP35-irix-64int|5.8.8|irix|6.5|200902131134
3281925|3281925-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902130428
3281901|3281901-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902131026
3281895|3281895-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902131026
3281852|3281852-b19f-3f77-b713-d32bba55d77f|pass|200902|stro@cpan.org|CPAN-Testers-Common-Article|0.36|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200902131223
3281582|3281582-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130310
3281543|3281543-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902131100
3281321|3281321-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902131044
3281294|3281294-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902131042
3281188|3281188-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902131036
3281118|3281118-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902131031
3281035|3281035-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902131024
3281012|3281012-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902130921
3281002|3281002-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902130918
3280985|3280985-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902131013
3280838|3280838-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-Article|0.36|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902130956
3280521|3280521-b19f-3f77-b713-d32bba55d77f|pass|200902|stro@cpan.org|CPAN-Testers-Common-Article|0.36|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200902131025
3280382|3280382-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-Article|0.36|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902130813
3280280|3280280-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130252
3280097|3280097-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130240
3280069|3280069-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130237
3280043|3280043-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130232
3277837|3277837-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902122357
3277832|3277832-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902122357
3277831|3277831-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902122357
3277829|3277829-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902122356
3277824|3277824-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-Article|0.36|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902122356
3277296|3277296-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Mail-Outlook|0.15|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902122206
3277141|3277141-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902122229
3276437|3276437-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121953
3276312|3276312-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121052
3276084|3276084-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120918
3276046|3276046-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121915
3276045|3276045-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121915
3275224|3275224-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120920
3275100|3275100-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121243
3275099|3275099-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121243
3274975|3274975-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121235
3274972|3274972-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121235
3274952|3274952-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902121233
3274951|3274951-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902121233
3274779|3274779-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Mail-File|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121722
3274039|3274039-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121052
3272314|3272314-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-Testers-Common-Article|0.36||0|||200902121435
3270654|3270654-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Mail-File|0.08|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902120240
3269731|3269731-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121054
3269721|3269721-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121053
3269612|3269612-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Mail-File|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120359
3269140|3269140-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Mail-File|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120234
3269115|3269115-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902121115
3268811|3268811-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902121054
3268618|3268618-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Mail-File|0.08|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902120359
3268585|3268585-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902121037
3268362|3268362-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.15|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902121023
3260158|3260158-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|Mail-Outlook|0.15|amd64-freebsd|5.8.8|freebsd|7.0-release|200902112134
3259888|3259888-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|Mail-Outlook|0.15|amd64-freebsd|5.8.9|freebsd|7.0-release|200902112134
3259349|3259349-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902112003
3258136|3258136-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902111127
3258055|3258055-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902111702
3258054|3258054-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902111702
3258047|3258047-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|alpha-netbsd|5.10.0|netbsd|4.0.1|200902111700
3258042|3258042-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|IP35-irix-64int|5.8.8|irix|6.5|200902111759
3258041|3258041-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902111657
3258040|3258040-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902111657
3258039|3258039-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Mail-Outlook|0.15|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902111657
3257088|3257088-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.55|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111411
3256717|3256717-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111318
3256716|3256716-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111318
3255754|3255754-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902110640
3255422|3255422-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Mail-Outlook|0.15|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111052
3254871|3254871-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902110929
3254605|3254605-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|Mail-Outlook|0.15|i86pc-solaris-64int|5.10.0|solaris|2.11|200902110956
3254512|3254512-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|Mail-Outlook|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902111637
3254339|3254339-b19f-3f77-b713-d32bba55d77f|pass|200902|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Mail-Outlook|0.15|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200902111527
3253720|3253720-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902110157
3252997|3252997-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|Mail-Outlook|0.15||0|||200902110057
3250655|3250655-b19f-3f77-b713-d32bba55d77f|pass|200902|davidp@preshweb.co.uk ("David Precious")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24.2|200902092159
3250492|3250492-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200902101533
3250108|3250108-b19f-3f77-b713-d32bba55d77f|pass|200902|artur+cpan@niif.spb.su (ARTO)|Test-YAML-Meta|0.11|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200902091110
3248609|3248609-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902100647
3247946|3247946-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902100314
3247899|3247899-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902100308
3247452|3247452-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902100148
3247433|3247433-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902100146
3247243|3247243-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.11.0 patch GitLive-blead-571-gabd7186|freebsd|7.0-release|200902100124
3246971|3246971-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902100021
3246651|3246651-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902091855
3246614|3246614-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902091852
3246495|3246495-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902091845
3245565|3245565-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902091650
3245558|3245558-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902091648
3245514|3245514-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902091644
3241468|3241468-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902091457
3236614|3236614-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902090259
3236575|3236575-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902090253
3235170|3235170-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902082255
3234983|3234983-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080333
3234952|3234952-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080332
3234879|3234879-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080334
3234534|3234534-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080335
3234531|3234531-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080333
3234474|3234474-b19f-3f77-b713-d32bba55d77f|pass|200902|myxomatosis@snoogans.org|Test-YAML-Meta|0.11|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.24-16-server|200902080810
3234401|3234401-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080233
3229957|3229957-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200902081016
3229283|3229283-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080327
3229279|3229279-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080327
3229262|3229262-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080326
3229259|3229259-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080325
3229249|3229249-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080324
3229197|3229197-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080319
3229194|3229194-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080319
3229179|3229179-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080317
3229177|3229177-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080317
3229160|3229160-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080316
3228897|3228897-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080248
3228892|3228892-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080247
3228886|3228886-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080246
3228883|3228883-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080246
3228875|3228875-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080245
3228806|3228806-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080238
3228805|3228805-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080238
3228798|3228798-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080237
3228797|3228797-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080236
3228791|3228791-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080236
3228555|3228555-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080211
3228552|3228552-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080209
3228475|3228475-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080155
3228437|3228437-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080148
3226748|3226748-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080003
3226626|3226626-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Calendar-List|0.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071843
3221883|3221883-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.5100@gmail.com|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070835
3221535|3221535-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200902071207
3218664|3218664-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200902070103
3214600|3214600-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902051829
3214289|3214289-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902061230
3214277|3214277-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200902061228
3213971|3213971-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902051832
3213917|3213917-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902061139
3213772|3213772-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902061123
3213324|3213324-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902061016
3213323|3213323-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902061016
3212378|3212378-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902060200
3212374|3212374-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902060159
3209733|3209733-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902051412
3209687|3209687-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902051400
3209536|3209536-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902051335
3209528|3209528-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902051333
3209120|3209120-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902051228
3209024|3209024-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902051217
3209017|3209017-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902051216
3206570|3206570-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902051140
3206562|3206562-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902051134
3206557|3206557-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Generator|0.35|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902051131
3206117|3206117-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200902050957
3204537|3204537-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050319
3204460|3204460-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Games-Trackword|1.06|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902050312
3203518|3203518-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902050127
3202654|3202654-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.48|alpha-netbsd|5.10.0|netbsd|4.0.1|200902050003
3201718|3201718-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902042225
3201320|3201320-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.60|amd64-freebsd|5.10.0|freebsd|7.0-release|200902042257
3198952|3198952-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902041308
3197911|3197911-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-WWW-Testers|0.48|amd64-freebsd|5.10.0|freebsd|7.0-release|200902041311
3197681|3197681-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902041134
3197016|3197016-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.48|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902040936
3196662|3196662-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.47|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902040838
3195484|3195484-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902040230
3195305|3195305-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902040208
3195088|3195088-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902040148
3194762|3194762-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902040101
3194577|3194577-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902040041
3193732|3193732-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.48|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902032251
3193729|3193729-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.48|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902032250
3193723|3193723-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.47|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902032250
3193684|3193684-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902032108
3192969|3192969-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.47|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902032141
3192563|3192563-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.48|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902031510
3192540|3192540-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|CPAN-WWW-Testers|0.47|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902031507
3191873|3191873-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902031929
3191855|3191855-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902031921
3191844|3191844-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902031916
3191837|3191837-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Generator|0.35|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902031914
3191829|3191829-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902031906
3191819|3191819-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Data-Generator|0.35|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902031858
3191557|3191557-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200902031641
3191550|3191550-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200902031639
3191539|3191539-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902031130
3188034|3188034-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers|0.48|i686-linux|5.10.0|linux|2.6.18-4-686|200902030217
3187365|3187365-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902022354
3187359|3187359-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902022353
3187156|3187156-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902022319
3186366|3186366-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-WWW-Testers|0.48||0|||200902022230
3186072|3186072-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902021537
3186053|3186053-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902021534
3185949|3185949-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902022108
3185921|3185921-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Generator|0.35|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902022106
3185393|3185393-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.60|amd64-freebsd|5.8.9|freebsd|7.0-release|200902021857
3185385|3185385-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.60|amd64-freebsd|5.8.8|freebsd|7.0-release|200902021857
3185326|3185326-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902021752
3184811|3184811-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-WWW-Testers|0.47||0|||200902021735
3184401|3184401-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.60|i86pc-solaris-64int|5.10.0|solaris|2.11|200902021625
3184097|3184097-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Test-YAML-Meta|0.11|alpha-netbsd|5.10.0|netbsd|4.0.1|200902021416
3183948|3183948-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Test-YAML-Meta|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902021342
3183820|3183820-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Test-YAML-Meta|0.11|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902021316
3183660|3183660-b19f-3f77-b713-d32bba55d77f|cpan|200902|BARBIE|CPAN-Testers-WWW-Statistics|0.60||0|||200902021333
3183425|3183425-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902021221
3181885|3181885-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902020701
3181883|3181883-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902020700
3181170|3181170-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902020116
3180309|3180309-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|amd64-freebsd|5.10.0|freebsd|7.0-release|200902012250
3180305|3180305-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|CPAN-Testers-Data-Generator|0.35|amd64-freebsd|5.10.0|freebsd|7.0-release|200902012249
3178689|3178689-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902011325
3178688|3178688-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902011325
3178668|3178668-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902011323
3178665|3178665-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902011323
3178652|3178652-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902011321
3178647|3178647-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902011321
3178614|3178614-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902011319
3178611|3178611-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902011319
3178580|3178580-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902011315
3178579|3178579-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902011315
3178567|3178567-b19f-3f77-b713-d32bba55d77f|fail|200902|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.59|amd64-freebsd|5.10.0|freebsd|7.0-release|200902011912
3177029|3177029-b19f-3f77-b713-d32bba55d77f|fail|200902|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.59|amd64-freebsd|5.8.9|freebsd|7.0-release|200902011531
3176873|3176873-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.59|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902011408
3176870|3176870-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.59|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902011408
3176835|3176835-b19f-3f77-b713-d32bba55d77f|fail|200902|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.59|amd64-freebsd|5.8.8|freebsd|7.0-release|200902011456
3176225|3176225-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902011218
3176219|3176219-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902011217
3176217|3176217-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902011217
3176178|3176178-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902011208
3175629|3175629-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902010622
3175622|3175622-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902010620
3175618|3175618-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902010619
3175614|3175614-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902010618
3173864|3173864-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200901312308
3173863|3173863-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200901312307
3173862|3173862-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200901312306
3173817|3173817-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200901312257
3172580|3172580-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-WWW-Statistics|0.59|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311535
3172569|3172569-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-WWW-Statistics|0.58|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311533
3172544|3172544-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-WWW-Statistics|0.57|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311530
3172538|3172538-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-WWW-Statistics|0.56|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311528
3172463|3172463-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311523
3172456|3172456-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311523
3172287|3172287-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.56|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311455
3172286|3172286-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.59|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311458
3172279|3172279-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.58|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311457
3172270|3172270-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-WWW-Statistics|0.57|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311456
3172234|3172234-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311452
3172220|3172220-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Statistics|0.59|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311449
3172210|3172210-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Statistics|0.58|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311446
3172208|3172208-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Statistics|0.57|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311444
3172182|3172182-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-WWW-Statistics|0.56|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311442
3172105|3172105-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.blead@gmail.com|CPAN-Testers-WWW-Statistics|0.59|i686-linux-thread-multi|5.11.0|linux|2.6.24-19-generic|200901311434
3172100|3172100-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311436
3172093|3172093-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.blead@gmail.com|CPAN-Testers-WWW-Statistics|0.58|i686-linux-thread-multi|5.11.0|linux|2.6.24-19-generic|200901311433
3172086|3172086-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.blead@gmail.com|CPAN-Testers-WWW-Statistics|0.57|i686-linux-thread-multi|5.11.0|linux|2.6.24-19-generic|200901311432
3172083|3172083-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.blead@gmail.com|CPAN-Testers-WWW-Statistics|0.56|i686-linux-thread-multi|5.11.0|linux|2.6.24-19-generic|200901311431
3171414|3171414-b19f-3f77-b713-d32bba55d77f|fail|200902|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.59|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902010129
3170952|3170952-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901311558
3170921|3170921-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901311554
3170915|3170915-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901311553
3170914|3170914-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901311552
3170903|3170903-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901311552
3170737|3170737-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901311539
3170719|3170719-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901311537
3170703|3170703-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901311536
3170686|3170686-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901311535
3169457|3169457-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.46|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200901310914
3168973|3168973-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901311214
3168971|3168971-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901311213
3168969|3168969-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901311211
3168968|3168968-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901311210
3168947|3168947-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901311153
3168945|3168945-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.59|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901311155
3168944|3168944-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901311151
3168941|3168941-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901311150
3168571|3168571-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901310514
3168570|3168570-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901310514
3168073|3168073-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310426
3167893|3167893-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901310412
3167885|3167885-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310411
3167849|3167849-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310409
3167818|3167818-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|GD-Chart-Radial|0.07|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901310405
3166461|3166461-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901302221
3166460|3166460-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901302220
3165707|3165707-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-Data-Generator|0.34|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901301215
3165675|3165675-b19f-3f77-b713-d32bba55d77f|pass|200901|alexchorny@gmail.com|Mail-Outlook|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200901301504
3164595|3164595-b19f-3f77-b713-d32bba55d77f|pass|200901|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.35|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200901301158
3164585|3164585-b19f-3f77-b713-d32bba55d77f|pass|200901|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200901301156
3163156|3163156-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Statistics|0.59||0|||200901301421
3162917|3162917-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300955
3162711|3162711-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901301110
3162708|3162708-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901301006
3162702|3162702-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901301109
3162650|3162650-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300955
3162538|3162538-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.14|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901300530
3162518|3162518-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300953
3162411|3162411-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901301006
3162377|3162377-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300955
3162373|3162373-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901301013
3162371|3162371-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901301013
3162297|3162297-b19f-3f77-b713-d32bba55d77f|fail|200901|stsc@refcnt.org ("Steven Schubiger")|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.18-4-686|200901301142
3162287|3162287-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300953
3162227|3162227-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901301024
3162222|3162222-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.14|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901301028
3162220|3162220-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.14|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901301028
3162209|3162209-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901301007
3162205|3162205-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901301006
3162187|3162187-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300955
3162163|3162163-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300953
3162103|3162103-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300955
3162090|3162090-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901300953
3161945|3161945-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.14|alpha-netbsd|5.10.0|netbsd|4.0.1|200901300939
3161867|3161867-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.14|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901300927
3161310|3161310-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.55|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300018
3160706|3160706-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-Data-Generator|0.35|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901300516
3160516|3160516-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300430
3160513|3160513-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300430
3160459|3160459-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901300417
3159773|3159773-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901300130
3159771|3159771-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901300129
3159518|3159518-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901300040
3159420|3159420-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.14|i686-linux|5.10.0|linux|2.6.18-4-686|200901300121
3159382|3159382-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Data-Generator|0.35|i686-linux|5.10.0|linux|2.6.18-4-686|200901300112
3159323|3159323-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901292354
3158015|3158015-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.14|i86pc-solaris-64int|5.10.0|solaris|2.11|200901292237
3158013|3158013-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.35|i86pc-solaris-64int|5.10.0|solaris|2.11|200901292236
3157332|3157332-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.14||0|||200901291331
3157225|3157225-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-Data-Generator|0.35||0|||200901291422
3157165|3157165-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|amd64-freebsd|5.8.8|freebsd|7.0-release|200901291813
3157068|3157068-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-Data-Generator|0.35|amd64-freebsd|5.8.9|freebsd|7.0-release|200901291813
3157067|3157067-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.14|amd64-freebsd|5.8.9|freebsd|7.0-release|200901291813
3157065|3157065-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-Data-Generator|0.35|amd64-freebsd|5.8.8|freebsd|7.0-release|200901291813
3156634|3156634-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.03|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901290813
3156457|3156457-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291517
3156456|3156456-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291517
3155886|3155886-b19f-3f77-b713-d32bba55d77f|fail|200901|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.58|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901291500
3155641|3155641-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901291248
3155640|3155640-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901291247
3155292|3155292-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291035
3155287|3155287-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291035
3155284|3155284-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291034
3155123|3155123-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901290920
3155121|3155121-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901290919
3155103|3155103-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901290903
3155102|3155102-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901290902
3154588|3154588-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290615
3154585|3154585-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290615
3154564|3154564-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290613
3154560|3154560-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290612
3154337|3154337-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901290917
3154231|3154231-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290853
3154223|3154223-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290850
3154143|3154143-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290835
3154061|3154061-b19f-3f77-b713-d32bba55d77f|pass|200901|MKUTTER@cpan.org ("Martin Kutter")|Test-CPAN-Meta|0.12|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200901290920
3153432|3153432-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901290536
3153302|3153302-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290503
3153291|3153291-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290500
3153290|3153290-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290500
3153252|3153252-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290444
3153246|3153246-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290440
3153245|3153245-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290440
3152009|3152009-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200901290205
3151796|3151796-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901290106
3150849|3150849-b19f-3f77-b713-d32bba55d77f|pass|200901|pjacklam@online.no|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200901282306
3150420|3150420-b19f-3f77-b713-d32bba55d77f|pass|200901|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|x86_64-linux-ld|5.10.0|linux|2.6.27-9-generic|200901281527
3149927|3149927-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901281321
3149905|3149905-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901281320
3149903|3149903-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901281319
3149853|3149853-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901281307
3149621|3149621-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200901281225
3147820|3147820-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901280657
3147801|3147801-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200901280649
3147799|3147799-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200901280649
3147767|3147767-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901280645
3145983|3145983-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901280218
3145637|3145637-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.58|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901272244
3145632|3145632-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901272243
3145627|3145627-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901272242
3145359|3145359-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.58|amd64-freebsd|5.10.0|freebsd|7.0-release|200901272326
3144281|3144281-b19f-3f77-b713-d32bba55d77f|pass|200901|alexchorny@gmail.com|Parse-CPAN-Distributions|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200901271302
3143884|3143884-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200901271511
3143881|3143881-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200901271511
3143633|3143633-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901271510
3143632|3143632-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901271509
3142220|3142220-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.58|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901271052
3142207|3142207-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.58|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901271051
3142205|3142205-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.58|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901271052
3142195|3142195-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901271050
3141467|3141467-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200901270609
3141437|3141437-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200901270600
3141436|3141436-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200901270559
3140613|3140613-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901270307
3140527|3140527-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Regexp-Log-Common|0.05|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901270300
3139959|3139959-b19f-3f77-b713-d32bba55d77f|fail|200901|rhaen@cpan.org (Ulrich Habel)|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901270218
3139897|3139897-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901270129
3139891|3139891-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901270129
3139856|3139856-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200901270128
3139855|3139855-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200901270128
3139252|3139252-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901270054
3139209|3139209-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901270048
3138283|3138283-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901262210
3137683|3137683-b19f-3f77-b713-d32bba55d77f|fail|200901|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.58|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901270421
3137224|3137224-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200901261752
3137157|3137157-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901261741
3137128|3137128-b19f-3f77-b713-d32bba55d77f|fail|200901|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.57|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901261837
3137127|3137127-b19f-3f77-b713-d32bba55d77f|fail|200901|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.56|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901261837
3136547|3136547-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.58|i86pc-solaris-64int|5.10.0|solaris|2.11|200901261625
3136426|3136426-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.58|amd64-freebsd|5.8.9|freebsd|7.0-release|200901261532
3136421|3136421-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.58|amd64-freebsd|5.8.8|freebsd|7.0-release|200901261532
3135923|3135923-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.57|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901261232
3135462|3135462-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-WWW-Testers|0.46|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200901261139
3135423|3135423-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Statistics|0.58||0|||200901261122
3135399|3135399-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.56|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901261015
3135398|3135398-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.57|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901261016
3135385|3135385-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.57|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901261007
3135384|3135384-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.56|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901261006
3135381|3135381-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901261004
3135327|3135327-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.57|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901260927
3135325|3135325-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.56|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901260927
3134950|3134950-b19f-3f77-b713-d32bba55d77f|fail|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.57|amd64-freebsd|5.10.0|freebsd|7.0-release|200901260840
3134694|3134694-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901260703
3134690|3134690-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901260702
3133334|3133334-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901260030
3133297|3133297-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901260014
3133209|3133209-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.57|amd64-freebsd|5.8.9|freebsd|7.0-release|200901260008
3133111|3133111-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.57|amd64-freebsd|5.8.8|freebsd|7.0-release|200901260008
3132914|3132914-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.56|amd64-freebsd|5.8.8|freebsd|7.0-release|200901252205
3132897|3132897-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.56|amd64-freebsd|5.8.9|freebsd|7.0-release|200901252205
3132861|3132861-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Statistics|0.57||0|||200901252159
3132344|3132344-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Statistics|0.56||0|||200901251837
3131987|3131987-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-netbsd|5.10.0|netbsd|4.0.1|200901251602
3131984|3131984-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Phrasebook|0.29|alpha-netbsd|5.10.0|netbsd|4.0.1|200901251601
3131323|3131323-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901251228
3131322|3131322-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Phrasebook|0.29|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901251228
3131070|3131070-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901251159
3131068|3131068-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Phrasebook|0.29|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901251159
3129244|3129244-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200901250057
3129243|3129243-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200901250057
3128280|3128280-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200901242122
3128252|3128252-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200901242116
3128236|3128236-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.46|amd64-freebsd|5.10.0|freebsd|7.0-release|200901242107
3127536|3127536-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200901241827
3127534|3127534-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200901241827
3126616|3126616-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901241528
3126615|3126615-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|Data-Phrasebook|0.29|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901241528
3126187|3126187-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200901241337
3126154|3126154-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200901241331
3125449|3125449-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Games-Trackword|1.06|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240914
3125448|3125448-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Calendar-List|0.21|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240914
3123991|3123991-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240111
3121008|3121008-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.46|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901231508
3121007|3121007-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.46|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901231508
3120829|3120829-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.44|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901231522
3120712|3120712-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901231353
3118892|3118892-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.55|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901230916
3118159|3118159-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901230657
3117234|3117234-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901230104
3117233|3117233-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901230104
3117002|3117002-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901222200
3116913|3116913-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901222148
3116496|3116496-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901222131
3114867|3114867-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.46||0|||200901221456
3114825|3114825-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.45||0|||200901221439
3114541|3114541-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.55|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901221402
3114481|3114481-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901221145
3114300|3114300-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-Data-Generator|0.34|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901221035
3114294|3114294-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-WWW-Statistics|0.54|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901221034
3112230|3112230-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.55|amd64-freebsd|5.10.0|freebsd|7.0-release|200901220037
3112126|3112126-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901212313
3112103|3112103-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901212307
3111416|3111416-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.44|amd64-freebsd|5.10.0|freebsd|7.0-release|200901212135
3111325|3111325-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.55|amd64-freebsd|5.8.9|freebsd|7.0-release|200901212102
3110750|3110750-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-WWW-Statistics|0.55|darwin-2level|5.10.0|darwin|9.2.0|200901211022
3110729|3110729-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.55|amd64-freebsd|5.8.8|freebsd|7.0-release|200901211919
3110014|3110014-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901220011
3109560|3109560-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.55|i686-linux|5.10.0|linux|2.6.18-4-686|200901211516
3109435|3109435-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.55|i86pc-solaris-64int|5.10.0|solaris|2.11|200901211512
3109191|3109191-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901210747
3108606|3108606-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.55|alpha-netbsd|5.10.0|netbsd|4.0.1|200901211035
3108310|3108310-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.55|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901210907
3108297|3108297-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.55|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901210905
3108292|3108292-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.55|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901210904
3108005|3108005-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901210805
3107989|3107989-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.55|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901210801
3107740|3107740-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901210647
3107649|3107649-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-WWW-Reports-Mailer|0.13|darwin-2level|5.10.0|darwin|9.2.0|200901210624
3106271|3106271-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901210030
3106268|3106268-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901210030
3105793|3105793-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Statistics|0.55||0|||200901202218
3105536|3105536-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.13|amd64-freebsd|5.10.0|freebsd|7.0-release|200901202122
3105101|3105101-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.13|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901201328
3104430|3104430-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.13|i86pc-solaris-64int|5.10.0|solaris|2.11|200901201737
3103215|3103215-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.44|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901200628
3103212|3103212-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.44|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901201227
3103206|3103206-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.13|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901201227
3103179|3103179-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901201219
3103174|3103174-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901201219
3103090|3103090-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers|0.44|i686-linux|5.10.0|linux|2.6.18-4-686|200901201308
3103032|3103032-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.12|alpha-netbsd|5.10.0|netbsd|4.0.1|200901201202
3102994|3102994-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.13|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901201155
3102818|3102818-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.13|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901200520
3102817|3102817-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.13|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901201119
3102815|3102815-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.13|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901201119
3102812|3102812-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.12|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901201119
3102808|3102808-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901201119
3102763|3102763-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901200506
3102762|3102762-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901201105
3102758|3102758-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901201105
3102664|3102664-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.13|i686-linux|5.10.0|linux|2.6.18-4-686|200901201141
3102555|3102555-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201009
3102550|3102550-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201008
3102529|3102529-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201004
3102442|3102442-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901200944
3100337|3100337-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Test-YAML-Meta|0.11|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901200022
3099844|3099844-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901191822
3099356|3099356-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.13|amd64-freebsd|5.8.9|freebsd|7.0-release|200901192252
3099354|3099354-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.13|amd64-freebsd|5.8.8|freebsd|7.0-release|200901192252
3098688|3098688-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.13||0|||200901192108
3097789|3097789-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901191838
3097710|3097710-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901191833
3097621|3097621-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901191827
3097561|3097561-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901191820
3097549|3097549-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.54|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901191922
3097545|3097545-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901191921
3097468|3097468-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901191814
3097406|3097406-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901191807
3097326|3097326-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901191751
3097272|3097272-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200901191810
3097194|3097194-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901191839
3096998|3096998-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901191817
3096967|3096967-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200901191810
3096412|3096412-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.11|i686-linux|5.10.0|linux|2.6.18-4-686|200901191637
3095709|3095709-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200901191507
3095461|3095461-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901190809
3095281|3095281-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.44||0|||200901191324
3095212|3095212-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.12||0|||200901191313
3094905|3094905-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-WWW-Testers|0.43|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200901191224
3094834|3094834-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.11|alpha-netbsd|5.10.0|netbsd|4.0.1|200901191107
3094832|3094832-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901191107
3094825|3094825-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|alpha-netbsd|5.10.0|netbsd|4.0.1|200901191106
3094791|3094791-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901190459
3094529|3094529-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Mail-Outlook|0.14|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901191001
3094287|3094287-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901190859
3094282|3094282-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901190859
3094279|3094279-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.11|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901190859
3094277|3094277-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901190859
3094276|3094276-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901190859
3094055|3094055-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Mailer|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901191618
3093856|3093856-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200901190829
3093854|3093854-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200901190829
3093794|3093794-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901190719
3093793|3093793-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901190719
3092512|3092512-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.8.9|mirbsd|10|200901182356
3091968|3091968-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.11||0|||200901182252
3091952|3091952-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-Data-Generator|0.34|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901181647
3091946|3091946-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901181646
3090779|3090779-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.18-4-686|200901181857
3090767|3090767-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.18-4-686|200901181855
3090754|3090754-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.18-4-686|200901181852
3090542|3090542-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.18-4-686|200901181824
3089291|3089291-b19f-3f77-b713-d32bba55d77f|fail|200901|vrurg@otoib.dp.ua|Finance-Currency-Convert-XE|0.15|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200901161558
3089176|3089176-b19f-3f77-b713-d32bba55d77f|pass|200901|nothingmuch@woobling.org|CPAN-WWW-Testers|0.43|darwin-2level|5.10.0|darwin|9.5.0|200901172112
3088656|3088656-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.10.0|linux|2.6.18-4-686|200901181423
3088644|3088644-b19f-3f77-b713-d32bba55d77f|fail|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.10.0|linux|2.6.18-4-686|200901181420
3088610|3088610-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.10.0|linux|2.6.18-4-686|200901181416
3088598|3088598-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.10.0|linux|2.6.18-4-686|200901181413
3087765|3087765-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901180958
3083718|3083718-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200901171827
3080417|3080417-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200901170117
3079417|3079417-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200901162015
3076616|3076616-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901160836
3074438|3074438-b19f-3f77-b713-d32bba55d77f|fail|200901|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901160600
3072714|3072714-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.43|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200901150921
3072052|3072052-b19f-3f77-b713-d32bba55d77f|pass|200901|sartak@gmail.com|Test-YAML-Meta|0.11|darwin-2level|5.8.8|darwin|9.5.0|200901141112
3071547|3071547-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901150807
3071483|3071483-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901150741
3069852|3069852-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.43|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901150043
3069155|3069155-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901142144
3069112|3069112-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901141303
3068593|3068593-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.43|amd64-freebsd|5.10.0|freebsd|7.0-release|200901142008
3068541|3068541-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.54|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901141955
3067194|3067194-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.43|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901140813
3067063|3067063-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.43|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901141311
3067002|3067002-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.43|i686-linux|5.8.8|linux|2.4.27-3-686|200901141253
3066688|3066688-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901141136
3066502|3066502-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.54|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200901141222
3066501|3066501-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-Data-Generator|0.34|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200901141222
3064369|3064369-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901140020
3064315|3064315-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-WWW-Statistics|0.54|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901140007
3063820|3063820-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.43||0|||200901132314
3061634|3061634-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901131428
3061485|3061485-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200901131117
3061455|3061455-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901131404
3061296|3061296-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.54|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901132141
3060302|3060302-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.54|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901131057
3060061|3060061-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.54|i686-linux|5.8.8|linux|2.4.27-3-686|200901130959
3060051|3060051-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.54|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901130957
3057036|3057036-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901130041
3056785|3056785-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901122356
3056591|3056591-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.54|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901130118
3056556|3056556-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|CPAN-Testers-Data-Generator|0.34|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901130110
3056486|3056486-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.34|i86pc-solaris-64int|5.10.0|solaris|2.11|200901130019
3056482|3056482-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.54|i86pc-solaris-64int|5.10.0|solaris|2.11|200901130019
3055683|3055683-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901122053
3055678|3055678-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901122053
3055603|3055603-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901122044
3055593|3055593-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901122044
3055586|3055586-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901122043
3055572|3055572-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901122041
3055184|3055184-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901122057
3055157|3055157-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901122056
3054740|3054740-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-Data-Generator|0.34|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901122013
3054109|3054109-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901121754
3053826|3053826-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901121717
3053530|3053530-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.54|amd64-freebsd|5.10.0|freebsd|7.0-release|200901121724
3053529|3053529-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-Data-Generator|0.34|amd64-freebsd|5.10.0|freebsd|7.0-release|200901121724
3053474|3053474-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901121613
3052765|3052765-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.54|amd64-freebsd|5.8.9|freebsd|7.0-release|200901121515
3052764|3052764-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-Data-Generator|0.34|amd64-freebsd|5.8.9|freebsd|7.0-release|200901121515
3052676|3052676-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-Data-Generator|0.34|amd64-freebsd|5.8.8|freebsd|7.0-release|200901121458
3052675|3052675-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.54|amd64-freebsd|5.8.8|freebsd|7.0-release|200901121458
3052585|3052585-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901121336
3052403|3052403-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-WWW-Testers|0.42|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200901121355
3052324|3052324-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-WWW-Statistics|0.54||0|||200901121338
3052213|3052213-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-Testers-Data-Generator|0.34||0|||200901121310
3051861|3051861-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901121024
3050831|3050831-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901120708
3049557|3049557-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|GD-Chart-Radial|0.07|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901120241
3049536|3049536-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901120227
3048751|3048751-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901120112
3048746|3048746-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-FormValidator-Constraints-Words|0.03|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901120111
3048558|3048558-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901112336
3048441|3048441-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112312
3048439|3048439-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112311
3048438|3048438-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112311
3048436|3048436-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112311
3048434|3048434-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112310
3048419|3048419-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112306
3048141|3048141-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112155
3048132|3048132-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112154
3047350|3047350-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901111947
3046764|3046764-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111246
3046760|3046760-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111246
3046740|3046740-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Mail-File|0.08|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111242
3046582|3046582-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111210
3046581|3046581-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111209
3046184|3046184-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901111641
3046183|3046183-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901111640
3044186|3044186-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901110105
3043869|3043869-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901110329
3043867|3043867-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901110329
3043456|3043456-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.42|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200901110009
3043328|3043328-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200901102344
3043223|3043223-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.42|i686-linux|5.8.8|linux|2.4.27-3-686|200901102326
3043218|3043218-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.42|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901101727
3043216|3043216-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.42|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901102327
3043214|3043214-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|IP35-irix|5.8.8|irix|6.5|200901110027
3041170|3041170-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901101516
3039409|3039409-b19f-3f77-b713-d32bba55d77f|pass|200901|nothingmuch@woobling.org|CPAN-Testers-Common-DBUtils|0.03|darwin-2level|5.10.0|darwin|9.5.0|200901100653
3039279|3039279-b19f-3f77-b713-d32bba55d77f|pass|200901|nothingmuch@woobling.org|CPAN-WWW-Testers|0.42|darwin-2level|5.10.0|darwin|9.5.0|200901100655
3036271|3036271-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.42|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200901100032
3036265|3036265-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.41|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200901100031
3036037|3036037-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.42|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901100047
3035215|3035215-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901092059
3034843|3034843-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.42|amd64-freebsd|5.10.0|freebsd|7.0-release|200901092147
3034228|3034228-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901091939
3034224|3034224-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901091938
3032625|3032625-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901091552
3032431|3032431-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.42||0|||200901091513
3031482|3031482-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901090847
3031481|3031481-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901090847
3031239|3031239-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.41|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901090309
3030035|3030035-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-FormValidator-Constraints-Words|0.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901090039
3029345|3029345-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901090424
3028567|3028567-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901090056
3028344|3028344-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901090028
3027881|3027881-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.41|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901082327
3027375|3027375-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901082257
3026466|3026466-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.41|i686-linux|5.8.8|linux|2.4.27-3-686|200901081928
3025994|3025994-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Games-Trackword|1.06|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081229
3025992|3025992-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Calendar-List|0.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081229
3025648|3025648-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers|0.41|i86pc-solaris-64int|5.10.0|solaris|2.11|200901081745
3025030|3025030-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Test-CPAN-Meta|0.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080847
3024969|3024969-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers|0.41|i686-linux|5.10.0|linux|2.6.18-4-686|200901081408
3024800|3024800-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-WWW-Testers|0.41|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200901081308
3024678|3024678-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers|0.41|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901081929
3024207|3024207-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901080419
3023770|3023770-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901080733
3023768|3023768-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901080733
3023762|3023762-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901080731
3023761|3023761-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901080730
3022226|3022226-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.41|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901080133
3021967|3021967-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.41|amd64-freebsd|5.8.9|freebsd|7.0-release|200901080049
3021963|3021963-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.41|amd64-freebsd|5.8.8|freebsd|7.0-release|200901080049
3021922|3021922-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.41|amd64-freebsd|5.10.0|freebsd|7.0-release|200901080044
3021277|3021277-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200901072221
3021245|3021245-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200901072214
3021074|3021074-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.41||0|||200901072251
3020365|3020365-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901072005
3017356|3017356-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901070607
3017208|3017208-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901070531
3017206|3017206-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901070531
3016304|3016304-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901070852
3015833|3015833-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901070742
3015335|3015335-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901070452
3015333|3015333-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901070451
3013964|3013964-b19f-3f77-b713-d32bba55d77f|pass|200901|amoore@cpan.org|Test-YAML-Meta|0.11|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.26-1-vserver-amd64|200901061008
3013566|3013566-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Mail-Outlook|0.14|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061752
3013549|3013549-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Parse-CPAN-Distributions|0.05|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061748
3013520|3013520-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901062244
3013518|3013518-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901062243
3013455|3013455-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901062234
3012503|3012503-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061533
3012502|3012502-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|WWW-UsePerl-Journal|0.22|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061533
3011998|3011998-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers-Generator|0.30|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061441
3010831|3010831-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061258
3010830|3010830-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s1@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061257
3010752|3010752-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061247
3010751|3010751-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061247
3010213|3010213-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901061652
3009249|3009249-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901061508
3008773|3008773-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901061419
3007965|3007965-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901060731
3007927|3007927-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901060724
3007333|3007333-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-WWW-Testers|0.40|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200901061159
3007306|3007306-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200901061152
3006476|3006476-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901060830
3006475|3006475-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901060829
3006161|3006161-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901060729
3006158|3006158-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901060729
3006030|3006030-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901060709
3006028|3006028-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901060709
3005832|3005832-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901060635
3005830|3005830-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901060634
3003872|3003872-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Regexp-Log-Common|0.05|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901060213
3003818|3003818-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901060302
3003229|3003229-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901060103
3002998|3002998-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901060036
3002477|3002477-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901052348
3002307|3002307-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901052342
3001676|3001676-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901052349
3000184|3000184-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901051929
3000181|3000181-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901051929
2998257|2998257-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901050944
2998256|2998256-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901050944
2997269|2997269-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901051203
2995860|2995860-b19f-3f77-b713-d32bba55d77f|pass|200901|vutral@gmail.com|Test-YAML-Meta|0.11|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.26-1-vserver-amd64|200901042304
2995350|2995350-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901050311
2995349|2995349-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901050311
2995223|2995223-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901050233
2995222|2995222-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-Phrasebook|0.29|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901050233
2994663|2994663-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.40|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901050039
2994651|2994651-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.39|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901050037
2994621|2994621-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901050031
2994413|2994413-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.33|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901042351
2994379|2994379-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901042347
2994362|2994362-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.33|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901041741
2994357|2994357-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901041740
2994221|2994221-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901042316
2993878|2993878-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.33|i86pc-solaris-64int|5.10.0|solaris|2.11|200901042341
2993691|2993691-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.33|IP35-irix-64int|5.8.8|irix|6.5|200901042254
2993680|2993680-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|IP35-irix-64int|5.8.8|irix|6.5|200901042252
2993675|2993675-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.40|i686-linux|5.8.8|linux|2.4.27-3-686|200901042150
2993481|2993481-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-WWW-Testers|0.39|i686-linux|5.8.8|linux|2.4.27-3-686|200901042131
2993437|2993437-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901041626
2993323|2993323-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers|0.40|i86pc-solaris-64int|5.10.0|solaris|2.11|200901042234
2993162|2993162-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041603
2993111|2993111-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Data-Generator|0.33|i686-linux|5.8.8|linux|2.4.27-3-686|200901042100
2993077|2993077-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041558
2993062|2993062-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.8.8|linux|2.4.27-3-686|200901042057
2991475|2991475-b19f-3f77-b713-d32bba55d77f|fail|200901|altblue@gmail.com ("Marius Feraru")|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux-ld|5.11.0 patch 34814|linux|2.6.18-8.1.14.el5|200901041832
2991460|2991460-b19f-3f77-b713-d32bba55d77f|pass|200901|altblue@gmail.com ("Marius Feraru")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux-ld|5.11.0 patch 34814|linux|2.6.18-8.1.14.el5|200901041830
2989637|2989637-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901041530
2989635|2989635-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901041530
2988314|2988314-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200901040912
2986882|2986882-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-WWW-Testers|0.40|darwin-2level|5.10.0|darwin|9.2.0|200901040031
2986704|2986704-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901032335
2986701|2986701-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901032335
2986563|2986563-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901032310
2986559|2986559-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901032309
2984710|2984710-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901031329
2984650|2984650-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901031319
2984643|2984643-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901031318
2984608|2984608-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901031313
2984080|2984080-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200901031524
2984078|2984078-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200901031524
2983710|2983710-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901030843
2982966|2982966-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901031149
2982873|2982873-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200901031122
2981194|2981194-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901020117
2981114|2981114-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901030148
2981086|2981086-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0 RC2|linux|2.6.24-19-generic|200901030143
2980827|2980827-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0 RC1|linux|2.6.24-19-generic|200901030116
2980722|2980722-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901021030
2980617|2980617-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-Common-DBUtils|0.03|darwin-2level|5.10.0|darwin|9.2.0|200901030050
2980608|2980608-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901030032
2980412|2980412-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901021030
2980369|2980369-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901020117
2980094|2980094-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901030006
2979957|2979957-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901021832
2979956|2979956-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901021831
2979486|2979486-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200901022053
2979455|2979455-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200901022046
2979453|2979453-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200901022045
2979177|2979177-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.18.8|200901021459
2979175|2979175-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.18.8|200901021459
2978757|2978757-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.18.8|200901021413
2978618|2978618-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901021900
2978615|2978615-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901021900
2977436|2977436-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901021133
2977433|2977433-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901021132
2977401|2977401-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901021128
2977381|2977381-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901021126
2976844|2976844-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901021029
2976839|2976839-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901021029
2976598|2976598-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200901021440
2976559|2976559-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200901021432
2976393|2976393-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901021351
2976207|2976207-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers|0.40|i686-linux|5.10.0|linux|2.6.18-4-686|200901021403
2975964|2975964-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers|0.40|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901021918
2975765|2975765-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901020240
2975759|2975759-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPAN-WWW-Testers|0.40|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200901021006
2975632|2975632-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.40|amd64-freebsd|5.8.9|freebsd|7.0-release|200901020836
2975507|2975507-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.40|amd64-freebsd|5.8.8|freebsd|7.0-release|200901020836
2974898|2974898-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901020212
2974754|2974754-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.40|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-k7|200901020036
2974607|2974607-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901011730
2974516|2974516-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901020241
2974399|2974399-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Test-CPAN-Meta|0.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-k7|200901020045
2974286|2974286-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.39|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-k7|200901020025
2974135|2974135-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901011730
2974090|2974090-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0 RC2|linux|2.6.24-19-generic|200901011500
2974057|2974057-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901011733
2973903|2973903-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901020212
2973859|2973859-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901020142
2973768|2973768-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0 RC2|linux|2.6.24-19-generic|200901020056
2973626|2973626-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-k7|200901020022
2973610|2973610-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-WWW-Testers|0.37|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-k7|200901020017
2973579|2973579-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Parse-CPAN-Distributions|0.05|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-k7|200901020012
2973465|2973465-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0 RC1|linux|2.6.24-19-generic|200901011842
2973332|2973332-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901011745
2973303|2973303-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901011733
2973046|2973046-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901011411
2972624|2972624-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200901020050
2972299|2972299-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200901012342
2972154|2972154-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010228
2972024|2972024-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.40|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901012345
2971872|2971872-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|CPAN-WWW-Testers|0.40|amd64-freebsd|5.10.0|freebsd|7.0-release|200901012301
2971793|2971793-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901010421
2971676|2971676-b19f-3f77-b713-d32bba55d77f|cpan|200901|BARBIE|CPAN-WWW-Testers|0.40||0|||200901012155
2971370|2971370-b19f-3f77-b713-d32bba55d77f|pass|200812|CPAN.DCOLLINS@comcast.net|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200812311752
2971253|2971253-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.10|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901012012
2970603|2970603-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010010
2970572|2970572-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010350
2970387|2970387-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010138
2970266|2970266-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@herlpacker.co.uk|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200901011620
2970244|2970244-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010228
2970229|2970229-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010220
2970228|2970228-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010220
2970006|2970006-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010010
2969991|2969991-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010006
2969977|2969977-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010001
2969883|2969883-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901010421
2969791|2969791-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010348
2969610|2969610-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901010237
2969405|2969405-b19f-3f77-b713-d32bba55d77f|pass|200901|CPAN.DCOLLINS@comcast.net|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901010105
2969353|2969353-b19f-3f77-b713-d32bba55d77f|pass|200812|CPAN.DCOLLINS@comcast.net|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200812311752
2969173|2969173-b19f-3f77-b713-d32bba55d77f|pass|200812|cpanblead@example.com ((cpanblead))|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200812311538
2968744|2968744-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Data-Generator|0.33|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901011542
2966905|2966905-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901010735
2966904|2966904-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901010735
2966873|2966873-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901010727
2966872|2966872-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901010726
2965720|2965720-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901010222
2965711|2965711-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901010220
2965403|2965403-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901010227
2965397|2965397-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901010226
2965152|2965152-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901010037
2965151|2965151-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901010037
2964991|2964991-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901010106
2964988|2964988-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901010106
2964901|2964901-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901010044
2964894|2964894-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901010043
2964830|2964830-b19f-3f77-b713-d32bba55d77f|pass|200812|CPAN.DCOLLINS@comcast.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200812311140
2962836|2962836-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812311618
2962835|2962835-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812311618
2962485|2962485-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.10.0|freebsd|7.0-release|200812311342
2962484|2962484-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.10.0|freebsd|7.0-release|200812311342
2962257|2962257-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812311141
2962226|2962226-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200812311127
2962225|2962225-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200812311127
2962224|2962224-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812311125
2961998|2961998-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812310725
2961996|2961996-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812310725
2961992|2961992-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812310722
2961991|2961991-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812310722
2961960|2961960-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812310654
2961959|2961959-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812310653
2961937|2961937-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812310651
2961936|2961936-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812310650
2961375|2961375-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812310336
2961288|2961288-b19f-3f77-b713-d32bba55d77f|pass|200812|davidrw@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200812301413
2961120|2961120-b19f-3f77-b713-d32bba55d77f|pass|200812|davidrw@cpan.org|Test-YAML-Meta|0.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200812301537
2959270|2959270-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200812301425
2958555|2958555-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|CPAN-Testers-Data-Generator|0.33|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200812301113
2957248|2957248-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812300632
2957162|2957162-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812300558
2956435|2956435-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812300221
2956434|2956434-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812300220
2956320|2956320-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812300147
2956318|2956318-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812300146
2955596|2955596-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.33|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812292255
2955545|2955545-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.33|amd64-freebsd|5.10.0|freebsd|7.0-release|200812292156
2955276|2955276-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.33|amd64-freebsd|5.8.9|freebsd|7.0-release|200812292137
2955070|2955070-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.33|amd64-freebsd|5.8.8|freebsd|7.0-release|200812292041
2954945|2954945-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-Data-Generator|0.33||0|||200812292011
2954898|2954898-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Trackword|1.06|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812291948
2954895|2954895-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Calendar-List|0.21|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812291947
2953095|2953095-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|CPAN-WWW-Testers|0.39|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200812291159
2953071|2953071-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|CPAN-Testers-Common-DBUtils|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200812291153
2952894|2952894-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-WWW-Testers|0.39|i686-linux|5.10.0|linux|2.6.18-4-686|200812291111
2952691|2952691-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-WWW-Testers|0.39|amd64-freebsd|5.8.9|freebsd|7.0-release|200812291001
2952690|2952690-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-WWW-Testers|0.39|amd64-freebsd|5.8.8|freebsd|7.0-release|200812291000
2952186|2952186-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812290717
2951803|2951803-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812290447
2951567|2951567-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812290233
2951565|2951565-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812290232
2951543|2951543-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290219
2951542|2951542-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290219
2951541|2951541-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290217
2951539|2951539-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290216
2951538|2951538-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290216
2951537|2951537-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290216
2951536|2951536-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|GD-Chart-Radial|0.07|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290216
2951535|2951535-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290215
2951534|2951534-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290215
2951533|2951533-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290215
2951532|2951532-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290215
2951531|2951531-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290215
2951530|2951530-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290214
2951529|2951529-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290214
2951527|2951527-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290214
2951524|2951524-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290213
2951522|2951522-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812290211
2951098|2951098-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-WWW-Testers|0.39|amd64-freebsd|5.10.0|freebsd|7.0-release|200812290003
2950893|2950893-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-WWW-Testers|0.39||0|||200812282251
2950588|2950588-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812282131
2948887|2948887-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.10|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812281359
2946292|2946292-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Mailer|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812281359
2946253|2946253-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-DBUtils|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812281353
2945386|2945386-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812280434
2945298|2945298-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200812280325
2943675|2943675-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812280009
2942633|2942633-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Test-YAML-Meta|0.11|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812271951
2941799|2941799-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200812271557
2941747|2941747-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200812271547
2941430|2941430-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200812271545
2941402|2941402-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200812271541
2941195|2941195-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812271506
2941194|2941194-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812271506
2938630|2938630-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812262244
2938606|2938606-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812262237
2938358|2938358-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200812262045
2936769|2936769-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.18-4-686|200812261634
2936032|2936032-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200812261147
2935787|2935787-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812261050
2935751|2935751-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812261043
2935671|2935671-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812261034
2935235|2935235-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812261011
2935195|2935195-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812261004
2935170|2935170-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812261001
2935156|2935156-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812260958
2934745|2934745-b19f-3f77-b713-d32bba55d77f|pass|200812|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-DBUtils|0.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200812260018
2934099|2934099-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200812252335
2933310|2933310-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200812251642
2932930|2932930-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812251252
2932449|2932449-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200812251116
2932298|2932298-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812251051
2927850|2927850-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812241513
2927823|2927823-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200812241509
2927781|2927781-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812241459
2927342|2927342-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812241303
2926513|2926513-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812240457
2926459|2926459-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812240912
2919650|2919650-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812231550
2919643|2919643-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812231551
2918307|2918307-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812231252
2913677|2913677-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230023
2913676|2913676-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230023
2913675|2913675-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230023
2913674|2913674-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230023
2913618|2913618-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230011
2911545|2911545-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200812221827
2911541|2911541-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200812221826
2911506|2911506-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200812221818
2911502|2911502-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200812221818
2909190|2909190-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.32|i86pc-solaris-64int|5.10.0|solaris|2.11|200812221147
2909183|2909183-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812221028
2908483|2908483-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200812220831
2908479|2908479-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200812220831
2908354|2908354-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200812220814
2908347|2908347-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200812220813
2905973|2905973-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812220153
2905470|2905470-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812220030
2905000|2905000-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812212321
2904998|2904998-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812212321
2904269|2904269-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211649
2903811|2903811-b19f-3f77-b713-d32bba55d77f|pass|200812|rafl@debian.org|Test-CPAN-Meta|0.12|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200812212108
2902906|2902906-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211152
2902904|2902904-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211152
2901880|2901880-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210932
2901088|2901088-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812211227
2900304|2900304-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812211059
2900299|2900299-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812211059
2899912|2899912-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812211031
2899909|2899909-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812211030
2899463|2899463-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210448
2898276|2898276-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.14|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210148
2897855|2897855-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210055
2897854|2897854-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210054
2897806|2897806-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210042
2896094|2896094-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210017
2896092|2896092-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210017
2895952|2895952-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210003
2895467|2895467-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812202254
2895465|2895465-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Data-Phrasebook|0.29|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812202254
2895353|2895353-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812201741
2892496|2892496-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812201710
2892494|2892494-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812201710
2892492|2892492-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812201710
2892447|2892447-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Regexp-Log-Common|0.05|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812201703
2891823|2891823-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.10|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812201045
2891436|2891436-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812201502
2891435|2891435-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812201501
2891434|2891434-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812201501
2891368|2891368-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812201456
2891359|2891359-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812201456
2891355|2891355-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812201456
2890852|2890852-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.32|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200916
2890849|2890849-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200916
2890325|2890325-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202129
2890313|2890313-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202127
2890278|2890278-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812201318
2890259|2890259-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202114
2890257|2890257-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Regexp-Log-Common|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202114
2890254|2890254-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Mail-Outlook|0.14|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202113
2890253|2890253-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Mail-File|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202113
2890251|2890251-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Games-Trackword|1.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202113
2890248|2890248-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202112
2890242|2890242-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202110
2890236|2890236-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202109
2890233|2890233-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202109
2890232|2890232-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202108
2890218|2890218-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202106
2890215|2890215-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202106
2890213|2890213-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Calendar-List|0.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202106
2890196|2890196-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-Outlook|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202102
2890181|2890181-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTP|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202058
2890160|2890160-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Parse-CPAN-Distributions|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202054
2890104|2890104-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Mailer|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202042
2890100|2890100-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-DBUtils|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812202038
2889794|2889794-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.32|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200608
2889579|2889579-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812201018
2889022|2889022-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.32|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812200937
2887993|2887993-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812201256
2886056|2886056-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.32|amd64-freebsd|5.10.0|freebsd|7.0-release|200812200201
2885838|2885838-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200812200149
2885670|2885670-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.10|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812200131
2885454|2885454-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.10|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812200114
2885379|2885379-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812200007
2885376|2885376-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812200007
2885369|2885369-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812200006
2884956|2884956-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200812192332
2884481|2884481-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200812191646
2884183|2884183-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.02|IP35-irix-64int|5.8.8|irix|6.5|200812192308
2884165|2884165-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200812192205
2884162|2884162-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.02|i686-linux|5.8.8|linux|2.4.27-3-686|200812192204
2881586|2881586-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.32|amd64-freebsd|5.8.8|freebsd|7.0-release|200812191729
2881337|2881337-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191652
2881335|2881335-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.09|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191651
2881330|2881330-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191651
2881328|2881328-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812191552
2881205|2881205-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.32|amd64-freebsd|5.8.9|freebsd|7.0-release|200812191729
2879925|2879925-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Data-Generator|0.31|i86pc-solaris-64int|5.10.0|solaris|2.11|200812191511
2879730|2879730-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812191330
2879719|2879719-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812191328
2879706|2879706-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812191327
2879469|2879469-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Data-Generator|0.31|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191245
2879464|2879464-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-Data-Generator|0.32||0|||200812191344
2878914|2878914-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812191249
2878705|2878705-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Test-YAML-Meta|0.11|amd64-freebsd|5.10.0|freebsd|7.0-release|200812191223
2878457|2878457-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191104
2878454|2878454-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191104
2878450|2878450-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191104
2878212|2878212-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Data-Generator|0.31|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190538
2878112|2878112-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812191023
2877243|2877243-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.31|amd64-freebsd|5.10.0|freebsd|7.0-release|200812190924
2874863|2874863-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812190344
2874278|2874278-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812190234
2874234|2874234-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812190228
2873909|2873909-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190057
2873904|2873904-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190057
2873894|2873894-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190056
2873851|2873851-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812190152
2873698|2873698-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812190138
2873668|2873668-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812190136
2873441|2873441-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812190120
2872995|2872995-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.31|amd64-freebsd|5.8.9|freebsd|7.0-release|200812190041
2872986|2872986-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Data-Generator|0.31|amd64-freebsd|5.8.8|freebsd|7.0-release|200812190041
2872306|2872306-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812182346
2872109|2872109-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181727
2872107|2872107-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181727
2872105|2872105-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181727
2872089|2872089-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181726
2872083|2872083-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812182323
2871972|2871972-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181715
2871850|2871850-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812182302
2871834|2871834-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.03|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812182300
2871393|2871393-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812182223
2870200|2870200-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-Data-Generator|0.31||0|||200812182043
2867312|2867312-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181350
2867300|2867300-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181348
2867242|2867242-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181342
2867238|2867238-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181341
2867232|2867232-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181341
2866979|2866979-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200812181306
2866968|2866968-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200812181305
2866930|2866930-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200812181301
2866925|2866925-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200812181300
2866922|2866922-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200812181300
2866799|2866799-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.10|i86pc-solaris-64int|5.10.0|solaris|2.11|200812181400
2866797|2866797-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Common-DBUtils|0.03|i86pc-solaris-64int|5.10.0|solaris|2.11|200812181400
2865954|2865954-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.03|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180553
2865937|2865937-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.10|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180550
2865792|2865792-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812180951
2865788|2865788-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812180950
2865785|2865785-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812180950
2864818|2864818-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|amd64-freebsd|5.10.0|freebsd|7.0-release|200812180958
2864684|2864684-b19f-3f77-b713-d32bba55d77f|fail|200812|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180339
2864383|2864383-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180300
2862884|2862884-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180355
2862879|2862879-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180354
2862208|2862208-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180221
2862187|2862187-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180217
2862184|2862184-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180217
2861137|2861137-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812180001
2861132|2861132-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812180001
2861131|2861131-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812180000
2860312|2860312-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.10|i686-linux|5.10.0|linux|2.6.18-4-686|200812172300
2860309|2860309-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-DBUtils|0.03|i686-linux|5.10.0|linux|2.6.18-4-686|200812172300
2860244|2860244-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171651
2859850|2859850-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812172101
2859845|2859845-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812172100
2859842|2859842-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812172059
2859233|2859233-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.03|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812172030
2859210|2859210-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.14|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171429
2858943|2858943-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.12|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171350
2858942|2858942-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.22|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171350
2858873|2858873-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.30|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171342
2858473|2858473-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.52|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171250
2858223|2858223-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812171715
2857017|2857017-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200812171540
2856967|2856967-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812171613
2856669|2856669-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|amd64-freebsd|5.8.9|freebsd|7.0-release|200812171540
2856665|2856665-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.10|amd64-freebsd|5.8.8|freebsd|7.0-release|200812171540
2856660|2856660-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.03|amd64-freebsd|5.8.8|freebsd|7.0-release|200812171540
2856403|2856403-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812171510
2856157|2856157-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200812171351
2856101|2856101-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200812171342
2855779|2855779-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.01|IP35-irix-64int|5.8.8|irix|6.5|200812171428
2855440|2855440-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.10||0|||200812171408
2855403|2855403-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.09||0|||200812171406
2855159|2855159-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812171214
2855156|2855156-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.03|amd64-freebsd|5.10.0|freebsd|7.0-release|200812171332
2855154|2855154-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812171213
2855026|2855026-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200812171423
2854900|2854900-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-Common-DBUtils|0.03||0|||200812171309
2854304|2854304-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|CPAN-Testers-Common-DBUtils|0.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812171223
2854053|2854053-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.08|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200812170324
2854051|2854051-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.08|i686-linux|5.8.8|linux|2.4.27-3-686|200812170924
2854050|2854050-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-WWW-Reports-Mailer|0.08|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200812170924
2853818|2853818-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200812170249
2853645|2853645-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200812170835
2853613|2853613-b19f-3f77-b713-d32bba55d77f|pass|200812|david@cantrell.org.uk|CPAN-Testers-Common-DBUtils|0.01|i686-linux|5.8.8|linux|2.4.27-3-686|200812170831
2853582|2853582-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170330
2853581|2853581-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170330
2853394|2853394-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170312
2853363|2853363-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200812170907
2852671|2852671-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170153
2852658|2852658-b19f-3f77-b713-d32bba55d77f|fail|200812|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170151
2852655|2852655-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170152
2851083|2851083-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812170512
2850688|2850688-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812170432
2850308|2850308-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812170358
2849016|2849016-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812170211
2848854|2848854-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Reports-Mailer|0.08|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170101
2848424|2848424-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-Common-DBUtils|0.02|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170030
2846571|2846571-b19f-3f77-b713-d32bba55d77f|pass|200812|mw487.yahoo.com@gmail.com|CPAN-Testers-Common-DBUtils|0.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200812161640
2846108|2846108-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.18-4-686|200812162144
2846084|2846084-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.18-4-686|200812162141
2843738|2843738-b19f-3f77-b713-d32bba55d77f|pass|200812|vpit@cpan.org|CPAN-Testers-Common-DBUtils|0.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200812161724
2843736|2843736-b19f-3f77-b713-d32bba55d77f|pass|200812|vpit@cpan.org|CPAN-Testers-Common-DBUtils|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200812161724
2843566|2843566-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812161610
2843563|2843563-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812161610
2843258|2843258-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812161544
2843256|2843256-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812161544
2842371|2842371-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Common-DBUtils|0.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200812161449
2842037|2842037-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812161305
2841901|2841901-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812161118
2841896|2841896-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812161118
2841693|2841693-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812161155
2841673|2841673-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|CPAN-Testers-Common-DBUtils|0.01|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812161146
2841595|2841595-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|CPAN-Testers-WWW-Reports-Mailer|0.08|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812161131
2841590|2841590-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|CPAN-Testers-Common-DBUtils|0.02|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812161131
2841553|2841553-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812161122
2841513|2841513-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812161113
2841207|2841207-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812161027
2841172|2841172-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812161019
2841097|2841097-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812161010
2841087|2841087-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812161007
2840319|2840319-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Reports-Mailer|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200812161452
2840308|2840308-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-Testers-Common-DBUtils|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200812161448
2839655|2839655-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812160217
2839654|2839654-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812160215
2839443|2839443-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812160051
2839442|2839442-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812160049
2839437|2839437-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812160048
2838554|2838554-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.02|amd64-freebsd|5.10.0|freebsd|7.0-release|200812152146
2838155|2838155-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.02|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812152157
2837967|2837967-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-DBUtils|0.02|i686-linux|5.10.0|linux|2.6.18-4-686|200812152145
2837217|2837217-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-Common-DBUtils|0.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200812151821
2837216|2837216-b19f-3f77-b713-d32bba55d77f|pass|200812|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Reports-Mailer|0.08|i86pc-solaris-64int|5.10.0|solaris|2.11|200812151821
2837147|2837147-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200812151748
2837140|2837140-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200812151748
2836863|2836863-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-Common-DBUtils|0.02||0|||200812151614
2836606|2836606-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812151319
2836496|2836496-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Reports-Mailer|0.08|i686-linux|5.10.0|linux|2.6.18-4-686|200812151329
2836495|2836495-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812151229
2836494|2836494-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-Common-DBUtils|0.01|i686-linux|5.10.0|linux|2.6.18-4-686|200812151329
2836377|2836377-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812151240
2836146|2836146-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200812151108
2836032|2836032-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812151042
2836013|2836013-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux|5.8.8|linux|2.6.18-92.el5|200812151036
2835938|2835938-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812151011
2835916|2835916-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812151004
2835857|2835857-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812150952
2835826|2835826-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Reports-Mailer|0.08|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812150943
2835825|2835825-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-Common-DBUtils|0.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812150943
2832589|2832589-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812141851
2832580|2832580-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812141849
2832572|2832572-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPAN-Testers-Common-DBUtils|0.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812141848
2832388|2832388-b19f-3f77-b713-d32bba55d77f|pass|200812|vovkasm@gmail.com|Regexp-Log-Common|0.05|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200812141326
2831988|2831988-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812141806
2831987|2831987-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.01|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812141806
2831366|2831366-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|amd64-freebsd|5.8.8|freebsd|7.0-release|200812141648
2831363|2831363-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|amd64-freebsd|5.8.9|freebsd|7.0-release|200812141648
2831177|2831177-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Reports-Mailer|0.08|amd64-freebsd|5.10.0|freebsd|7.0-release|200812141618
2831176|2831176-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.01|amd64-freebsd|5.10.0|freebsd|7.0-release|200812141618
2829541|2829541-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200812141258
2829540|2829540-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-Common-DBUtils|0.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200812141258
2829497|2829497-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-WWW-Reports-Mailer|0.08||0|||200812141249
2829106|2829106-b19f-3f77-b713-d32bba55d77f|cpan|200812|BARBIE|CPAN-Testers-Common-DBUtils|0.01||0|||200812141127
2828164|2828164-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812140650
2828162|2828162-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812140650
2828010|2828010-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.6.18-4-686|200812140557
2827999|2827999-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.6.18-4-686|200812140554
2825793|2825793-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200812131729
2824171|2824171-b19f-3f77-b713-d32bba55d77f|fail|200812|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|amd64-freebsd|5.8.9|freebsd|7.0-release|200812131225
2822681|2822681-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812131010
2822680|2822680-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812131010
2805145|2805145-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812102100
2804552|2804552-b19f-3f77-b713-d32bba55d77f|fail|200812|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|amd64-freebsd|5.8.8|freebsd|7.0-release|200812102258
2804544|2804544-b19f-3f77-b713-d32bba55d77f|fail|200812|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|amd64-freebsd|5.8.9|freebsd|7.0-release|200812102258
2799747|2799747-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200812101330
2796635|2796635-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|GD-Chart-Radial|0.07|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100417
2796244|2796244-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812100337
2796242|2796242-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812100337
2795808|2795808-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Mail-File|0.08|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100100
2795752|2795752-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100052
2795721|2795721-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200812100047
2795499|2795499-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100023
2795095|2795095-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|amd64-freebsd|5.8.8|freebsd|7.0-release|200812092201
2795033|2795033-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|amd64-freebsd|5.8.8|freebsd|7.0-release|200812092201
2794880|2794880-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Mail-File|0.08|amd64-freebsd|5.8.8|freebsd|7.0-release|200812092201
2794877|2794877-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812100037
2794785|2794785-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812092332
2794430|2794430-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812092332
2794150|2794150-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|amd64-freebsd|5.8.9|freebsd|7.0-release|200812092124
2794025|2794025-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200812092124
2793798|2793798-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200812092124
2793649|2793649-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200812092201
2793637|2793637-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|amd64-freebsd|5.8.9|freebsd|7.0-release|200812092124
2793595|2793595-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812092202
2793586|2793586-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812092201
2789880|2789880-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|GD-Chart-Radial|0.07|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091151
2789708|2789708-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091129
2789321|2789321-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Test-CPAN-Meta|0.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091306
2789234|2789234-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Calendar-List|0.21|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091108
2788759|2788759-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091330
2787823|2787823-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091329
2787793|2787793-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Mail-Outlook|0.14|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091214
2787141|2787141-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091123
2786702|2786702-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091329
2786701|2786701-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091329
2786546|2786546-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-UsePerl-Journal|0.22|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091330
2786259|2786259-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Test-YAML-Meta|0.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091311
2785237|2785237-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Regexp-Log-Common|0.05|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091250
2785191|2785191-b19f-3f77-b713-d32bba55d77f|pass|200812|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200812091151
2784959|2784959-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Parse-CPAN-Distributions|0.05|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091236
2784291|2784291-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091127
2783609|2783609-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Games-Trackword|1.06|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091151
2783565|2783565-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091148
2783234|2783234-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091129
2782987|2782987-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.52|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091123
2779535|2779535-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200812082233
2779426|2779426-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|amd64-freebsd|5.8.9|freebsd|7.0-release|200812082250
2778891|2778891-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|CPAN-WWW-Testers|0.37|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812082312
2778482|2778482-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Test-CPAN-Meta|0.12|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812082043
2777263|2777263-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Calendar-List|0.21|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081700
2777032|2777032-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Games-Trackword|1.06|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081700
2777004|2777004-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812081322
2776696|2776696-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812081729
2776276|2776276-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Test-CPAN-Meta|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081527
2776266|2776266-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081527
2774551|2774551-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.8.8|linux|2.6.18-92.el5|200812081020
2774550|2774550-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.8.8|linux|2.6.18-92.el5|200812081020
2774138|2774138-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Test-YAML-Meta|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200812080846
2771648|2771648-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Mail-Outlook|0.14|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072336
2770687|2770687-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072153
2770542|2770542-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-UsePerl-Journal|0.22|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072153
2770494|2770494-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072152
2770439|2770439-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.52|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072046
2770408|2770408-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812072142
2768217|2768217-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.18-4-686|200812071740
2767804|2767804-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Data-Phrasebook-Loader-YAML|0.09|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812071541
2767802|2767802-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Data-Phrasebook|0.29|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812071540
2767220|2767220-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812071210
2767044|2767044-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071009
2766732|2766732-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Regexp-Log-Common|0.05|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071008
2766165|2766165-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071006
2766020|2766020-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071006
2765771|2765771-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071009
2765548|2765548-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Parse-CPAN-Distributions|0.05|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071008
2764264|2764264-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Regexp-Log-Common|0.05|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812070838
2758574|2758574-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812061323
2756980|2756980-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200812060801
2756883|2756883-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Parse-CPAN-Distributions|0.05|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812060629
2756854|2756854-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812060616
2756845|2756845-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|WWW-Scraper-ISBN-Amazon_Driver|0.14|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812060613
2755452|2755452-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812052256
2755450|2755450-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812052256
2754807|2754807-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812052004
2747847|2747847-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200812042250
2747844|2747844-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200812042249
2747707|2747707-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812042333
2746594|2746594-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812041910
2746593|2746593-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812041910
2743353|2743353-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Test-YAML-Meta|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812040922
2741657|2741657-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Mail-Outlook|0.14|i686-linux|5.10.0|linux|2.6.18-4-686|200812032216
2736326|2736326-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.6.18-4-686|200812030632
2736325|2736325-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.18-4-686|200812030632
2727784|2727784-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPAN-Testers-WWW-Statistics|0.52|i686-linux|5.10.0|linux|2.6.18-4-686|200812011925
2723646|2723646-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812010017
2719703|2719703-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811301527
2717789|2717789-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200811300911
2713941|2713941-b19f-3f77-b713-d32bba55d77f|pass|200811|sjn@pvv.org ("Salve J. Nilsen")|Test-YAML-Meta|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.25|200811281705
2708214|2708214-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290019
2708013|2708013-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290018
2706461|2706461-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Calendar-List|0.21|amd64-freebsd|5.8.9|freebsd|7.0-release|200811282003
2706347|2706347-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Games-Trackword|1.06|amd64-freebsd|5.8.9|freebsd|7.0-release|200811282003
2705964|2705964-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Test-CPAN-Meta|0.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281757
2705798|2705798-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281757
2705691|2705691-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281757
2705047|2705047-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.18-4-686|200811281639
2704447|2704447-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Test-YAML-Meta|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281437
2703779|2703779-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Mail-Outlook|0.14|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811281327
2699696|2699696-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.8.9|freebsd|7.0-release|200811280030
2699688|2699688-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.8.9|freebsd|7.0-release|200811280030
2699392|2699392-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|amd64-freebsd|5.8.9|freebsd|7.0-release|200811272323
2699375|2699375-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|amd64-freebsd|5.8.9|freebsd|7.0-release|200811272323
2698458|2698458-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.18-4-686|200811272109
2698453|2698453-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.18-4-686|200811272108
2696139|2696139-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.18-4-686|200811271357
2691706|2691706-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.18-4-686|200811261441
2691680|2691680-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.10.0|linux|2.6.18-4-686|200811261432
2691670|2691670-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux|5.10.0|linux|2.6.18-4-686|200811261429
2687479|2687479-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.8.8|linux|2.4.27-2-386|200811260015
2679016|2679016-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200811240653
2679012|2679012-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200811240648
2678739|2678739-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.11|i86pc-solaris-64int|5.8.9|solaris|2.11|200811241148
2678738|2678738-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.10|i86pc-solaris-64int|5.8.9|solaris|2.11|200811241148
2678736|2678736-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200811241148
2678730|2678730-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Mail-File|0.08|i86pc-solaris-64int|5.8.9|solaris|2.11|200811241147
2678614|2678614-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|CPAN-WWW-Testers|0.37|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200811241055
2677615|2677615-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Mail-Outlook|0.14|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240351
2677603|2677603-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Parse-CPAN-Distributions|0.05|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240348
2677391|2677391-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240250
2677390|2677390-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|WWW-UsePerl-Journal|0.22|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240250
2677358|2677358-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|CPAN-WWW-Testers-Generator|0.30|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240237
2677141|2677141-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|CPAN-Testers-WWW-Statistics|0.52|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240142
2674933|2674933-b19f-3f77-b713-d32bba55d77f|pass|200811|dmdk1@comcast.net|Test-YAML-Meta|0.11|i486-linux-gnu|5.10.0|linux|2.6.24-15-server|200811230918
2674682|2674682-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811231020
2674678|2674678-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811231016
2674533|2674533-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200811231048
2674527|2674527-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200811231045
2674502|2674502-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811231037
2674493|2674493-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811231033
2674384|2674384-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811231040
2674383|2674383-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Data-Phrasebook|0.29|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811231040
2674251|2674251-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Regexp-Log-Common|0.05|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811231002
2673435|2673435-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811230706
2673430|2673430-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811230705
2671493|2671493-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.08|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200811222145
2671486|2671486-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.14|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200811222143
2671400|2671400-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200811222111
2671393|2671393-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200811222110
2671149|2671149-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.08|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200811221330
2671148|2671148-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.14|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200811221329
2670865|2670865-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.08|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200811221803
2670855|2670855-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.14|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200811221802
2670805|2670805-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux|5.8.8|linux|2.4.27-3-686|200811221757
2670802|2670802-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux|5.8.8|linux|2.4.27-3-686|200811221756
2670654|2670654-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811221728
2670633|2670633-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811221724
2670570|2670570-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811221817
2670565|2670565-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811221816
2669900|2669900-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200811221632
2669863|2669863-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200811221628
2669316|2669316-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811221219
2669307|2669307-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811221215
2669229|2669229-b19f-3f77-b713-d32bba55d77f|pass|200811|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200811221959
2669222|2669222-b19f-3f77-b713-d32bba55d77f|pass|200811|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.14|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200811221957
2666669|2666669-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811212332
2666668|2666668-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811212329
2665787|2665787-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811211719
2665786|2665786-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811211719
2665723|2665723-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200811211850
2664772|2664772-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-Outlook|0.06|i86pc-solaris-64int|5.8.9|solaris|2.11|200811211141
2660368|2660368-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811201957
2660365|2660365-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811201957
2660169|2660169-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal-Thread|0.12|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811201923
2660167|2660167-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-UsePerl-Journal|0.22|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811201923
2659813|2659813-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811201834
2659608|2659608-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers-Generator|0.30|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811201809
2658718|2658718-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200811201430
2658694|2658694-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200811201429
2658643|2658643-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811201319
2658635|2658635-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811201315
2657769|2657769-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811200919
2657737|2657737-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811200911
2656857|2656857-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.15|i86pc-solaris-64int|5.8.9|solaris|2.11|200811200749
2656378|2656378-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200811200628
2653887|2653887-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Games-Trackword|1.06|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192318
2653886|2653886-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Calendar-List|0.21|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192318
2652883|2652883-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Test-YAML-Meta|0.11|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192026
2652882|2652882-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Test-CPAN-Meta|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192026
2652880|2652880-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192025
2652879|2652879-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.09|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192026
2652577|2652577-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200811191845
2652570|2652570-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200811191844
2652125|2652125-b19f-3f77-b713-d32bba55d77f|fail|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811191511
2652104|2652104-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811191507
2649926|2649926-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Mail-Outlook|0.14|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190615
2649479|2649479-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190454
2649478|2649478-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal|0.22|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190454
2649419|2649419-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.30|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190442
2649162|2649162-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.52|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190322
2648876|2648876-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Regexp-Log-Common|0.05|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811190018
2648183|2648183-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811182139
2648153|2648153-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811182134
2647773|2647773-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811182130
2647728|2647728-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811182111
2647499|2647499-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811182023
2647114|2647114-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181857
2647113|2647113-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook|0.29|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181857
2647109|2647109-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200811181845
2647108|2647108-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200811181844
2646921|2646921-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Regexp-Log-Common|0.05|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181806
2646109|2646109-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Parse-CPAN-Distributions|0.05|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181501
2646105|2646105-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181500
2646104|2646104-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.14|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181459
2645758|2645758-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811181209
2645754|2645754-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811181204
2645417|2645417-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811181148
2645305|2645305-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811181127
2643089|2643089-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Parse-CPAN-Distributions|0.05|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811180352
2642306|2642306-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200811180041
2642206|2642206-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200811180029
2642166|2642166-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200811180025
2642012|2642012-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200811180006
2641944|2641944-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi|5.8.9|freebsd|6.1-release-p23|200811180056
2641611|2641611-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200811172309
2641594|2641594-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200811172306
2641588|2641588-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd|5.10.0|freebsd|6.1-release|200811180001
2641587|2641587-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd|5.10.0|freebsd|6.1-release|200811180000
2641584|2641584-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200811172303
2641570|2641570-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200811172301
2641380|2641380-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Regexp-Log-Common|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811172206
2640361|2640361-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.14|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811171941
2640359|2640359-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.08|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811171941
2639933|2639933-b19f-3f77-b713-d32bba55d77f|cpan|200811|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.14||0|||200811171550
2639894|2639894-b19f-3f77-b713-d32bba55d77f|cpan|200811|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.08||0|||200811171541
2639885|2639885-b19f-3f77-b713-d32bba55d77f|cpan|200811|BARBIE|CPAN-WWW-Testers|0.37||0|||200811171539
2636733|2636733-b19f-3f77-b713-d32bba55d77f|pass|200811|jeff@zeroclue.com|Data-Phrasebook-Loader-YAML|0.09|darwin-2level|5.10.0|darwin|9.2.0|200811161253
2636729|2636729-b19f-3f77-b713-d32bba55d77f|pass|200811|jeff@zeroclue.com|Data-Phrasebook|0.29|darwin-2level|5.10.0|darwin|9.2.0|200811161253
2630342|2630342-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811151216
2630340|2630340-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811151216
2622891|2622891-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811141528
2621178|2621178-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811141110
2620615|2620615-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811140927
2620597|2620597-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811140926
2619299|2619299-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811140757
2619277|2619277-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811140756
2616431|2616431-b19f-3f77-b713-d32bba55d77f|unknown|200811|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Statistics|0.52|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811140051
2616430|2616430-b19f-3f77-b713-d32bba55d77f|fail|200811|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-Testers-WWW-Statistics|0.52|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811140051
2615760|2615760-b19f-3f77-b713-d32bba55d77f|unknown|200811|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers|0.36|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811140018
2615759|2615759-b19f-3f77-b713-d32bba55d77f|fail|200811|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-WWW-Testers|0.36|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811140018
2612723|2612723-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132053
2611723|2611723-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131728
2611660|2611660-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2611481|2611481-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2610819|2610819-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2610806|2610806-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2610680|2610680-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2610439|2610439-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2609478|2609478-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131443
2607386|2607386-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131049
2607342|2607342-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131049
2605206|2605206-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200811130215
2605205|2605205-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200811130215
2605115|2605115-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200811130152
2605114|2605114-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200811130151
2604776|2604776-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130002
2604707|2604707-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130012
2604474|2604474-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130012
2604396|2604396-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130003
2603015|2603015-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121601
2602723|2602723-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121601
2602699|2602699-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121601
2601885|2601885-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121403
2600929|2600929-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121130
2600756|2600756-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121130
2600711|2600711-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121131
2600710|2600710-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121131
2600616|2600616-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121130
2598855|2598855-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120755
2597985|2597985-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120755
2597448|2597448-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811120623
2597413|2597413-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200811120515
2597410|2597410-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200811120514
2597116|2597116-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200811120352
2597111|2597111-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200811120351
2596676|2596676-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811120319
2596645|2596645-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811120314
2596641|2596641-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811120314
2596408|2596408-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811120222
2596406|2596406-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811120222
2596193|2596193-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811120140
2583410|2583410-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811101102
2582489|2582489-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811100834
2582443|2582443-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Regexp-Log-Common|0.05|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811100825
2581869|2581869-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811100640
2581861|2581861-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Test-CPAN-Meta|0.12|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811100639
2580640|2580640-b19f-3f77-b713-d32bba55d77f|pass|200811|perl@galumph.com|Test-YAML-Meta|0.11|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200811091457
2578676|2578676-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811090840
2578092|2578092-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811091007
2577925|2577925-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811090841
2577915|2577915-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811090939
2577844|2577844-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811090916
2576856|2576856-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811091007
2576848|2576848-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811090945
2576838|2576838-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811091000
2576837|2576837-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811091000
2576783|2576783-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811090945
2576771|2576771-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook-Loader-YAML|0.09|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811090939
2576722|2576722-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Phrasebook|0.29|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811090916
2553967|2553967-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.11|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811051707
2553966|2553966-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.10|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811051707
2553965|2553965-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.12|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811051707
2549127|2549127-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Mail-File|0.08|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042147
2548874|2548874-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-Outlook|0.06|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042056
2548873|2548873-b19f-3f77-b713-d32bba55d77f|fail|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-WebList|0.05|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042056
2548872|2548872-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTP|0.05|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042055
2548870|2548870-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042054
2547333|2547333-b19f-3f77-b713-d32bba55d77f|fail|200811|altblue@gmail.com ("Marius Feraru")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|x86_64-linux|5.11.0 patch 34595|linux|2.6.18-8.1.14.el5|200811040101
2547040|2547040-b19f-3f77-b713-d32bba55d77f|fail|200811|altblue@gmail.com ("Marius Feraru")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|x86_64-linux|5.11.0 patch 34712|linux|2.6.18-8.1.14.el5|200811040805
2547022|2547022-b19f-3f77-b713-d32bba55d77f|fail|200811|altblue@gmail.com ("Marius Feraru")|WWW-Scraper-ISBN-Amazon_Driver|0.13|x86_64-linux|5.11.0 patch 34595|linux|2.6.18-8.1.14.el5|200811040246
2538544|2538544-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811022057
2538479|2538479-b19f-3f77-b713-d32bba55d77f|pass|200811|perl@galumph.com|Test-CPAN-Meta|0.12|darwin-2level|5.10.0|darwin|9.1.0|200811021338
2536552|2536552-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.52|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811021220
2534982|2534982-b19f-3f77-b713-d32bba55d77f|fail|200811|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811012219
2533864|2533864-b19f-3f77-b713-d32bba55d77f|pass|200811|mw487.yahoo.com@gmail.com|Parse-CPAN-Distributions|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811011109
2530540|2530540-b19f-3f77-b713-d32bba55d77f|pass|200810|mw487.yahoo.com@gmail.com|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200810311209
2530539|2530539-b19f-3f77-b713-d32bba55d77f|pass|200810|mw487.yahoo.com@gmail.com|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200810311208
2524873|2524873-b19f-3f77-b713-d32bba55d77f|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|Test-YAML-Meta|0.11|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810302226
2524825|2524825-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.15|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810302227
2523954|2523954-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.03|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810302028
2516202|2516202-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Games-Trackword|1.06|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810291541
2516199|2516199-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Calendar-List|0.21|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810291541
2515674|2515674-b19f-3f77-b713-d32bba55d77f|pass|200810|autarch@urth.org|Test-YAML-Meta|0.11|x86_64-linux-gnu|5.10.0|linux|2.6.24-15-server|200810290221
2513981|2513981-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Test-CPAN-Meta|0.12|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290700
2513978|2513978-b19f-3f77-b713-d32bba55d77f|fail|200810|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.09|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290659
2513974|2513974-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290659
2513968|2513968-b19f-3f77-b713-d32bba55d77f|fail|200810|JOST@cpan.org ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290659
2510577|2510577-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Test-YAML-Meta|0.11|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281918
2507524|2507524-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Mail-Outlook|0.14|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810280630
2507069|2507069-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.12|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810280343
2507067|2507067-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal|0.22|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810280343
2506908|2506908-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.30|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810280244
2506353|2506353-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.52|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810272329
2505665|2505665-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Parse-CPAN-Distributions|0.05|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810272014
2505599|2505599-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271958
2505598|2505598-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook|0.29|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271958
2504683|2504683-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Regexp-Log-Common|0.05|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271639
2502592|2502592-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810270337
2502590|2502590-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810270336
2498417|2498417-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200810260934
2498415|2498415-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200810260933
2497665|2497665-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux|5.8.8|linux|2.4.27-2-386|200810260811
2497407|2497407-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810260208
2497405|2497405-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810260207
2497361|2497361-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810260138
2497360|2497360-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810260138
2496291|2496291-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252224
2495715|2495715-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252222
2495463|2495463-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252222
2494539|2494539-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252222
2494538|2494538-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252222
2494508|2494508-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252222
2494507|2494507-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252222
2493787|2493787-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Mail-Outlook|0.14|i686-linux|5.10.0|linux|2.4.27-2-386|200810252140
2493782|2493782-b19f-3f77-b713-d32bba55d77f|pass|200810|alexchorny@gmail.com|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200810251440
2492762|2492762-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.4.27-2-386|200810251904
2492549|2492549-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.10.0|linux|2.4.27-2-386|200810251821
2492275|2492275-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251455
2491698|2491698-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251456
2491491|2491491-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251455
2489651|2489651-b19f-3f77-b713-d32bba55d77f|pass|200810|autarch@urth.org|WWW-UsePerl-Journal|0.22|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200810250112
2488394|2488394-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810250318
2488393|2488393-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810250317
2488369|2488369-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810250249
2488367|2488367-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810250248
2487577|2487577-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200810242146
2485083|2485083-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240958
2484856|2484856-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240958
2484663|2484663-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240958
2483972|2483972-b19f-3f77-b713-d32bba55d77f|fail|200810|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240826
2483965|2483965-b19f-3f77-b713-d32bba55d77f|fail|200810|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240826
2483937|2483937-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240825
2483851|2483851-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240826
2483850|2483850-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240826
2482679|2482679-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200810240052
2482678|2482678-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200810240052
2482066|2482066-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200810240020
2482063|2482063-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200810240019
2481867|2481867-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240003
2481483|2481483-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810232006
2481480|2481480-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810232006
2481330|2481330-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2480867|2480867-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810232148
2480866|2480866-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810232147
2480531|2480531-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232100
2480529|2480529-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232100
2480440|2480440-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232058
2480271|2480271-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232058
2480057|2480057-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2479887|2479887-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2475823|2475823-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200810230034
2475817|2475817-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200810230034
2475765|2475765-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200810230029
2475758|2475758-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200810230029
2471123|2471123-b19f-3f77-b713-d32bba55d77f|pass|200810|mw487.yahoo.com@gmail.com|Regexp-Log-Common|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200810220821
2470570|2470570-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810221128
2470566|2470566-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810221127
2470179|2470179-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810221021
2470172|2470172-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810221021
2468604|2468604-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810220329
2468602|2468602-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810220329
2468096|2468096-b19f-3f77-b713-d32bba55d77f|pass|200810|davidp@preshweb.co.uk ("David Precious")|Finance-Currency-Convert-XE|0.15|i486-linux-gnu|5.10.0|linux|2.6.26.1|200810211927
2466508|2466508-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810211219
2466502|2466502-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810211217
2466225|2466225-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.52|i686-linux|5.10.0|linux|2.4.27-2-386|200810211227
2465472|2465472-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200810210222
2462643|2462643-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200810201938
2462642|2462642-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|Data-Phrasebook|0.29|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200810201938
2462231|2462231-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.4.27-2-386|200810201815
2461954|2461954-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810201443
2461951|2461951-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810201443
2461757|2461757-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.4.27-2-386|200810201541
2461685|2461685-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810201314
2461682|2461682-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810201314
2461677|2461677-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810201311
2461676|2461676-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810201310
2461607|2461607-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200810201257
2461603|2461603-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810201256
2461601|2461601-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810201256
2461146|2461146-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|CPAN-WWW-Testers|0.36|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200810201125
2460909|2460909-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810200701
2460904|2460904-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810200654
2460895|2460895-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810200640
2460641|2460641-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux|5.8.8|linux|2.4.27-2-386|200810200058
2459261|2459261-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200810191616
2458601|2458601-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.4.27-2-386|200810191525
2457437|2457437-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-WWW-Testers-Generator|0.30|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200810191354
2457431|2457431-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-WWW-Testers|0.36|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200810191349
2457411|2457411-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-WWW-Testers|0.34|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200810191343
2457386|2457386-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.52|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200810191338
2457371|2457371-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.51|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200810191333
2456880|2456880-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810190757
2456878|2456878-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810190757
2456873|2456873-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810190755
2456870|2456870-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810190754
2456865|2456865-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200810190753
2456859|2456859-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810190752
2456854|2456854-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810190751
2454535|2454535-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810181609
2454509|2454509-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810181557
2454477|2454477-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810181544
2450710|2450710-b19f-3f77-b713-d32bba55d77f|cpan|200810|BARBIE|CPAN-WWW-Testers|0.36||0|||200810171419
2448609|2448609-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2448587|2448587-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162147
2448569|2448569-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162147
2448559|2448559-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162147
2448557|2448557-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162114
2448405|2448405-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2448298|2448298-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162147
2448286|2448286-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162147
2448283|2448283-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162147
2448065|2448065-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162148
2448037|2448037-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2447973|2447973-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810162148
2447792|2447792-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2447735|2447735-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2447734|2447734-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2447732|2447732-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162112
2439818|2439818-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810151106
2439497|2439497-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810151051
2436197|2436197-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810141125
2435630|2435630-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810141009
2435084|2435084-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140831
2434754|2434754-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140749
2434730|2434730-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140747
2434558|2434558-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140728
2434418|2434418-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140709
2434155|2434155-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140634
2434039|2434039-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140621
2434022|2434022-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140620
2433982|2433982-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140616
2433823|2433823-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140558
2433778|2433778-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140552
2433486|2433486-b19f-3f77-b713-d32bba55d77f|fail|200810|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140003
2433423|2433423-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140517
2433112|2433112-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.51|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140437
2432748|2432748-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140401
2432631|2432631-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140352
2431228|2431228-b19f-3f77-b713-d32bba55d77f|fail|200810|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140147
2430379|2430379-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140054
2430316|2430316-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.51|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140050
2429821|2429821-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140017
2429750|2429750-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140010
2429458|2429458-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140141
2428537|2428537-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140026
2427681|2427681-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810132322
2427674|2427674-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810132322
2427587|2427587-b19f-3f77-b713-d32bba55d77f|fail|200810|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810132319
2427477|2427477-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810132233
2424396|2424396-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.52|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200810130104
2424009|2424009-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.52|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200810122159
2423549|2423549-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.52|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810121702
2422614|2422614-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.52|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810120417
2422607|2422607-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.52|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810121006
2422604|2422604-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.52|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810121004
2422603|2422603-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.52|i686-linux|5.8.8|linux|2.4.27-3-686|200810121003
2421572|2421572-b19f-3f77-b713-d32bba55d77f|pass|200810|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.52|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810120238
2417194|2417194-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.52|i86pc-solaris-64int|5.10.0|solaris|2.11|200810101615
2417025|2417025-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.52|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200810101419
2416945|2416945-b19f-3f77-b713-d32bba55d77f|pass|200810|martin.evans@easysoft.com|Test-YAML-Meta|0.11|i486-linux-gnu|5.8.8|linux|2.6.15.7|200810101151
2416872|2416872-b19f-3f77-b713-d32bba55d77f|cpan|200810|BARBIE|CPAN-Testers-WWW-Statistics|0.52||0|||200810101156
2416812|2416812-b19f-3f77-b713-d32bba55d77f|pass|200810|bobtfish@bobtfish.net|Test-YAML-Meta|0.11|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200810100014
2416426|2416426-b19f-3f77-b713-d32bba55d77f|pass|200810|carlos.arenas@gmail.com ("Carlos Arenas")|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200810091809
2416149|2416149-b19f-3f77-b713-d32bba55d77f|fail|200810|bingos@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810100730
2416125|2416125-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810100723
2416121|2416121-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810100721
2416047|2416047-b19f-3f77-b713-d32bba55d77f|fail|200810|bingos@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810100648
2415921|2415921-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810100557
2415636|2415636-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810100354
2412252|2412252-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|Regexp-Log-Common|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200810091941
2408910|2408910-b19f-3f77-b713-d32bba55d77f|fail|200810|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.8.7|linux|2.6.26.5|200810090340
2406226|2406226-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810081533
2405360|2405360-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi-64int|5.8.8|linux|2.4.26|200810081857
2405253|2405253-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Regexp-Log-Common|0.05|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810081245
2405246|2405246-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Regexp-Log-Common|0.05|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810081744
2405027|2405027-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Regexp-Log-Common|0.05|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810081815
2404331|2404331-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Regexp-Log-Common|0.05|i686-linux|5.8.8|linux|2.4.27-3-686|200810081702
2403907|2403907-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Regexp-Log-Common|0.05|IP35-irix-64int|5.8.8|irix|6.5|200810081719
2403862|2403862-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Regexp-Log-Common|0.05|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810081609
2403731|2403731-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.8.7|linux|2.6.26.5|200810081056
2402905|2402905-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.8.7|linux|2.6.26.5|200810080837
2402904|2402904-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.22|i686-linux|5.8.7|linux|2.6.26.5|200810080837
2400112|2400112-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.8.7|linux|2.6.26.5|200810080340
2397651|2397651-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.8.6|linux|2.6.26.5|200810071811
2395731|2395731-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.10.0 patch 34465|netbsd|4.0|200810071903
2395730|2395730-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.10.0 patch 34465|netbsd|4.0|200810071903
2395373|2395373-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.11.0 patch 34470|netbsd|4.0|200810071818
2395371|2395371-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.11.0 patch 34470|netbsd|4.0|200810071818
2395217|2395217-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071259
2394084|2394084-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.8.6|linux|2.6.26.5|200810071031
2393177|2393177-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810070813
2392395|2392395-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810071134
2392393|2392393-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810071133
2391457|2391457-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810071000
2391450|2391450-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810070959
2391439|2391439-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200810070958
2391432|2391432-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200810070956
2391421|2391421-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200810070955
2391410|2391410-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200810070953
2391404|2391404-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200810070952
2391400|2391400-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200810070951
2391393|2391393-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200810070950
2391389|2391389-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810070949
2391280|2391280-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200810071037
2391088|2391088-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200810071002
2389068|2389068-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810070339
2389054|2389054-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810070337
2389039|2389039-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810070335
2386689|2386689-b19f-3f77-b713-d32bba55d77f|pass|200810|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.51|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810070330
2385724|2385724-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810061738
2385708|2385708-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810061736
2385697|2385697-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810061735
2385523|2385523-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810061713
2385509|2385509-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810061711
2385490|2385490-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810061709
2380651|2380651-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.6|linux|2.6.26.5|200810041705
2380650|2380650-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.8.6|linux|2.6.26.5|200810041704
2377550|2377550-b19f-3f77-b713-d32bba55d77f|pass|200810|jeff@zeroclue.com|CPAN-WWW-Testers-Generator|0.30|darwin-2level|5.10.0|darwin|9.2.0|200810031110
2377123|2377123-b19f-3f77-b713-d32bba55d77f|pass|200810|jeff@zeroclue.com|CPAN-Testers-WWW-Statistics|0.51|darwin-2level|5.10.0|darwin|9.2.0|200810031112
2377018|2377018-b19f-3f77-b713-d32bba55d77f|pass|200810|jeff@zeroclue.com|Test-YAML-Meta|0.11|darwin-2level|5.10.0|darwin|9.2.0|200810030909
2373644|2373644-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.7|linux|2.6.26.5|200810040006
2373643|2373643-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.8.7|linux|2.6.26.5|200810040006
2373476|2373476-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34456|openbsd|4.2|200810032227
2373460|2373460-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34456|openbsd|4.2|200810032225
2373443|2373443-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34456|openbsd|4.2|200810032222
2365509|2365509-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810022330
2365493|2365493-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810022327
2365477|2365477-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810022325
2364857|2364857-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810022201
2364839|2364839-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810022159
2364831|2364831-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810022157
2363284|2363284-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810021923
2363281|2363281-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810021921
2363273|2363273-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200810021920
2363262|2363262-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810021918
2363260|2363260-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810021916
2363259|2363259-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810021915
2363252|2363252-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200810021913
2363247|2363247-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810021911
2363244|2363244-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810021910
2363226|2363226-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810021906
2363193|2363193-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200810021903
2363179|2363179-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810021859
2362870|2362870-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Trackword|1.06|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021339
2362850|2362850-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Mail-File|0.08|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021335
2362798|2362798-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021326
2362795|2362795-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.30|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810021225
2362783|2362783-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Calendar-List|0.21|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021324
2362777|2362777-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|GD-Chart-Radial|0.07|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021323
2362771|2362771-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021323
2362755|2362755-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.51|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810021221
2362754|2362754-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021321
2362646|2362646-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.30|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810021707
2362642|2362642-b19f-3f77-b713-d32bba55d77f|fail|200810|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810021307
2362625|2362625-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.51|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810021703
2362549|2362549-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.30|IP35-irix-64int|5.8.8|irix|6.5|200810021850
2362547|2362547-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.30|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810021749
2362542|2362542-b19f-3f77-b713-d32bba55d77f|pass|200810|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-WWW-Testers-Generator|0.30|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200810030148
2362539|2362539-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.51|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810021742
2362537|2362537-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.6.2|freebsd|6.1-release|200810021809
2362528|2362528-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.30|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810021746
2362526|2362526-b19f-3f77-b713-d32bba55d77f|pass|200810|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-Testers-WWW-Statistics|0.51|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200810030146
2362523|2362523-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.51|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810021745
2362517|2362517-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.30|i686-linux|5.8.8|linux|2.4.27-3-686|200810021743
2362508|2362508-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.51|i686-linux|5.8.8|linux|2.4.27-3-686|200810021742
2362128|2362128-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810021413
2362123|2362123-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810021411
2362109|2362109-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810021408
2362093|2362093-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810021405
2362085|2362085-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810021402
2362080|2362080-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810021359
2361919|2361919-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200810021638
2361915|2361915-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.51|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200810021637
2361765|2361765-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.6.2|freebsd|6.1-release|200810021558
2360537|2360537-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810021256
2360267|2360267-b19f-3f77-b713-d32bba55d77f|pass|200810|martin.evans@easysoft.com|CPAN-Testers-WWW-Statistics|0.51|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200810021128
2360261|2360261-b19f-3f77-b713-d32bba55d77f|pass|200810|martin.evans@easysoft.com|CPAN-WWW-Testers-Generator|0.30|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200810021127
2359737|2359737-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.51|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810021102
2359736|2359736-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810021102
2359088|2359088-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|CPAN-WWW-Testers-Generator|0.30|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200810020955
2358997|2358997-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.51|i86pc-solaris-64int|5.10.0|solaris|2.11|200810020945
2358994|2358994-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.30|i86pc-solaris-64int|5.10.0|solaris|2.11|200810020945
2357109|2357109-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.21|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020300
2356926|2356926-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020231
2356861|2356861-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.01|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020222
2356805|2356805-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020215
2356696|2356696-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020158
2356615|2356615-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020135
2356603|2356603-b19f-3f77-b713-d32bba55d77f|fail|200810|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020134
2356509|2356509-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Test-CPAN-Meta|0.12|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020117
2356440|2356440-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810020056
2356052|2356052-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-WWW-Testers-Generator|0.30|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200810020222
2356040|2356040-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.51|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200810020217
2355940|2355940-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.10.0|freebsd|6.1-release|200810020044
2355603|2355603-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200810012348
2355602|2355602-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.51|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200810012348
2354883|2354883-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.51|i386-freebsd|5.10.0|freebsd|6.1-release|200810012133
2354882|2354882-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.30|i386-freebsd|5.10.0|freebsd|6.1-release|200810012133
2354375|2354375-b19f-3f77-b713-d32bba55d77f|cpan|200810|BARBIE|CPAN-WWW-Testers-Generator|0.30||0|||200810012017
2354368|2354368-b19f-3f77-b713-d32bba55d77f|cpan|200810|BARBIE|CPAN-Testers-WWW-Statistics|0.51||0|||200810012015
2353976|2353976-b19f-3f77-b713-d32bba55d77f|fail|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi-64int|5.11.0 patch 34451|freebsd|7.0-release|200810011630
2353936|2353936-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810011735
2353914|2353914-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810011733
2353892|2353892-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810011730
2353882|2353882-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810011728
2353873|2353873-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810011726
2353851|2353851-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810011723
2353029|2353029-b19f-3f77-b713-d32bba55d77f|pass|200810|martin.evans@easysoft.com|WWW-UsePerl-Journal-Thread|0.12|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200810011518
2352864|2352864-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810011337
2352850|2352850-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810011335
2352834|2352834-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810011332
2352159|2352159-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.12|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810011053
2352146|2352146-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810011151
2352145|2352145-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810010552
2352144|2352144-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.8.8|linux|2.4.27-3-686|200810011152
2352143|2352143-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810011151
2351776|2351776-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.6.2|linux|2.4.27-3-686|200810011039
2351627|2351627-b19f-3f77-b713-d32bba55d77f|pass|200810|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810011707
2351467|2351467-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810010921
2351461|2351461-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810010919
2351452|2351452-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200810010918
2351450|2351450-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200810010917
2351448|2351448-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200810010916
2351434|2351434-b19f-3f77-b713-d32bba55d77f|pass|200810|vpit@cpan.org|CPAN-WWW-Testers|0.35|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200810011015
2351432|2351432-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200810010914
2351426|2351426-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200810010913
2351422|2351422-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200810010912
2351417|2351417-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200810010911
2351413|2351413-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810010910
2351409|2351409-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810010909
2351402|2351402-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200810011007
2351401|2351401-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810010906
2351387|2351387-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200810010904
2351373|2351373-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200810010859
2351353|2351353-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200810010857
2351331|2351331-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200810010854
2351318|2351318-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200810010851
2351292|2351292-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200810010849
2351286|2351286-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200810010846
2351281|2351281-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810010843
2350924|2350924-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.8.8|linux|2.6.26.5|200810010238
2350899|2350899-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.22|i686-linux|5.8.8|linux|2.6.26.5|200810010234
2347172|2347172-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|WWW-UsePerl-Journal|0.22|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809302309
2346747|2346747-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809301527
2346466|2346466-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.10.0 patch 34437|netbsd|4.0|200809301946
2346463|2346463-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.10.0 patch 34437|netbsd|4.0|200809301946
2346350|2346350-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-freebsd-thread-multi-64int|5.11.0 patch 34448|freebsd|6.2-release|200809301408
2346340|2346340-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi-64int|5.11.0 patch 34448|freebsd|6.2-release|200809301407
2346258|2346258-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.22|i686-linux|5.10.0|linux|2.6.26.5|200809301418
2346081|2346081-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809301851
2346078|2346078-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809301849
2346073|2346073-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809301847
2346071|2346071-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809301846
2345812|2345812-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|WWW-UsePerl-Journal-Thread|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809301902
2345806|2345806-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809301902
2345797|2345797-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.8.8 patch 34439|netbsd|4.0|200809301755
2345792|2345792-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.8.8 patch 34439|netbsd|4.0|200809301755
2345656|2345656-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.10.0|linux|2.6.26.5|200809301223
2345541|2345541-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.12|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809301156
2345432|2345432-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd|5.6.2|freebsd|6.1-release|200809301740
2345425|2345425-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.12|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809301741
2344729|2344729-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809301549
2344624|2344624-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|WWW-UsePerl-Journal-Thread|0.11|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809301436
2344622|2344622-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|WWW-UsePerl-Journal|0.22|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809301436
2344331|2344331-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-netbsd-thread-multi-64int|5.11.0 patch 34444|netbsd|4.0|200809301356
2344318|2344318-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|WWW-UsePerl-Journal|0.22|i386-netbsd-thread-multi-64int|5.11.0 patch 34444|netbsd|4.0|200809301351
2343991|2343991-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.11|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809301212
2343989|2343989-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809301211
2343964|2343964-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.11|i686-linux|5.6.2|linux|2.4.27-3-686|200809301306
2343962|2343962-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|i686-linux|5.6.2|linux|2.4.27-3-686|200809301306
2343758|2343758-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809300627
2343753|2343753-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809300627
2343649|2343649-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809301303
2343578|2343578-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809301157
2343577|2343577-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809301157
2343499|2343499-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|WWW-UsePerl-Journal-Thread|0.12||0|||200809301242
2343456|2343456-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200809301136
2343452|2343452-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|i686-linux|5.8.8|linux|2.4.27-3-686|200809301136
2343451|2343451-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809301135
2343448|2343448-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|WWW-UsePerl-Journal|0.22|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809301135
2343415|2343415-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809301823
2343409|2343409-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.22|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809301821
2342949|2342949-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd|5.10.0|freebsd|6.1-release|200809301057
2342907|2342907-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Mail-Outlook|0.14|i86pc-solaris-64int|5.10.0|solaris|2.11|200809301055
2342864|2342864-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal|0.22|i86pc-solaris-64int|5.10.0|solaris|2.11|200809301044
2342681|2342681-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200809301008
2342667|2342667-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.11|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300401
2342666|2342666-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.22|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300400
2342584|2342584-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809300846
2342561|2342561-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809300843
2342521|2342521-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809300839
2342500|2342500-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809300837
2342223|2342223-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|WWW-UsePerl-Journal|0.22|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809301001
2339845|2339845-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291953
2339842|2339842-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291953
2338665|2338665-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|WWW-UsePerl-Journal-Thread|0.11||0|||200809292345
2338362|2338362-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809292207
2338326|2338326-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809292202
2338249|2338249-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809292157
2338231|2338231-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.22|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809292153
2336646|2336646-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200809291955
2336644|2336644-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.10|i86pc-solaris-64int|5.10.0|solaris|2.11|200809291955
2336642|2336642-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200809291955
2336173|2336173-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal|0.22|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809291847
2335954|2335954-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.29|i86pc-solaris-64int|5.10.0|solaris|2.11|200809291829
2334984|2334984-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.50|i86pc-solaris-64int|5.10.0|solaris|2.11|200809291642
2334761|2334761-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Parse-CPAN-Distributions|0.05|i86pc-solaris-64int|5.10.0|solaris|2.11|200809291610
2334461|2334461-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|WWW-UsePerl-Journal|0.22||0|||200809291524
2333219|2333219-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809290631
2331775|2331775-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers|0.35|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809290840
2328912|2328912-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.26.5|200809281619
2328786|2328786-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Trackword|1.06|i686-linux|5.8.8|linux|2.6.26.5|200809281552
2328728|2328728-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.26.5|200809281543
2328573|2328573-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-File|0.08|i686-linux|5.8.8|linux|2.6.26.5|200809281526
2328494|2328494-b19f-3f77-b713-d32bba55d77f|pass|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Parse-CPAN-Distributions|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809290417
2328135|2328135-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.26.5|200809281443
2328101|2328101-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|GD-Chart-Radial|0.07|i686-linux|5.10.0|linux|2.6.26.5|200809281440
2328066|2328066-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.6.26.5|200809281437
2328009|2328009-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.6.26.5|200809281430
2327982|2327982-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Calendar-List|0.21|i686-linux|5.8.8|linux|2.6.26.5|200809281426
2327950|2327950-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|GD-Chart-Radial|0.07|i686-linux|5.8.8|linux|2.6.26.5|200809281423
2327773|2327773-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.8.8|linux|2.6.26.5|200809281405
2327726|2327726-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.8.8|linux|2.6.26.5|200809281400
2327359|2327359-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.10.0|linux|2.6.26.5|200809281316
2327202|2327202-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.21|i686-linux|5.10.0|linux|2.6.26.5|200809281254
2327197|2327197-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.8.8|linux|2.6.26.5|200809281253
2326887|2326887-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.21|i686-linux|5.8.8|linux|2.6.26.5|200809281222
2326635|2326635-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.26.5|200809281157
2326370|2326370-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.01|i686-linux|5.10.0|linux|2.6.26.5|200809281131
2326201|2326201-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.8.8|linux|2.6.26.5|200809281109
2326134|2326134-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.26.5|200809281102
2325916|2325916-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.01|i686-linux|5.8.8|linux|2.6.26.5|200809281042
2325877|2325877-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-WWW-Testers|0.35||0|||200809281637
2325646|2325646-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.26.5|200809281019
2325554|2325554-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.8.8|linux|2.6.26.5|200809281009
2325216|2325216-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.10.0|linux|2.6.26.5|200809280933
2325185|2325185-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.10.0|linux|2.6.26.5|200809280930
2325061|2325061-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.8.8|linux|2.6.26.5|200809280919
2324825|2324825-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.26.5|200809280854
2324668|2324668-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.8.8|linux|2.6.26.5|200809280835
2324635|2324635-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.8.8|linux|2.6.26.5|200809280832
2324573|2324573-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.26.5|200809280827
2324378|2324378-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-CPAN-Meta|0.12|i686-linux|5.8.8|linux|2.6.26.5|200809280804
2324083|2324083-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.8.8|linux|2.6.26.5|200809280739
2323122|2323122-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Trackword|1.06|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280539
2323066|2323066-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-File|0.08|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280525
2322843|2322843-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Calendar-List|0.21|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280434
2322837|2322837-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|GD-Chart-Radial|0.07|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280432
2322830|2322830-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280431
2322801|2322801-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280427
2322514|2322514-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280321
2322285|2322285-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.21|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280254
2321723|2321723-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280139
2321554|2321554-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.01|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280117
2321455|2321455-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280100
2321215|2321215-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280029
2321104|2321104-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280004
2321088|2321088-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280001
2320930|2320930-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-CPAN-Meta|0.12|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280325
2320827|2320827-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809280250
2318193|2318193-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809272013
2318020|2318020-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.50|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809272055
2317920|2317920-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809271346
2316164|2316164-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809271919
2315731|2315731-b19f-3f77-b713-d32bba55d77f|pass|200809|jeff@zeroclue.com|CPAN-WWW-Testers-Generator|0.25|darwin-2level|5.10.0|darwin|9.2.0|200809261631
2315279|2315279-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.50|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809270420
2315229|2315229-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.50|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809270910
2315157|2315157-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.50|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809270948
2315129|2315129-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.50|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809270949
2315116|2315116-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.50|i686-linux|5.8.8|linux|2.4.27-3-686|200809270947
2312452|2312452-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809270100
2312163|2312163-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809270304
2311698|2311698-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809262331
2311665|2311665-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809262327
2311647|2311647-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809262322
2311624|2311624-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809262316
2311596|2311596-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809262312
2311583|2311583-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809261807
2311573|2311573-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809262304
2311546|2311546-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809262258
2311524|2311524-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809262254
2311477|2311477-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809262248
2310946|2310946-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200809262113
2310514|2310514-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.50|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809262115
2310408|2310408-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200809262002
2310126|2310126-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int|5.8.8|linux|2.6.26.3-29.fc9.i686|200809261914
2309683|2309683-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Mail-Outlook|0.14|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809261852
2309528|2309528-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|CPAN-Testers-WWW-Statistics|0.49|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809261730
2309134|2309134-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|Mail-Outlook|0.14|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809261643
2308805|2308805-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int|5.10.0|linux|2.6.26.3-29.fc9.i686|200809261603
2308749|2308749-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|Parse-CPAN-Distributions|0.05|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809261557
2308060|2308060-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.50|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809261452
2308057|2308057-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.50|i386-freebsd|5.10.0|freebsd|6.1-release|200809261450
2307990|2307990-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-Testers-WWW-Statistics|0.50||0|||200809261437
2306641|2306641-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.26.5|200809260422
2305306|2305306-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.8.8|linux|2.6.26.5|200809260327
2304285|2304285-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.11.0 patch 34419|solaris|2.10|200809260113
2299794|2299794-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809250846
2296934|2296934-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250157
2296930|2296930-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250157
2296929|2296929-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250157
2296926|2296926-b19f-3f77-b713-d32bba55d77f|fail|200809|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250156
2296923|2296923-b19f-3f77-b713-d32bba55d77f|fail|200809|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250155
2294573|2294573-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.8.8 patch 34415|solaris|2.10|200809250121
2294556|2294556-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.8.8 patch 34415|solaris|2.10|200809250119
2294231|2294231-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.10.0 patch 34413|solaris|2.10|200809250038
2294228|2294228-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.10.0 patch 34413|solaris|2.10|200809250036
2293382|2293382-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809241754
2291953|2291953-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809242129
2291859|2291859-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809242127
2291848|2291848-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809242126
2291402|2291402-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.26.5|200809241329
2291400|2291400-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.26.5|200809241329
2291279|2291279-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.29|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-386|200809241309
2290685|2290685-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.8|linux|2.6.26.5|200809241144
2290683|2290683-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.8.8|linux|2.6.26.5|200809241144
2286032|2286032-b19f-3f77-b713-d32bba55d77f|pass|200809|dmdk1@comcast.net|Parse-CPAN-Distributions|0.05|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809240215
2283686|2283686-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809231619
2283682|2283682-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809231619
2282819|2282819-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231413
2282818|2282818-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231413
2282790|2282790-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809231909
2282756|2282756-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809231906
2282732|2282732-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200809231904
2282696|2282696-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200809231901
2282597|2282597-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809231851
2282568|2282568-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809231849
2282119|2282119-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.49|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231316
2282072|2282072-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.14|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231312
2282002|2282002-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231308
2281994|2281994-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231307
2281935|2281935-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231303
2281929|2281929-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231303
2281611|2281611-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Parse-CPAN-Distributions|0.04|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231242
2281389|2281389-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.28|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231227
2281383|2281383-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPAN-Testers-WWW-Statistics|0.49|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231227
2281221|2281221-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.14|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231215
2280449|2280449-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|Test-YAML-Meta|0.11|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809231509
2280257|2280257-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Test-YAML-Meta|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809231543
2278975|2278975-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Finance-Currency-Convert-XE|0.15|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809231258
2278876|2278876-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230655
2278843|2278843-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230653
2273048|2273048-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230153
2271937|2271937-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230054
2271289|2271289-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230011
2271060|2271060-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230356
2270074|2270074-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809222342
2270058|2270058-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809222334
2270030|2270030-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809222327
2269998|2269998-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809222319
2269934|2269934-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809222304
2269899|2269899-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809222258
2269873|2269873-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809222251
2269859|2269859-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809222245
2269843|2269843-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200809222241
2269837|2269837-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200809222239
2269833|2269833-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200809222237
2269829|2269829-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200809222235
2268222|2268222-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd-thread-multi-64int|5.8.8 patch 34395|freebsd|7.0-release|200809221432
2268201|2268201-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd-thread-multi-64int|5.8.8 patch 34395|freebsd|7.0-release|200809221429
2268180|2268180-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi-64int|5.8.8 patch 34395|freebsd|7.0-release|200809221426
2268160|2268160-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi-64int|5.8.8 patch 34395|freebsd|7.0-release|200809221423
2267948|2267948-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd-thread-multi-64int|5.10.0 patch 34372|freebsd|7.0-release|200809221355
2267934|2267934-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd-thread-multi-64int|5.10.0 patch 34372|freebsd|7.0-release|200809221352
2267925|2267925-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi-64int|5.10.0 patch 34372|freebsd|7.0-release|200809221349
2267918|2267918-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi-64int|5.10.0 patch 34372|freebsd|7.0-release|200809221348
2267507|2267507-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809221043
2267444|2267444-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.05|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809221509
2267442|2267442-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809221508
2267441|2267441-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809221508
2267439|2267439-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809221508
2267435|2267435-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.49|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809221506
2267302|2267302-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809221220
2267295|2267295-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809221219
2267289|2267289-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809221218
2267284|2267284-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809221217
2267140|2267140-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809221157
2267134|2267134-b19f-3f77-b713-d32bba55d77f|pass|200809|frank.wiegand@gmail.com ("Frank Wiegand")|Parse-CPAN-Distributions|0.05|i686-linux|5.11.0 patch 34384|linux|2.6.24-21-generic|200809221419
2266757|2266757-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809221028
2266596|2266596-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809221035
2266595|2266595-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809221020
2266272|2266272-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|CPAN-WWW-Testers-Generator|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200809221151
2266266|2266266-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200809221150
2262879|2262879-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.29|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809212116
2262844|2262844-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809212114
2260545|2260545-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.29|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809211506
2260513|2260513-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809211502
2260338|2260338-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.29|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809210833
2260293|2260293-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809210826
2260202|2260202-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.29|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809211311
2260151|2260151-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809211302
2259964|2259964-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.29|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809211340
2259922|2259922-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809211336
2259820|2259820-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.29|IP35-irix-64int|5.8.8|irix|6.5|200809211421
2259722|2259722-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|IP35-irix-64int|5.8.8|irix|6.5|200809211418
2259674|2259674-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.29|i686-linux|5.8.8|linux|2.4.27-3-686|200809211316
2259649|2259649-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|i686-linux|5.8.8|linux|2.4.27-3-686|200809211312
2259630|2259630-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.05|i686-linux|5.6.2|linux|2.4.27-3-686|200809211310
2259534|2259534-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809211258
2259518|2259518-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809211256
2259512|2259512-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809211255
2259504|2259504-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809211254
2259503|2259503-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809211254
2259464|2259464-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809211253
2259430|2259430-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809211252
2259408|2259408-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809211251
2259108|2259108-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809211232
2259105|2259105-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809211231
2258892|2258892-b19f-3f77-b713-d32bba55d77f|pass|200809|shlomif@cpan.org|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.27-desktop-0.rc6.3.2mnb|200809211338
2258388|2258388-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.29|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809211018
2258018|2258018-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.8.8|linux|2.6.26.5|200809210339
2257851|2257851-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809210909
2257645|2257645-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809210233
2257543|2257543-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.26.5|200809210213
2256782|2256782-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809210225
2256508|2256508-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.8.8|linux|2.6.26.5|200809210002
2256472|2256472-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809210250
2256457|2256457-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.04|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809210244
2256431|2256431-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809210236
2256414|2256414-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809210230
2256355|2256355-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809210013
2256353|2256353-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809210012
2256351|2256351-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809210011
2256348|2256348-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809210010
2256340|2256340-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809210009
2256334|2256334-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809210008
2256329|2256329-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809210006
2256323|2256323-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809210005
2256318|2256318-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200809210004
2256313|2256313-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809210003
2256304|2256304-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.26.5|200809201902
2256268|2256268-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809201849
2255287|2255287-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.29|i386-freebsd|5.6.2|freebsd|6.1-release|200809202039
2255256|2255256-b19f-3f77-b713-d32bba55d77f|pass|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809210316
2255194|2255194-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.6.2|freebsd|6.1-release|200809201943
2254964|2254964-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.29|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809201739
2254836|2254836-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200809201602
2254822|2254822-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200809201558
2254808|2254808-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200809201554
2254792|2254792-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200809201550
2254520|2254520-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809201403
2254508|2254508-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809201359
2254498|2254498-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809201356
2254492|2254492-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809201354
2254470|2254470-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809201350
2254452|2254452-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809201348
2254439|2254439-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809201345
2254428|2254428-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809201343
2254256|2254256-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.29|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809201438
2254249|2254249-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.10.0|linux|2.6.24.3|200809200733
2254078|2254078-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.11.0 patch 34379|linux|2.6.24.3|200809200627
2253895|2253895-b19f-3f77-b713-d32bba55d77f|pass|200809|shlomif@cpan.org|Parse-CPAN-Distributions|0.04|i686-linux|5.10.0|linux|2.6.27-desktop-0.rc6.3.2mnb|200809201247
2253889|2253889-b19f-3f77-b713-d32bba55d77f|pass|200809|shlomif@cpan.org|CPAN-WWW-Testers-Generator|0.28|i686-linux|5.10.0|linux|2.6.27-desktop-0.rc6.3.2mnb|200809201247
2253743|2253743-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.05|i686-linux|5.8.8|linux|2.6.24.3|200809200511
2253631|2253631-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Mail-Outlook|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809200915
2253605|2253605-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809200925
2251195|2251195-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809192245
2251164|2251164-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809192241
2251123|2251123-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809192237
2251089|2251089-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809192231
2251040|2251040-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809192227
2251037|2251037-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Parse-CPAN-Distributions|0.04|i686-linux|5.10.0|linux|2.4.27-2-386|200809200026
2250993|2250993-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809192222
2250943|2250943-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.29|i386-freebsd|5.10.0|freebsd|6.1-release|200809192316
2250936|2250936-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809192217
2250857|2250857-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809192212
2250706|2250706-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.49|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809192206
2250580|2250580-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.10.0|freebsd|6.1-release|200809192258
2250532|2250532-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.28|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809192200
2250508|2250508-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-UsePerl-Journal|0.21|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192114
2250478|2250478-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.28|i686-linux|5.10.0|linux|2.4.27-2-386|200809191816
2250467|2250467-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.49|i686-linux|5.10.0|linux|2.4.27-2-386|200809191815
2250123|2250123-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.29|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809191607
2249729|2249729-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.27|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192111
2249454|2249454-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809190854
2249269|2249269-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809192149
2249241|2249241-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|Parse-CPAN-Distributions|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809200345
2249239|2249239-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|Mail-Outlook|0.14|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809200345
2249227|2249227-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.49|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809200343
2248611|2248611-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809191650
2248553|2248553-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.28|i386-freebsd|5.6.2|freebsd|6.1-release|200809190953
2248541|2248541-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd|5.6.2|freebsd|6.1-release|200809191200
2248525|2248525-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.49|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809191319
2248522|2248522-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.28|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809191320
2248503|2248503-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.05|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809191340
2248502|2248502-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809191215
2248485|2248485-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.6.2|freebsd|6.1-release|200809190855
2248444|2248444-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809191634
2248047|2248047-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809192007
2247924|2247924-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.8.8|linux|2.6.24.3|200809191339
2247883|2247883-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.10.0|linux|2.6.24.3|200809191333
2247547|2247547-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809191709
2247537|2247537-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809191706
2247524|2247524-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809191700
2247520|2247520-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.05|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809191658
2247274|2247274-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809191756
2246985|2246985-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-WWW-Testers|0.34||0|||200809191518
2246896|2246896-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i386-dragonfly-thread-multi-64int|5.10.0 patch 34372|dragonfly|2.0.0-release|200809191425
2246869|2246869-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i386-dragonfly-thread-multi-64int|5.10.0 patch 34372|dragonfly|2.0.0-release|200809191421
2246852|2246852-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i386-dragonfly-thread-multi-64int|5.10.0 patch 34372|dragonfly|2.0.0-release|200809191416
2246835|2246835-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i386-dragonfly-thread-multi-64int|5.10.0 patch 34372|dragonfly|2.0.0-release|200809191413
2246501|2246501-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.11.0 patch 34379|linux|2.6.24.3|200809190748
2245811|2245811-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|i686-linux|5.6.2|linux|2.4.27-3-686|200809191141
2245699|2245699-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809191023
2245695|2245695-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.28|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809191022
2245677|2245677-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.49|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809191020
2245653|2245653-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809190518
2245644|2245644-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.28|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809190518
2245631|2245631-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.49|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809190516
2245625|2245625-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809191112
2245622|2245622-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.28|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809191111
2245613|2245613-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.49|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809191110
2245580|2245580-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809191107
2245579|2245579-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.28|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809191107
2245573|2245573-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.49|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809191106
2245560|2245560-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|IP35-irix-64int|5.8.8|irix|6.5|200809191205
2245550|2245550-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.28|IP35-irix-64int|5.8.8|irix|6.5|200809191204
2245547|2245547-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Mail-Outlook|0.14|i686-linux|5.8.8|linux|2.4.27-3-686|200809191103
2245544|2245544-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.28|i686-linux|5.8.8|linux|2.4.27-3-686|200809191103
2245538|2245538-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.49|i686-linux|5.8.8|linux|2.4.27-3-686|200809191102
2245437|2245437-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-WWW-Testers-Generator|0.29||0|||200809191150
2245222|2245222-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i686-linux-thread-multi-64int-ld|5.11.0 patch 34379|linux|2.6.21.5-smp|200809191005
2245212|2245212-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.11.0 patch 34379|linux|2.6.21.5-smp|200809191003
2245203|2245203-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.11.0 patch 34379|linux|2.6.21.5-smp|200809191000
2245187|2245187-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.11.0 patch 34379|linux|2.6.21.5-smp|200809190958
2245094|2245094-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|Parse-CPAN-Distributions|0.05||0|||200809191048
2244332|2244332-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-Outlook|0.14|i686-linux|5.11.0 patch 34379|linux|2.6.24.3|200809190249
2243892|2243892-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.28|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809190646
2243887|2243887-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.49|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809190642
2243525|2243525-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.28|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809190403
2243511|2243511-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809190157
2243507|2243507-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809190156
2243505|2243505-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809190155
2243499|2243499-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809190154
2243495|2243495-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809190153
2243492|2243492-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809190152
2243489|2243489-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809190151
2243487|2243487-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809190149
2243481|2243481-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809190147
2243477|2243477-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-Testers-WWW-Statistics|0.49|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809190347
2243038|2243038-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.04|i386-dragonfly-thread-multi-64int|5.8.8 patch 34376|dragonfly|2.0.0-release|200809182332
2243027|2243027-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i386-dragonfly-thread-multi-64int|5.8.8 patch 34376|dragonfly|2.0.0-release|200809182329
2243011|2243011-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i386-dragonfly-thread-multi-64int|5.8.8 patch 34376|dragonfly|2.0.0-release|200809182326
2242999|2242999-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i386-dragonfly-thread-multi-64int|5.8.8 patch 34376|dragonfly|2.0.0-release|200809182324
2242978|2242978-b19f-3f77-b713-d32bba55d77f|pass|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Mail-Outlook|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809190643
2242964|2242964-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.28|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809182334
2242963|2242963-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.49|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809182334
2242925|2242925-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809182324
2242924|2242924-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd|5.10.0|freebsd|6.1-release|200809182323
2242827|2242827-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809182301
2242473|2242473-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.28|i386-freebsd|5.10.0|freebsd|6.1-release|200809182100
2242472|2242472-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.49|i386-freebsd|5.10.0|freebsd|6.1-release|200809182059
2242465|2242465-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.28|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809182057
2242464|2242464-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.49|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809182057
2242338|2242338-b19f-3f77-b713-d32bba55d77f|pass|200809|dmdk1@comcast.net|Parse-CPAN-Distributions|0.04|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809181415
2242174|2242174-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-Outlook|0.14|i386-freebsd|5.10.0|freebsd|6.1-release|200809181913
2242134|2242134-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|Mail-Outlook|0.14||0|||200809181859
2242111|2242111-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.04|i686-linux|5.8.8|linux|2.6.24.3|200809181249
2241588|2241588-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-Testers-WWW-Statistics|0.49||0|||200809181548
2241584|2241584-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-WWW-Testers-Generator|0.28||0|||200809181547
2241281|2241281-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200809181302
2241273|2241273-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200809181259
2241263|2241263-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200809181257
2241247|2241247-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200809181254
2241093|2241093-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809181124
2241084|2241084-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|IP35-irix-64int|5.8.8|irix|6.5|200809181237
2241078|2241078-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809181035
2241076|2241076-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809180534
2241074|2241074-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809181133
2241072|2241072-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|i686-linux|5.8.8|linux|2.4.27-3-686|200809181133
2240564|2240564-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.04|i686-linux|5.6.2|linux|2.4.27-3-686|200809180910
2240552|2240552-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809180907
2240541|2240541-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809180904
2240540|2240540-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809180904
2240532|2240532-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809180901
2240527|2240527-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809180859
2240524|2240524-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809180859
2240519|2240519-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809180857
2240506|2240506-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809180855
2240431|2240431-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200809180907
2240428|2240428-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200809180906
2240424|2240424-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200809180905
2240421|2240421-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200809180904
2239785|2239785-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.03|i686-linux|5.8.8|linux|2.6.24.3|200809180038
2238583|2238583-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809180202
2238556|2238556-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809180158
2238543|2238543-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809180155
2238525|2238525-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.04|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809180153
2235646|2235646-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.27|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809172012
2235641|2235641-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.26|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809172012
2235639|2235639-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.25|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809172011
2235539|2235539-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.27|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809171955
2235534|2235534-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.26|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809171955
2235528|2235528-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.25|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809171953
2235092|2235092-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi-64int|5.8.8 patch 34376|freebsd|6.2-release|200809171039
2235086|2235086-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi-64int|5.8.8 patch 34376|freebsd|6.2-release|200809171038
2235077|2235077-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi-64int|5.8.8 patch 34376|freebsd|6.2-release|200809171037
2234467|2234467-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.11.0 patch 34378|linux|2.6.24-19-generic|200809171345
2234443|2234443-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.11.0 patch 34378|linux|2.6.24-19-generic|200809171338
2234437|2234437-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.11.0 patch 34378|linux|2.6.24-19-generic|200809171335
2234136|2234136-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.04|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809171302
2233790|2233790-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 34376|linux|2.6.24-19-generic|200809171029
2233781|2233781-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.8.8 patch 34376|linux|2.6.24-19-generic|200809171027
2233768|2233768-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.8.8 patch 34376|linux|2.6.24-19-generic|200809171026
2233641|2233641-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|Parse-CPAN-Distributions|0.04||0|||200809171102
2233502|2233502-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809170925
2233501|2233501-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809170924
2233500|2233500-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809170924
2233499|2233499-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809170923
2233498|2233498-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809170922
2233497|2233497-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809170922
2233496|2233496-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809170921
2233495|2233495-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809170921
2233494|2233494-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200809170920
2233492|2233492-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809170920
2233475|2233475-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809170909
2233474|2233474-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809170909
2233472|2233472-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809170908
2233471|2233471-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809170908
2233469|2233469-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809170907
2233465|2233465-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809170906
2233461|2233461-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809170906
2233460|2233460-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809170905
2233459|2233459-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200809170905
2233458|2233458-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809170904
2232284|2232284-b19f-3f77-b713-d32bba55d77f|pass|200809|dmdk1@comcast.net|Test-YAML-Meta|0.11|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809170152
2232196|2232196-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809170232
2232177|2232177-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809170230
2232171|2232171-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809170229
2232167|2232167-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809170227
2232153|2232153-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809170223
2232145|2232145-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809170222
2232133|2232133-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809170220
2232129|2232129-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809170219
2231795|2231795-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809170121
2231045|2231045-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 34372|linux|2.6.24-19-generic|200809162055
2231037|2231037-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 34372|linux|2.6.24-19-generic|200809162054
2231030|2231030-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.10.0 patch 34372|linux|2.6.24-19-generic|200809162053
2230876|2230876-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809162103
2230583|2230583-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200809161835
2230578|2230578-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200809161834
2230576|2230576-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200809161832
2230461|2230461-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd|5.6.2|freebsd|6.1-release|200809161856
2230141|2230141-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809161743
2229839|2229839-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809161422
2229838|2229838-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809161421
2229837|2229837-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809161421
2229834|2229834-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809161418
2229831|2229831-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809161417
2229830|2229830-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809161416
2229593|2229593-b19f-3f77-b713-d32bba55d77f|pass|200809|dmdk1@comcast.net|Parse-CPAN-Distributions|0.03|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809160632
2228913|2228913-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd|5.10.0|freebsd|6.1-release|200809161205
2228771|2228771-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|Parse-CPAN-Distributions|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809161651
2228673|2228673-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809160817
2228670|2228670-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809160816
2228669|2228669-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809160913
2228665|2228665-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809160912
2228664|2228664-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|IP35-irix-64int|5.8.8|irix|6.5|200809161014
2228663|2228663-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809160314
2228661|2228661-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|IP35-irix-64int|5.8.8|irix|6.5|200809161014
2228660|2228660-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809160314
2228657|2228657-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809160911
2228655|2228655-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809160911
2228653|2228653-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|i686-linux|5.8.8|linux|2.4.27-3-686|200809160911
2228652|2228652-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.03|i686-linux|5.6.2|linux|2.4.27-3-686|200809160911
2228649|2228649-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|i686-linux|5.6.2|linux|2.4.27-3-686|200809160910
2228648|2228648-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.02|i686-linux|5.8.8|linux|2.4.27-3-686|200809160910
2228072|2228072-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809160529
2227779|2227779-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809160151
2227588|2227588-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd|5.6.2|freebsd|6.1-release|200809160026
2227060|2227060-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.03|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809152105
2226296|2226296-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809151705
2226240|2226240-b19f-3f77-b713-d32bba55d77f|fail|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809151656
2225962|2225962-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|Parse-CPAN-Distributions|0.03||0|||200809151650
2225863|2225863-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809151634
2225852|2225852-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi-64int|5.8.8 patch 34360|freebsd|7.0-release|200809151153
2225763|2225763-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Parse-CPAN-Distributions|0.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809151604
2225705|2225705-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.8.8|linux|2.6.24.3|200809150951
2225671|2225671-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.02|i386-freebsd|5.10.0|freebsd|6.1-release|200809151537
2225556|2225556-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|Parse-CPAN-Distributions|0.02||0|||200809151506
2225488|2225488-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-File|0.08|i686-linux|5.8.8|linux|2.6.24.3|200809150837
2225277|2225277-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.8.8|linux|2.6.24.3|200809150721
2224606|2224606-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.8.8|linux|2.6.24.3|200809150502
2224056|2224056-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.01|i686-linux|5.8.8|linux|2.6.24.3|200809150313
2223931|2223931-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Parse-CPAN-Distributions|0.01|i686-linux|5.10.0|linux|2.6.24.3|200809150256
2223583|2223583-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.8.8|linux|2.6.24.3|200809150159
2221486|2221486-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809150139
2219047|2219047-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809141832
2218167|2218167-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi-64int|5.10.0 patch 34342|freebsd|7.0-release|200809141333
2218050|2218050-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200809141335
2217983|2217983-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200809141326
2217367|2217367-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.10.0|linux|2.6.24.3|200809140633
2217243|2217243-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809141026
2216972|2216972-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.24.3|200809140401
2216519|2216519-b19f-3f77-b713-d32bba55d77f|pass|200809|dmdk1@comcast.net|Parse-CPAN-Distributions|0.01|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809140215
2216415|2216415-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.24.3|200809140223
2214985|2214985-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.24.3|200809140248
2214911|2214911-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.8.8|linux|2.6.24.3|200809140237
2214378|2214378-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.6.24.3|200809140103
2213654|2213654-b19f-3f77-b713-d32bba55d77f|unknown|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.8.8|linux|2.6.24.3|200809131950
2211332|2211332-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809131900
2210741|2210741-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Parse-CPAN-Distributions|0.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200809131723
2210033|2210033-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd|5.6.2|freebsd|6.1-release|200809131528
2209853|2209853-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Trackword|1.06|i686-linux|5.8.8|linux|2.6.24.3|200809130857
2209439|2209439-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd|5.10.0|freebsd|6.1-release|200809131339
2209344|2209344-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809131131
2209339|2209339-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809130631
2209329|2209329-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809131229
2208840|2208840-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.01|IP35-irix-64int|5.8.8|irix|6.5|200809131230
2208837|2208837-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.01|i686-linux|5.6.2|linux|2.4.27-3-686|200809131129
2208813|2208813-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Parse-CPAN-Distributions|0.01|i686-linux|5.8.8|linux|2.4.27-3-686|200809131127
2208711|2208711-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809131054
2208709|2208709-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809131053
2208706|2208706-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809131052
2208705|2208705-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809131052
2208702|2208702-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809131051
2208693|2208693-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809131050
2208687|2208687-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809131050
2208684|2208684-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809131049
2208665|2208665-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200809131048
2208652|2208652-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809131048
2208578|2208578-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|Parse-CPAN-Distributions|0.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809131731
2206225|2206225-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809130415
2206213|2206213-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809130410
2206166|2206166-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809130357
2206159|2206159-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Parse-CPAN-Distributions|0.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809130355
2204842|2204842-b19f-3f77-b713-d32bba55d77f|fail|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130218
2204777|2204777-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130216
2204722|2204722-b19f-3f77-b713-d32bba55d77f|fail|200809|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130213
2204588|2204588-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|CPAN-WWW-Testers-Generator|0.27|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809121635
2204575|2204575-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130207
2204482|2204482-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130202
2204436|2204436-b19f-3f77-b713-d32bba55d77f|fail|200809|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130158
2204414|2204414-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130153
2204391|2204391-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130150
2204378|2204378-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130148
2204372|2204372-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Mail-File|0.08|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130146
2204371|2204371-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Games-Trackword|1.06|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130145
2204369|2204369-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130144
2204346|2204346-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130142
2204319|2204319-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130140
2204312|2204312-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130139
2204304|2204304-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130137
2204282|2204282-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130136
2204273|2204273-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130133
2204267|2204267-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130132
2204257|2204257-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Calendar-List|0.21|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809130131
2201808|2201808-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.8.8|linux|2.6.24.3|200809121443
2201744|2201744-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809122026
2201632|2201632-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Parse-CPAN-Distributions|0.01|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809122011
2201153|2201153-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.24.3|200809121303
2200886|2200886-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|Parse-CPAN-Distributions|0.01||0|||200809121832
2199134|2199134-b19f-3f77-b713-d32bba55d77f|unknown|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.10.0|linux|2.6.24.3|200809120911
2198985|2198985-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-CPAN-Meta|0.12|i686-linux|5.8.8|linux|2.6.24.3|200809120850
2197133|2197133-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.8.8|linux|2.6.24.3|200809120404
2195019|2195019-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.21|i686-linux|5.8.8|linux|2.6.24.3|200809111912
2193426|2193426-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.27|i386-freebsd|5.6.2|freebsd|6.1-release|200809112054
2192181|2192181-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.27|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809111658
2192018|2192018-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.27|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809111653
2191986|2191986-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111654
2191955|2191955-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111653
2191943|2191943-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111654
2191311|2191311-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.27|i86pc-solaris-64int|5.10.0|solaris|2.11|200809111632
2190575|2190575-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.27|i386-freebsd|5.10.0|freebsd|6.1-release|200809111428
2190144|2190144-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111412
2189662|2189662-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.27|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809111326
2189451|2189451-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111220
2188209|2188209-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-WWW-Testers-Generator|0.27||0|||200809111056
2188021|2188021-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111035
2184824|2184824-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102327
2184823|2184823-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102325
2184822|2184822-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102324
2183867|2183867-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.24.3|200809101449
2179546|2179546-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179345|2179345-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100846
2178705|2178705-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100848
2178115|2178115-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100846
2177930|2177930-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.48|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2177924|2177924-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.26|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2177820|2177820-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100844
2174008|2174008-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809091937
2173607|2173607-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809091836
2173606|2173606-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809091836
2173604|2173604-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809091836
2168892|2168892-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.6.24.3|200809090057
2168804|2168804-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.8.8|linux|2.6.24.3|200809090047
2167734|2167734-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|GD-Chart-Radial|0.07|i686-linux|5.8.8|linux|2.6.24.3|200809090148
2167605|2167605-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Mail-File|0.08|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090331
2167603|2167603-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Regexp-Log-Common|0.05|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090331
2167049|2167049-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-Outlook|0.06|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090206
2167047|2167047-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-WebList|0.05|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090205
2167042|2167042-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTP|0.05|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090202
2167041|2167041-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090202
2166973|2166973-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809090040
2166926|2166926-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809090026
2166024|2166024-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809082325
2166006|2166006-b19f-3f77-b713-d32bba55d77f|pass|200809|dwheeler@cpan.org|Test-YAML-Meta|0.11|darwin-2level|5.10.0|darwin|9.4.0|200809082129
2165955|2165955-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809082325
2165663|2165663-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809082257
2164485|2164485-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.24.3|200809081416
2162942|2162942-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.10.0|linux|2.6.24.3|200809081009
2162294|2162294-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809081238
2162293|2162293-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809081237
2162288|2162288-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809081235
2162287|2162287-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809081234
2161032|2161032-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|WWW-UsePerl-Journal|0.21|i686-linux|5.10.0|linux|2.6.24.3|200809080318
2159632|2159632-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.26|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809080029
2159615|2159615-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.48|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809080027
2157889|2157889-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.26|IP35-irix-64int|5.8.8|irix|6.5|200809072059
2157584|2157584-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.26|i686-linux|5.8.8|linux|2.4.27-3-686|200809071902
2157488|2157488-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.48|i686-linux|5.8.8|linux|2.4.27-3-686|200809071845
2156662|2156662-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.24.3|200809071057
2156268|2156268-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch 34282|linux|2.6.21.5-smp|200809071353
2156266|2156266-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch 34282|linux|2.6.21.5-smp|200809071353
2155934|2155934-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.8.8|linux|2.6.24.3|200809070716
2155899|2155899-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.26|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809070608
2155832|2155832-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.48|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809070555
2154286|2154286-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.24.3|200809070111
2154285|2154285-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24.3|200809070111
2146766|2146766-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809051944
2146759|2146759-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809051943
2145614|2145614-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809051523
2145489|2145489-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.24.3|200809051003
2145203|2145203-b19f-3f77-b713-d32bba55d77f|pass|200809|jrockway@cpan.org|Test-YAML-Meta|0.11|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200809050732
2143992|2143992-b19f-3f77-b713-d32bba55d77f|fail|200809|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.10|i86pc-solaris-64int|5.10.0|solaris|2.11|200809051116
2143988|2143988-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|WWW-UsePerl-Journal|0.21|i86pc-solaris-64int|5.10.0|solaris|2.11|200809051116
2142422|2142422-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|GD-Chart-Radial|0.07|i686-linux|5.10.0|linux|2.6.24.3|200809050100
2141487|2141487-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|CPAN-WWW-Testers-Generator|0.25|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809050201
2139471|2139471-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|CPAN-Testers-WWW-Statistics|0.48|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809042234
2139454|2139454-b19f-3f77-b713-d32bba55d77f|pass|200809|autarch@urth.org|WWW-UsePerl-Journal|0.21|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200809041000
2138943|2138943-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.15|i86pc-solaris-64int|5.10.0|solaris|2.11|200809041948
2138812|2138812-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809041718
2138810|2138810-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809041716
2138512|2138512-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.03|i86pc-solaris-64int|5.10.0|solaris|2.11|200809041740
2137749|2137749-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.25|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200809041251
2134098|2134098-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.25|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809031706
2133935|2133935-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.26|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809031948
2133871|2133871-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.25|i686-linux|5.8.8|linux|2.4.27-3-686|200809031920
2133859|2133859-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.48|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809031915
2133852|2133852-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.26|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809031814
2133695|2133695-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-Testers-WWW-Statistics|0.48|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809031747
2133403|2133403-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031843
2133402|2133402-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Data-Phrasebook|0.29|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031843
2133398|2133398-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.48|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809031839
2133038|2133038-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.26|i386-freebsd|5.6.2|freebsd|6.1-release|200809031734
2132302|2132302-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.26|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809031445
2132207|2132207-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809031203
2132068|2132068-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809031125
2132056|2132056-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809031233
2132052|2132052-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809031231
2132044|2132044-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809031228
2132038|2132038-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809031226
2132031|2132031-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809031223
2132026|2132026-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809031221
2132020|2132020-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809031219
2132015|2132015-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809031216
2132007|2132007-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-Testers-WWW-Statistics|0.48|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809031213
2131944|2131944-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200809031300
2131838|2131838-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.48|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809031227
2131773|2131773-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.26|i86pc-solaris-64int|5.10.0|solaris|2.11|200809031210
2131768|2131768-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-Testers-WWW-Statistics|0.48|i86pc-solaris-64int|5.10.0|solaris|2.11|200809031209
2131735|2131735-b19f-3f77-b713-d32bba55d77f|fail|200809|vpit@cpan.org|CPAN-WWW-Testers-Generator|0.26|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200809031201
2131732|2131732-b19f-3f77-b713-d32bba55d77f|fail|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.26|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809031059
2131355|2131355-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.48|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809031123
2131275|2131275-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|CPAN-Testers-WWW-Statistics|0.48|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809031713
2130598|2130598-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.26|i386-freebsd|5.10.0|freebsd|6.1-release|200809031000
2130080|2130080-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.26|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809030819
2130010|2130010-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-Testers-WWW-Statistics|0.48|i386-freebsd|5.10.0|freebsd|6.1-release|200809030845
2129768|2129768-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809030744
2128787|2128787-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-Testers-WWW-Statistics|0.48||0|||200809030203
2128258|2128258-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.25|IP35-irix-64int|5.8.8|irix|6.5|200809030045
2127841|2127841-b19f-3f77-b713-d32bba55d77f|cpan|200809|BARBIE|CPAN-WWW-Testers-Generator|0.26||0|||200809022319
2127302|2127302-b19f-3f77-b713-d32bba55d77f|pass|200809|shlomif@cpan.org|CPAN-WWW-Testers-Generator|0.25|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200809022210
2126220|2126220-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809021600
2126213|2126213-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809021559
2125629|2125629-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Test-YAML-Meta|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809011947
2124190|2124190-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809020607
2124189|2124189-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809020607
2123195|2123195-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.25|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809012144
2123193|2123193-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.25|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809012243
2122142|2122142-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|CPAN-WWW-Testers-Generator|0.25|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200809011608
2121278|2121278-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809011109
2120926|2120926-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809010921
2120361|2120361-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.25|i686-linux|5.8.8|linux|2.4.27-2-386|200809010602
2120231|2120231-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|CPAN-WWW-Testers-Generator|0.25|i686-linux|5.10.0|linux|2.4.27-2-386|200809010511
2115709|2115709-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808311327
2114880|2114880-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808311030
2114071|2114071-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808310415
2114070|2114070-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808310414
2113898|2113898-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808310231
2113896|2113896-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808310231
2113887|2113887-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808310229
2113886|2113886-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808310229
2113882|2113882-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200808310228
2113875|2113875-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808310226
2113873|2113873-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808310226
2113470|2113470-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808302247
2113466|2113466-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808302246
2113120|2113120-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200808302020
2113119|2113119-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200808302019
2113049|2113049-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808301949
2113045|2113045-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808301948
2112968|2112968-b19f-3f77-b713-d32bba55d77f|pass|200808|rurban@x-ray.at (Reini Urban)|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200808301817
2112729|2112729-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808301736
2112725|2112725-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808301734
2111920|2111920-b19f-3f77-b713-d32bba55d77f|pass|200808|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers-Generator|0.25|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200808301956
2109677|2109677-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.25|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808300139
2109504|2109504-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808292358
2109501|2109501-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808292357
2109498|2109498-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808292356
2109490|2109490-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808292355
2109487|2109487-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808292353
2109485|2109485-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808292352
2109483|2109483-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808292351
2109478|2109478-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808292350
2109476|2109476-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.25|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808292348
2109462|2109462-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.25|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808300036
2109448|2109448-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.25|i386-freebsd|5.10.0|freebsd|6.1-release|200808300031
2109304|2109304-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.25|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808292345
2109194|2109194-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.25|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808292305
2109078|2109078-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.25|i386-freebsd|5.6.2|freebsd|6.1-release|200808292219
2106482|2106482-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.6.2|linux|2.6.24.3|200808290657
2106471|2106471-b19f-3f77-b713-d32bba55d77f|cpan|200808|BARBIE|CPAN-WWW-Testers-Generator|0.25||0|||200808291251
2105277|2105277-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24.3|200808290322
2102387|2102387-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808282035
2102378|2102378-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808282034
2102108|2102108-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808282001
2102103|2102103-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808282000
2101905|2101905-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808282300
2101902|2101902-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808282300
2099624|2099624-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808281243
2099618|2099618-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808281242
2099088|2099088-b19f-3f77-b713-d32bba55d77f|pass|200808|cpan@herlpacker.co.uk|Data-Phrasebook|0.29|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808281008
2098476|2098476-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808281245
2098463|2098463-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808281244
2098435|2098435-b19f-3f77-b713-d32bba55d77f|pass|200808|cpan@herlpacker.co.uk|Data-Phrasebook-Loader-YAML|0.09|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808281008
2097810|2097810-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808280910
2097807|2097807-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808280909
2097359|2097359-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.6.2|linux|2.6.24.3|200808280045
2096441|2096441-b19f-3f77-b713-d32bba55d77f|fail|200808|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.10.0|linux|2.4.27-2-386|200808280143
2096437|2096437-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|WWW-UsePerl-Journal|0.21|i686-linux|5.10.0|linux|2.4.27-2-386|200808280143
2095937|2095937-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.24.3|200808271619
2095809|2095809-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Calendar-List|0.21|i686-linux|5.8.8|linux|2.6.24.3|200808271547
2095603|2095603-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.10.0|linux|2.6.24.3|200808271440
2095591|2095591-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.10.0|linux|2.6.24.3|200808271438
2095587|2095587-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.10.0|linux|2.6.24.3|200808271436
2095567|2095567-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.10.0|linux|2.6.24.3|200808271434
2095556|2095556-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-WWW-Testers-Generator|0.24|i686-linux|5.10.0|linux|2.6.24.3|200808271433
2095555|2095555-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.8.8|linux|2.6.24.3|200808271433
2095536|2095536-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.8.8|linux|2.6.24.3|200808271419
2095528|2095528-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.8.8|linux|2.6.24.3|200808271424
2095506|2095506-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.8.8|linux|2.6.24.3|200808271412
2095493|2095493-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-WWW-Testers-Generator|0.24|i686-linux|5.8.8|linux|2.6.24.3|200808271408
2095064|2095064-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.24.3|200808270805
2093572|2093572-b19f-3f77-b713-d32bba55d77f|fail|200808|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.10.0|linux|2.4.27-2-386|200808271137
2093530|2093530-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.4.27-2-386|200808271131
2093529|2093529-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.4.27-2-386|200808271131
2093522|2093522-b19f-3f77-b713-d32bba55d77f|fail|200808|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.10.0|linux|2.4.27-2-386|200808271129
2093045|2093045-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200808271153
2093036|2093036-b19f-3f77-b713-d32bba55d77f|fail|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.23|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200808271151
2092376|2092376-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200808270736
2092369|2092369-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200808270735
2092266|2092266-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808270713
2092265|2092265-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808270712
2092152|2092152-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.11.0 patch 34225|netbsd|4.0|200808270641
2092145|2092145-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.11.0 patch 34225|netbsd|4.0|200808270640
2092059|2092059-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200808270647
2092057|2092057-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200808270646
2092035|2092035-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200808270637
2092032|2092032-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200808270636
2089310|2089310-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200808261930
2089258|2089258-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200808261921
2088944|2088944-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Finance-Currency-Convert-XE|0.15|i686-linux|5.8.8|linux|2.6.24.3|200808261302
2088810|2088810-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200808261140
2088802|2088802-b19f-3f77-b713-d32bba55d77f|fail|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.23|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200808261139
2086234|2086234-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|CPAN-WWW-Testers-Generator|0.24|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200808261244
2086233|2086233-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|CPAN-WWW-Testers-Generator|0.23|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200808261244
2085607|2085607-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.8.8 patch 34096|linux|2.6.24-19-generic|200808260447
2085594|2085594-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-64int-ld|5.8.8 patch 34096|linux|2.6.24-19-generic|200808260447
2084491|2084491-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|IP35-irix-64int|5.8.8|irix|6.5|200808260056
2083458|2083458-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.10.0 patch 34161|linux|2.6.24-19-generic|200808251732
2083456|2083456-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-64int-ld|5.10.0 patch 34161|linux|2.6.24-19-generic|200808251732
2083226|2083226-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200808251511
2083223|2083223-b19f-3f77-b713-d32bba55d77f|fail|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.23|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200808251509
2081519|2081519-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch 34225|linux|2.6.24-19-generic|200808250618
2081518|2081518-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch 34225|linux|2.6.24-19-generic|200808250618
2081259|2081259-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200808250448
2081257|2081257-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200808250448
2081031|2081031-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Test-YAML-Meta|0.11|i686-linux|5.8.8|linux|2.6.24.3|200808250235
2080488|2080488-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-64int|5.11.0 patch 34218|openbsd|4.2|200808250046
2080487|2080487-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-64int|5.11.0 patch 34218|openbsd|4.2|200808250045
2077086|2077086-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808241006
2072369|2072369-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808231858
2072367|2072367-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808231858
2072366|2072366-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808231748
2072364|2072364-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808231857
2072360|2072360-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808231857
2072351|2072351-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808231855
2072350|2072350-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808231855
2072339|2072339-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808231854
2072337|2072337-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808231854
2072333|2072333-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808231852
2072327|2072327-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808231852
2072320|2072320-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808231851
2072317|2072317-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808231851
2072303|2072303-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808231849
2072302|2072302-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808231849
2072290|2072290-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808231848
2072282|2072282-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808231847
2072276|2072276-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808231846
2069911|2069911-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|i686-linux|5.8.8|linux|2.4.27-3-686|200808222302
2069908|2069908-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.23|i686-linux|5.8.8|linux|2.4.27-3-686|200808222302
2068374|2068374-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|CPAN-WWW-Testers-Generator|0.24|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200808221840
2068372|2068372-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|CPAN-WWW-Testers-Generator|0.23|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200808221840
2066816|2066816-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.24|i386-freebsd|5.10.0|freebsd|6.1-release|200808220749
2066159|2066159-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.11.0 patch 34212|linux|2.6.21.5-smp|200808220100
2065567|2065567-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200808212030
2065222|2065222-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200808211940
2065151|2065151-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200808211931
2064205|2064205-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0 patch 34161|netbsd|4.0|200808211509
2063863|2063863-b19f-3f77-b713-d32bba55d77f|pass|200808|gabor@pti.co.il ("Gabor Szabo")|Test-YAML-Meta|0.11|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808211610
2063152|2063152-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808211138
2062795|2062795-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808211100
2060294|2060294-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808210033
2058699|2058699-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200808201703
2058693|2058693-b19f-3f77-b713-d32bba55d77f|fail|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.23|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200808201703
2058475|2058475-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.24|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200808201732
2058470|2058470-b19f-3f77-b713-d32bba55d77f|fail|200808|david@cantrell.org.uk|CPAN-WWW-Testers-Generator|0.23|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200808201731
2057887|2057887-b19f-3f77-b713-d32bba55d77f|fail|200808|shlomif@cpan.org|CPAN-WWW-Testers-Generator|0.23|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200808191841
2057442|2057442-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200808201231
2057388|2057388-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200808201105
2057042|2057042-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200808201020
2057037|2057037-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200808201019
2056635|2056635-b19f-3f77-b713-d32bba55d77f|pass|200808|shlomif@cpan.org|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200808192004
2056441|2056441-b19f-3f77-b713-d32bba55d77f|pass|200808|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers-Generator|0.24|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200808201614
2054515|2054515-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808192233
2054512|2054512-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808192232
2054490|2054490-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808192228
2054488|2054488-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808192231
2054487|2054487-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808192230
2054475|2054475-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808192227
2054457|2054457-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808192226
2054451|2054451-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808192225
2054446|2054446-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.24|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808192223
2053988|2053988-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808192049
2053935|2053935-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.24|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808192128
2051753|2051753-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.23|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808191446
2051686|2051686-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.23|i86pc-solaris-64int|5.10.0|solaris|2.11|200808191436
2050939|2050939-b19f-3f77-b713-d32bba55d77f|cpan|200808|BARBIE|CPAN-WWW-Testers-Generator|0.24||0|||200808191231
2050781|2050781-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.23|i386-freebsd|5.6.2|freebsd|6.1-release|200808191134
2050752|2050752-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Calendar-List|0.21|i86pc-solaris-64int|5.10.0|solaris|2.11|200808190213
2049987|2049987-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Test-CPAN-Meta|0.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200808181926
2049321|2049321-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Games-Trackword|1.06|i86pc-solaris-64int|5.10.0|solaris|2.11|200808190214
2048497|2048497-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.23|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808190736
2047910|2047910-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200808190128
2047558|2047558-b19f-3f77-b713-d32bba55d77f|fail|200808|chris@bingosnet.co.uk|CPAN-WWW-Testers-Generator|0.23|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808182246
2045819|2045819-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.4.27-2-386|200808181541
2045778|2045778-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808181747
2045247|2045247-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.23|i386-freebsd|5.10.0|freebsd|6.1-release|200808181802
2045017|2045017-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.22|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808181711
2044382|2044382-b19f-3f77-b713-d32bba55d77f|cpan|200808|BARBIE|CPAN-WWW-Testers-Generator|0.23||0|||200808181624
2044069|2044069-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808181430
2041067|2041067-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux|5.11.0 patch 34204|linux|2.6.16.38|200808180040
2036762|2036762-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808170231
2036543|2036543-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808170055
2035785|2035785-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200808162050
2035316|2035316-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.8|linux|2.6.24.3|200808161308
2035315|2035315-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Phrasebook|0.29|i686-linux|5.8.8|linux|2.6.24.3|200808161308
2034996|2034996-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.22|i386-freebsd|5.10.0|freebsd|6.1-release|200808161754
2032426|2032426-b19f-3f77-b713-d32bba55d77f|pass|200808|rafl@debian.org|Test-YAML-Meta|0.11|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200808151104
2032015|2032015-b19f-3f77-b713-d32bba55d77f|pass|200808|skendric@fhcrc.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.18-53.1.13.el5|200808150739
2030960|2030960-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-64int|5.10.0|solaris|2.11|200808152211
2030959|2030959-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.29|i86pc-solaris-64int|5.10.0|solaris|2.11|200808152211
2027218|2027218-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808141413
2027176|2027176-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808141358
2027128|2027128-b19f-3f77-b713-d32bba55d77f|pass|200808|mmlange@cpan.org (Matthew Lange)|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux|5.8.8|linux|2.6.24-gentoo-r3|200808140049
2027074|2027074-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200808141432
2026875|2026875-b19f-3f77-b713-d32bba55d77f|pass|200808|mmlange@cpan.org (Matthew Lange)|Data-Phrasebook|0.29|x86_64-linux|5.8.8|linux|2.6.24-gentoo-r3|200808140049
2026520|2026520-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808141251
2026509|2026509-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808141247
2026434|2026434-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook-Loader-Ini|0.10|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808141231
2026423|2026423-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook-Loader-Ini|0.10|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808141228
2026413|2026413-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook-Loader-DBI|0.11|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808141224
2026402|2026402-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook-Loader-DBI|0.11|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808141222
2026365|2026365-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook|0.29|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808141216
2026342|2026342-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Phrasebook|0.29|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808141213
2024763|2024763-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-FormValidator-Constraints-Words|0.03|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808132223
2024761|2024761-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-FormValidator-Constraints-Words|0.03|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808132220
2021010|2021010-b19f-3f77-b713-d32bba55d77f|pass|200808|Pascal@Rockford.Com|Test-YAML-Meta|0.11|i386-linux|5.8.8|linux|2.6.18-53.1.19.el5xen|200808120329
2019709|2019709-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Games-Trackword|1.06|i86pc-solaris|5.10.0|solaris|2.11|200808120916
2019655|2019655-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris|5.10.0|solaris|2.11|200808120908
2018237|2018237-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.11|i86pc-solaris|5.10.0|solaris|2.11|200808120037
2018236|2018236-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.12|i86pc-solaris|5.10.0|solaris|2.11|200808120037
2016705|2016705-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.29|i86pc-solaris|5.10.0|solaris|2.11|200808111504
2015837|2015837-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24.3|200808110140
2014239|2014239-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808102142
2014197|2014197-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808102126
2014155|2014155-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808102110
2014075|2014075-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808102035
2014033|2014033-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808102019
2013975|2013975-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808101953
1999312|1999312-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.4.27-2-386|200808071706
1974799|1974799-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux|5.8.8|linux|2.6.16.38|200808020952
1950838|1950838-b19f-3f77-b713-d32bba55d77f|pass|200807|yanick@cpan.org ("Yanick Champoux")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.22-gentoo-r2enkidu|200807261442
1948782|1948782-b19f-3f77-b713-d32bba55d77f|pass|200807|conrad@fringehead.org|Test-YAML-Meta|0.11|darwin-2level|5.10.0|darwin|9.3.0|200807270006
1945904|1945904-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807260823
1945903|1945903-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807260823
1945659|1945659-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807260735
1945656|1945656-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807260734
1944878|1944878-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807260334
1944876|1944876-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807260333
1942761|1942761-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Calendar-List|0.21|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807252107
1942753|1942753-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Calendar-List|0.21|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807252102
1940574|1940574-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-64int|5.11.0 patch 34156|freebsd|7.0-release|200807250000
1940572|1940572-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-64int|5.11.0 patch 34156|freebsd|7.0-release|200807250000
1940356|1940356-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807250205
1940353|1940353-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807250204
1940334|1940334-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200807250056
1940330|1940330-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200807250056
1940261|1940261-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807250039
1940257|1940257-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807250039
1938884|1938884-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi|5.11.0 patch 34156|freebsd|6.2-release|200807242026
1938875|1938875-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi|5.11.0 patch 34156|freebsd|6.2-release|200807242025
1937840|1937840-b19f-3f77-b713-d32bba55d77f|pass|200807|Pascal@Rockford.Com|Test-YAML-Meta|0.11|i386-linux|5.8.8|linux|2.6.18-53.1.19.el5xen|200807241201
1934282|1934282-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200807232307
1934280|1934280-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200807232306
1933856|1933856-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200807232013
1933853|1933853-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200807232012
1933736|1933736-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-64int|5.11.0 patch 34153|openbsd|4.1|200807231854
1933733|1933733-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-64int|5.11.0 patch 34153|openbsd|4.1|200807231853
1930997|1930997-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807230809
1926612|1926612-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200807221644
1926611|1926611-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200807221644
1926472|1926472-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200807221555
1926470|1926470-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200807221554
1925805|1925805-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-ld|5.11.0 patch 34151|linux|2.6.16.38|200807221211
1925801|1925801-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-ld|5.11.0 patch 34151|linux|2.6.16.38|200807221210
1925619|1925619-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807221054
1925615|1925615-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807221053
1925049|1925049-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807220751
1925043|1925043-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807220748
1923938|1923938-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807220101
1923933|1923933-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807220059
1923898|1923898-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807220050
1923894|1923894-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807220050
1920520|1920520-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807210633
1919659|1919659-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807210131
1919657|1919657-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807210131
1919282|1919282-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807202216
1919279|1919279-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807202215
1917094|1917094-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.4.27-2-386|200807200946
1917093|1917093-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.4.27-2-386|200807200946
1916299|1916299-b19f-3f77-b713-d32bba55d77f|pass|200807|greg@turnstep.com|Test-YAML-Meta|0.11|x86_64-linux|5.8.8|linux|2.6.18-53.1.19.el5xen|200807200253
1913928|1913928-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|IP35-irix-64int|5.8.8|irix|6.5|200807192217
1913925|1913925-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Data-Phrasebook|0.29|IP35-irix-64int|5.8.8|irix|6.5|200807192216
1909521|1909521-b19f-3f77-b713-d32bba55d77f|pass|200807|vovkasm@gmail.com|Regexp-Log-Common|0.05|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200807190202
1909520|1909520-b19f-3f77-b713-d32bba55d77f|pass|200807|vovkasm@gmail.com|Test-YAML-Meta|0.11|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200807190203
1909349|1909349-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807182351
1909346|1909346-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807182349
1909326|1909326-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807182342
1909298|1909298-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807182334
1909290|1909290-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807182332
1898099|1898099-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160841
1898098|1898098-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160840
1895675|1895675-b19f-3f77-b713-d32bba55d77f|fail|200807|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200807152233
1895511|1895511-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200807152202
1895510|1895510-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200807152202
1894296|1894296-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34134|openbsd|4.2|200807151325
1892246|1892246-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807142147
1891975|1891975-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807141959
1889384|1889384-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807132117
1887800|1887800-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807131019
1884463|1884463-b19f-3f77-b713-d32bba55d77f|pass|200807|unimlor@tibo.dk ((unimlor))|Test-YAML-Meta|0.11|i586-linux-thread-multi|5.8.3|linux|2.6.5|200807121055
1884307|1884307-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807121558
1883631|1883631-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807121344
1881738|1881738-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807111942
1881689|1881689-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807111916
1881293|1881293-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807111759
1880579|1880579-b19f-3f77-b713-d32bba55d77f|fail|200807|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200807111552
1878981|1878981-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34117|openbsd|4.3|200807110013
1878908|1878908-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807110022
1877360|1877360-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200807101548
1874495|1874495-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-64int|5.11.0 patch 34114|openbsd|4.1|200807092159
1873407|1873407-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200807091654
1871673|1871673-b19f-3f77-b713-d32bba55d77f|fail|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.22|sun4-solaris|5.10.0|solaris|2.9|200807090412
1870334|1870334-b19f-3f77-b713-d32bba55d77f|pass|200807|mgardner@usatech.com|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200807081529
1869573|1869573-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int|5.10.0|linux|2.6.23.1-42.fc8|200807081703
1868356|1868356-b19f-3f77-b713-d32bba55d77f|pass|200807|mmlange@cpan.org (Matthew Lange)|Test-YAML-Meta|0.11|x86_64-linux|5.8.8|linux|2.6.24-gentoo-r3|200807080206
1866706|1866706-b19f-3f77-b713-d32bba55d77f|pass|200807|jlmartinez@capside.com|Mail-File|0.08|i386-freebsd|5.8.7|freebsd|6.0-stable|200807071503
1866705|1866705-b19f-3f77-b713-d32bba55d77f|pass|200807|jlmartinez@capside.com|Test-CPAN-Meta|0.12|i386-freebsd|5.8.7|freebsd|6.0-stable|200807071517
1866703|1866703-b19f-3f77-b713-d32bba55d77f|pass|200807|jlmartinez@capside.com|Regexp-Log-Common|0.05|i386-freebsd|5.8.7|freebsd|6.0-stable|200807071512
1866702|1866702-b19f-3f77-b713-d32bba55d77f|pass|200807|jlmartinez@capside.com|GD-Chart-Radial|0.07|i386-freebsd|5.8.7|freebsd|6.0-stable|200807071506
1866570|1866570-b19f-3f77-b713-d32bba55d77f|pass|200807|jlmartinez@capside.com|Calendar-List|0.21|i386-freebsd|5.8.7|freebsd|6.0-stable|200807071501
1866460|1866460-b19f-3f77-b713-d32bba55d77f|pass|200807|jlmartinez@capside.com|Regexp-Log-Common|0.05|i386-freebsd|5.8.7|freebsd|6.0-stable|200807071509
1865855|1865855-b19f-3f77-b713-d32bba55d77f|pass|200807|artur+cpan@niif.spb.su (ARTO)|Test-YAML-Meta|0.11|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5|200807071056
1864552|1864552-b19f-3f77-b713-d32bba55d77f|pass|200807|sanko@cpan.org|Test-CPAN-Meta|0.12|MSWin32-x86-multi-thread|5.11.0 patch 34101|MSWin32|5.1|200807052312
1863824|1863824-b19f-3f77-b713-d32bba55d77f|pass|200807|sanko@cpan.org|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.11.0 patch 34101|MSWin32|5.1|200807052307
1861536|1861536-b19f-3f77-b713-d32bba55d77f|pass|200807|rurban@x-ray.at (Reini Urban laptop)|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200807052344
1861397|1861397-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200807052251
1860664|1860664-b19f-3f77-b713-d32bba55d77f|pass|200807|andy@hexten.net|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200807051909
1860131|1860131-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807051236
1858296|1858296-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050610
1858215|1858215-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050600
1858214|1858214-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050600
1857012|1857012-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050218
1857010|1857010-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050218
1857004|1857004-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050217
1854518|1854518-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807041625
1854497|1854497-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807041615
1854449|1854449-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807041552
1854397|1854397-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807041521
1854305|1854305-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807041448
1853273|1853273-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-64int|5.8.8|freebsd|6.2-release|200807040910
1852933|1852933-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200807040818
1852851|1852851-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807040737
1852425|1852425-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807040604
1852369|1852369-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807040554
1852351|1852351-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807040551
1852342|1852342-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807040548
1852339|1852339-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807040547
1851722|1851722-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040553
1851689|1851689-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040546
1851661|1851661-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040542
1851620|1851620-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040531
1851578|1851578-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040518
1851537|1851537-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040506
1851523|1851523-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-freebsd|5.11.0 patch 34101|freebsd|7.0-release|200807040503
1851454|1851454-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040439
1851448|1851448-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040436
1851422|1851422-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040423
1851393|1851393-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040411
1851351|1851351-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040357
1851332|1851332-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040354
1851317|1851317-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807040350
1850772|1850772-b19f-3f77-b713-d32bba55d77f|pass|200807|andy@hexten.net|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200807040247
1850725|1850725-b19f-3f77-b713-d32bba55d77f|pass|200807|rlane10@wi.rr.com|Test-YAML-Meta|0.11|darwin-2level-ld|5.10.0|darwin|8.11.0|200807040055
1850327|1850327-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040029
1850042|1850042-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807031935
1845045|1845045-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031158
1845040|1845040-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031152
1845037|1845037-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031150
1845026|1845026-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031144
1845023|1845023-b19f-3f77-b713-d32bba55d77f|fail|200807|stro@cpan.org|CPAN-WWW-Testers-Generator|0.22|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031140
1842934|1842934-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021535
1842911|1842911-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021525
1842834|1842834-b19f-3f77-b713-d32bba55d77f|pass|200807|claco@chrislaco.com ("Christopher H. Laco")|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.8.6|darwin|8.0|200807011833
1842817|1842817-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021515
1842747|1842747-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021506
1842698|1842698-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021456
1842665|1842665-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021445
1842643|1842643-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807021438
1842593|1842593-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux|5.8.6|linux|2.4.20|200807021424
1841745|1841745-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Calendar-List|0.21|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200807020841
1840882|1840882-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Test-YAML-Meta|0.11|i686-linux|5.8.8|linux|2.4.27-2-386|200807020023
1840026|1840026-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200807012256
1840024|1840024-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200807012256
1838883|1838883-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011915
1838839|1838839-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011907
1838827|1838827-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011904
1838781|1838781-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011858
1838746|1838746-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011853
1838730|1838730-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011849
1838675|1838675-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011843
1838662|1838662-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011841
1838623|1838623-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011832
1838617|1838617-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011832
1838562|1838562-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011822
1838556|1838556-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011820
1838551|1838551-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807011819
1838537|1838537-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807011817
1838110|1838110-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.5.5|freebsd|6.1-release|200807011728
1837506|1837506-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Finance-Currency-Convert-XE|0.15|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807011732
1837158|1837158-b19f-3f77-b713-d32bba55d77f|fail|200807|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010922
1835124|1835124-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807010254
1831266|1831266-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806302106
1831015|1831015-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.11|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200806301122
1830585|1830585-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301343
1830426|1830426-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301315
1830422|1830422-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301314
1829239|1829239-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806301703
1829234|1829234-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806301702
1829146|1829146-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806301647
1829140|1829140-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-CPAN-Meta|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806301645
1828681|1828681-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300809
1828680|1828680-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300809
1828679|1828679-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300809
1828672|1828672-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300807
1828671|1828671-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300807
1828562|1828562-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|WWW-Scraper-ISBN-ORA_Driver|0.09|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200806300210
1828536|1828536-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806301158
1828527|1828527-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806301155
1828520|1828520-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806301151
1828503|1828503-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806301146
1828495|1828495-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806301142
1828487|1828487-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806301139
1828479|1828479-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806301136
1828453|1828453-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806301119
1828442|1828442-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806301116
1828437|1828437-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806301112
1828429|1828429-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806301109
1828411|1828411-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806301104
1828353|1828353-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200806300207
1828341|1828341-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806301043
1828339|1828339-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806301040
1828336|1828336-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806301037
1828301|1828301-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806301021
1828187|1828187-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806300911
1828185|1828185-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806300908
1828180|1828180-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806300904
1828166|1828166-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806300859
1828158|1828158-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806300856
1828149|1828149-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806300852
1828146|1828146-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806300849
1828129|1828129-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806300833
1828128|1828128-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806300829
1828125|1828125-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806300826
1828123|1828123-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806300823
1828086|1828086-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806300818
1828082|1828082-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806300815
1828081|1828081-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806300812
1828080|1828080-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806300809
1828066|1828066-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806300752
1827983|1827983-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806300744
1827943|1827943-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|Test-YAML-Meta|0.11|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200806300212
1827942|1827942-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|Test-CPAN-Meta|0.12|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200806300211
1827937|1827937-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200806300210
1827935|1827935-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200806300208
1827841|1827841-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806300723
1827838|1827838-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806300720
1827832|1827832-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806300714
1827828|1827828-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806300711
1827822|1827822-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806300707
1827818|1827818-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806300704
1827799|1827799-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806300648
1827795|1827795-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806300644
1827791|1827791-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806300643
1827787|1827787-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806300642
1827784|1827784-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806300641
1827781|1827781-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806300640
1827780|1827780-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806300639
1827778|1827778-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806300639
1827777|1827777-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806300638
1827774|1827774-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806300637
1827773|1827773-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806300635
1827772|1827772-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806300635
1827771|1827771-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806300634
1827770|1827770-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806300634
1827769|1827769-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806300633
1827768|1827768-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806300633
1827767|1827767-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806300633
1827764|1827764-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806300632
1827763|1827763-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806300632
1827762|1827762-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806300631
1827580|1827580-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300359
1827565|1827565-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-YAML-Meta|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806300653
1827561|1827561-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-CPAN-Meta|0.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806300651
1826328|1826328-b19f-3f77-b713-d32bba55d77f|pass|200806|vpit@cpan.org|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.9-5.elsmp|200806292321
1826201|1826201-b19f-3f77-b713-d32bba55d77f|pass|200806|vpit@cpan.org|Test-YAML-Meta|0.11|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200806300545
1826035|1826035-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806291753
1826032|1826032-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806291753
1825068|1825068-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806292049
1824983|1824983-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806292037
1824942|1824942-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806292026
1824891|1824891-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806292015
1824811|1824811-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806292003
1824748|1824748-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806291951
1824707|1824707-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806291947
1824429|1824429-b19f-3f77-b713-d32bba55d77f|pass|200806|mw487.yahoo.com@gmail.com|Test-YAML-Meta|0.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200806290353
1824426|1824426-b19f-3f77-b713-d32bba55d77f|pass|200806|mw487.yahoo.com@gmail.com|Test-CPAN-Meta|0.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200806290340
1824270|1824270-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291812
1824216|1824216-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291759
1824137|1824137-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291745
1824033|1824033-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291731
1823988|1823988-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291721
1823953|1823953-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291713
1823948|1823948-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806291711
1823186|1823186-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290914
1823185|1823185-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290914
1822838|1822838-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|IP35-irix-64int|5.8.8|irix|6.5|200806291322
1822820|1822820-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|IP35-irix-64int|5.8.8|irix|6.5|200806291316
1822809|1822809-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|IP35-irix-64int|5.8.8|irix|6.5|200806291315
1819789|1819789-b19f-3f77-b713-d32bba55d77f|pass|200806|MKUTTER@cpan.org ("Martin Kutter")|Test-YAML-Meta|0.11|i486-linux-gnu|5.8.8|linux|2.6.15.7|200806282245
1819477|1819477-b19f-3f77-b713-d32bba55d77f|pass|200806|MKUTTER@cpan.org ("Martin Kutter")|Test-CPAN-Meta|0.12|i486-linux-gnu|5.8.8|linux|2.6.15.7|200806282246
1819476|1819476-b19f-3f77-b713-d32bba55d77f|pass|200806|MKUTTER@cpan.org ("Martin Kutter")|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.22-14-generic|200806282244
1819174|1819174-b19f-3f77-b713-d32bba55d77f|pass|200806|MKUTTER@cpan.org ("Martin Kutter")|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.22-14-generic|200806282244
1818245|1818245-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Phrasebook|0.29|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806290153
1817500|1817500-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806282002
1817493|1817493-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806282002
1817490|1817490-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806282001
1817427|1817427-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806281954
1817423|1817423-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806281953
1817416|1817416-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806281951
1817413|1817413-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806281950
1817196|1817196-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281704
1817174|1817174-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281703
1817157|1817157-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281701
1817134|1817134-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281659
1817114|1817114-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281657
1817037|1817037-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281651
1817018|1817018-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806281649
1815735|1815735-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|Test-YAML-Meta|0.11|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200806281158
1815733|1815733-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282030
1815724|1815724-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282028
1815713|1815713-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282026
1815699|1815699-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282025
1815678|1815678-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282023
1815620|1815620-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282019
1815600|1815600-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806282017
1815024|1815024-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.24-16-generic|200806281419
1813052|1813052-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200806281048
1812492|1812492-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806282129
1812479|1812479-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Pearson_Driver|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806282127
1812454|1812454-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-ORA_Driver|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806282124
1812447|1812447-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806282123
1812444|1812444-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.13|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806282122
1812431|1812431-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Pearson_Driver|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806282121
1812429|1812429-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806282120
1812424|1812424-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806282119
1812401|1812401-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-ORA_Driver|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806282117
1812387|1812387-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806282115
1812376|1812376-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281313
1812375|1812375-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806282113
1812367|1812367-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281312
1812364|1812364-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.12|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806282112
1812356|1812356-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281311
1812351|1812351-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281310
1812343|1812343-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281309
1812308|1812308-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.8.8|linux|2.4.27-3-686|200806281041
1812305|1812305-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.8.8|linux|2.4.27-3-686|200806281041
1812304|1812304-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.8.8|linux|2.4.27-3-686|200806281040
1812295|1812295-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200806281040
1812291|1812291-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i686-linux|5.8.8|linux|2.4.27-3-686|200806281040
1812283|1812283-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281401
1812277|1812277-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281401
1812272|1812272-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281400
1812269|1812269-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281400
1812266|1812266-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281359
1812263|1812263-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281259
1812252|1812252-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200806281035
1812244|1812244-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|i686-linux|5.6.2|linux|2.4.27-3-686|200806281035
1812239|1812239-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806281256
1812228|1812228-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|i686-linux|5.8.8|linux|2.4.27-3-686|200806281033
1812218|1812218-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281354
1812209|1812209-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806281352
1811946|1811946-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281201
1811906|1811906-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281154
1811863|1811863-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281145
1811830|1811830-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281138
1811797|1811797-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.12|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281130
1811753|1811753-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.11|sun4-solaris|5.10.0|solaris|2.9|200806281318
1811742|1811742-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.12|sun4-solaris|5.10.0|solaris|2.9|200806281317
1811722|1811722-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281122
1811703|1811703-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806281119
1811702|1811702-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.09|sun4-solaris|5.10.0|solaris|2.9|200806281312
1811686|1811686-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.10|sun4-solaris|5.10.0|solaris|2.9|200806281309
1811670|1811670-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.07|sun4-solaris|5.10.0|solaris|2.9|200806281304
1811660|1811660-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.13|sun4-solaris|5.10.0|solaris|2.9|200806281259
1811385|1811385-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806280959
1811371|1811371-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806280956
1810693|1810693-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.11|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200806280008
1810295|1810295-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806280818
1810293|1810293-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806280818
1810292|1810292-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806280818
1810291|1810291-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806280818
1810081|1810081-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.11|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200806280010
1810075|1810075-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.11|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200806280005
1810073|1810073-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.11|i586-linux-thread-multi|5.8.8|linux|2.6.16|200806272320
1809666|1809666-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280348
1809664|1809664-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280347
1809654|1809654-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280345
1809334|1809334-b19f-3f77-b713-d32bba55d77f|pass|200806|yanick@cpan.org ("Yanick Champoux")|WWW-UsePerl-Journal|0.21|i686-linux|5.10.0|linux|2.6.22-gentoo-r2enkidu|200806271210
1808295|1808295-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806280030
1808293|1808293-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806280030
1808218|1808218-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.10.0|freebsd|6.1-release|200806271926
1808198|1808198-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271818
1808195|1808195-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271818
1808187|1808187-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.09|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271817
1808179|1808179-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.10|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271816
1808170|1808170-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271814
1808163|1808163-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.13|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271812
1807847|1807847-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806271928
1807827|1807827-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.07|i386-freebsd|5.10.0|freebsd|6.1-release|200806272303
1807826|1807826-b19f-3f77-b713-d32bba55d77f|fail|200806|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.13|i386-freebsd|5.10.0|freebsd|6.1-release|200806272303
1807735|1807735-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806272111
1807695|1807695-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806272109
1807514|1807514-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806272050
1807476|1807476-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806272044
1807402|1807402-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806271559
1806711|1806711-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd|5.10.0|freebsd|6.1-release|200806271927
1806697|1806697-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806271928
1806686|1806686-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.10|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806271944
1806684|1806684-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.11|i686-linux|5.8.6|linux|2.4.18|200806271826
1806661|1806661-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd|5.10.0|freebsd|6.1-release|200806271926
1806647|1806647-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806271957
1806645|1806645-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806271957
1806625|1806625-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806271944
1806380|1806380-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.13||0|||200806271901
1806263|1806263-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.07||0|||200806271830
1806119|1806119-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.11|sun4-solaris|5.10.0|solaris|2.9|200806271807
1806108|1806108-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.10|sun4-solaris|5.10.0|solaris|2.9|200806271805
1806097|1806097-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.12|sun4-solaris|5.10.0|solaris|2.9|200806271804
1806091|1806091-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.08|sun4-solaris|5.10.0|solaris|2.9|200806271802
1806040|1806040-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.10||0|||200806271749
1806018|1806018-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806271528
1805958|1805958-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.09||0|||200806271734
1805823|1805823-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806271528
1805820|1805820-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806271550
1805812|1805812-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.6.2|freebsd|6.1-release|200806271538
1805806|1805806-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.6.2|freebsd|6.1-release|200806271537
1805804|1805804-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806271541
1805803|1805803-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806271541
1805754|1805754-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Mail-File|0.08|sun4-solaris|5.10.0|solaris|2.9|200806271658
1805751|1805751-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Regexp-Log-Common|0.05|sun4-solaris|5.10.0|solaris|2.9|200806271657
1805632|1805632-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806271550
1805614|1805614-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.11|i386-freebsd|5.10.0|freebsd|6.1-release|200806271520
1805613|1805613-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.12|i386-freebsd|5.10.0|freebsd|6.1-release|200806271520
1805611|1805611-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.12||0|||200806271644
1805268|1805268-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270952
1805267|1805267-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270951
1805266|1805266-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270951
1805120|1805120-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270911
1805119|1805119-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270910
1804993|1804993-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|Test-CPAN-Meta|0.12||0|||200806271438
1804978|1804978-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|Test-YAML-Meta|0.11||0|||200806271437
1804819|1804819-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-Outlook|0.06|sun4-solaris|5.10.0|solaris|2.9|200806271357
1804136|1804136-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270503
1801897|1801897-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270122
1801697|1801697-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270035
1801214|1801214-b19f-3f77-b713-d32bba55d77f|fail|200806|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806270001
1795155|1795155-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806260122
1794922|1794922-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-CPAN-Meta|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806260702
1794527|1794527-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-CPAN-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806260328
1794349|1794349-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Calendar-List|0.20|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806260206
1785435|1785435-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250132
1782136|1782136-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240733
1782132|1782132-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240733
1781918|1781918-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240705
1781916|1781916-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240705
1781326|1781326-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240539
1781324|1781324-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240539
1781323|1781323-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240539
1781321|1781321-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240538
1781313|1781313-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240537
1781312|1781312-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240537
1781223|1781223-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240527
1781069|1781069-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240506
1779631|1779631-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240143
1779622|1779622-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240142
1779020|1779020-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.10|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806240618
1778120|1778120-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240243
1777989|1777989-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240217
1777987|1777987-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240217
1774380|1774380-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231714
1774371|1774371-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231712
1774338|1774338-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231706
1774325|1774325-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231703
1774313|1774313-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231700
1774290|1774290-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231657
1774263|1774263-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231651
1774221|1774221-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231146
1774198|1774198-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231642
1774179|1774179-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231640
1774142|1774142-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Mail-File|0.08|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231635
1774130|1774130-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231633
1774122|1774122-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231631
1774104|1774104-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231627
1774091|1774091-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231624
1774077|1774077-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231622
1774060|1774060-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231620
1774050|1774050-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231619
1774038|1774038-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231617
1774029|1774029-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231615
1774020|1774020-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231613
1773993|1773993-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231608
1773969|1773969-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231601
1773959|1773959-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231558
1773930|1773930-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231053
1773896|1773896-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806231540
1772531|1772531-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Games-Trackword|1.05|i686-linux|5.8.8|linux|2.4.27-2-386|200806231239
1771556|1771556-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230418
1771555|1771555-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230418
1771497|1771497-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230407
1771496|1771496-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230407
1771136|1771136-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230312
1767997|1767997-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-YAML-Meta|0.09|i686-linux|5.10.0|linux|2.4.27-2-386|200806230125
1765104|1765104-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.18-5-686|200806221951
1757459|1757459-b19f-3f77-b713-d32bba55d77f|fail|200806|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i386-freebsd|5.10.0|freebsd|6.1-release|200806211849
1754111|1754111-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210014
1754056|1754056-b19f-3f77-b713-d32bba55d77f|pass|200806|skendric@fhcrc.org|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.8.8|linux|2.6.18-53.1.13.el5|200806201444
1753915|1753915-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210331
1753444|1753444-b19f-3f77-b713-d32bba55d77f|pass|200806|rlane10@wi.rr.com|Test-YAML-Meta|0.10|darwin-2level-ld|5.10.0|darwin|8.11.0|200806201137
1751237|1751237-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201706
1751236|1751236-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201706
1751235|1751235-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201706
1751232|1751232-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201705
1751231|1751231-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201705
1751145|1751145-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201657
1750277|1750277-b19f-3f77-b713-d32bba55d77f|pass|200806|smoretti@unil.ch|Test-YAML-Meta|0.10|i386-linux|5.8.6|linux|2.6.9-34.elsmp|200806201502
1747362|1747362-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200937
1747361|1747361-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200937
1747360|1747360-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200937
1747359|1747359-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200936
1747348|1747348-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.10.0|freebsd|6.1-release|200806200912
1747321|1747321-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200935
1747319|1747319-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Mail-File|0.08|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200935
1747198|1747198-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-freebsd|5.10.0|freebsd|6.1-release|200806200911
1747164|1747164-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200907
1747163|1747163-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200909
1747161|1747161-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200907
1745397|1745397-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.6.2|freebsd|6.1-release|200806200511
1745396|1745396-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.6.2|freebsd|6.1-release|200806200512
1745392|1745392-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.6.2|freebsd|6.1-release|200806200510
1745391|1745391-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.6.2|freebsd|6.1-release|200806200509
1745390|1745390-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.6.2|freebsd|6.1-release|200806200509
1745316|1745316-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.6.2|freebsd|6.1-release|200806200500
1745314|1745314-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.6.2|freebsd|6.1-release|200806200459
1745041|1745041-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200225
1745040|1745040-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200225
1744322|1744322-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.11|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200231
1744321|1744321-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200231
1744319|1744319-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Calendar-List|0.21|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200232
1742442|1742442-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191606
1741370|1741370-b19f-3f77-b713-d32bba55d77f|pass|200806|joel-cpan@fysh.org|Test-YAML-Meta|0.10|darwin-thread-multi-2level|5.8.8|darwin|9.0|200806181622
1741026|1741026-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191230
1739686|1739686-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806191350
1738988|1738988-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806191255
1738987|1738987-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806191255
1738984|1738984-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Calendar-List|0.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806191255
1737925|1737925-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.11|i386-freebsd|5.10.0|freebsd|6.1-release|200806190814
1737918|1737918-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.10.0|freebsd|6.1-release|200806190814
1737917|1737917-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.10.0|freebsd|6.1-release|200806190813
1737081|1737081-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190321
1737076|1737076-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190321
1736998|1736998-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190254
1736628|1736628-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190159
1736627|1736627-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190159
1736561|1736561-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190150
1735631|1735631-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190008
1733599|1733599-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806182134
1733292|1733292-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.10|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806182142
1732405|1732405-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.09|sun4-solaris|5.10.0|solaris|2.9|200806182008
1732348|1732348-b19f-3f77-b713-d32bba55d77f|fail|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.06|sun4-solaris|5.10.0|solaris|2.9|200806182004
1731449|1731449-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-64int|5.8.8|freebsd|6.2-release|200806181717
1731253|1731253-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806181638
1730166|1730166-b19f-3f77-b713-d32bba55d77f|pass|200806|jlmartinez@capside.com|Mail-File|0.08|i386-freebsd|5.8.4|freebsd|4.7-release-p22|200806180108
1729810|1729810-b19f-3f77-b713-d32bba55d77f|pass|200806|jlmartinez@capside.com|Test-CPAN-Meta|0.11|i386-freebsd|5.8.4|freebsd|4.7-release-p22|200806180109
1729808|1729808-b19f-3f77-b713-d32bba55d77f|pass|200806|jlmartinez@capside.com|Regexp-Log-Common|0.05|i386-freebsd|5.8.4|freebsd|4.7-release-p22|200806180108
1729807|1729807-b19f-3f77-b713-d32bba55d77f|pass|200806|jlmartinez@capside.com|Calendar-List|0.21|i386-freebsd|5.8.4|freebsd|4.7-release-p22|200806180107
1729805|1729805-b19f-3f77-b713-d32bba55d77f|pass|200806|jlmartinez@capside.com|GD-Chart-Radial|0.07|i386-freebsd|5.8.4|freebsd|4.7-release-p22|200806180108
1729038|1729038-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.10|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806181435
1728243|1728243-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.6.2|freebsd|6.1-release|200806181240
1728206|1728206-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.11|i386-freebsd|5.5.5|freebsd|6.1-release|200806181300
1728011|1728011-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.6.2|freebsd|6.1-release|200806181240
1728009|1728009-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-CPAN-Meta|0.11|i386-freebsd|5.6.2|freebsd|6.1-release|200806181241
1726789|1726789-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180502
1726250|1726250-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.10|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806181008
1725852|1725852-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.10|i386-freebsd|5.10.0|freebsd|6.1-release|200806180928
1723503|1723503-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.5.5|freebsd|6.1-release|200806180415
1722642|1722642-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Test-YAML-Meta|0.10|i386-freebsd|5.6.2|freebsd|6.1-release|200806180227
1722119|1722119-b19f-3f77-b713-d32bba55d77f|pass|200806|cpan@ap0.org|Test-YAML-Meta|0.10|x86_64-linux|5.10.0|linux|2.6.18-53.1.14.el5|200806171209
1721741|1721741-b19f-3f77-b713-d32bba55d77f|pass|200806|cpan@ap0.org|Test-CPAN-Meta|0.11|x86_64-linux|5.10.0|linux|2.6.18-53.1.14.el5|200806171208
1719966|1719966-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Trackword|1.06|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806172151
1719201|1719201-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171437
1719200|1719200-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171437
1719199|1719199-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171436
1719188|1719188-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171435
1719183|1719183-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171435
1719071|1719071-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171423
1717461|1717461-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Calendar-List|0.21|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806171733
1716738|1716738-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171011
1716732|1716732-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171010
1715590|1715590-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170655
1715424|1715424-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170622
1715421|1715421-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170622
1713208|1713208-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170154
1712993|1712993-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170109
1712965|1712965-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200806170203
1712383|1712383-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806170004
1711701|1711701-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Calendar-List|0.21|darwin-2level|5.8.1|darwin|7.9.0|200806162212
1711158|1711158-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806162043
1710487|1710487-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161413
1710486|1710486-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161413
1710485|1710485-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161413
1710412|1710412-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161402
1710410|1710410-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161402
1709975|1709975-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161251
1709162|1709162-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux|5.8.6|linux|2.4.18|200806161426
1708013|1708013-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160148
1708009|1708009-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160148
1707722|1707722-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806162149
1704877|1704877-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151149
1704656|1704656-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151123
1704654|1704654-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151123
1700165|1700165-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806141606
1699918|1699918-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806141519
1697550|1697550-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806141246
1697275|1697275-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140757
1697274|1697274-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140757
1696337|1696337-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140231
1696336|1696336-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140231
1695136|1695136-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140103
1692568|1692568-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.8.8|linux|2.4.27-2-386|200806140033
1690574|1690574-b19f-3f77-b713-d32bba55d77f|fail|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.11|sun4-solaris|5.10.0|solaris|2.9|200806140011
1689425|1689425-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|GD-Chart-Radial|0.07|sun4-solaris|5.10.0|solaris|2.9|200806132246
1688976|1688976-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 34034|darwin|8.10.0|200806132112
1687618|1687618-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200806131725
1687187|1687187-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806131745
1686509|1686509-b19f-3f77-b713-d32bba55d77f|fail|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.10|sun4-solaris|5.10.0|solaris|2.9|200806131736
1686497|1686497-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.21|sun4-solaris|5.10.0|solaris|2.9|200806131736
1686059|1686059-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux|5.8.6|linux|2.4.20|200806131455
1684487|1684487-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130823
1683501|1683501-b19f-3f77-b713-d32bba55d77f|pass|200806|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200806130758
1676377|1676377-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121242
1676375|1676375-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121242
1676374|1676374-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121241
1676365|1676365-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121241
1676350|1676350-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121240
1676348|1676348-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121240
1676235|1676235-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121230
1675391|1675391-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200806121458
1675227|1675227-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806121525
1674507|1674507-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120855
1674503|1674503-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120855
1673760|1673760-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|IP35-irix-64int|5.8.8|irix|6.5|200806121321
1673116|1673116-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120556
1672968|1672968-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120529
1672966|1672966-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120529
1669368|1669368-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120052
1668306|1668306-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806111537
1667265|1667265-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806111658
1667250|1667250-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806111657
1665532|1665532-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110726
1665530|1665530-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110726
1665423|1665423-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110713
1665421|1665421-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110713
1664746|1664746-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110546
1664665|1664665-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806110536
1664664|1664664-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806110536
1664474|1664474-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806110447
1661094|1661094-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806101807
1661089|1661089-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806101807
1659934|1659934-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Games-Trackword|1.06|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806102300
1657338|1657338-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101007
1656201|1656201-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200806101232
1655489|1655489-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Calendar-List|0.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806101258
1655397|1655397-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|alpha-linux-thread-multi|5.11.0 patch 34031|linux|2.6.18-5-alpha-generic|200806101043
1652156|1652156-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100100
1652154|1652154-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100100
1652153|1652153-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100059
1652152|1652152-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100059
1652146|1652146-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100058
1652145|1652145-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100058
1652084|1652084-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100049
1651587|1651587-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806091918
1650639|1650639-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091653
1650637|1650637-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091652
1650449|1650449-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806091617
1650447|1650447-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806091616
1648974|1648974-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091117
1648795|1648795-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091048
1648793|1648793-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091048
1648349|1648349-b19f-3f77-b713-d32bba55d77f|pass|200806|perl@galumph.com ("Elliot Shank")|Test-YAML-Meta|0.10|darwin-thread-multi-2level|5.8.8|darwin|8.9.1|200806090447
1645920|1645920-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806090139
1645912|1645912-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806090137
1642719|1642719-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Mail-Outlook|0.13|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806080928
1642272|1642272-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080808
1641865|1641865-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080707
1641782|1641782-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806080706
1641757|1641757-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806080702
1641747|1641747-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806080701
1641742|1641742-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806080701
1641328|1641328-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806080603
1641315|1641315-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806080602
1641305|1641305-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806080559
1641031|1641031-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080452
1640009|1640009-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080143
1638818|1638818-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Finance-Currency-Convert-XE|0.15|darwin-2level|5.8.3|darwin|7.9.0|200806080100
1638803|1638803-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806080056
1638797|1638797-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806080056
1637741|1637741-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071549
1637740|1637740-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071549
1637738|1637738-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071548
1637737|1637737-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071548
1637643|1637643-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071531
1637642|1637642-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071531
1636941|1636941-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.8|linux|2.4.27-2-386|200806071752
1636940|1636940-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.8.8|linux|2.4.27-2-386|200806071752
1636938|1636938-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.8.8|linux|2.4.27-2-386|200806071752
1636937|1636937-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.8.8|linux|2.4.27-2-386|200806071751
1636935|1636935-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Phrasebook|0.29|i686-linux|5.8.8|linux|2.4.27-2-386|200806071751
1636643|1636643-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Test-YAML-Meta|0.10|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071805
1635681|1635681-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071523
1632769|1632769-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806070948
1632554|1632554-b19f-3f77-b713-d32bba55d77f|pass|200806|rafl@debian.org|Test-YAML-Meta|0.10|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200806070003
1632495|1632495-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Finance-Currency-Convert-XE|0.15|darwin-2level|5.8.2|darwin|7.9.0|200806070911
1629277|1629277-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070034
1629252|1629252-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070031
1629249|1629249-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070030
1629247|1629247-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070030
1629235|1629235-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070027
1628963|1628963-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806061945
1628962|1628962-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806061945
1627339|1627339-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806062135
1627319|1627319-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806062134
1627311|1627311-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806062133
1626740|1626740-b19f-3f77-b713-d32bba55d77f|fail|200806|jj@jonallen.info ("JJ")|WWW-Scraper-ISBN-ORA_Driver|0.08|darwin-2level|5.8.1|darwin|7.9.0|200806062016
1623961|1623961-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Test-YAML-Meta|0.10|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806061514
1622948|1622948-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Data-FormValidator-Constraints-Words|0.03|darwin-2level|5.8.3|darwin|7.9.0|200806061339
1622481|1622481-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060742
1622258|1622258-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061145
1622256|1622256-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061144
1622246|1622246-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061141
1622244|1622244-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061140
1621857|1621857-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.8.8|linux|2.4.27-2-386|200806060055
1621845|1621845-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.8.8|linux|2.4.27-2-386|200806060053
1621843|1621843-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i686-linux|5.8.8|linux|2.4.27-2-386|200806060053
1621829|1621829-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.8.8|linux|2.4.27-2-386|200806060050
1621827|1621827-b19f-3f77-b713-d32bba55d77f|fail|200806|stro@cpan.org|CPAN-WWW-Testers-Generator|0.22|i686-linux|5.8.8|linux|2.4.27-2-386|200806060049
1621660|1621660-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806060939
1621651|1621651-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806060937
1621628|1621628-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806060933
1621621|1621621-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806060932
1621156|1621156-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806060733
1621152|1621152-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806060732
1621142|1621142-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806060730
1621140|1621140-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806060730
1621057|1621057-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806060706
1620226|1620226-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806060533
1620222|1620222-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806060532
1619465|1619465-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060242
1619464|1619464-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060242
1619462|1619462-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060242
1619461|1619461-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060242
1619456|1619456-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060241
1619455|1619455-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060241
1619340|1619340-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060228
1617946|1617946-b19f-3f77-b713-d32bba55d77f|fail|200806|jj@jonallen.info ("JJ")|WWW-Scraper-ISBN-Yahoo_Driver|0.06|darwin-2level|5.8.1|darwin|7.9.0|200806060021
1617094|1617094-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051756
1617085|1617085-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051755
1615359|1615359-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-YAML-Meta|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806052152
1615059|1615059-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051421
1614779|1614779-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051348
1614644|1614644-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051831
1614621|1614621-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051829
1614539|1614539-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Calendar-List|0.21|darwin-2level|5.8.2|darwin|7.9.0|200806051820
1614062|1614062-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806051729
1614051|1614051-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806051729
1613717|1613717-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806051656
1613707|1613707-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806051656
1612193|1612193-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051426
1612182|1612182-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Calendar-List|0.21|i386-linux|5.8.8|linux|2.6.18-53.el5|200806050825
1612176|1612176-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051425
1612173|1612173-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Games-Trackword|1.06|i386-linux|5.8.8|linux|2.6.18-53.el5|200806050824
1612168|1612168-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Test-YAML-Meta|0.10|i386-linux|5.8.8|linux|2.6.18-53.el5|200806050824
1612160|1612160-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Test-CPAN-Meta|0.11|i386-linux|5.8.8|linux|2.6.18-53.el5|200806050823
1609410|1609410-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050200
1609322|1609322-b19f-3f77-b713-d32bba55d77f|fail|200806|jj@jonallen.info ("JJ")|WWW-Scraper-ISBN-Amazon_Driver|0.11|darwin-2level|5.8.1|darwin|7.9.0|200806050642
1609208|1609208-b19f-3f77-b713-d32bba55d77f|fail|200806|jj@jonallen.info ("JJ")|WWW-UsePerl-Journal-Thread|0.10|darwin-2level|5.8.1|darwin|7.9.0|200806050620
1609071|1609071-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050045
1607971|1607971-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806050254
1607952|1607952-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806050252
1607946|1607946-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806050251
1607938|1607938-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806050251
1607408|1607408-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.15|sun4-solaris|5.10.0|solaris|2.9|200806050234
1605389|1605389-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806042233
1605361|1605361-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806042230
1605352|1605352-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806042229
1605347|1605347-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806042229
1605127|1605127-b19f-3f77-b713-d32bba55d77f|pass|200806|d@0x64.nl (devogon)|Calendar-List|0.21|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200806042317
1605106|1605106-b19f-3f77-b713-d32bba55d77f|pass|200806|d@0x64.nl (devogon)|Test-YAML-Meta|0.10|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200806042315
1605102|1605102-b19f-3f77-b713-d32bba55d77f|pass|200806|d@0x64.nl (devogon)|Test-CPAN-Meta|0.11|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200806042315
1604193|1604193-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.10|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200806041823
1602965|1602965-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806041750
1602959|1602959-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806041749
1602944|1602944-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806041748
1602099|1602099-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041212
1602096|1602096-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041212
1602093|1602093-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041212
1602091|1602091-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041212
1601665|1601665-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041119
1601664|1601664-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041119
1600273|1600273-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806040908
1600259|1600259-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806040906
1600243|1600243-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806040902
1600203|1600203-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806040859
1599571|1599571-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.03|sun4-solaris|5.10.0|solaris|2.9|200806041407
1598774|1598774-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Test-YAML-Meta|0.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806041342
1598003|1598003-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806041711
1597990|1597990-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806041711
1597979|1597979-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Games-Trackword|1.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806041711
1597969|1597969-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Calendar-List|0.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806041710
1597851|1597851-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806041707
1597847|1597847-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806041706
1597842|1597842-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Games-Trackword|1.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806041705
1597837|1597837-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Calendar-List|0.21|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806041705
1597664|1597664-b19f-3f77-b713-d32bba55d77f|pass|200806|claco@chrislaco.com ("Christopher H. Laco")|Test-YAML-Meta|0.10|darwin-thread-multi-2level|5.8.6|darwin|8.0|200806031755
1597574|1597574-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.10|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200806031922
1597564|1597564-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.10|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200806031925
1597559|1597559-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.10|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200806031924
1597548|1597548-b19f-3f77-b713-d32bba55d77f|pass|200806|g.grigelionis@computer.org|Test-YAML-Meta|0.10|i586-linux-thread-multi|5.8.8|linux|2.6.16|200806031902
1595315|1595315-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806040315
1595287|1595287-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806040311
1595282|1595282-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806040310
1595279|1595279-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806040309
1594624|1594624-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Data-FormValidator-Constraints-Words|0.03|darwin-2level|5.8.2|darwin|7.9.0|200806040228
1594159|1594159-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031858
1592796|1592796-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806031343
1592717|1592717-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806031335
1592716|1592716-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806031334
1592715|1592715-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806031334
1592610|1592610-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.11|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031314
1592609|1592609-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.10|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031314
1592608|1592608-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.21|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031313
1592607|1592607-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.06|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031314
1592166|1592166-b19f-3f77-b713-d32bba55d77f|pass|200806|vpit@cpan.org|Test-YAML-Meta|0.10|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200806031631
1592154|1592154-b19f-3f77-b713-d32bba55d77f|pass|200806|vpit@cpan.org|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200806031301
1591764|1591764-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806030942
1591749|1591749-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806030940
1591736|1591736-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806030939
1591727|1591727-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806030938
1591686|1591686-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|IP35-irix|5.8.8|irix|6.5|200806031633
1591678|1591678-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|IP35-irix|5.8.8|irix|6.5|200806031632
1591671|1591671-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|IP35-irix|5.8.8|irix|6.5|200806031631
1591666|1591666-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|IP35-irix|5.8.8|irix|6.5|200806031631
1591658|1591658-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806030936
1591647|1591647-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806030935
1591642|1591642-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806031527
1591638|1591638-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806031526
1591637|1591637-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806031526
1591635|1591635-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806030933
1591633|1591633-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806031526
1591622|1591622-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806030932
1591576|1591576-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806031412
1591572|1591572-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806031411
1591567|1591567-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806031410
1591563|1591563-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806031409
1591513|1591513-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806031451
1591507|1591507-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806031451
1591503|1591503-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806031450
1591502|1591502-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806031450
1591265|1591265-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030916
1591263|1591263-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030915
1591262|1591262-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030915
1591258|1591258-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030914
1591240|1591240-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030911
1591238|1591238-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030910
1591232|1591232-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.05|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030910
1591046|1591046-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030840
1590481|1590481-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200806031212
1590328|1590328-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Games-Trackword|1.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806031357
1590300|1590300-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.11|sun4-solaris|5.10.0|solaris|2.9|200806031251
1590288|1590288-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.10|sun4-solaris|5.10.0|solaris|2.9|200806031250
1590284|1590284-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Games-Trackword|1.06|sun4-solaris|5.10.0|solaris|2.9|200806031249
1590280|1590280-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.21|sun4-solaris|5.10.0|solaris|2.9|200806031248
1590027|1590027-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Calendar-List|0.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806031306
1589779|1589779-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|i686-linux|5.6.2|linux|2.4.27-3-686|200806031029
1589778|1589778-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|i686-linux|5.6.2|linux|2.4.27-3-686|200806031028
1589777|1589777-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|i686-linux|5.6.2|linux|2.4.27-3-686|200806031028
1589771|1589771-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-CPAN-Meta|0.11|darwin-2level|5.8.2|darwin|7.9.0|200806031034
1589762|1589762-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-YAML-Meta|0.10|darwin-2level|5.8.2|darwin|7.9.0|200806031033
1589749|1589749-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Games-Trackword|1.06|darwin-2level|5.8.2|darwin|7.9.0|200806031031
1589517|1589517-b19f-3f77-b713-d32bba55d77f|pass|200806|artur+cpan@niif.spb.su (ARTO)|Test-YAML-Meta|0.10|i386-linux|5.10.0|linux|2.6.18-53.1.14.el5xen|200806031046
1589154|1589154-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-YAML-Meta|0.10|i686-linux|5.8.8|linux|2.4.27-3-686|200806030915
1589151|1589151-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Test-CPAN-Meta|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200806030915
1589149|1589149-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Games-Trackword|1.06|i686-linux|5.8.8|linux|2.4.27-3-686|200806030915
1589148|1589148-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Calendar-List|0.21|i686-linux|5.8.8|linux|2.4.27-3-686|200806030915
1588382|1588382-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-CPAN-Meta|0.11|darwin-2level|5.8.1|darwin|7.9.0|200806030754
1588375|1588375-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-YAML-Meta|0.10|darwin-2level|5.8.1|darwin|7.9.0|200806030753
1588371|1588371-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Games-Trackword|1.06|darwin-2level|5.8.1|darwin|7.9.0|200806030751
1588340|1588340-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-CPAN-Meta|0.11|darwin-2level|5.8.3|darwin|7.9.0|200806030747
1588329|1588329-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-YAML-Meta|0.10|darwin-2level|5.8.3|darwin|7.9.0|200806030746
1588310|1588310-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Games-Trackword|1.06|darwin-2level|5.8.3|darwin|7.9.0|200806030745
1587836|1587836-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806030652
1587829|1587829-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806030651
1587822|1587822-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806030650
1587814|1587814-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806030649
1587803|1587803-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806030648
1587793|1587793-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806030647
1587788|1587788-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806030646
1587785|1587785-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806030645
1587781|1587781-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806030644
1587768|1587768-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806030643
1587765|1587765-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806030642
1587761|1587761-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806030642
1587757|1587757-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806030642
1587751|1587751-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806030641
1587749|1587749-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806030641
1587744|1587744-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806030641
1587740|1587740-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806030641
1587736|1587736-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806030640
1587733|1587733-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806030640
1587731|1587731-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806030640
1587726|1587726-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806030639
1587725|1587725-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806030639
1587724|1587724-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806030638
1587720|1587720-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806030638
1587716|1587716-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806030637
1587711|1587711-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806030637
1587705|1587705-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806030636
1587700|1587700-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806030635
1587699|1587699-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806030635
1587693|1587693-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806030634
1587690|1587690-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806030634
1587686|1587686-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806030634
1587684|1587684-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806030633
1587679|1587679-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806030633
1587675|1587675-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806030632
1587670|1587670-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806030632
1587665|1587665-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806030631
1587662|1587662-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806030631
1587658|1587658-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806030630
1585549|1585549-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030041
1585546|1585546-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030040
1585543|1585543-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030040
1585542|1585542-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030040
1585529|1585529-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030039
1585527|1585527-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030039
1585524|1585524-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.05|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030039
1585384|1585384-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030028
1585112|1585112-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021959
1585097|1585097-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021958
1583454|1583454-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806022233
1583447|1583447-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200806022232
1583445|1583445-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Calendar-List|0.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806022232
1583427|1583427-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806022228
1583393|1583393-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-YAML-Meta|0.10|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806022225
1583364|1583364-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806022222
1583357|1583357-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200806022222
1583352|1583352-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Games-Trackword|1.06|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806022221
1583347|1583347-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806022221
1583325|1583325-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Test-CPAN-Meta|0.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806022219
1582858|1582858-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021637
1582850|1582850-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021636
1582218|1582218-b19f-3f77-b713-d32bba55d77f|pass|200806|vpit@cpan.org|Test-YAML-Meta|0.10|i686-linux-thread-multi|5.10.0|linux|2.6.9-5.elsmp|200806022125
1582187|1582187-b19f-3f77-b713-d32bba55d77f|pass|200806|vpit@cpan.org|Test-YAML-Meta|0.10|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200806030223
1581540|1581540-b19f-3f77-b713-d32bba55d77f|pass|200806|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Calendar-List|0.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200806030247
1580743|1580743-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|Calendar-List|0.21||0|||200806021706
1580664|1580664-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021048
1580655|1580655-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|Games-Trackword|1.06||0|||200806021646
1580615|1580615-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|Test-YAML-Meta|0.10||0|||200806021632
1580610|1580610-b19f-3f77-b713-d32bba55d77f|cpan|200806|BARBIE|Test-CPAN-Meta|0.11||0|||200806021630
1580363|1580363-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806020929
1580360|1580360-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806020929
1580182|1580182-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806020845
1580116|1580116-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020833
1579873|1579873-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020801
1579869|1579869-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020801
1575598|1575598-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020257
1575160|1575160-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.20|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020116
1575158|1575158-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.10|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020116
1575155|1575155-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020116
1574459|1574459-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.09|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011919
1573629|1573629-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011723
1572474|1572474-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.20|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011347
1572472|1572472-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.10|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011347
1572471|1572471-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011347
1571607|1571607-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011112
1571606|1571606-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011112
1571456|1571456-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.09|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011056
1570856|1570856-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Test-YAML-Meta|0.09|darwin-2level|5.8.2|darwin|7.9.0|200806011443
1567435|1567435-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010120
1567434|1567434-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010120
1560441|1560441-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805310759
1556973|1556973-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310217
1556934|1556934-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310208
1556904|1556904-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310201
1556856|1556856-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310153
1556815|1556815-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310144
1556760|1556760-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310136
1556703|1556703-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310127
1556674|1556674-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310124
1556648|1556648-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310123
1556634|1556634-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Mail-File|0.08|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310122
1556627|1556627-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Games-Trackword|1.05|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310121
1556621|1556621-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310121
1556575|1556575-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310119
1556524|1556524-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310114
1556511|1556511-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310112
1556478|1556478-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310107
1556470|1556470-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310107
1556370|1556370-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310059
1556364|1556364-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310058
1556360|1556360-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Calendar-List|0.20|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310057
1556231|1556231-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805310047
1553644|1553644-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook-Loader-YAML|0.09|darwin-2level|5.8.3|darwin|7.9.0|200805301639
1553640|1553640-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook|0.29|darwin-2level|5.8.3|darwin|7.9.0|200805301639
1549777|1549777-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300323
1549776|1549776-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300323
1549774|1549774-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300323
1549773|1549773-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300323
1549766|1549766-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300321
1549764|1549764-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300321
1549762|1549762-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.05|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300320
1549700|1549700-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300305
1548315|1548315-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291814
1548312|1548312-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291813
1547234|1547234-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291357
1547085|1547085-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291322
1547083|1547083-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291322
1545871|1545871-b19f-3f77-b713-d32bba55d77f|pass|200805|artur+cpan@niif.spb.su (ARTO)|Finance-Currency-Convert-XE|0.15|i386-linux|5.10.0|linux|2.6.18-53.1.14.el5xen|200805291424
1543466|1543466-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290113
1542944|1542944-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.20|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290003
1542942|1542942-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290002
1542941|1542941-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290002
1541573|1541573-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290111
1539198|1539198-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281610
1539197|1539197-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281610
1538594|1538594-b19f-3f77-b713-d32bba55d77f|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris|5.10.0|solaris|2.9|200805282118
1538585|1538585-b19f-3f77-b713-d32bba55d77f|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.29|sun4-solaris|5.10.0|solaris|2.9|200805282118
1534081|1534081-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook-Loader-YAML|0.09|darwin-2level|5.8.2|darwin|7.9.0|200805280605
1534079|1534079-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook|0.29|darwin-2level|5.8.2|darwin|7.9.0|200805280605
1526917|1526917-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805270059
1526914|1526914-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805270058
1526143|1526143-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Calendar-List|0.20|i686-linux|5.8.8|linux|2.4.27-2-386|200805270150
1525515|1525515-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805262104
1505527|1505527-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-WWW-Testers-Generator|0.22|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805230133
1503215|1503215-b19f-3f77-b713-d32bba55d77f|pass|200805|gabor@pti.co.il ("Gabor Szabo")|Test-YAML-Meta|0.09|i486-linux-gnu|5.8.8|linux|2.6.15.7|200805221748
1498962|1498962-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|CPAN-WWW-Testers-Generator|0.22|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200805212214
1498383|1498383-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook-Loader-DBI|0.11|darwin-2level|5.8.1|darwin|7.9.0|200805211832
1498370|1498370-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook-Loader-Ini|0.10|darwin-2level|5.8.1|darwin|7.9.0|200805211829
1498337|1498337-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Mail-File|0.08|darwin-2level|5.8.1|darwin|7.9.0|200805211818
1498332|1498332-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Regexp-Log-Common|0.05|darwin-2level|5.8.1|darwin|7.9.0|200805211817
1498330|1498330-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Games-Trackword|1.05|darwin-2level|5.8.1|darwin|7.9.0|200805211817
1497863|1497863-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|CPAN-YACSmoke-Plugin-Outlook|0.06|darwin-2level|5.8.1|darwin|7.9.0|200805211551
1496655|1496655-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805210951
1496648|1496648-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805210948
1494068|1494068-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805202014
1494062|1494062-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805202012
1491755|1491755-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-DBI|0.11|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200910
1491753|1491753-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-Ini|0.10|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200910
1491752|1491752-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-XML|0.12|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200910
1491750|1491750-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200910
1491735|1491735-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Mail-File|0.08|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200908
1491733|1491733-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Regexp-Log-Common|0.05|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200908
1491732|1491732-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Games-Trackword|1.05|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200908
1491632|1491632-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200855
1487643|1487643-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805192333
1487640|1487640-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805192332
1486901|1486901-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191608
1486898|1486898-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191607
1486733|1486733-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|WWW-Scraper-ISBN-Pearson_Driver|0.09|darwin-2level|5.8.1|darwin|7.9.0|200805192045
1482796|1482796-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805190040
1481611|1481611-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805181826
1481363|1481363-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805182249
1480495|1480495-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|IP35-irix|5.8.8|irix|6.5|200805182133
1480475|1480475-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Phrasebook|0.29|IP35-irix|5.8.8|irix|6.5|200805182130
1474483|1474483-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171805
1474014|1474014-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.20|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171640
1474012|1474012-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.10|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171640
1474010|1474010-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171640
1472571|1472571-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|WWW-UsePerl-Journal|0.21|darwin-2level|5.8.1|darwin|7.9.0|200805171704
1468391|1468391-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805170028
1466322|1466322-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.09|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805160905
1463694|1463694-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805160022
1463692|1463692-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805160022
1461586|1461586-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805151549
1454847|1454847-b19f-3f77-b713-d32bba55d77f|pass|200805|james@mastros.biz|Finance-Currency-Convert-XE|0.15|i486-linux-gnu|5.10.0|linux|2.6.24.4|200805141415
1452344|1452344-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805140302
1452342|1452342-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805140301
1452339|1452339-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805140300
1448685|1448685-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Finance-Currency-Convert-XE|0.15|darwin-2level|5.8.1|darwin|7.9.0|200805131254
1447489|1447489-b19f-3f77-b713-d32bba55d77f|pass|200805|mmlange@cpan.org (Matthew Lange)|Test-YAML-Meta|0.09|x86_64-linux|5.8.8|linux|2.6.23-gentoo-r3|200805130126
1446878|1446878-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.11.0 patch 33822|darwin|8.10.0|200805130611
1446872|1446872-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.11.0 patch 33822|darwin|8.10.0|200805130609
1446326|1446326-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Calendar-List|0.20|darwin-2level|5.8.1|darwin|7.9.0|200805130239
1446324|1446324-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Test-CPAN-Meta|0.10|darwin-2level|5.8.1|darwin|7.9.0|200805130239
1446322|1446322-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805130138
1446321|1446321-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-FormValidator-Constraints-Words|0.03|darwin-2level|5.8.1|darwin|7.9.0|200805130238
1445685|1445685-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|i386-freebsd|5.10.0|freebsd|6.1-release|200805122351
1445644|1445644-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-freebsd|5.10.0|freebsd|6.1-release|200805122342
1445313|1445313-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|WWW-UsePerl-Journal|0.21|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805122151
1444207|1444207-b19f-3f77-b713-d32bba55d77f|pass|200805|Pascal@Rockford.Com|Test-YAML-Meta|0.09|i386-linux|5.8.8|linux|2.6.18-53.1.14.el5xen|200805120526
1442119|1442119-b19f-3f77-b713-d32bba55d77f|pass|200805|perl@galumph.com ("Elliot Shank")|Test-YAML-Meta|0.09|darwin-thread-multi-2level|5.8.8|darwin|8.9.1|200805120009
1439068|1439068-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Test-YAML-Meta|0.09|darwin-2level|5.8.1|darwin|7.9.0|200805111818
1433179|1433179-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook-Loader-YAML|0.09|darwin-2level|5.8.1|darwin|7.9.0|200805101120
1433085|1433085-b19f-3f77-b713-d32bba55d77f|pass|200805|icerider70@gmail.com ("ICERIDER")|Data-FormValidator-Constraints-Words|0.03|i386-linux|5.8.8|linux|2.6.18-53.el5|200805100831
1433080|1433080-b19f-3f77-b713-d32bba55d77f|pass|200805|icerider70@gmail.com ("ICERIDER")|Test-YAML-Meta|0.09|i386-linux|5.8.8|linux|2.6.18-53.el5|200805100831
1433075|1433075-b19f-3f77-b713-d32bba55d77f|pass|200805|icerider70@gmail.com ("ICERIDER")|Test-CPAN-Meta|0.10|i386-linux|5.8.8|linux|2.6.18-53.el5|200805100830
1433071|1433071-b19f-3f77-b713-d32bba55d77f|pass|200805|icerider70@gmail.com ("ICERIDER")|Calendar-List|0.20|i386-linux|5.8.8|linux|2.6.18-53.el5|200805100830
1433014|1433014-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Phrasebook|0.29|darwin-2level|5.8.1|darwin|7.9.0|200805101120
1431567|1431567-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.11.0 patch 33797|linux|2.6.24-17-generic|200805101043
1431565|1431565-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Data-Phrasebook|0.29|i686-linux|5.11.0 patch 33797|linux|2.6.24-17-generic|200805101043
1430050|1430050-b19f-3f77-b713-d32bba55d77f|pass|200805|amoore@cpan.org|Test-YAML-Meta|0.09|i486-linux-gnu|5.8.8|linux|2.6.24.4|200805091532
1423334|1423334-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.11.0 patch 33789|solaris|2.10|200805082121
1423330|1423330-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.11.0 patch 33789|solaris|2.10|200805082120
1413921|1413921-b19f-3f77-b713-d32bba55d77f|pass|200805|artur+cpan@niif.spb.su (ARTO)|Test-YAML-Meta|0.09|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805061614
1413653|1413653-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805060919
1413651|1413651-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805060918
1413308|1413308-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.11.0 patch 33788|netbsd|4.0|200805061243
1413305|1413305-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.11.0 patch 33788|netbsd|4.0|200805061241
1412724|1412724-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Test-YAML-Meta|0.09|i686-linux|5.11.0 patch 33788|linux|2.6.24-17-generic|200805061043
1412451|1412451-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Test-CPAN-Meta|0.10|i686-linux|5.11.0 patch 33788|linux|2.6.24-17-generic|200805060933
1412125|1412125-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200805060651
1412113|1412113-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200805060649
1411583|1411583-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200805060226
1411581|1411581-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200805060224
1410501|1410501-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|i386-freebsd|5.6.2|freebsd|6.1-release|200805052213
1408283|1408283-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33782|openbsd|4.2|200805050613
1408277|1408277-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33782|openbsd|4.2|200805050610
1406930|1406930-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200805041812
1406924|1406924-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200805041809
1403562|1403562-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|CPAN-YACSmoke-Plugin-WebList|0.05|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040206
1403550|1403550-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Calendar-List|0.20|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040205
1403291|1403291-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Test-YAML-Meta|0.09|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040128
1403001|1403001-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Test-CPAN-Meta|0.10|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040045
1402706|1402706-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Mail-File|0.08|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032340
1402489|1402489-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Finance-Currency-Convert-XE|0.15|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032257
1402393|1402393-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032243
1402392|1402392-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Phrasebook-Loader-XML|0.12|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032243
1402391|1402391-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032243
1402389|1402389-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Phrasebook|0.29|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032243
1399058|1399058-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Games-Trackword|1.05|i386-freebsd|5.5.5|freebsd|6.1-release|200805030736
1398997|1398997-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.5.5|freebsd|6.1-release|200805030729
1398094|1398094-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.5.5|freebsd|6.1-release|200805030103
1397865|1397865-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.5.5|freebsd|6.1-release|200805030103
1397864|1397864-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.5.5|freebsd|6.1-release|200805030103
1397863|1397863-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.5.5|freebsd|6.1-release|200805030103
1397858|1397858-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.5.5|freebsd|6.1-release|200805030103
1397756|1397756-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.5.5|freebsd|6.1-release|200805022353
1397287|1397287-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.5.5|freebsd|6.1-release|200805022353
1397286|1397286-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.5.5|freebsd|6.1-release|200805022352
1397283|1397283-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.5.5|freebsd|6.1-release|200805022352
1397282|1397282-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd|5.5.5|freebsd|6.1-release|200805022352
1397258|1397258-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.5.5|freebsd|6.1-release|200805022351
1392421|1392421-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805012231
1392417|1392417-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805012228
1392407|1392407-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805012227
1389438|1389438-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|darwin-thread-multi-64int-2level|5.11.0 patch 33741|darwin|8.10.0|200804301642
1388357|1388357-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-64int-2level|5.11.0 patch 33741|darwin|8.10.0|200804300544
1385706|1385706-b19f-3f77-b713-d32bba55d77f|fail|200804|daxim@cpan.org|WWW-UsePerl-Journal|0.21|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290937
1383694|1383694-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Finance-Currency-Convert-XE|0.15|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290002
1383002|1383002-b19f-3f77-b713-d32bba55d77f|pass|200804|Pascal@Rockford.Com|Test-YAML-Meta|0.09|i386-linux|5.8.8|linux|2.6.9-55.0.9.elsmp|200804281129
1378077|1378077-b19f-3f77-b713-d32bba55d77f|pass|200804|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.09|i686-linux|5.10.0|linux|2.6.22-3-486|200804270230
1378007|1378007-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Finance-Currency-Convert-XE|0.15|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804270218
1366602|1366602-b19f-3f77-b713-d32bba55d77f|fail|200804|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804231831
1366600|1366600-b19f-3f77-b713-d32bba55d77f|fail|200804|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804231830
1366322|1366322-b19f-3f77-b713-d32bba55d77f|fail|200804|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804231731
1364232|1364232-b19f-3f77-b713-d32bba55d77f|fail|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804230036
1360462|1360462-b19f-3f77-b713-d32bba55d77f|pass|200804|rolf.wagner@uniklinik-ulm.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.2.24-7.0.3|200804220813
1360459|1360459-b19f-3f77-b713-d32bba55d77f|pass|200804|rolf.wagner@uniklinik-ulm.de|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.2.24-7.0.3|200804220813
1359400|1359400-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804220113
1358967|1358967-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-UsePerl-Journal|0.21|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804220004
1353454|1353454-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTP|0.05|sun4-solaris|5.10.0|solaris|2.9|200804202231
1353452|1353452-b19f-3f77-b713-d32bba55d77f|fail|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|sun4-solaris|5.10.0|solaris|2.9|200804202231
1353427|1353427-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-WebList|0.05|sun4-solaris|5.10.0|solaris|2.9|200804202227
1351871|1351871-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.09|sun4-solaris|5.10.0|solaris|2.9|200804201800
1344016|1344016-b19f-3f77-b713-d32bba55d77f|fail|200804|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191451
1343994|1343994-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191442
1343982|1343982-b19f-3f77-b713-d32bba55d77f|fail|200804|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191436
1343955|1343955-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191427
1343914|1343914-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191418
1343903|1343903-b19f-3f77-b713-d32bba55d77f|fail|200804|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191409
1343825|1343825-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191358
1343813|1343813-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191355
1343810|1343810-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191354
1343808|1343808-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Mail-File|0.08|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191353
1343803|1343803-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Games-Trackword|1.05|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191353
1343800|1343800-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191352
1343797|1343797-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191351
1343778|1343778-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191346
1343775|1343775-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191344
1343756|1343756-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191340
1343755|1343755-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191339
1343739|1343739-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191330
1343737|1343737-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191330
1343698|1343698-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804191318
1342005|1342005-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|cygwin-thread-multi-64int|5.11.0 patch 33713|cygwin|1.5.24(0.15642)|200804190146
1337015|1337015-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.10|sun4-solaris|5.10.0|solaris|2.9|200804181216
1333870|1333870-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Games-Trackword|1.05|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804172059
1333782|1333782-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804172033
1333680|1333680-b19f-3f77-b713-d32bba55d77f|pass|200804|artur+cpan@niif.spb.su|Finance-Currency-Convert-XE|0.15|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200804171548
1333514|1333514-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Regexp-Log-Common|0.05|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171906
1333305|1333305-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171747
1332884|1332884-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-CPAN-Meta|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804171711
1332883|1332883-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-CPAN-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804171711
1332684|1332684-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171532
1332683|1332683-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171532
1332682|1332682-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171532
1332639|1332639-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171501
1332637|1332637-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171500
1332504|1332504-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171502
1329727|1329727-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170135
1329597|1329597-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170135
1329519|1329519-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Test-YAML-Meta|0.09|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170121
1329441|1329441-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-YAML-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804170213
1329426|1329426-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200804170005
1328369|1328369-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804162226
1324932|1324932-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804161218
1322749|1322749-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200804160616
1322077|1322077-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160514
1320868|1320868-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Calendar-List|0.20|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160212
1320340|1320340-b19f-3f77-b713-d32bba55d77f|pass|200804|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200804160003
1320293|1320293-b19f-3f77-b713-d32bba55d77f|pass|200804|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200804152356
1320096|1320096-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.10.0|freebsd|6.1-release|200804160003
1316446|1316446-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804151033
1316295|1316295-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200804150855
1316148|1316148-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804150902
1315360|1315360-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804150255
1315160|1315160-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-UsePerl-Journal|0.21|i386-freebsd|5.10.0|freebsd|6.1-release|200804150134
1313419|1313419-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|darwin-thread-multi-64int-2level|5.11.0 patch 33659|darwin|8.10.0|200804141535
1312884|1312884-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33670|openbsd|4.2|200804141303
1310092|1310092-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804140040
1309856|1309856-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|i386-freebsd|5.10.0|freebsd|6.1-release|200804132353
1309040|1309040-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200804131917
1308916|1308916-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200804131843
1304821|1304821-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Mail-File|0.08|i386-freebsd|5.10.0|freebsd|6.1-release|200804122349
1304333|1304333-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-UsePerl-Journal|0.21|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804122231
1304287|1304287-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Games-Trackword|1.05|i386-freebsd|5.10.0|freebsd|6.1-release|200804122218
1304065|1304065-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-freebsd|5.10.0|freebsd|6.1-release|200804122123
1304061|1304061-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd|5.10.0|freebsd|6.1-release|200804122122
1304060|1304060-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd|5.10.0|freebsd|6.1-release|200804122123
1303819|1303819-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd|5.10.0|freebsd|6.1-release|200804121916
1303800|1303800-b19f-3f77-b713-d32bba55d77f|fail|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd|5.10.0|freebsd|6.1-release|200804121912
1303490|1303490-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd|5.10.0|freebsd|6.1-release|200804121913
1303438|1303438-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd|5.10.0|freebsd|6.1-release|200804121902
1302879|1302879-b19f-3f77-b713-d32bba55d77f|pass|200804|andy@hexten.net|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200804121631
1299730|1299730-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|cygwin-thread-multi-64int|5.11.0 patch 33669|cygwin|1.5.24(0.15642)|200804120741
1299178|1299178-b19f-3f77-b713-d32bba55d77f|fail|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.10|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804120029
1299176|1299176-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.21|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804120029
1295063|1295063-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804111019
1295058|1295058-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804111018
1294774|1294774-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200804110733
1294437|1294437-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.10.0|freebsd|6.1-release|200804110554
1294436|1294436-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.10.0|freebsd|6.1-release|200804110554
1292948|1292948-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|GD-Chart-Radial|0.07|i386-freebsd|5.6.2|freebsd|6.1-release|200804102137
1291854|1291854-b19f-3f77-b713-d32bba55d77f|pass|200804|david@cantrell.org.uk|Test-YAML-Meta|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200804101459
1289357|1289357-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200804092105
1289055|1289055-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804092217
1289054|1289054-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804092217
1288385|1288385-b19f-3f77-b713-d32bba55d77f|pass|200804|david@cantrell.org.uk|Test-YAML-Meta|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200804091736
1288382|1288382-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|WWW-UsePerl-Journal|0.21|i386-freebsd|5.6.2|freebsd|6.1-release|200804091831
1282944|1282944-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200804081817
1282452|1282452-b19f-3f77-b713-d32bba55d77f|pass|200804|david@cantrell.org.uk|Test-YAML-Meta|0.09|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200804081710
1281967|1281967-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|alpha-linux-thread-multi|5.11.0 patch 33655|linux|2.6.18-5-alpha-generic|200804081420
1280630|1280630-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804080850
1280629|1280629-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804080850
1279012|1279012-b19f-3f77-b713-d32bba55d77f|pass|200804|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.09|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200804072310
1273320|1273320-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200804070239
1273319|1273319-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200804070238
1273318|1273318-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200804070238
1273310|1273310-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200804070237
1272312|1272312-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Calendar-List|0.20|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804062314
1272310|1272310-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Test-CPAN-Meta|0.10|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804062313
1272307|1272307-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Data-FormValidator-Constraints-Words|0.03|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804062313
1272306|1272306-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Test-YAML-Meta|0.09|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804062313
1270602|1270602-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.6.2|freebsd|6.1-release|200804061357
1270578|1270578-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Phrasebook|0.29|i386-freebsd|5.6.2|freebsd|6.1-release|200804061354
1268201|1268201-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200804060020
1268175|1268175-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200804060017
1268168|1268168-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200804060016
1268163|1268163-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200804060016
1267444|1267444-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-YAML-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804060044
1267430|1267430-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-YAML-Meta|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804060041
1265407|1265407-b19f-3f77-b713-d32bba55d77f|pass|200804|mthurn@cpan.org|Test-YAML-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804051117
1265148|1265148-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200804051527
1265136|1265136-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200804051525
1265132|1265132-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200804051525
1265123|1265123-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200804051523
1264639|1264639-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-CPAN-Meta|0.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200804051515
1264632|1264632-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Test-CPAN-Meta|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200804051513
1260590|1260590-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|cygwin-thread-multi-64int|5.11.0 patch 33643|cygwin|1.5.24(0.15642)|200804041830
1260580|1260580-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|cygwin-thread-multi-64int|5.11.0 patch 33643|cygwin|1.5.24(0.15642)|200804041827
1260573|1260573-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|cygwin-thread-multi-64int|5.11.0 patch 33643|cygwin|1.5.24(0.15642)|200804041825
1260439|1260439-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Data-FormValidator-Constraints-Words|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804041852
1260423|1260423-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Calendar-List|0.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804041843
1258386|1258386-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200804040826
1258380|1258380-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200804040822
1258375|1258375-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200804040820
1258373|1258373-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200804040820
1253644|1253644-b19f-3f77-b713-d32bba55d77f|fail|200804|dagolden@cpan.org (DAGOLDEN)|WWW-Scraper-ISBN-Amazon_Driver|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804030651
1253614|1253614-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804031145
1253594|1253594-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804031142
1253585|1253585-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804031141
1253172|1253172-b19f-3f77-b713-d32bba55d77f|pass|200804|rlane10@wi.rr.com|Test-YAML-Meta|0.09|darwin-2level-ld|5.10.0|darwin|8.11.0|200804021815
1253058|1253058-b19f-3f77-b713-d32bba55d77f|pass|200804|claco@chrislaco.com ("Christopher H. Laco")|Test-YAML-Meta|0.09|darwin-thread-multi-2level|5.8.6|darwin|8.0|200804030017
1252304|1252304-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804030512
1252303|1252303-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804030511
1252302|1252302-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804030510
1252300|1252300-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804030509
1251917|1251917-b19f-3f77-b713-d32bba55d77f|fail|200804|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal-Thread|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804030147
1251916|1251916-b19f-3f77-b713-d32bba55d77f|pass|200804|dagolden@cpan.org (DAGOLDEN)|WWW-UsePerl-Journal|0.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804030147
1249405|1249405-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200804021108
1249153|1249153-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200804020927
1249150|1249150-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200804020923
1249146|1249146-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200804020922
1249145|1249145-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200804020921
1248809|1248809-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804020714
1248799|1248799-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804020712
1248795|1248795-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804020712
1248792|1248792-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804020712
1248677|1248677-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804020844
1248671|1248671-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.29|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804020843
1248369|1248369-b19f-3f77-b713-d32bba55d77f|pass|200804|icerider70@gmail.com ("ICERIDER")|Calendar-List|0.19|i386-linux|5.8.8|linux|2.6.18-53.el5|200804020013
1247767|1247767-b19f-3f77-b713-d32bba55d77f|pass|200804|icerider70@gmail.com ("ICERIDER")|Finance-Currency-Convert-XE|0.15|i386-linux|5.8.8|linux|2.6.18-53.el5|200804020049
1247710|1247710-b19f-3f77-b713-d32bba55d77f|pass|200804|icerider70@gmail.com ("ICERIDER")|Test-CPAN-Meta|0.09|i386-linux|5.8.8|linux|2.6.18-53.el5|200804020032
1247708|1247708-b19f-3f77-b713-d32bba55d77f|pass|200804|icerider70@gmail.com ("ICERIDER")|Test-YAML-Meta|0.08|i386-linux|5.8.8|linux|2.6.18-53.el5|200804020031
1246985|1246985-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804012303
1244529|1244529-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804010956
1244514|1244514-b19f-3f77-b713-d32bba55d77f|pass|200804|krzys@igf.edu.pl|Test-YAML-Meta|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.18-4-vserver-amd64|200804010556
1244512|1244512-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804010954
1244509|1244509-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804010954
1244242|1244242-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804011015
1244200|1244200-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804011010
1244195|1244195-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804011009
1244191|1244191-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Calendar-List|0.20|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804011008
1242344|1242344-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.09|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200803312114
1242317|1242317-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.09|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200803312118
1242312|1242312-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.09|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200803312119
1242305|1242305-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.09|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200803312114
1241335|1241335-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.09|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803311423
1241325|1241325-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.10|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803311422
1241324|1241324-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.03|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803311420
1241321|1241321-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.20|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803311419
1241275|1241275-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Test-CPAN-Meta|0.10|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803311910
1241272|1241272-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.09|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803311909
1241269|1241269-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Data-FormValidator-Constraints-Words|0.03|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803311908
1240798|1240798-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.09|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803311659
1240787|1240787-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.10|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803311658
1240612|1240612-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.09|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803311551
1240609|1240609-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.20|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803311750
1240605|1240605-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.10|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803311549
1240594|1240594-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.10|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803311748
1240591|1240591-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.03|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803311548
1240586|1240586-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.20|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803311547
1240585|1240585-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.09|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803311747
1240574|1240574-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.03|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803311745
1240256|1240256-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.11.0 patch 33609|netbsd|3.1|200803311525
1240253|1240253-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.11.0 patch 33609|netbsd|3.1|200803311524
1239635|1239635-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.9-5.elsmp|200803311101
1239623|1239623-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i686-linux|5.8.6|linux|2.4.18|200803311253
1239622|1239622-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200803311253
1239438|1239438-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.09|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200803311818
1239433|1239433-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200803311058
1239427|1239427-b19f-3f77-b713-d32bba55d77f|pass|200803|artur+cpan@niif.spb.su|Test-YAML-Meta|0.09|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200803311135
1239339|1239339-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200803311146
1239326|1239326-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200803311143
1239318|1239318-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200803311142
1239224|1239224-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Calendar-List|0.20|i686-linux|5.10.0|linux|2.6.22-3-486|200803311221
1239222|1239222-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Test-CPAN-Meta|0.10|i686-linux|5.10.0|linux|2.6.22-3-486|200803311219
1239219|1239219-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Test-YAML-Meta|0.09|i686-linux|5.10.0|linux|2.6.22-3-486|200803311218
1239215|1239215-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Data-FormValidator-Constraints-Words|0.03|i686-linux|5.10.0|linux|2.6.22-3-486|200803311217
1239056|1239056-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803311718
1239055|1239055-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803311718
1239051|1239051-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803311717
1239050|1239050-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803311717
1239049|1239049-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803311717
1239048|1239048-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803311717
1239047|1239047-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Calendar-List|0.20|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803311717
1239046|1239046-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Calendar-List|0.20|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803311716
1239004|1239004-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803310951
1239001|1239001-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803310949
1238999|1238999-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803310948
1238998|1238998-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803310948
1238563|1238563-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Calendar-List|0.20|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803310813
1238559|1238559-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Test-CPAN-Meta|0.10|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803310813
1238558|1238558-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Test-YAML-Meta|0.09|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803310813
1238557|1238557-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Data-FormValidator-Constraints-Words|0.03|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803310813
1238534|1238534-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.10.0|freebsd|6.1-release|200803310804
1237982|1237982-b19f-3f77-b713-d32bba55d77f|pass|200803|rafl@debian.org|Test-YAML-Meta|0.09|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200803301737
1237930|1237930-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803310127
1237929|1237929-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803310126
1237927|1237927-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803310125
1237926|1237926-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803310125
1237421|1237421-b19f-3f77-b713-d32bba55d77f|na|200803|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|i386-freebsd|5.5.5|freebsd|6.1-release|200803310032
1236387|1236387-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.20|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200803301956
1236386|1236386-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200803301955
1236381|1236381-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200803301955
1236379|1236379-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.09|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200803301955
1236334|1236334-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803301931
1236245|1236245-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.20|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803301932
1236244|1236244-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803301931
1236243|1236243-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803301930
1236127|1236127-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200803301911
1236126|1236126-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.20|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200803301913
1236124|1236124-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200803301909
1236113|1236113-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.09|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200803301907
1235906|1235906-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.09|i386-freebsd|5.10.0|freebsd|6.1-release|200803301745
1235858|1235858-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Test-YAML-Meta|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803301706
1235802|1235802-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.20|i386-freebsd|5.10.0|freebsd|6.1-release|200803301743
1235766|1235766-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd|5.10.0|freebsd|6.1-release|200803301744
1235764|1235764-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.10.0|freebsd|6.1-release|200803301743
1235480|1235480-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.09|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200803301220
1235243|1235243-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803301100
1235242|1235242-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803301059
1235241|1235241-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803301059
1235240|1235240-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803301059
1235239|1235239-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803301059
1235238|1235238-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803301058
1235237|1235237-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803301058
1235236|1235236-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803301058
1235234|1235234-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803301057
1235233|1235233-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803301057
1235196|1235196-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.09|i586-linux-thread-multi|5.8.8|linux|2.6.16|200803292349
1235018|1235018-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.6.2|freebsd|6.1-release|200803300917
1234909|1234909-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.03|i386-freebsd|5.5.5|freebsd|6.1-release|200803300929
1234908|1234908-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd|5.5.5|freebsd|6.1-release|200803300928
1234890|1234890-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.09|i386-freebsd|5.6.2|freebsd|6.1-release|200803300917
1234885|1234885-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.10|i386-freebsd|5.6.2|freebsd|6.1-release|200803300917
1234884|1234884-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.20|i386-freebsd|5.6.2|freebsd|6.1-release|200803300916
1234718|1234718-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803300602
1234716|1234716-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803300601
1234714|1234714-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803300601
1234712|1234712-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803300600
1234711|1234711-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803300600
1234710|1234710-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803300600
1234709|1234709-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803300559
1234708|1234708-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803300559
1234706|1234706-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803300558
1234704|1234704-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803300558
1234703|1234703-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803300557
1234700|1234700-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803300557
1234699|1234699-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803300557
1234698|1234698-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803300556
1234697|1234697-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803300556
1234696|1234696-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803300555
1234695|1234695-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803300555
1234694|1234694-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803300554
1234693|1234693-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803300554
1234692|1234692-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.10|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803300553
1234691|1234691-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803300553
1234690|1234690-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803300553
1234689|1234689-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803300552
1234688|1234688-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803300552
1234687|1234687-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803300551
1234686|1234686-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803300550
1234684|1234684-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.20|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803300550
1234134|1234134-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803292242
1234084|1234084-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803292241
1233949|1233949-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803292204
1233690|1233690-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Data-FormValidator-Constraints-Words|0.03||0|||200803292131
1233689|1233689-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Test-YAML-Meta|0.09||0|||200803292130
1233686|1233686-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Test-CPAN-Meta|0.10||0|||200803292129
1233681|1233681-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Calendar-List|0.20||0|||200803292125
1233307|1233307-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.09|i386-freebsd|5.6.2|freebsd|6.1-release|200803291855
1233173|1233173-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.08|i386-freebsd|5.6.2|freebsd|6.1-release|200803291856
1228252|1228252-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281532
1228232|1228232-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803281442
1227205|1227205-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Data-FormValidator-Constraints-Words|0.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803280559
1223685|1223685-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270700
1222104|1222104-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Calendar-List|0.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803262147
1221875|1221875-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803261731
1221872|1221872-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803261731
1221857|1221857-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803261726
1221845|1221845-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803261726
1221841|1221841-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803261725
1221829|1221829-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803261723
1221622|1221622-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Calendar-List|0.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803261739
1219565|1219565-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803260327
1219563|1219563-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803260326
1219562|1219562-b19f-3f77-b713-d32bba55d77f|pass|200803|mthurn@cpan.org|Test-YAML-Meta|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803260326
1218023|1218023-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|amd64-freebsd|5.6.2|freebsd|6.2-release|200803252246
1218020|1218020-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|amd64-freebsd|5.6.2|freebsd|6.2-release|200803252245
1215947|1215947-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|cygwin-thread-multi-64int|5.11.0 patch 33547|cygwin|1.5.24(0.15642)|200803251239
1215927|1215927-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|cygwin-thread-multi-64int|5.11.0 patch 33547|cygwin|1.5.24(0.15642)|200803251236
1215897|1215897-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|cygwin-thread-multi-64int|5.11.0 patch 33547|cygwin|1.5.24(0.15642)|200803251232
1215888|1215888-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|cygwin-thread-multi-64int|5.11.0 patch 33547|cygwin|1.5.24(0.15642)|200803251231
1215073|1215073-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803250828
1215072|1215072-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803250826
1215070|1215070-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803250823
1215068|1215068-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803250822
1215061|1215061-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803250821
1215033|1215033-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803250818
1212986|1212986-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803250037
1211438|1211438-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-UsePerl-Journal|0.21|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803241944
1211205|1211205-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803241944
1211087|1211087-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.19|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803241922
1209831|1209831-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33550|openbsd|4.2|200803241214
1209830|1209830-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33550|openbsd|4.2|200803241212
1209805|1209805-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33550|openbsd|4.2|200803241209
1209804|1209804-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33550|openbsd|4.2|200803241208
1209803|1209803-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33550|openbsd|4.2|200803241208
1208261|1208261-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Calendar-List|0.19|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803240704
1206121|1206121-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803231442
1206112|1206112-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803231438
1206101|1206101-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803231435
1206099|1206099-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803231434
1206095|1206095-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803231431
1205731|1205731-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803231148
1205730|1205730-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803231146
1205727|1205727-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803231143
1205725|1205725-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803231142
1205722|1205722-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803231141
1205708|1205708-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803231138
1205695|1205695-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Calendar-List|0.19|i686-linux|5.10.0|linux|2.6.22-3-486|200803231234
1202325|1202325-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803220100
1202324|1202324-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803220058
1202322|1202322-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803220055
1202319|1202319-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803220054
1202315|1202315-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803220052
1201865|1201865-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.08|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803212212
1201862|1201862-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Test-CPAN-Meta|0.09|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803212211
1201441|1201441-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803211945
1200765|1200765-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803211627
1200759|1200759-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803211625
1200752|1200752-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803211623
1200748|1200748-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803211622
1200744|1200744-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803211621
1199747|1199747-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|i386-freebsd|5.6.2|freebsd|6.1-release|200803211132
1199416|1199416-b19f-3f77-b713-d32bba55d77f|pass|200803|rafl@debian.org|Test-YAML-Meta|0.08|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200803210419
1199322|1199322-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803210934
1199319|1199319-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803210933
1199318|1199318-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803210933
1199316|1199316-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803210932
1199315|1199315-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803210932
1199312|1199312-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803210931
1199310|1199310-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803210931
1199307|1199307-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803210930
1199302|1199302-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803210930
1199299|1199299-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803210929
1198603|1198603-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Calendar-List|0.19|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803210744
1198021|1198021-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Calendar-List|0.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803210335
1196973|1196973-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|cygwin-thread-multi-64int|5.11.0 patch 33543|cygwin|1.5.24(0.15642)|200803202101
1196954|1196954-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|cygwin-thread-multi-64int|5.11.0 patch 33543|cygwin|1.5.24(0.15642)|200803202057
1196928|1196928-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|cygwin-thread-multi-64int|5.11.0 patch 33543|cygwin|1.5.24(0.15642)|200803202053
1196927|1196927-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|cygwin-thread-multi-64int|5.11.0 patch 33543|cygwin|1.5.24(0.15642)|200803202052
1196482|1196482-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803200831
1196481|1196481-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803200830
1196478|1196478-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803200829
1196477|1196477-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|amd64-freebsd|5.10.0|freebsd|6.2-release|200803200829
1196019|1196019-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.08|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803201752
1196015|1196015-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.09|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803201750
1195908|1195908-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.15|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803201705
1195812|1195812-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201154
1195807|1195807-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201152
1195794|1195794-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201151
1195792|1195792-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201150
1195787|1195787-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201149
1195765|1195765-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|i686-linux|5.6.2|linux|2.4.27-3-686|200803201531
1195668|1195668-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803201010
1195658|1195658-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803201508
1195649|1195649-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|i686-linux|5.8.8|linux|2.4.27-3-686|200803201507
1195539|1195539-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803201429
1195535|1195535-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803201433
1195533|1195533-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Calendar-List|0.19|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803201426
1195072|1195072-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Data-FormValidator-Constraints-Words|0.02|i686-linux|5.10.0|linux|2.6.22-3-486|200803201221
1194871|1194871-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Test-YAML-Meta|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803200630
1194870|1194870-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Test-CPAN-Meta|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803200629
1194752|1194752-b19f-3f77-b713-d32bba55d77f|pass|200803|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Calendar-List|0.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200803201234
1194656|1194656-b19f-3f77-b713-d32bba55d77f|pass|200803|claco@chrislaco.com ("Christopher H. Laco")|Test-YAML-Meta|0.08|darwin-thread-multi-2level|5.8.6|darwin|8.0|200803200040
1194630|1194630-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Calendar-List|0.19|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803201728
1194571|1194571-b19f-3f77-b713-d32bba55d77f|pass|200803|rlane10@wi.rr.com|Test-YAML-Meta|0.08|darwin-2level-ld|5.10.0|darwin|8.11.0|200803200339
1194396|1194396-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Calendar-List|0.19|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201606
1194014|1194014-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|darwin-2level|5.8.8|darwin|8.10.1|200803200802
1193980|1193980-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803200707
1193975|1193975-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803200706
1193959|1193959-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.19|amd64-freebsd|5.6.2|freebsd|6.2-release|200803200759
1193957|1193957-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Calendar-List|0.19|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803200705
1193011|1193011-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Finance-Currency-Convert-XE|0.15|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803200030
1192707|1192707-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.15|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201142
1192352|1192352-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803200305
1192351|1192351-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803200304
1192350|1192350-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-64int|5.8.8|linux|2.6.14|200803200303
1192347|1192347-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803200303
1192345|1192345-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803200302
1192333|1192333-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803200305
1192155|1192155-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803200302
1192152|1192152-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803200301
1192149|1192149-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803200300
1192146|1192146-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Calendar-List|0.19|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803200300
1192043|1192043-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200209
1191598|1191598-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Test-YAML-Meta|0.08|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803200035
1191597|1191597-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Test-CPAN-Meta|0.09|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803200035
1191579|1191579-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Finance-Currency-Convert-XE|0.15|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803200032
1191557|1191557-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Calendar-List|0.19||0|||200803200033
1190271|1190271-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200803191652
1190227|1190227-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803191640
1190225|1190225-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803191639
1190223|1190223-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803191637
1190221|1190221-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803191636
1190212|1190212-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803191634
1190203|1190203-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803191633
1190196|1190196-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803191632
1190170|1190170-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803191619
1190114|1190114-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191445
1190113|1190113-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191443
1190105|1190105-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191442
1190104|1190104-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191441
1190089|1190089-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191441
1189786|1189786-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803191442
1189784|1189784-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803191442
1189782|1189782-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803191442
1189781|1189781-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803191441
1189780|1189780-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803191441
1189778|1189778-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803191440
1189777|1189777-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803191440
1189773|1189773-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803191439
1189772|1189772-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803191439
1189771|1189771-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803191439
1189769|1189769-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803191438
1189767|1189767-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803191438
1189766|1189766-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803191437
1189762|1189762-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803191437
1189759|1189759-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803191436
1189753|1189753-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803191436
1189750|1189750-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803191435
1189749|1189749-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803191435
1189745|1189745-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803191434
1189741|1189741-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803191434
1189739|1189739-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803191434
1189734|1189734-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803191433
1189724|1189724-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803191432
1189722|1189722-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803191431
1189721|1189721-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803191429
1189718|1189718-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803191428
1189709|1189709-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803191424
1189706|1189706-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803191425
1189701|1189701-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803191422
1189686|1189686-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803191415
1189683|1189683-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803191414
1189682|1189682-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803191413
1189679|1189679-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803191412
1189676|1189676-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803191411
1189675|1189675-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803191409
1189671|1189671-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803191408
1189670|1189670-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803191407
1189669|1189669-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803191405
1189666|1189666-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803191403
1189516|1189516-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191311
1189515|1189515-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191309
1189509|1189509-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191306
1189507|1189507-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191305
1189505|1189505-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191305
1189031|1189031-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.07|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200803191015
1189023|1189023-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.07|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200803191014
1189021|1189021-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-CPAN-Meta|0.08|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200803191013
1189018|1189018-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-CPAN-Meta|0.08|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200803191011
1188999|1188999-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.08|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200803191008
1188997|1188997-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.08|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200803191006
1188995|1188995-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-CPAN-Meta|0.09|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200803191005
1188989|1188989-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Test-CPAN-Meta|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200803191003
1188799|1188799-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Finance-Currency-Convert-XE|0.15|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200803190915
1188790|1188790-b19f-3f77-b713-d32bba55d77f|pass|200803|bob@randomness.org.uk ("bob walker")|Finance-Currency-Convert-XE|0.15|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200803190913
1188757|1188757-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.08|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200803190847
1188698|1188698-b19f-3f77-b713-d32bba55d77f|pass|200803|krzys@igf.edu.pl|Test-YAML-Meta|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.18-4-vserver-amd64|200803190209
1187528|1187528-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803190903
1187526|1187526-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.08|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200803181843
1187512|1187512-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803190902
1187511|1187511-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.15|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803190901
1186713|1186713-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803182048
1186711|1186711-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803182047
1186709|1186709-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803182046
1186702|1186702-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803182044
1186315|1186315-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.08|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803182009
1186314|1186314-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Test-CPAN-Meta|0.09|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803182009
1186048|1186048-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.22-3-486|200803181931
1186043|1186043-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.22-3-486|200803181931
1185933|1185933-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Finance-Currency-Convert-XE|0.15|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803181851
1185222|1185222-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181517
1185207|1185207-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181514
1185193|1185193-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181510
1185183|1185183-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181509
1185180|1185180-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181508
1185022|1185022-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Test-YAML-Meta|0.08|i686-linux|5.10.0|linux|2.6.22-3-486|200803181547
1185015|1185015-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Test-CPAN-Meta|0.09|i686-linux|5.10.0|linux|2.6.22-3-486|200803181546
1184893|1184893-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Finance-Currency-Convert-XE|0.15|i686-linux|5.10.0|linux|2.6.22-3-486|200803181531
1184443|1184443-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.9-5.elsmp|200803181020
1184440|1184440-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.08|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200803181830
1184379|1184379-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.08|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200803181021
1184196|1184196-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.08|i686-linux|5.8.8|linux|2.4.27-3-686|200803181046
1184187|1184187-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.07|i686-linux|5.8.8|linux|2.4.27-3-686|200803181045
1184178|1184178-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|i686-linux|5.6.2|linux|2.4.27-3-686|200803181044
1184174|1184174-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|i686-linux|5.6.2|linux|2.4.27-3-686|200803181043
1184169|1184169-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200803181042
1184166|1184166-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.08|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803181042
1184165|1184165-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|i686-linux|5.8.8|linux|2.4.27-3-686|200803181042
1184164|1184164-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.07|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803181042
1184159|1184159-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803181041
1184158|1184158-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803181041
1184156|1184156-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.15|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803181040
1183870|1183870-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.08|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200803172248
1183792|1183792-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803181647
1183789|1183789-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803181646
1183783|1183783-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803181645
1183781|1183781-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803181644
1183773|1183773-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.08|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200803172245
1183751|1183751-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.08|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200803172247
1183739|1183739-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.08|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803180325
1183737|1183737-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.07|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803180324
1183723|1183723-b19f-3f77-b713-d32bba55d77f|pass|200803|artur+cpan@niif.spb.su|Test-YAML-Meta|0.08|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200803180648
1183683|1183683-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Test-YAML-Meta|0.08|i586-linux-thread-multi|5.8.8|linux|2.6.16|200803172212
1183665|1183665-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803180321
1183657|1183657-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803180320
1183656|1183656-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803180824
1183653|1183653-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.15|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803180319
1183651|1183651-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.07|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803180823
1183646|1183646-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.08|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803180817
1183644|1183644-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.07|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803180817
1183640|1183640-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803180816
1183638|1183638-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803180820
1183636|1183636-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803180816
1183630|1183630-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803180819
1183622|1183622-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.15|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803180816
1183614|1183614-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.08|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803180810
1183610|1183610-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-YAML-Meta|0.07|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803180809
1183588|1183588-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.09|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803180806
1183585|1183585-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Test-CPAN-Meta|0.08|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803180806
1183579|1183579-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.15|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803180804
1182189|1182189-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|darwin-2level|5.8.8|darwin|8.10.1|200803180050
1182012|1182012-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803180220
1181547|1181547-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803172223
1181189|1181189-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803172246
1181187|1181187-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.09|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803172244
1181155|1181155-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.08|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803172243
1181152|1181152-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803172242
1181148|1181148-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.09|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803172242
1181143|1181143-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.08|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803172242
1181086|1181086-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.09|amd64-freebsd|5.6.2|freebsd|6.2-release|200803172127
1181033|1181033-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.09|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803172212
1181030|1181030-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.08|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803172211
1181026|1181026-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Finance-Currency-Convert-XE|0.15|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803172213
1180981|1180981-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803172107
1180974|1180974-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803172106
1180971|1180971-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803172105
1180965|1180965-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.08|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803172102
1180952|1180952-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803172058
1180946|1180946-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-CPAN-Meta|0.08|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803172056
1180944|1180944-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803172055
1180891|1180891-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Test-YAML-Meta|0.07|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803172052
1180362|1180362-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803171737
1180359|1180359-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803171737
1180358|1180358-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803171736
1180357|1180357-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-64int|5.8.8|linux|2.6.14|200803171736
1180356|1180356-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803171736
1180354|1180354-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803171735
1180353|1180353-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803171735
1180352|1180352-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803171735
1180351|1180351-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803171734
1180347|1180347-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.15|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803171734
1180336|1180336-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Finance-Currency-Convert-XE|0.15||0|||200803171731
1179877|1179877-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803171503
1179872|1179872-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803171503
1179870|1179870-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803171502
1179869|1179869-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803171502
1179868|1179868-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803171502
1179867|1179867-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-64int|5.8.8|linux|2.6.14|200803171503
1179866|1179866-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803171503
1179865|1179865-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803171502
1179864|1179864-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803171502
1179862|1179862-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.09|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803171503
1179807|1179807-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803171452
1179804|1179804-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803171453
1179803|1179803-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803171500
1179802|1179802-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803171456
1179801|1179801-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803171453
1179799|1179799-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803171456
1179798|1179798-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803171500
1179796|1179796-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803171459
1179793|1179793-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803171455
1179791|1179791-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803171452
1179790|1179790-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803171455
1179789|1179789-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803171459
1179788|1179788-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803171452
1179787|1179787-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803171459
1179784|1179784-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803171454
1179783|1179783-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.8.8|linux|2.6.14|200803171500
1179780|1179780-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-64int|5.8.8|linux|2.6.14|200803171453
1179779|1179779-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803171455
1179778|1179778-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803171459
1179777|1179777-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803171452
1179773|1179773-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803171452
1179770|1179770-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803171459
1179768|1179768-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803171455
1179765|1179765-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.08|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803171459
1179764|1179764-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.07|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803171452
1179763|1179763-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803171455
1179760|1179760-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803171456
1179717|1179717-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Test-CPAN-Meta|0.09||0|||200803171501
1179688|1179688-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Test-YAML-Meta|0.08||0|||200803171458
1179670|1179670-b19f-3f77-b713-d32bba55d77f|fail|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.08|i686-linux-64int|5.8.8|linux|2.6.14|200803171456
1179635|1179635-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Test-CPAN-Meta|0.08||0|||200803171452
1179624|1179624-b19f-3f77-b713-d32bba55d77f|cpan|200803|BARBIE|Test-YAML-Meta|0.07||0|||200803171451
1176970|1176970-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Games-Trackword|1.05|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803162054
1171793|1171793-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803160101
1169765|1169765-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803151312
1169760|1169760-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803151306
1167593|1167593-b19f-3f77-b713-d32bba55d77f|pass|200803|vpit@cpan.org|Test-YAML-Meta|0.06|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200803142253
1163418|1163418-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132004
1158655|1158655-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130056
1157243|1157243-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.08|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803122035
1157183|1157183-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Calendar-List|0.18|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803122011
1157182|1157182-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Games-Trackword|1.05|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803122011
1157181|1157181-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Regexp-Log-Common|0.05|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803122011
1156118|1156118-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121349
1151816|1151816-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112103
1149172|1149172-b19f-3f77-b713-d32bba55d77f|pass|200803|daxim@cpan.org|Test-CPAN-Meta|0.07|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803111235
1148226|1148226-b19f-3f77-b713-d32bba55d77f|pass|200803|daxim@cpan.org|Data-FormValidator-Constraints-Words|0.02|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803110712
1147529|1147529-b19f-3f77-b713-d32bba55d77f|pass|200803|daxim@cpan.org|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803110223
1147527|1147527-b19f-3f77-b713-d32bba55d77f|pass|200803|daxim@cpan.org|Data-Phrasebook|0.29|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803110223
1146628|1146628-b19f-3f77-b713-d32bba55d77f|pass|200803|daxim@cpan.org|Test-YAML-Meta|0.06|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803102300
1145650|1145650-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102012
1140740|1140740-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803092011
1140597|1140597-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.05|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803092115
1140596|1140596-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803092115
1140566|1140566-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803092111
1140564|1140564-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.05|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803092111
1137699|1137699-b19f-3f77-b713-d32bba55d77f|fail|200803|d@0x64.nl ("DEVOGON")|WWW-Scraper-ISBN-Amazon_Driver|0.11|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803091252
1137689|1137689-b19f-3f77-b713-d32bba55d77f|fail|200803|d@0x64.nl ("DEVOGON")|Finance-Currency-Convert-XE|0.14|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803091251
1135608|1135608-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.07|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803090117
1135452|1135452-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Test-YAML-Meta|0.06|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803090247
1135059|1135059-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Test-CPAN-Meta|0.07|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803090140
1133679|1133679-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081856
1133327|1133327-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Regexp-Log-Common|0.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803082013
1129889|1129889-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Test-YAML-Meta|0.06|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803080933
1129597|1129597-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|WWW-UsePerl-Journal-Thread|0.10|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803080845
1129596|1129596-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|WWW-UsePerl-Journal|0.21|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803080844
1129074|1129074-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|WWW-UsePerl-Journal-Thread|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803080829
1128970|1128970-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080654
1125606|1125606-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071725
1122673|1122673-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070545
1116633|1116633-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061058
1114522|1114522-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.8.8 patch 33436|linux|2.6.22-1-k7|200803060243
1110239|1110239-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|GD-Chart-Radial|0.07|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803051140
1107820|1107820-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042337
1104011|1104011-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041107
1102366|1102366-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Test-CPAN-Meta|0.07|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803040735
1101995|1101995-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040621
1101991|1101991-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Phrasebook-Loader-XML|0.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040621
1101982|1101982-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Phrasebook-Loader-Ini|0.10|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040620
1101980|1101980-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Phrasebook-Loader-DBI|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040619
1101644|1101644-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040403
1097744|1097744-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Calendar-List|0.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803030812
1096805|1096805-b19f-3f77-b713-d32bba55d77f|fail|200803|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.06|amd64-freebsd|5.10.0|freebsd|6.2-release|200803022339
1096804|1096804-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|amd64-freebsd|5.10.0|freebsd|6.2-release|200803022338
1094915|1094915-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-YAML-Meta|0.06|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803021532
1094631|1094631-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Test-CPAN-Meta|0.07|amd64-freebsd|5.5.5|freebsd|6.2-release|200803021330
1094028|1094028-b19f-3f77-b713-d32bba55d77f|fail|200803|srezic@cpan.org|Finance-Currency-Convert-XE|0.14|amd64-freebsd|5.10.0|freebsd|6.2-release|200803021036
1093970|1093970-b19f-3f77-b713-d32bba55d77f|na|200803|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.5.5|freebsd|6.2-release|200803021047
1093966|1093966-b19f-3f77-b713-d32bba55d77f|na|200803|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.5.5|freebsd|6.2-release|200803021047
1093955|1093955-b19f-3f77-b713-d32bba55d77f|fail|200803|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|amd64-freebsd|5.10.0|freebsd|6.2-release|200803021042
1093788|1093788-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|GD-Chart-Radial|0.07|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020107
1093039|1093039-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020033
1092912|1092912-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-UsePerl-Journal|0.21|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020033
1092640|1092640-b19f-3f77-b713-d32bba55d77f|fail|200803|srezic@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803012140
1092627|1092627-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803012141
1087103|1087103-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|WWW-UsePerl-Journal|0.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290201
1085735|1085735-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802290012
1078618|1078618-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Mail-File|0.08|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802270037
1078543|1078543-b19f-3f77-b713-d32bba55d77f|pass|200802|andy@hexten.net|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200802262231
1071497|1071497-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802242316
1071382|1071382-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802242315
1071374|1071374-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802242310
1069550|1069550-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Phrasebook-Loader-Ini|0.10|amd64-freebsd|5.10.0|freebsd|6.2-release|200802241210
1069518|1069518-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Phrasebook-Loader-XML|0.12|amd64-freebsd|5.10.0|freebsd|6.2-release|200802241212
1069500|1069500-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Phrasebook-Loader-DBI|0.11|amd64-freebsd|5.10.0|freebsd|6.2-release|200802241209
1067844|1067844-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Mail-File|0.08|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802232352
1066532|1066532-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Mail-File|0.08|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232012
1063920|1063920-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Games-Trackword|1.05|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802230117
1061868|1061868-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Data-FormValidator-Constraints-Words|0.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802220801
1061657|1061657-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802220814
1059812|1059812-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl ("DEVOGON")|Test-CPAN-Meta|0.07|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802220829
1048489|1048489-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|cygwin-thread-multi-64int|5.11.0 patch 33318|cygwin|1.5.24(0.15642)|200802181717
1044130|1044130-b19f-3f77-b713-d32bba55d77f|pass|200802|g.grigelionis@computer.org|Test-YAML-Meta|0.06|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200802162010
1042648|1042648-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802161642
1042270|1042270-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802160128
1042252|1042252-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802160007
1040897|1040897-b19f-3f77-b713-d32bba55d77f|pass|200802|root@kubuntu-1.americanstaffing.org ((root))|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200802141828
1038327|1038327-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200802140826
1037525|1037525-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.06|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802131955
1036225|1036225-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33286|openbsd|4.2|200802130252
1036065|1036065-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Test-YAML-Meta|0.06|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802130016
1034339|1034339-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200802120724
1034064|1034064-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802120054
1033759|1033759-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802112250
1032507|1032507-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802112313
1031843|1031843-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200802110927
1027757|1027757-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200802091929
1027756|1027756-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Data-Phrasebook|0.29|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200802091929
1026527|1026527-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.11.0 patch 33254|cygwin|1.5.24(0.15642)|200802091135
1026521|1026521-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.11.0 patch 33254|cygwin|1.5.24(0.15642)|200802091133
1021287|1021287-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200802061719
1021285|1021285-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200802061718
1020150|1020150-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger@ruhr-uni-bochum.de|Test-CPAN-Meta|0.07|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802061111
1019733|1019733-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.06|i686-linux|5.10.0|linux|2.6.22-3-486|200802060230
1019464|1019464-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.11.0 patch 33238|linux|2.6.22-3-amd64|200802052227
1019463|1019463-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.11.0 patch 33238|linux|2.6.22-3-amd64|200802052227
1019371|1019371-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|alpha-linux-thread-multi|5.11.0 patch 33230|linux|2.6.18-5-alpha-generic|200802052145
1018559|1018559-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-linux-thread-multi|5.11.0 patch 33230|linux|2.6.18-5-alpha-generic|200802051425
1018556|1018556-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-linux-thread-multi|5.11.0 patch 33230|linux|2.6.18-5-alpha-generic|200802051423
1017773|1017773-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802050535
1017772|1017772-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802050534
1017474|1017474-b19f-3f77-b713-d32bba55d77f|fail|200802|coding@etilem.net ("Et!L3W")|Finance-Currency-Convert-XE|0.14|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200802050203
1017367|1017367-b19f-3f77-b713-d32bba55d77f|fail|200802|vpit@cpan.org|CPAN-WWW-Testers-Generator|0.22|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200802041538
1016753|1016753-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|Test-YAML-Meta|0.06|x86_64-linux-thread-multi-ld|5.11.0 patch 33235|linux|2.6.22-3-amd64|200802041936
1016520|1016520-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int-ld|5.11.0 patch 33228|linux|2.6.16.38|200802041834
1016048|1016048-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802041325
1016044|1016044-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802041324
1015976|1015976-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.11.0 patch 33228|linux|2.6.16.38|200802041252
1015975|1015975-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.11.0 patch 33228|linux|2.6.16.38|200802041251
1015070|1015070-b19f-3f77-b713-d32bba55d77f|pass|200802|vpit@cpan.org|CPAN-WWW-Testers|0.33|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200802032030
1015051|1015051-b19f-3f77-b713-d32bba55d77f|pass|200802|vpit@cpan.org|Test-YAML-Meta|0.06|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200802040035
1012018|1012018-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802021817
1010962|1010962-b19f-3f77-b713-d32bba55d77f|pass|200802|vpit@cpan.org|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.9-5.elsmp|200802011907
1008057|1008057-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Test-YAML-Meta|0.06|amd64-freebsd|5.10.0|freebsd|6.2-release|200801312154
1005586|1005586-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Test-YAML-Meta|0.06|x86_64-linux-thread-multi-ld|5.11.0 patch 33109|linux|2.6.22-3-amd64|200801301932
1004659|1004659-b19f-3f77-b713-d32bba55d77f|pass|200801|ferreira@cpan.org|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200801301156
1003725|1003725-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.06|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801300511
1003677|1003677-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.06|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801300446
1003102|1003102-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Test-YAML-Meta|0.06|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801291658
1001542|1001542-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.06|i686-linux|5.10.0|linux|2.6.22-3-486|200801291416
1001492|1001492-b19f-3f77-b713-d32bba55d77f|pass|200801|stro@cpan.org|Data-FormValidator-Constraints-Words|0.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200801291239
1001452|1001452-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.06|i86pc-solaris|5.10.0|solaris|2.10|200801291243
1001428|1001428-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Test-YAML-Meta|0.06|i86pc-solaris|5.8.8|solaris|2.10|200801291229
997545|997545-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200801280051
997544|997544-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200801280051
995953|995953-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200801271422
995952|995952-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200801271421
994385|994385-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801270023
993408|993408-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200801260940
993407|993407-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200801260939
992656|992656-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200801252127
992655|992655-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200801252126
992487|992487-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200801251943
992486|992486-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200801251942
991572|991572-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200801251002
991571|991571-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200801251002
991043|991043-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200801242358
991042|991042-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200801242358
990732|990732-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-FormValidator-Constraints-Words|0.02|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200801242107
990695|990695-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801242058
990690|990690-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801242056
990489|990489-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200801250343
990486|990486-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-FormValidator-Constraints-Words|0.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200801250343
989782|989782-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200801241342
989781|989781-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200801241342
989622|989622-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200801241222
989621|989621-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200801241221
988520|988520-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Test-YAML-Meta|0.06|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801232058
987327|987327-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801231251
987326|987326-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801231251
986890|986890-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200801230531
986889|986889-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200801230531
986764|986764-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200801230723
986763|986763-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200801230723
986762|986762-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200801230723
986761|986761-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200801230722
986760|986760-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200801230722
986759|986759-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200801230722
986758|986758-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200801230721
986757|986757-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200801230721
986756|986756-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200801230721
986754|986754-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801230721
986753|986753-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200801230720
986752|986752-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200801230720
986750|986750-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200801230720
986749|986749-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200801230719
986748|986748-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200801230719
986747|986747-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200801230719
986745|986745-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200801230718
986744|986744-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200801230718
986743|986743-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200801230718
986742|986742-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801230718
986466|986466-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+perl@rub.de|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801230349
986460|986460-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+perl@rub.de|Data-Phrasebook|0.29|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801230348
986040|986040-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801222259
985176|985176-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.02|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200801221850
985147|985147-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.02|amd64-freebsd|5.6.2|freebsd|6.2-release|200801221924
985031|985031-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.02|amd64-freebsd|5.10.0|freebsd|6.2-release|200801221856
984791|984791-b19f-3f77-b713-d32bba55d77f|fail|200801|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.02|amd64-freebsd|5.5.5|freebsd|6.2-release|200801221739
984741|984741-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-FormValidator-Constraints-Words|0.02|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801221809
983974|983974-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-linux-thread-multi|5.11.0 patch 33022|linux|2.6.18-5-alpha-generic|200801221401
983959|983959-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-linux-thread-multi|5.11.0 patch 33022|linux|2.6.18-5-alpha-generic|200801221400
983425|983425-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.02|i686-linux|5.6.2|linux|2.4.27-3-686|200801221008
983422|983422-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.01|i686-linux|5.6.2|linux|2.4.27-3-686|200801221008
983364|983364-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.02|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801220947
983363|983363-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801220934
983362|983362-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.01|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801220947
983355|983355-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801220933
983352|983352-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.02|i686-linux|5.8.8|linux|2.4.27-3-686|200801220945
983348|983348-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.01|i686-linux|5.8.8|linux|2.4.27-3-686|200801220945
983122|983122-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801220856
983121|983121-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-FormValidator-Constraints-Words|0.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801220856
982451|982451-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200801220216
982419|982419-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200801220215
982228|982228-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.22-3-486|200801220121
982223|982223-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.22-3-486|200801220120
981992|981992-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl ("DEVOGON")|Data-FormValidator-Constraints-Words|0.02|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801220013
981497|981497-b19f-3f77-b713-d32bba55d77f|pass|200801|salvacpan@gmail.com|Data-FormValidator-Constraints-Words|0.02|sparc64-netbsd-thread-multi|5.10.0|netbsd|4.0|200801212136
981321|981321-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-FormValidator-Constraints-Words|0.02|x86_64-linux-thread-multi-ld|5.11.0 patch 33035|linux|2.6.22-3-amd64|200801211859
981128|981128-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-FormValidator-Constraints-Words|0.01|x86_64-linux-thread-multi-ld|5.11.0 patch 33035|linux|2.6.22-3-amd64|200801211858
980888|980888-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|GD-Chart-Radial|0.01|i686-linux|5.6.2|linux|2.4.27-3-686|200801211547
980526|980526-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-FormValidator-Constraints-Words|0.02|i686-linux|5.10.0|linux|2.6.22-3-486|200801211550
980291|980291-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.02|alpha-linux-thread-multi|5.11.0 patch 33022|linux|2.6.18-5-alpha-generic|200801211306
980289|980289-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|alpha-linux-thread-multi|5.11.0 patch 33022|linux|2.6.18-5-alpha-generic|200801211306
980096|980096-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+perl@rub.de|Data-FormValidator-Constraints-Words|0.02|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801211227
979801|979801-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-FormValidator-Constraints-Words|0.02|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801210912
978466|978466-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.11.0 patch 33018|linux|2.6.22-3-amd64|200801210039
978462|978462-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.11.0 patch 33018|linux|2.6.22-3-amd64|200801210038
978405|978405-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801210015
978403|978403-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801210015
978038|978038-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801202300
978035|978035-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook|0.29|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801202259
978018|978018-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801201656
978015|978015-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook|0.29|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801201656
978014|978014-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801202201
977999|977999-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801202159
977621|977621-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.02|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801202147
977613|977613-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.02|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801202146
977601|977601-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801202132
976910|976910-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200801201819
976908|976908-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|darwin-thread-multi|5.6.2|darwin|8.10.0|200801201819
976906|976906-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-FormValidator-Constraints-Words|0.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801201818
976018|976018-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.02|i86pc-solaris|5.10.0|solaris|2.10|200801201250
976014|976014-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.02|i86pc-solaris|5.8.8|solaris|2.10|200801201249
975957|975957-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.01|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801201212
975954|975954-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.01|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801201210
975910|975910-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.01|i86pc-solaris|5.10.0|solaris|2.10|200801201142
975909|975909-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-FormValidator-Constraints-Words|0.01|i86pc-solaris|5.8.8|solaris|2.10|200801201141
975908|975908-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-FormValidator-Constraints-Words|0.02|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200801201240
975906|975906-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-FormValidator-Constraints-Words|0.02|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200801201240
975905|975905-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-FormValidator-Constraints-Words|0.02|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200801201239
975904|975904-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-FormValidator-Constraints-Words|0.02|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200801201238
975903|975903-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-FormValidator-Constraints-Words|0.02|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200801201238
975902|975902-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-FormValidator-Constraints-Words|0.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200801201238
975895|975895-b19f-3f77-b713-d32bba55d77f|cpan|200801|BARBIE|Data-FormValidator-Constraints-Words|0.02||0|||200801201234
975877|975877-b19f-3f77-b713-d32bba55d77f|cpan|200801|BARBIE|Data-FormValidator-Constraints-Words|0.01||0|||200801201209
975466|975466-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801200654
975465|975465-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook|0.29|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801200654
975461|975461-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801200651
975460|975460-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook|0.29|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801200651
975294|975294-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801200446
975291|975291-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801200444
974469|974469-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris|5.10.0|solaris|2.10|200801192246
974468|974468-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook|0.29|i86pc-solaris|5.10.0|solaris|2.10|200801192246
974460|974460-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris|5.8.8|solaris|2.10|200801192245
974459|974459-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Phrasebook|0.29|i86pc-solaris|5.8.8|solaris|2.10|200801192244
974320|974320-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200801192304
974319|974319-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200801192304
969936|969936-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801182048
968579|968579-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl|CPAN-YACSmoke-Plugin-NNTP|0.05|i686-linux|5.10.0|linux|2.6.22-3-486|200801181419
968528|968528-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux|5.10.0|linux|2.6.22-3-486|200801181403
965436|965436-b19f-3f77-b713-d32bba55d77f|pass|200801|salvacpan@gmail.com|Test-CPAN-Meta|0.07|sparc64-netbsd-thread-multi|5.10.0|netbsd|4.0|200801171236
964694|964694-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Test-YAML-Meta|0.06|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801170819
961111|961111-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200801161223
960941|960941-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|alpha-linux-thread-multi|5.11.0 patch 32981|linux|2.6.18-5-alpha-generic|200801161114
958635|958635-b19f-3f77-b713-d32bba55d77f|fail|200801|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801152128
957943|957943-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200801151820
957139|957139-b19f-3f77-b713-d32bba55d77f|pass|200801|paul.reinerfelt@gmail.com|Test-YAML-Meta|0.06|i386-linux|5.8.8|linux|2.6.9-55.0.9.elsmp|200801151339
956843|956843-b19f-3f77-b713-d32bba55d77f|pass|200801|cpan@pqpq.de|Test-CPAN-Meta|0.07|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200801151507
955067|955067-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200801142346
954120|954120-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Test-CPAN-Meta|0.07|amd64-freebsd|5.6.2|freebsd|6.2-release|200801141926
953985|953985-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Test-CPAN-Meta|0.07|amd64-freebsd|5.10.0|freebsd|6.2-release|200801141904
953979|953979-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Test-CPAN-Meta|0.07|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200801141904
953303|953303-b19f-3f77-b713-d32bba55d77f|pass|200801|vpit@cpan.org|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.18.3-tmb-desktop-2mdvsmp|200801141501
952703|952703-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-CPAN-Meta|0.07|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200801141310
952452|952452-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801141144
952261|952261-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.11.0 patch 32971|netbsd|4.0|200801141027
950530|950530-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+perl@rub.de|Test-CPAN-Meta|0.07|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801131824
949699|949699-b19f-3f77-b713-d32bba55d77f|pass|200801|gam3-cpanp@gam3.net|WWW-Scraper-ISBN-Amazon_Driver|0.11|i486-linux-gnu|5.8.8|linux|2.6.22.10|200801121314
949698|949698-b19f-3f77-b713-d32bba55d77f|pass|200801|gam3-cpanp@gam3.net|WWW-Scraper-ISBN-ORA_Driver|0.08|i486-linux-gnu|5.8.8|linux|2.6.22.10|200801121335
949615|949615-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200801131118
949506|949506-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200801130959
949432|949432-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801131718
949320|949320-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Test-CPAN-Meta|0.07|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801130826
947010|947010-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Test-CPAN-Meta|0.07|x86_64-linux-thread-multi-ld|5.11.0 patch 32966|linux|2.6.22-3-amd64|200801121048
946903|946903-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200801120134
946355|946355-b19f-3f77-b713-d32bba55d77f|pass|200801|icerider70@gmail.com ("ICERIDER")|Test-CPAN-Meta|0.07|i386-linux|5.8.8|linux|2.6.18-53.el5|200801120058
945162|945162-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200801111839
945159|945159-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801111838
945093|945093-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Test-CPAN-Meta|0.07|x86_64-linux-thread-multi-ld|5.11.0 patch 32959|linux|2.6.22-3-amd64|200801111748
944909|944909-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|cygwin-thread-multi-64int|5.11.0 patch 32953|cygwin|1.5.24(0.15642)|200801111724
944840|944840-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Test-CPAN-Meta|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200801120106
944784|944784-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200801111757
944781|944781-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200801111756
944777|944777-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200801111755
944774|944774-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200801111755
944773|944773-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200801111754
944772|944772-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200801111754
944769|944769-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200801111754
944766|944766-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-CPAN-Meta|0.07|i686-linux|5.11.0|linux|2.6.22-1-k7|200801111753
943677|943677-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200801111004
943420|943420-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Test-CPAN-Meta|0.07|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801110815
943399|943399-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200801110633
943398|943398-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200801110633
943397|943397-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200801110633
943396|943396-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200801110632
943395|943395-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200801110632
943394|943394-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200801110631
943393|943393-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200801110631
943392|943392-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200801110630
943391|943391-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200801110630
943390|943390-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Test-CPAN-Meta|0.07|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801110630
943192|943192-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Test-CPAN-Meta|0.07|i86pc-solaris|5.10.0|solaris|2.10|200801110233
943189|943189-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Test-CPAN-Meta|0.07|i86pc-solaris|5.8.8|solaris|2.10|200801110232
941643|941643-b19f-3f77-b713-d32bba55d77f|cpan|200801|BARBIE|Test-CPAN-Meta|0.07||0|||200801101517
935918|935918-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801082044
935914|935914-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Phrasebook-Loader-XML|0.12|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801082042
935913|935913-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801082042
935911|935911-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Phrasebook|0.29|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801082041
935819|935819-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Calendar-List|0.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801081944
935816|935816-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Mail-File|0.08|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801081942
934542|934542-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|CPAN-YACSmoke-Plugin-WebList|0.05|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801081145
933317|933317-b19f-3f77-b713-d32bba55d77f|pass|200801|dhsanto@wildblue.net|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.8|darwin|9.0|200801071614
931600|931600-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072237
931597|931597-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072234
931593|931593-b19f-3f77-b713-d32bba55d77f|fail|200801|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072231
931590|931590-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Pearson_Driver|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072229
931581|931581-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-ORA_Driver|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072227
931572|931572-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072226
931565|931565-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Regexp-Log-Common|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072223
931561|931561-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Mail-File|0.08|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072222
931560|931560-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Games-Trackword|1.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072221
931558|931558-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.07|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072221
931556|931556-b19f-3f77-b713-d32bba55d77f|fail|200801|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.14|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072220
931553|931553-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072219
931551|931551-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072219
931550|931550-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.10|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072218
931549|931549-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072217
931545|931545-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072215
931544|931544-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Calendar-List|0.18|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072215
931542|931542-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-WebList|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072214
931537|931537-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-Outlook|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072212
931530|931530-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072211
931512|931512-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTP|0.05|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801072205
915218|915218-b19f-3f77-b713-d32bba55d77f|pass|200801|mmlange@cpan.org (Matthew Lange)|Test-YAML-Meta|0.06|x86_64-linux|5.8.8|linux|2.6.23-gentoo-r3|200801021300
914790|914790-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.18-5-686|200801021611
913276|913276-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl|Finance-Currency-Convert-XE|0.14|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801020137
909722|909722-b19f-3f77-b713-d32bba55d77f|pass|200801|gabor@pti.co.il ("Gabor Szabo")|Test-YAML-Meta|0.06|i686-linux|5.10.0|linux|2.6.22-14-generic|200801010715
906677|906677-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712311140
906670|906670-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712311137
906352|906352-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712310846
906346|906346-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712310845
903325|903325-b19f-3f77-b713-d32bba55d77f|fail|200712|janus@errornet.de (Simon Bertrang)|Finance-Currency-Convert-XE|0.13|i386-openbsd|5.8.8|openbsd|4.2|200712291832
898037|898037-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712271312
898036|898036-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712271313
897332|897332-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271043
894623|894623-b19f-3f77-b713-d32bba55d77f|pass|200712|rlane10@wi.rr.com|Test-YAML-Meta|0.06|darwin-2level|5.10.0|darwin|8.11.0|200712261626
892538|892538-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712260429
892537|892537-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712260428
890906|890906-b19f-3f77-b713-d32bba55d77f|pass|200712|cpan@pqpq.de|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712251613
890905|890905-b19f-3f77-b713-d32bba55d77f|pass|200712|cpan@pqpq.de|Data-Phrasebook|0.29|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712251613
889554|889554-b19f-3f77-b713-d32bba55d77f|pass|200712|salvacpan@gmail.com|Data-Phrasebook|0.29|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200712241427
889462|889462-b19f-3f77-b713-d32bba55d77f|pass|200712|salvacpan@gmail.com|Data-Phrasebook-Loader-YAML|0.09|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200712241428
888288|888288-b19f-3f77-b713-d32bba55d77f|pass|200712|amoore@cpan.org|Test-YAML-Meta|0.06|x86_64-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712231152
886993|886993-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712232014
886990|886990-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712232014
886941|886941-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.10.0|freebsd|6.2-release|200712232003
886940|886940-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.10.0|freebsd|6.2-release|200712232003
886320|886320-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712231543
886316|886316-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712231544
885914|885914-b19f-3f77-b713-d32bba55d77f|pass|200712|overlordq@gmail.com|CPAN-YACSmoke-Plugin-NNTP|0.05|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712230258
884307|884307-b19f-3f77-b713-d32bba55d77f|fail|200712|david@cantrell.org.uk|WWW-UsePerl-Journal|0.11|i386-freebsd|5.9.5|freebsd|6.2-release|200712222148
881097|881097-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220426
878647|878647-b19f-3f77-b713-d32bba55d77f|pass|200712|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|Test-YAML-Meta|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200712220249
877386|877386-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.11.0|linux|2.6.22-1-k7|200712210733
872388|872388-b19f-3f77-b713-d32bba55d77f|pass|200712|rafl@debian.org|Test-YAML-Meta|0.06|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200712191929
868643|868643-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Test-YAML-Meta|0.06|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200712190044
866879|866879-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Finance-Currency-Convert-XE|0.14|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181915
866862|866862-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Finance-Currency-Convert-XE|0.14|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181814
866743|866743-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181759
866734|866734-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Phrasebook|0.29|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181858
866256|866256-b19f-3f77-b713-d32bba55d77f|pass|200712|schwern@pobox.com|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200712180550
864145|864145-b19f-3f77-b713-d32bba55d77f|pass|200712|njh@bandsman.co.uk (Nigel Horne)|Test-YAML-Meta|0.06|mips-linux-gnu|5.8.8|linux|2.6.17-1-sb1-bcm91250a|200712172034
863772|863772-b19f-3f77-b713-d32bba55d77f|pass|200712|gam3-cpanp@gam3.net|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712171047
862607|862607-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170045
860413|860413-b19f-3f77-b713-d32bba55d77f|pass|200712|overlordq@gmail.com|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712160110
860024|860024-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712152359
860023|860023-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712152359
860015|860015-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712152353
860014|860014-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712152353
860006|860006-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200712152347
860005|860005-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200712152346
859996|859996-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200712152341
859994|859994-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200712152340
859984|859984-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200712152334
859983|859983-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200712152334
859973|859973-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712152328
859971|859971-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712152328
859962|859962-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712152322
859961|859961-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712152322
859944|859944-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712152316
859941|859941-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712152316
859929|859929-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi|5.6.2|darwin|8.10.0|200712152312
859911|859911-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712152306
859904|859904-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712152304
853688|853688-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712122043
853678|853678-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712122040
850359|850359-b19f-3f77-b713-d32bba55d77f|pass|200712|alexchorny@gmail.com|Test-YAML-Meta|0.06|i686-linux|5.10.0 patch 32604|linux|2.4.20-8smp|200712111132
849721|849721-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712111520
849720|849720-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712111519
848306|848306-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712102205
848304|848304-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712102204
845935|845935-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200712100300
845934|845934-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200712100259
844432|844432-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200712091511
844431|844431-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook|0.29|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200712091510
844344|844344-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200712091429
844343|844343-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200712091428
843851|843851-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200712090524
843850|843850-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook|0.29|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200712090524
842153|842153-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712080526
842150|842150-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712080525
840392|840392-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200712071629
840391|840391-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200712071629
839772|839772-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712071054
839771|839771-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712071053
839490|839490-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200712070927
839489|839489-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook|0.29|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200712070927
838191|838191-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd|5.9.5|freebsd|6.2-release|200712060710
838187|838187-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Phrasebook|0.29|i386-freebsd|5.9.5|freebsd|6.2-release|200712060709
836973|836973-b19f-3f77-b713-d32bba55d77f|pass|200712|notbenh@cpan.org|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712051508
836216|836216-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712050943
836212|836212-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712050942
834813|834813-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712051102
834812|834812-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712051102
834762|834762-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712051034
834759|834759-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712051033
834255|834255-b19f-3f77-b713-d32bba55d77f|pass|200712|icerider70@gmail.com ("ICERIDER")|Data-Phrasebook-Loader-YAML|0.09|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712050442
834253|834253-b19f-3f77-b713-d32bba55d77f|pass|200712|icerider70@gmail.com ("ICERIDER")|Data-Phrasebook|0.29|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712050442
834152|834152-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200712050330
834151|834151-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200712050330
834144|834144-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200712050325
834141|834141-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200712050324
834132|834132-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200712050320
834131|834131-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200712050320
834124|834124-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200712050316
834123|834123-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200712050315
834117|834117-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200712050314
834116|834116-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200712050313
834109|834109-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200712050312
834108|834108-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200712050312
834099|834099-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200712050310
834097|834097-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200712050310
834093|834093-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200712050309
833498|833498-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712042110
833377|833377-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712042110
833253|833253-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.6.2|freebsd|6.2-release|200712042123
833105|833105-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200712042011
833103|833103-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200712042013
833099|833099-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200712042015
833098|833098-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux|5.10.0|linux|2.6.22-1-k7|200712042009
833096|833096-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200712042013
833087|833087-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook-Loader-YAML|0.09|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712042036
833086|833086-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Phrasebook|0.29|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712042036
833084|833084-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.10.0|linux|2.6.22-1-k7|200712042010
833074|833074-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200712042020
833073|833073-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200712042017
833072|833072-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200712042016
833071|833071-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200712042018
833067|833067-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200712042016
833038|833038-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200712042023
833035|833035-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200712042021
833023|833023-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200712042014
833020|833020-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Phrasebook|0.29|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200712042011
826879|826879-b19f-3f77-b713-d32bba55d77f|pass|200712|schwern@pobox.com|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.8|darwin|8.8.1|200712020159
821695|821695-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302151
817626|817626-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i386-linux|5.8.5|linux|2.6.9-42.elsmp|200711291442
817293|817293-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i686-linux|5.8.6|linux|2.4.18|200711291205
816528|816528-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711290758
816249|816249-b19f-3f77-b713-d32bba55d77f|pass|200711|mmlange@cpan.org (Matthew Lange)|Test-YAML-Meta|0.06|i686-linux|5.8.8|linux|2.6.20-gentoo-r6|200711290246
815761|815761-b19f-3f77-b713-d32bba55d77f|pass|200711|d@0x64.nl|Test-YAML-Meta|0.06|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200711282200
813638|813638-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711280846
811417|811417-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|ppc-linux-thread-multi|5.10.0 patch 32376|linux|2.6.20-16-powerpc|200711271410
805275|805275-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i386-freebsd-thread-multi|5.10.0 patch 32487|freebsd|6.2-release|200711252230
802286|802286-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0 patch 32478|linux|2.6.18-5-686|200711241929
793369|793369-b19f-3f77-b713-d32bba55d77f|pass|200711|mmlange@cpan.org (Matthew Lange)|Test-YAML-Meta|0.06|i686-linux|5.8.8|linux|2.6.12-gentoo-r6|200711211123
784808|784808-b19f-3f77-b713-d32bba55d77f|pass|200711|frank.wiegand@gmail.com ("Frank Wiegand")|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200711191145
782686|782686-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Test-YAML-Meta|0.06|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200711181919
777094|777094-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Finance-Currency-Convert-XE|0.14|darwin-thread-multi-2level|5.10.0 patch 32245|darwin|9.0.0|200711170446
776710|776710-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i686-linux-thread-multi|5.10.0 patch 32330|linux|2.6.22-14-generic|200711170143
776081|776081-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711161641
774738|774738-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|powerpc-linux-gnu|5.8.8|linux|2.6.17-10-powerpc64-smp|200711161403
774323|774323-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Regexp-Log-Common|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711161149
771565|771565-b19f-3f77-b713-d32bba55d77f|pass|200711|frank.wiegand@gmail.com ("Frank Wiegand")|Data-Phrasebook|0.29|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711151352
771488|771488-b19f-3f77-b713-d32bba55d77f|pass|200711|david@landgren.net|Test-YAML-Meta|0.06|i386-freebsd-64int|5.8.8|freebsd|6.0-stable|200711151304
770600|770600-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711150549
770431|770431-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711150426
769044|769044-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711141937
769008|769008-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711141929
768992|768992-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711141922
765285|765285-b19f-3f77-b713-d32bba55d77f|pass|200711|claco@chrislaco.com ("Christopher H. Laco")|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.6|darwin|8.0|200711130140
765085|765085-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130841
765081|765081-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130838
765078|765078-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130835
765073|765073-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130832
765068|765068-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130828
765065|765065-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130823
765063|765063-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711130820
764485|764485-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130150
764481|764481-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130147
764479|764479-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130144
764475|764475-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130141
764472|764472-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130138
764468|764468-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130136
764465|764465-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130133
763496|763496-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711122102
763290|763290-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|sun4-solaris|5.9.5|solaris|2.9|200711121405
763274|763274-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711121153
763273|763273-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711122001
763269|763269-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|WWW-UsePerl-Journal|0.21|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711121152
763261|763261-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|Test-YAML-Meta|0.06|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711121151
763151|763151-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|sun4-solaris|5.9.5|solaris|2.9|200711121332
763065|763065-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|WWW-UsePerl-Journal|0.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711122018
762544|762544-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|Test-YAML-Meta|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711121522
762543|762543-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|Test-YAML-Meta|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711121522
761749|761749-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121159
761721|761721-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121153
761702|761702-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121148
761658|761658-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711121137
761638|761638-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711121133
761615|761615-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711121128
761600|761600-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711121124
761593|761593-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711121121
761530|761530-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711121059
761515|761515-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711121055
761499|761499-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711121051
761462|761462-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711121047
761149|761149-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711120950
761130|761130-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711120947
761121|761121-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711120943
761114|761114-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711120940
761099|761099-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711120937
761095|761095-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711120933
761091|761091-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711120931
761085|761085-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711120927
761068|761068-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711120924
760961|760961-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120855
760957|760957-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120852
760954|760954-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120849
760951|760951-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120846
760943|760943-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120843
760935|760935-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120840
760930|760930-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120837
759717|759717-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711120051
759486|759486-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.10|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711112356
759483|759483-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.21|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711112355
758236|758236-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111208
758229|758229-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111204
758225|758225-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111201
758221|758221-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111157
758217|758217-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111154
758215|758215-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111151
758213|758213-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111147
757297|757297-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711110109
757295|757295-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711110106
757293|757293-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711110103
757290|757290-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711110100
757288|757288-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711110057
757286|757286-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711110054
757285|757285-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711110051
757280|757280-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711110048
757277|757277-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711110045
757125|757125-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.9.5|linux|2.4.27-3-686|200711102304
757020|757020-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711102222
757014|757014-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711102218
757004|757004-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711102214
757001|757001-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.8.8|linux|2.4.27-3-686|200711102212
756990|756990-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711102210
756977|756977-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711102206
756968|756968-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711102201
756967|756967-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711102157
756959|756959-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711102152
756929|756929-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-thread-multi|5.6.2|darwin|8.10.0|200711102139
756869|756869-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711102106
756856|756856-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711102103
756850|756850-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711102059
756844|756844-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711102056
756837|756837-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711102053
756833|756833-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711102050
756829|756829-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711102045
756820|756820-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711102041
756812|756812-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|darwin-thread-multi|5.6.2|darwin|8.10.0|200711102038
756804|756804-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711102035
756794|756794-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711102033
756764|756764-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711102002
756756|756756-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711101959
756747|756747-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711101956
756742|756742-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711101952
756738|756738-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711101949
756736|756736-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711101946
756734|756734-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|darwin-thread-multi|5.6.2|darwin|8.10.0|200711101943
756686|756686-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|i686-linux|5.9.5|linux|2.4.27-3-686|200711101837
756629|756629-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Test-YAML-Meta|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711101757
755963|755963-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|i686-linux|5.8.8|linux|2.4.27-3-686|200711101300
755923|755923-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|i686-linux|5.6.2|linux|2.4.27-3-686|200711101251
755922|755922-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|i386-freebsd|5.9.5|freebsd|6.2-release|200711101208
755601|755601-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|i386-freebsd|5.9.5|freebsd|6.2-release|200711100943
755591|755591-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.10|darwin-2level|5.9.5|darwin|8.10.1|200711101021
755569|755569-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|darwin-2level|5.9.5|darwin|8.10.1|200711101015
755492|755492-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.21|i686-linux|5.6.2|linux|2.4.27-3-686|200711100950
755391|755391-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100854
755389|755389-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100849
755382|755382-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100844
755378|755378-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100840
755374|755374-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100835
755369|755369-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100831
755364|755364-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711100826
755227|755227-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711101442
755175|755175-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.21|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711101428
754490|754490-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@0x64.nl|WWW-UsePerl-Journal|0.21|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200711092006
754451|754451-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.10|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711092233
754377|754377-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711092157
754220|754220-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711092053
753474|753474-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal-Thread|0.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090838
753432|753432-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090825
753416|753416-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|GD-Chart-Radial|0.07|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711091459
753391|753391-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal-Thread|0.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090802
753370|753370-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal|0.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090755
753270|753270-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|GD-Chart-Radial|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711091459
752924|752924-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711090942
752920|752920-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|sun4-solaris|5.9.5|solaris|2.9|200711090341
752750|752750-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090139
752656|752656-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal|0.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090047
751953|751953-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|amd64-freebsd|5.6.2|freebsd|6.2-release|200711082103
751876|751876-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.21|amd64-freebsd|5.6.2|freebsd|6.2-release|200711082102
751808|751808-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081941
751807|751807-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.21|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081941
751795|751795-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081937
751792|751792-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081934
751790|751790-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|WWW-UsePerl-Journal|0.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711082024
751784|751784-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081930
751781|751781-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081927
751775|751775-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711081925
751711|751711-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|i386-netbsd-thread-multi-64int|5.10.0 patch 32243|netbsd|3.1|200711081907
751693|751693-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.10.0 patch 32243|netbsd|3.1|200711081856
751661|751661-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|i686-linux|5.6.2|linux|2.4.27-3-686|200711081800
751645|751645-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.10.0 patch 32243|netbsd|3.1|200711081843
751613|751613-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.10.0 patch 32243|netbsd|3.1|200711081836
751601|751601-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.10.0 patch 32243|netbsd|3.1|200711081832
751593|751593-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.10.0 patch 32243|netbsd|3.1|200711081829
751559|751559-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.21|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711081918
751508|751508-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.10|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711081858
751499|751499-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|i386-freebsd|5.9.5|freebsd|6.2-release|200711081726
751477|751477-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.21|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711081857
751428|751428-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.20|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711081847
751345|751345-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|i686-linux|5.9.5|linux|2.4.27-3-686|200711081731
751318|751318-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|darwin-2level|5.9.5|darwin|8.10.1|200711081727
751301|751301-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.20|i686-linux|5.8.8|linux|2.4.27-3-686|200711081724
751225|751225-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.10.0 patch 32245|darwin|9.0.0|200711081708
751121|751121-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711081727
751118|751118-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711081726
751115|751115-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711081724
751109|751109-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711081723
751101|751101-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711081721
751092|751092-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711081719
751084|751084-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711081717
751074|751074-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.10|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711081715
751070|751070-b19f-3f77-b713-d32bba55d77f|pass|200711|bob@randomness.org.uk ("bob walker")|WWW-UsePerl-Journal|0.20|i86pc-solaris|5.8.8|solaris|2.10|200711081608
751069|751069-b19f-3f77-b713-d32bba55d77f|pass|200711|bob@randomness.org.uk ("bob walker")|WWW-UsePerl-Journal-Thread|0.10|i86pc-solaris|5.8.8|solaris|2.10|200711081608
750964|750964-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|WWW-UsePerl-Journal-Thread|0.10||0|||200711081630
750777|750777-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711081445
750775|750775-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711081442
750774|750774-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711081438
750773|750773-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711081435
750770|750770-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711081432
750765|750765-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711081428
750756|750756-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711081425
750749|750749-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.21|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711081421
750738|750738-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|WWW-UsePerl-Journal|0.21||0|||200711081417
750603|750603-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200711081220
750380|750380-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711080922
750176|750176-b19f-3f77-b713-d32bba55d77f|pass|200711|schwern@pobox.com|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.8|darwin|8.8.1|200711080014
750140|750140-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.20|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711080803
749730|749730-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711080331
749575|749575-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072327
749565|749565-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.20|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072321
749561|749561-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072317
749557|749557-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072313
749551|749551-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072309
749549|749549-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072304
749546|749546-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711072303
749363|749363-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.20|amd64-freebsd|5.6.2|freebsd|6.2-release|200711072225
749060|749060-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711072010
749050|749050-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.20|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711072105
749026|749026-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|darwin-2level|5.8.8|darwin|8.10.1|200711072001
748984|748984-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.20|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711072010
748780|748780-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal-Thread|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711080246
748777|748777-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.20|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711080246
748642|748642-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.19|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711080212
748391|748391-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.06|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711071644
748318|748318-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.09|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711071523
748207|748207-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.06|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711071426
748005|748005-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711071408
747987|747987-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711071404
747979|747979-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711071400
747974|747974-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711071356
747968|747968-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711071352
747966|747966-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711071348
747961|747961-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711071345
747947|747947-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.20|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711071341
747909|747909-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|WWW-UsePerl-Journal|0.20||0|||200711071326
747811|747811-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.06|i686-linux|5.8.8|linux|2.4.27-3-686|200711071203
747810|747810-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.06|i686-linux|5.9.5|linux|2.4.27-3-686|200711071202
747807|747807-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.06|sun4-solaris|5.9.5|solaris|2.9|200711070602
747803|747803-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.06|darwin-2level|5.9.5|darwin|8.10.1|200711071201
747648|747648-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711071120
747644|747644-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711071116
747641|747641-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711071113
747635|747635-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711071109
747616|747616-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711071105
747590|747590-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711071058
747551|747551-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711071033
747543|747543-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711071029
747534|747534-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-thread-multi|5.6.2|darwin|8.10.0|200711071026
747532|747532-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711071022
747529|747529-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711071018
747524|747524-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711071015
747522|747522-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711071012
747518|747518-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711071009
747514|747514-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711071006
747509|747509-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711071003
747501|747501-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711071001
747488|747488-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|darwin-thread-multi|5.6.2|darwin|8.10.0|200711070958
747486|747486-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070955
747485|747485-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070951
747482|747482-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070949
747477|747477-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070946
747454|747454-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070942
747434|747434-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070939
747419|747419-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070936
747410|747410-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070932
747405|747405-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|darwin-thread-multi|5.6.2|darwin|8.10.0|200711070929
747402|747402-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070926
747397|747397-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070923
747395|747395-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.09|sun4-solaris|5.9.5|solaris|2.9|200711070321
747392|747392-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070920
747387|747387-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070917
747379|747379-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070914
747376|747376-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070911
747374|747374-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070908
747369|747369-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070905
747365|747365-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|darwin-thread-multi|5.6.2|darwin|8.10.0|200711070903
747363|747363-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070900
747360|747360-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070858
747358|747358-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070857
747356|747356-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070855
747352|747352-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070854
747348|747348-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070852
747345|747345-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070851
747339|747339-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070849
747335|747335-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070848
747323|747323-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070846
747317|747317-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070845
747314|747314-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200711070844
747312|747312-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070843
747310|747310-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200711070843
747307|747307-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070841
747301|747301-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070840
747293|747293-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070838
747288|747288-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070837
747283|747283-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070834
747281|747281-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070833
747280|747280-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070832
747277|747277-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070831
747276|747276-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070829
747275|747275-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070828
747274|747274-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070827
747272|747272-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070826
747270|747270-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|darwin-thread-multi|5.6.2|darwin|8.10.0|200711070825
747267|747267-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070824
747265|747265-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070823
747263|747263-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070822
747262|747262-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070820
747261|747261-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070819
747259|747259-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070818
747258|747258-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070817
747254|747254-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070816
747252|747252-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|darwin-thread-multi|5.6.2|darwin|8.10.0|200711070815
747250|747250-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711070814
747247|747247-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711070812
747244|747244-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711070811
747238|747238-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711070810
747235|747235-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711070809
747230|747230-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711070808
747229|747229-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711070807
747228|747228-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711070806
747225|747225-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|darwin-thread-multi|5.6.2|darwin|8.10.0|200711070805
747052|747052-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal-Thread|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711070053
747049|747049-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711070050
747044|747044-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|Test-YAML-Meta|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711070049
747011|747011-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711070025
746466|746466-b19f-3f77-b713-d32bba55d77f|pass|200711|g.grigelionis@computer.org|Test-YAML-Meta|0.06|i586-linux-thread-multi|5.8.8|linux|2.6.16|200711062216
746192|746192-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711062326
746124|746124-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711062253
746121|746121-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|sun4-solaris|5.9.5|solaris|2.9|200711061652
746107|746107-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711062248
746099|746099-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711062244
746088|746088-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711062240
746069|746069-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711062234
746067|746067-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711062233
745898|745898-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.09|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711062223
745885|745885-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.09|i686-linux|5.9.5|linux|2.4.27-3-686|200711062125
745867|745867-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Test-YAML-Meta|0.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711062140
745846|745846-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Test-YAML-Meta|0.06|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711062210
745837|745837-b19f-3f77-b713-d32bba55d77f|fail|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.09|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711062117
745829|745829-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.19|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711062116
745815|745815-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.09|amd64-freebsd|5.6.2|freebsd|6.2-release|200711062132
745808|745808-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711062113
745802|745802-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.09|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711062142
745722|745722-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|i386-freebsd|5.9.5|freebsd|6.2-release|200711062034
745704|745704-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|i686-linux|5.9.5|linux|2.4.27-3-686|200711062054
745702|745702-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|i686-linux|5.8.8|linux|2.4.27-3-686|200711062021
745669|745669-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200711062047
745634|745634-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.09|darwin-2level|5.9.5|darwin|8.10.1|200711062041
745535|745535-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|darwin-2level|5.9.5|darwin|8.10.1|200711062001
745348|745348-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal-Thread|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711061919
745341|745341-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.19|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711061909
745333|745333-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Test-YAML-Meta|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711061905
745265|745265-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.18|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711070130
745227|745227-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.05|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711061716
745048|745048-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711061551
745046|745046-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711061547
745040|745040-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711061543
745033|745033-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@0x64.nl|WWW-UsePerl-Journal|0.19|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200711061615
745028|745028-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711061539
745018|745018-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711061535
745009|745009-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711061531
745003|745003-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711061526
744999|744999-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711061523
744996|744996-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711061518
744993|744993-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711061515
744991|744991-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711061511
744981|744981-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711061507
744961|744961-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711061503
744953|744953-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711061459
744940|744940-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711061456
744929|744929-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711061452
744920|744920-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711061449
744911|744911-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711061445
744908|744908-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711061441
744907|744907-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711061440
744906|744906-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711061439
744904|744904-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711061439
744903|744903-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711061438
744902|744902-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711061437
744901|744901-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711061436
744900|744900-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711061435
744892|744892-b19f-3f77-b713-d32bba55d77f|pass|200711|g.grigelionis@computer.org|Test-YAML-Meta|0.06|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200711061458
744785|744785-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.09|i686-linux|5.6.2|linux|2.4.27-3-686|200711061357
744598|744598-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.19|i686-linux|5.6.2|linux|2.4.27-3-686|200711061154
744545|744545-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Test-YAML-Meta|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711061134
744447|744447-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|Test-YAML-Meta|0.06|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711061133
744446|744446-b19f-3f77-b713-d32bba55d77f|fail|200711|cpan@pqpq.de|WWW-UsePerl-Journal|0.19|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711061133
744440|744440-b19f-3f77-b713-d32bba55d77f|na|200711|cpan@pqpq.de|WWW-UsePerl-Journal-Thread|0.09|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711061131
744182|744182-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal-Thread|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711060843
744144|744144-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.19|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711060839
744120|744120-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.06|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711060834
743666|743666-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711060322
743652|743652-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal-Thread|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711060311
743651|743651-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal|0.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711060310
743650|743650-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Test-YAML-Meta|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711060308
743542|743542-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711060145
743541|743541-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711060144
743540|743540-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711060143
743539|743539-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711060143
743537|743537-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711060142
743535|743535-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711060141
743534|743534-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.06|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711060141
743533|743533-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711060140
743532|743532-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711060139
743531|743531-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711060138
743529|743529-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711060137
743526|743526-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711060137
743522|743522-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711060136
743520|743520-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711060135
743518|743518-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal-Thread|0.09|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711060134
743501|743501-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|Test-YAML-Meta|0.06||0|||200711060111
743483|743483-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|WWW-UsePerl-Journal-Thread|0.09||0|||200711060044
743313|743313-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.18|amd64-freebsd|5.6.2|freebsd|6.2-release|200711052306
743128|743128-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.19|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711052133
743047|743047-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.19|amd64-freebsd|5.6.2|freebsd|6.2-release|200711052206
742884|742884-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711052110
742883|742883-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711052100
742879|742879-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711052105
742868|742868-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.19|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711052100
742861|742861-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711052036
742858|742858-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711052031
742856|742856-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711052042
742851|742851-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711052053
742845|742845-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.19|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711052048
742723|742723-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.05|darwin-2level|5.9.5|darwin|9.0.0|200711051847
742637|742637-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|WWW-UsePerl-Journal|0.19||0|||200711051913
742615|742615-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Test-YAML-Meta|0.05|darwin-2level|5.8.8|darwin|8.10.1|200711051756
742603|742603-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|GD-Chart-Radial|0.07|darwin-2level|5.8.8|darwin|8.10.1|200711051749
742570|742570-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|i686-linux|5.6.2|linux|2.4.27-3-686|200711051529
742482|742482-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|i686-linux|5.8.8|linux|2.4.27-3-686|200711051529
742418|742418-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|i386-freebsd|5.9.5|freebsd|6.2-release|200711051536
742404|742404-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|darwin-2level|5.9.5|darwin|8.10.1|200711051542
742400|742400-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|sun4-solaris|5.9.5|solaris|2.9|200711050953
742399|742399-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|i686-linux|5.9.5|linux|2.4.27-3-686|200711051533
742394|742394-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.18|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711051544
742199|742199-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711051437
742192|742192-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711051433
742190|742190-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711051428
742178|742178-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711051422
742163|742163-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711051418
741861|741861-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200711051137
741779|741779-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711051016
741773|741773-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711051011
741771|741771-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711051008
741709|741709-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.18|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711050859
741641|741641-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|Finance-Currency-Convert-XE|0.14|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050923
741640|741640-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|GD-Chart-Radial|0.05|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050923
741639|741639-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|GD-Chart-Radial|0.06|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050923
741638|741638-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|GD-Chart-Radial|0.07|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050922
741637|741637-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050922
741636|741636-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|WWW-UsePerl-Journal|0.17|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050921
741629|741629-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|WWW-UsePerl-Journal|0.18|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050919
741466|741466-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|Test-YAML-Meta|0.05|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050835
741323|741323-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711050532
741318|741318-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711050529
741317|741317-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711050526
741316|741316-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711050522
741315|741315-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711050521
741313|741313-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711050517
741311|741311-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711050514
741265|741265-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711050444
741261|741261-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-Scraper-ISBN-Amazon_Driver|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711050442
741255|741255-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Test-YAML-Meta|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711050440
741250|741250-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711050438
741246|741246-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Finance-Currency-Convert-XE|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711050437
741216|741216-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.18|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711050426
740877|740877-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|WWW-UsePerl-Journal|0.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711050248
740815|740815-b19f-3f77-b713-d32bba55d77f|pass|200711|claco@chrislaco.com ("Christopher H. Laco")|Test-YAML-Meta|0.05|darwin-thread-multi-2level|5.8.6|darwin|8.0|200711041523
740501|740501-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711042315
740500|740500-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711042312
740497|740497-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711042307
740494|740494-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711042305
740394|740394-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711042301
740386|740386-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711042254
740384|740384-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711042250
740371|740371-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711042246
740367|740367-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711042243
740355|740355-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711042239
740351|740351-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.18|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711042235
740346|740346-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|WWW-UsePerl-Journal|0.18||0|||200711042232
740065|740065-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.05|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711041913
739557|739557-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711041241
739390|739390-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.07|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711041126
739332|739332-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041115
739326|739326-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041105
739319|739319-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041101
739318|739318-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041059
738284|738284-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030940
738269|738269-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030937
738257|738257-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030934
738253|738253-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030933
738248|738248-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030933
738244|738244-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030932
738240|738240-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711030931
737807|737807-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Test-YAML-Meta|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711031806
737806|737806-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|GD-Chart-Radial|0.07|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711031805
737802|737802-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.05|sun4-solaris|5.9.5|solaris|2.9|200711031305
737646|737646-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711040058
737585|737585-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.05|i686-linux|5.9.5|linux|2.4.27-3-686|200711031637
737577|737577-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.05|i386-freebsd|5.9.5|freebsd|6.2-release|200711031623
737559|737559-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.05|i686-linux|5.8.8|linux|2.4.27-3-686|200711031630
737493|737493-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|Finance-Currency-Convert-XE|0.14|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030301
737485|737485-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|Test-YAML-Meta|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711031110
737454|737454-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.07|sun4-solaris|5.9.5|solaris|2.9|200711031053
737450|737450-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.07|i686-linux|5.6.2|linux|2.4.27-3-686|200711031550
737438|737438-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.07|i686-linux|5.8.8|linux|2.4.27-3-686|200711031541
737360|737360-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.07|i686-linux|5.9.5|linux|2.4.27-3-686|200711031511
737325|737325-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Test-YAML-Meta|0.05|darwin-2level|5.9.5|darwin|8.10.1|200711031507
736982|736982-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711031325
736980|736980-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711031326
736976|736976-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711031322
736972|736972-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711031325
736947|736947-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711031324
736944|736944-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711031323
736941|736941-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711031321
736937|736937-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711031320
736933|736933-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711031320
736931|736931-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711031319
736929|736929-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711031319
736927|736927-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711031318
736926|736926-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711031317
736925|736925-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711031317
736924|736924-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711031316
736920|736920-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711031315
736919|736919-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711031315
736833|736833-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030302
736813|736813-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|Test-YAML-Meta|0.05|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030301
736789|736789-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711030729
736755|736755-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|Test-YAML-Meta|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711030714
736704|736704-b19f-3f77-b713-d32bba55d77f|fail|200711|alexchorny@gmail.com|WWW-UsePerl-Journal|0.17|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030303
736701|736701-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|GD-Chart-Radial|0.07|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030301
736634|736634-b19f-3f77-b713-d32bba55d77f|pass|200711|g.grigelionis@computer.org|Test-YAML-Meta|0.05|i586-linux-thread-multi|5.8.8|linux|2.6.16|200711030822
736630|736630-b19f-3f77-b713-d32bba55d77f|pass|200711|g.grigelionis@computer.org|Test-YAML-Meta|0.05|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200711030836
736301|736301-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030932
736289|736289-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030930
736281|736281-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030926
736280|736280-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.07|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030926
736279|736279-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030926
736277|736277-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030926
736276|736276-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030923
736088|736088-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030556
735751|735751-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@0x64.nl|Finance-Currency-Convert-XE|0.14|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200711022235
735456|735456-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Test-YAML-Meta|0.05|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711022119
735359|735359-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|CPAN-YACSmoke-Plugin-NNTP|0.05|darwin-2level|5.8.8|darwin|8.10.1|200711022212
735266|735266-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|GD-Chart-Radial|0.07|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711022119
735203|735203-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|GD-Chart-Radial|0.07|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711022142
735183|735183-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|GD-Chart-Radial|0.07|amd64-freebsd|5.6.2|freebsd|6.2-release|200711022216
734911|734911-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Test-YAML-Meta|0.05|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711022142
734838|734838-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711022024
734830|734830-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711022014
734828|734828-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711022013
734597|734597-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|GD-Chart-Radial|0.06|darwin-2level|5.8.8|darwin|8.10.1|200711021834
734546|734546-b19f-3f77-b713-d32bba55d77f|pass|200711|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|GD-Chart-Radial|0.07|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200711030322
734352|734352-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711021632
734238|734238-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711022357
733806|733806-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.05|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711021214
733804|733804-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.05|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711021214
733802|733802-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.05|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711021214
733801|733801-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.05|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711021213
733799|733799-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|Test-YAML-Meta|0.05||0|||200711021212
733778|733778-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.07|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711021149
733776|733776-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.07|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711021149
733770|733770-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.07|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711021149
733768|733768-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.07|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711021149
733761|733761-b19f-3f77-b713-d32bba55d77f|cpan|200711|BARBIE|GD-Chart-Radial|0.07||0|||200711021147
733729|733729-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711021010
733728|733728-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711021009
733633|733633-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.06|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711020854
733596|733596-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711020935
733299|733299-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|WWW-UsePerl-Journal|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711020426
732187|732187-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|GD-Chart-Radial|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711011945
732032|732032-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.17|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711011948
731962|731962-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711011904
731906|731906-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.17|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711020229
731902|731902-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.05|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711020227
731726|731726-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711011716
731610|731610-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.05|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711011653
731511|731511-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|i386-freebsd|5.9.5|freebsd|6.2-release|200711011611
731502|731502-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|GD-Chart-Radial|0.05|i686-linux|5.6.2|linux|2.4.27-3-686|200711011553
731477|731477-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|GD-Chart-Radial|0.06|i686-linux|5.6.2|linux|2.4.27-3-686|200711011607
731449|731449-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.06|i686-linux|5.9.5|linux|2.4.27-3-686|200711011531
731443|731443-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|i686-linux|5.6.2|linux|2.4.27-3-686|200711011556
731374|731374-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.06|sun4-solaris|5.9.5|solaris|2.9|200711011030
731357|731357-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|i686-linux|5.9.5|linux|2.4.27-3-686|200711011523
731346|731346-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.05|i686-linux|5.9.5|linux|2.4.27-3-686|200711011515
731345|731345-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.05|i686-linux|5.8.8|linux|2.4.27-3-686|200711011400
731331|731331-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|sun4-solaris|5.9.5|solaris|2.9|200711011011
731267|731267-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711011451
731261|731261-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711011450
731260|731260-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711011450
731258|731258-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711011449
731257|731257-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711011448
731256|731256-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711011447
731255|731255-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711011447
731254|731254-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711011446
731253|731253-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.06|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711011445
731183|731183-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.06|i686-linux|5.8.8|linux|2.4.27-3-686|200711011405
731172|731172-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|i686-linux|5.8.8|linux|2.4.27-3-686|200711011402
731171|731171-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|GD-Chart-Radial|0.05|sun4-solaris|5.9.5|solaris|2.9|200711010902
731066|731066-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|WWW-UsePerl-Journal|0.17|darwin-2level|5.9.5|darwin|8.10.1|200711011308
731035|731035-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011259
731017|731017-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011254
730999|730999-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|GD-Chart-Radial|0.05|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010750
730984|730984-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|WWW-UsePerl-Journal|0.17|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010747
730983|730983-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011246
730551|730551-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.17|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711010228
730549|730549-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.17|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711010232
730546|730546-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-UsePerl-Journal|0.17|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711010230
730248|730248-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711010843
730238|730238-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711010840
730229|730229-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711010837
730226|730226-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711010834
730225|730225-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711010831
730224|730224-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711010829
730223|730223-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711010826
730222|730222-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711010823
730221|730221-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.17|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711010820
730220|730220-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711010818
730219|730219-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711010817
730218|730218-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711010816
730217|730217-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711010816
730216|730216-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711010815
730215|730215-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711010815
730214|730214-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711010814
730213|730213-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711010813
730212|730212-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|GD-Chart-Radial|0.05|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711010813
730138|730138-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711010529
729683|729683-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|WWW-Scraper-ISBN-Amazon_Driver|0.11|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010445
729644|729644-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|Finance-Currency-Convert-XE|0.14|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010433
729547|729547-b19f-3f77-b713-d32bba55d77f|pass|200711|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|GD-Chart-Radial|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200711011305
729376|729376-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.17|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711010106
729291|729291-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.06|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711010250
729290|729290-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.06|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711010249
729288|729288-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|GD-Chart-Radial|0.06|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711010250
728950|728950-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|GD-Chart-Radial|0.06|amd64-freebsd|5.6.2|freebsd|6.2-release|200711010130
728937|728937-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.17|amd64-freebsd|5.6.2|freebsd|6.2-release|200711010134
728837|728837-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|GD-Chart-Radial|0.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711010104
728800|728800-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|GD-Chart-Radial|0.06|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711010013
728751|728751-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|WWW-UsePerl-Journal|0.17|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711010017
728472|728472-b19f-3f77-b713-d32bba55d77f|pass|200710|alexchorny@gmail.com|Test-YAML-Meta|0.04|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710311058
728294|728294-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710311924
728287|728287-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710311919
728240|728240-b19f-3f77-b713-d32bba55d77f|cpan|200710|BARBIE|GD-Chart-Radial|0.06||0|||200710311918
728110|728110-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.14|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010035
728076|728076-b19f-3f77-b713-d32bba55d77f|cpan|200710|BARBIE|WWW-UsePerl-Journal|0.17||0|||200710311654
728036|728036-b19f-3f77-b713-d32bba55d77f|cpan|200710|BARBIE|GD-Chart-Radial|0.05||0|||200710311617
727661|727661-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710310837
727660|727660-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710310831
727646|727646-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Test-YAML-Meta|0.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310328
727507|727507-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Finance-Currency-Convert-XE|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310042
727334|727334-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Finance-Currency-Convert-XE|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310334
726878|726878-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710302152
726714|726714-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Test-YAML-Meta|0.04|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200710302032
726122|726122-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710310039
725832|725832-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|i386-freebsd|5.9.5|freebsd|6.2-release|200710301025
725738|725738-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|sun4-solaris|5.9.5|solaris|2.9|200710300810
725691|725691-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710301259
725686|725686-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200710301052
725608|725608-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|sun4-solaris|5.9.5|solaris|2.9|200710300736
725539|725539-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710301223
725536|725536-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i386-freebsd|5.9.5|freebsd|6.2-release|200710301003
725445|725445-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|i686-linux|5.9.5|linux|2.4.27-3-686|200710301123
725434|725434-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|darwin-2level|5.9.5|darwin|8.10.1|200710301118
725429|725429-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.14|i686-linux|5.8.8|linux|2.4.27-3-686|200710301118
725428|725428-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|darwin-2level|5.9.5|darwin|8.10.1|200710301052
725416|725416-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux|5.9.5|linux|2.4.27-3-686|200710301104
725165|725165-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.11|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710300815
725163|725163-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.14|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710300814
724735|724735-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710300118
724732|724732-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710300117
724729|724729-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710300115
724728|724728-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.14|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710300113
724599|724599-b19f-3f77-b713-d32bba55d77f|na|200710|srezic@cpan.org|Finance-Currency-Convert-XE|0.14|amd64-freebsd|5.5.5|freebsd|6.2-release|200710300022
724370|724370-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710292305
724351|724351-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.11|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710292325
724308|724308-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710292220
724294|724294-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Finance-Currency-Convert-XE|0.14|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710292317
724257|724257-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Finance-Currency-Convert-XE|0.14|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710292255
723679|723679-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.14|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710291754
723678|723678-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.14|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710291753
723674|723674-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.14|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710291752
723671|723671-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.14|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710291751
723670|723670-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.14|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710291751
723669|723669-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Finance-Currency-Convert-XE|0.14|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710291750
723668|723668-b19f-3f77-b713-d32bba55d77f|cpan|200710|BARBIE|Finance-Currency-Convert-XE|0.14||0|||200710291749
723246|723246-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710291237
723245|723245-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710291237
723234|723234-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710291238
723228|723228-b19f-3f77-b713-d32bba55d77f|fail|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710291235
723219|723219-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710291236
723217|723217-b19f-3f77-b713-d32bba55d77f|fail|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.11|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710291235
723213|723213-b19f-3f77-b713-d32bba55d77f|cpan|200710|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.11||0|||200710291234
719972|719972-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710280437
719739|719739-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Test-YAML-Meta|0.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710280126
718729|718729-b19f-3f77-b713-d32bba55d77f|fail|200710|janus@errornet.de (Simon Bertrang)|Finance-Currency-Convert-XE|0.13|amd64-openbsd|5.8.8|openbsd|4.2|200710271135
718068|718068-b19f-3f77-b713-d32bba55d77f|pass|200710|andy@hexten.net|Test-YAML-Meta|0.04|powerpc-linux-gnu|5.8.8|linux|2.6.17-10-powerpc64-smp|200710270856
717623|717623-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710262302
715914|715914-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710260404
715162|715162-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Test-YAML-Meta|0.04|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710252104
712368|712368-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250120
712202|712202-b19f-3f77-b713-d32bba55d77f|fail|200710|srezic@cpan.org|Test-YAML-Meta|0.04|i386-freebsd|5.6.2|freebsd|6.1-release|200710250008
711913|711913-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Test-YAML-Meta|0.04|i386-freebsd|5.10.0 patch 32171|freebsd|6.1-release|200710242242
711807|711807-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Test-YAML-Meta|0.04|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710242209
707938|707938-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230526
705957|705957-b19f-3f77-b713-d32bba55d77f|pass|200710|andy@hexten.net|Test-YAML-Meta|0.04|i486-linux-gnu|5.8.8|linux|2.6.15.7|200710222226
698409|698409-b19f-3f77-b713-d32bba55d77f|fail|200710|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.08|sun4-solaris|5.9.5|solaris|2.9|200710200022
697665|697665-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|sun4-solaris|5.9.5|solaris|2.9|200710191205
697664|697664-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|sun4-solaris|5.9.5|solaris|2.9|200710191203
697661|697661-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|sun4-solaris|5.9.5|solaris|2.9|200710191203
697660|697660-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|sun4-solaris|5.9.5|solaris|2.9|200710191201
697657|697657-b19f-3f77-b713-d32bba55d77f|fail|200710|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|sun4-solaris|5.9.5|solaris|2.9|200710191201
697632|697632-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Test-YAML-Meta|0.04|sun4-solaris|5.9.5|solaris|2.9|200710191153
697608|697608-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Regexp-Log-Common|0.05|sun4-solaris|5.9.5|solaris|2.9|200710191030
697433|697433-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Mail-File|0.08|sun4-solaris|5.9.5|solaris|2.9|200710191028
697430|697430-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Games-Trackword|1.05|sun4-solaris|5.9.5|solaris|2.9|200710191028
697424|697424-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|GD-Chart-Radial|0.04|sun4-solaris|5.9.5|solaris|2.9|200710191027
697420|697420-b19f-3f77-b713-d32bba55d77f|fail|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|sun4-solaris|5.9.5|solaris|2.9|200710191026
697389|697389-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris|5.9.5|solaris|2.9|200710191016
697377|697377-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|sun4-solaris|5.9.5|solaris|2.9|200710191008
697376|697376-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.11|sun4-solaris|5.9.5|solaris|2.9|200710191008
697375|697375-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Data-Phrasebook|0.29|sun4-solaris|5.9.5|solaris|2.9|200710191007
697374|697374-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Calendar-List|0.18|sun4-solaris|5.9.5|solaris|2.9|200710191007
697373|697373-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-WebList|0.05|sun4-solaris|5.9.5|solaris|2.9|200710191006
697364|697364-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|sun4-solaris|5.9.5|solaris|2.9|200710191004
697359|697359-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|sun4-solaris|5.9.5|solaris|2.9|200710191003
697347|697347-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|sun4-solaris|5.9.5|solaris|2.9|200710190957
684568|684568-b19f-3f77-b713-d32bba55d77f|pass|200710|conrad@fringehead.org|Test-YAML-Meta|0.04|i686-linux-thread-multi|5.8.8|linux|2.6.20-16-386|200710131409
677151|677151-b19f-3f77-b713-d32bba55d77f|pass|200710|zeph.gillen@asu.edu|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.9-55.0.6.elsmp|200710080228
677103|677103-b19f-3f77-b713-d32bba55d77f|pass|200710|zeph.gillen@asu.edu|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.9-55.0.6.elsmp|200710080228
676166|676166-b19f-3f77-b713-d32bba55d77f|fail|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|darwin-2level|5.9.5|darwin|8.10.1|200710072046
675000|675000-b19f-3f77-b713-d32bba55d77f|pass|200710|fayland@gmail.com|Test-YAML-Meta|0.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200710061047
674270|674270-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710061323
666575|666575-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux|5.10.0|linux|2.6.22-1-k7|200710022050
666203|666203-b19f-3f77-b713-d32bba55d77f|fail|200710|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|i686-linux|5.6.2|linux|2.4.27-3-686|200710021922
665487|665487-b19f-3f77-b713-d32bba55d77f|pass|200710|zeph.gillen@asu.edu|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi|5.8.8|linux|2.6.9-11.elsmp|200710020302
665344|665344-b19f-3f77-b713-d32bba55d77f|pass|200710|zeph.gillen@asu.edu|Data-Phrasebook|0.29|i686-linux-thread-multi|5.8.8|linux|2.6.9-11.elsmp|200710020302
660678|660678-b19f-3f77-b713-d32bba55d77f|pass|200709|david@landgren.net|Test-YAML-Meta|0.04|i386-freebsd-64int|5.8.8|freebsd|6.0-stable|200709271112
654069|654069-b19f-3f77-b713-d32bba55d77f|fail|200709|david@cantrell.org.uk|WWW-UsePerl-Journal|0.11|darwin-2level|5.9.5|darwin|8.10.1|200709231850
651783|651783-b19f-3f77-b713-d32bba55d77f|fail|200709|david@cantrell.org.uk|WWW-UsePerl-Journal|0.11|i686-linux|5.6.2|linux|2.4.27-3-686|200709230103
644263|644263-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200709200203
644246|644246-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200709200151
644233|644233-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200709200148
644223|644223-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200709200136
644216|644216-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200709200126
644195|644195-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200709200122
644159|644159-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200709200117
643518|643518-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|alpha-linux-thread-multi|5.10.0 patch 31900|linux|2.6.16.19|200709191930
639822|639822-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709181147
638350|638350-b19f-3f77-b713-d32bba55d77f|fail|200709|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.08|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172134
638331|638331-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172124
638327|638327-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172121
638325|638325-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172120
638320|638320-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172119
638317|638317-b19f-3f77-b713-d32bba55d77f|fail|200709|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172119
638270|638270-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Test-YAML-Meta|0.04|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172054
638244|638244-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Regexp-Log-Common|0.05|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172042
638240|638240-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Mail-File|0.08|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172040
638233|638233-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172037
638227|638227-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172035
638226|638226-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.11|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172034
638207|638207-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Phrasebook|0.29|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709172027
637645|637645-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709171645
636334|636334-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200709170036
635603|635603-b19f-3f77-b713-d32bba55d77f|pass|200709|andy@hexten.net|Test-YAML-Meta|0.04|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709161055
635273|635273-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200709161438
632954|632954-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Mail-File|0.08|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151257
632432|632432-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Data-Phrasebook|0.29|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151234
632412|632412-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151234
632406|632406-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Test-YAML-Meta|0.04|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151429
632136|632136-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151449
630512|630512-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709141440
630144|630144-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709141440
629045|629045-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Test-YAML-Meta|0.04|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200709131554
628917|628917-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200709140025
626278|626278-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200709130942
623695|623695-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200709121151
623693|623693-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200709121150
623692|623692-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200709121149
623681|623681-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200709121148
620882|620882-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Calendar-List|0.18|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709102135
620874|620874-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709102121
616074|616074-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Test-YAML-Meta|0.04|i386-freebsd|5.9.5|freebsd|6.2-release|200709072101
613099|613099-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200709070044
598233|598233-b19f-3f77-b713-d32bba55d77f|pass|200708|dmo+cpanreporter@roaringpenguin.com ("Dave O''Neill")|Test-YAML-Meta|0.04|i486-linux-gnu|5.8.8|linux|2.6.18.3|200708291149
597533|597533-b19f-3f77-b713-d32bba55d77f|pass|200708|ewaters@cpan.org|Test-YAML-Meta|0.04|i486-linux-gnu|5.8.8|linux|2.6.18.3|200708281041
595912|595912-b19f-3f77-b713-d32bba55d77f|pass|200708|schwern@pobox.com|Test-YAML-Meta|0.04|darwin-thread-multi-2level|5.8.8|darwin|8.8.1|200708261252
592954|592954-b19f-3f77-b713-d32bba55d77f|pass|200708|cogent@cpan.org|Test-YAML-Meta|0.04|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200708231540
570612|570612-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.08|i686-linux|5.6.2|linux|2.4.27-3-686|200708131226
570572|570572-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200708131218
569325|569325-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|darwin-2level|5.9.5|darwin|8.10.1|200708122223
569284|569284-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|WWW-UsePerl-Journal-Thread|0.08|darwin-2level|5.9.5|darwin|8.10.1|200708122224
569270|569270-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|darwin-2level|5.9.5|darwin|8.10.1|200708122221
569268|569268-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|darwin-2level|5.9.5|darwin|8.10.1|200708122221
569264|569264-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.6.2|linux|2.4.27-3-686|200708122213
569262|569262-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|darwin-2level|5.9.5|darwin|8.10.1|200708122221
569257|569257-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux|5.6.2|linux|2.4.27-3-686|200708122221
569255|569255-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i686-linux|5.6.2|linux|2.4.27-3-686|200708122221
569253|569253-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|darwin-2level|5.9.5|darwin|8.10.1|200708122221
569222|569222-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Test-YAML-Meta|0.04|darwin-2level|5.9.5|darwin|8.10.1|200708122220
569220|569220-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Regexp-Log-Common|0.05|darwin-2level|5.9.5|darwin|8.10.1|200708122219
569218|569218-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Mail-File|0.08|darwin-2level|5.9.5|darwin|8.10.1|200708122219
569217|569217-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Games-Trackword|1.05|darwin-2level|5.9.5|darwin|8.10.1|200708122219
569216|569216-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|darwin-2level|5.9.5|darwin|8.10.1|200708122217
569215|569215-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|darwin-2level|5.9.5|darwin|8.10.1|200708122217
569214|569214-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Calendar-List|0.18|darwin-2level|5.9.5|darwin|8.10.1|200708122215
569213|569213-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|darwin-2level|5.9.5|darwin|8.10.1|200708122216
569211|569211-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.11|darwin-2level|5.9.5|darwin|8.10.1|200708122216
569210|569210-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook|0.29|darwin-2level|5.9.5|darwin|8.10.1|200708122216
569209|569209-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Regexp-Log-Common|0.05|i686-linux|5.6.2|linux|2.4.27-3-686|200708122215
569206|569206-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-WebList|0.05|darwin-2level|5.9.5|darwin|8.10.1|200708122215
569205|569205-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Mail-File|0.08|i686-linux|5.6.2|linux|2.4.27-3-686|200708122215
569203|569203-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Games-Trackword|1.05|i686-linux|5.6.2|linux|2.4.27-3-686|200708122215
569202|569202-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|i686-linux|5.6.2|linux|2.4.27-3-686|200708122215
569201|569201-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|darwin-2level|5.9.5|darwin|8.10.1|200708122215
569199|569199-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|darwin-2level|5.9.5|darwin|8.10.1|200708122214
569198|569198-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.6.2|linux|2.4.27-3-686|200708122213
569197|569197-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.6.2|linux|2.4.27-3-686|200708122213
569196|569196-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Calendar-List|0.18|i686-linux|5.6.2|linux|2.4.27-3-686|200708122213
569195|569195-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux|5.6.2|linux|2.4.27-3-686|200708122213
569192|569192-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|darwin-2level|5.9.5|darwin|8.10.1|200708122205
561972|561972-b19f-3f77-b713-d32bba55d77f|pass|200708|jeff@zeroclue.com|Test-YAML-Meta|0.04|darwin-thread-multi-2level|5.8.6|darwin|8.0|200708091047
557042|557042-b19f-3f77-b713-d32bba55d77f|pass|200708|andy@hexten.net|Test-YAML-Meta|0.04|darwin-2level|5.8.8|darwin|8.10.1|200708061716
553732|553732-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708031941
553696|553696-b19f-3f77-b713-d32bba55d77f|pass|200708|ferreira@cpan.org ("Adriano Ferreira")|CPAN-WWW-Testers|0.33|cygwin|5.9.5|cygwin|1.5.24(0.15642)|200708031506
551714|551714-b19f-3f77-b713-d32bba55d77f|pass|200707|ferreira@cpan.org ("Adriano Ferreira")|Test-YAML-Meta|0.04|cygwin|5.9.5|cygwin|1.5.24(0.15642)|200707311124
551229|551229-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707301307
551211|551211-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707301307
551208|551208-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707301306
551207|551207-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707301308
551169|551169-b19f-3f77-b713-d32bba55d77f|pass|200707|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.10|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200707301454
551058|551058-b19f-3f77-b713-d32bba55d77f|pass|200707|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200707301909
551002|551002-b19f-3f77-b713-d32bba55d77f|pass|200707|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Yahoo_Driver|0.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200707301821
550600|550600-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200707290836
550175|550175-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200707281921
550119|550119-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200707281857
550089|550089-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux|5.9.5|linux|2.4.27-3-686|200707281737
550087|550087-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux|5.8.8|linux|2.4.27-3-686|200707281737
550082|550082-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707281833
550059|550059-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux|5.6.2|linux|2.4.27-3-686|200707281718
549801|549801-b19f-3f77-b713-d32bba55d77f|fail|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.09|i686-linux-64int|5.8.8|linux|2.6.14|200707281415
549793|549793-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int|5.8.8|linux|2.6.14|200707281414
549779|549779-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int|5.8.8|linux|2.6.14|200707281410
549496|549496-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200707281238
549487|549487-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200707281233
549482|549482-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200707281229
549481|549481-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200707281225
549455|549455-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux-64int|5.8.8|linux|2.6.14|200707281316
549315|549315-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200707281116
549312|549312-b19f-3f77-b713-d32bba55d77f|fail|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.09|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707281122
549311|549311-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707281121
549310|549310-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200707281111
549308|549308-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707281118
549302|549302-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.10|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200707281106
549300|549300-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200707281100
549266|549266-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Scraper-ISBN-Amazon_Driver|0.10|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707281027
548911|548911-b19f-3f77-b713-d32bba55d77f|cpan|200707|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.10||0|||200707271840
548776|548776-b19f-3f77-b713-d32bba55d77f|pass|200707|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Pearson_Driver|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200707272149
548772|548772-b19f-3f77-b713-d32bba55d77f|pass|200707|imacat@mail.imacat.idv.tw|WWW-Scraper-ISBN-Amazon_Driver|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200707272146
548702|548702-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux|5.6.2|linux|2.4.27-3-686|200707271358
548682|548682-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707271449
548681|548681-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux|5.6.2|linux|2.4.27-3-686|200707271349
548678|548678-b19f-3f77-b713-d32bba55d77f|fail|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|i686-linux|5.6.2|linux|2.4.27-3-686|200707271348
548633|548633-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707271335
548632|548632-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707271335
548626|548626-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux|5.9.5|linux|2.4.27-3-686|200707271232
548625|548625-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i686-linux|5.8.8|linux|2.4.27-3-686|200707271232
548617|548617-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200707271230
548615|548615-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|i686-linux|5.9.5|linux|2.4.27-3-686|200707271230
548612|548612-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|i686-linux|5.9.5|linux|2.4.27-3-686|200707271229
548611|548611-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200707271229
548553|548553-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200707271118
548550|548550-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200707271113
548547|548547-b19f-3f77-b713-d32bba55d77f|fail|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200707271107
548515|548515-b19f-3f77-b713-d32bba55d77f|pass|200707|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200707270929
548514|548514-b19f-3f77-b713-d32bba55d77f|pass|200707|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.09|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200707270928
548513|548513-b19f-3f77-b713-d32bba55d77f|pass|200707|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.09|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200707270928
548316|548316-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707270041
548315|548315-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200707270037
548307|548307-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707262242
548305|548305-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200707262237
548054|548054-b19f-3f77-b713-d32bba55d77f|cpan|200707|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.06||0|||200707261822
547889|547889-b19f-3f77-b713-d32bba55d77f|cpan|200707|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.09||0|||200707261645
547836|547836-b19f-3f77-b713-d32bba55d77f|cpan|200707|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.09||0|||200707261609
545854|545854-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707242218
545596|545596-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-freebsd-64int|5.8.6|freebsd|5.4-release|200707241500
545542|545542-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux|5.8.6|linux|2.4.18|200707241413
543567|543567-b19f-3f77-b713-d32bba55d77f|pass|200707|g.grigelionis@computer.org|Test-YAML-Meta|0.04|i586-linux-thread-multi|5.8.8|linux|2.6.16|200707201014
543269|543269-b19f-3f77-b713-d32bba55d77f|pass|200707|jl_morel@bribes.org ("Jean-Louis Morel")|Test-YAML-Meta|0.04|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200707211742
537569|537569-b19f-3f77-b713-d32bba55d77f|pass|200707|jrockway@cpan.org|CPAN-WWW-Testers|0.33|i486-linux-gnu|5.8.8|linux|2.6.18.3|200707150514
533071|533071-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200707101742
533070|533070-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-pc-solaris2.11|5.8.7|solaris|2.11|200707101742
531889|531889-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200707091449
531888|531888-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200707091449
531270|531270-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200707081913
531269|531269-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200707081913
530396|530396-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200707072226
530395|530395-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200707072226
529835|529835-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200707070541
529834|529834-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200707070540
529660|529660-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200707062235
529624|529624-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200707062100
529623|529623-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200707062100
528858|528858-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux|5.6.2|linux|2.4.27-3-686|200707052109
528281|528281-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200707042302
528280|528280-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200707042301
527811|527811-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707041917
527810|527810-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707041917
527775|527775-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux|5.8.8|linux|2.4.27-3-686|200707041647
527686|527686-b19f-3f77-b713-d32bba55d77f|pass|200707|tom@eborcom.com ("Tom Hukins")|Data-Phrasebook|0.29|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200707040741
527670|527670-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200707041648
527568|527568-b19f-3f77-b713-d32bba55d77f|pass|200707|tom@eborcom.com ("Tom Hukins")|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200707040741
527398|527398-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.9.5 patch 31416|linux|2.4.27-3-686|200707041414
527340|527340-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux|5.9.5 patch 31416|linux|2.4.27-3-686|200707041414
527076|527076-b19f-3f77-b713-d32bba55d77f|pass|200707|perl@astola.org|Data-Phrasebook|0.29|i486-linux-gnu|5.8.8|linux|2.6.18.3|200707040856
527074|527074-b19f-3f77-b713-d32bba55d77f|pass|200707|perl@astola.org|Data-Phrasebook-Loader-YAML|0.09|i486-linux-gnu|5.8.8|linux|2.6.18.3|200707040856
526687|526687-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707032032
526686|526686-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707032032
526535|526535-b19f-3f77-b713-d32bba55d77f|pass|200707|tom@eborcom.com ("Tom Hukins")|Test-YAML-Meta|0.04|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200707030757
525953|525953-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707031438
524932|524932-b19f-3f77-b713-d32bba55d77f|pass|200707|rafl@debian.org|Test-YAML-Meta|0.04|i686-linux-thread-multi|5.8.8|linux|2.6.18|200707021655
524180|524180-b19f-3f77-b713-d32bba55d77f|pass|200707|amoore@cpan.org|Test-YAML-Meta|0.04|i486-linux-gnu|5.8.8|linux|2.6.18.3|200707011319
524143|524143-b19f-3f77-b713-d32bba55d77f|pass|200707|amoore@cpan.org|Test-YAML-Meta|0.04|x86_64-linux-gnu|5.8.8|linux|2.6.18-1-amd64|200707011319
523618|523618-b19f-3f77-b713-d32bba55d77f|pass|200707|vpit@cpan.org|Test-YAML-Meta|0.04|i686-linux-thread|5.8.8|linux|2.6.21.3-chii.profvince.com|200707011003
515593|515593-b19f-3f77-b713-d32bba55d77f|pass|200706|devogon@gmail.com ((daniel))|Data-Phrasebook|0.29|x86_64-linux|5.8.8|linux|2.6.17-reiser4-r1|200706222029
513809|513809-b19f-3f77-b713-d32bba55d77f|na|200706|ferreira@cpan.org ("Adriano Ferreira")|CPAN-WWW-Testers|0.33|cygwin|5.8.8|cygwin|1.5.22(0.15642)|200706211617
510926|510926-b19f-3f77-b713-d32bba55d77f|fail|200706|chris@bingosnet.co.uk|GD-Chart-Radial|0.04|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200706181014
510925|510925-b19f-3f77-b713-d32bba55d77f|fail|200706|chris@bingosnet.co.uk|GD-Chart-Radial|0.03|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200706181013
510923|510923-b19f-3f77-b713-d32bba55d77f|fail|200706|chris@bingosnet.co.uk|GD-Chart-Radial|0.02|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200706181012
510201|510201-b19f-3f77-b713-d32bba55d77f|pass|200706|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-YACSmoke-Plugin-WebList|0.05|i686-linux-64int|5.9.5|linux|2.6.18-4-k7|200706160947
509457|509457-b19f-3f77-b713-d32bba55d77f|pass|200706|njh@bandsman.co.uk|GD-Chart-Radial|0.03|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200706140604
509387|509387-b19f-3f77-b713-d32bba55d77f|fail|200706|david@cantrell.org.uk|GD-Chart-Radial|0.04|i686-linux|5.6.2|linux|2.4.27-3-686|200706132252
509372|509372-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|GD-Chart-Radial|0.04|i686-linux|5.9.5 patch 31335|linux|2.4.27-3-686|200706132247
509183|509183-b19f-3f77-b713-d32bba55d77f|pass|200706|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.04|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200706132214
509016|509016-b19f-3f77-b713-d32bba55d77f|pass|200706|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|GD-Chart-Radial|0.04|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200706130833
508881|508881-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|GD-Chart-Radial|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200706121728
508880|508880-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|GD-Chart-Radial|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200706121727
508845|508845-b19f-3f77-b713-d32bba55d77f|pass|200706|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200706122252
508844|508844-b19f-3f77-b713-d32bba55d77f|fail|200706|imacat@mail.imacat.idv.tw|GD-Chart-Radial|0.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200706122252
508776|508776-b19f-3f77-b713-d32bba55d77f|pass|200706|stro@cpan.org|GD-Chart-Radial|0.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200706121629
508755|508755-b19f-3f77-b713-d32bba55d77f|pass|200706|stro@cpan.org|GD-Chart-Radial|0.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200706121628
508710|508710-b19f-3f77-b713-d32bba55d77f|fail|200706|david@cantrell.org.uk|GD-Chart-Radial|0.03|i686-linux|5.6.2|linux|2.4.27-3-686|200706121427
508664|508664-b19f-3f77-b713-d32bba55d77f|pass|200706|devogon@gmail.com ((daniel))|Finance-Currency-Convert-XE|0.13|x86_64-linux|5.8.8|linux|2.6.17-reiser4-r1|200706121405
508446|508446-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|GD-Chart-Radial|0.02|i686-linux|5.6.2|linux|2.4.27-3-686|200706121246
508354|508354-b19f-3f77-b713-d32bba55d77f|pass|200706|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|GD-Chart-Radial|0.03|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200706121059
508118|508118-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|GD-Chart-Radial|0.03|i686-linux|5.9.5 patch 31335|linux|2.4.27-3-686|200706121105
508114|508114-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|GD-Chart-Radial|0.02|i686-linux|5.9.5 patch 31335|linux|2.4.27-3-686|200706121105
507927|507927-b19f-3f77-b713-d32bba55d77f|cpan|200706|BARBIE|GD-Chart-Radial|0.04||0|||200706121057
506696|506696-b19f-3f77-b713-d32bba55d77f|cpan|200706|BARBIE|GD-Chart-Radial|0.03||0|||200706111641
506683|506683-b19f-3f77-b713-d32bba55d77f|cpan|200706|BARBIE|GD-Chart-Radial|0.02||0|||200706111637
492006|492006-b19f-3f77-b713-d32bba55d77f|pass|200705|saper@cpan.org|Mail-File|0.08|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200705221348
491215|491215-b19f-3f77-b713-d32bba55d77f|pass|200705|saper@cpan.org|Calendar-List|0.18|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200705211120
491197|491197-b19f-3f77-b713-d32bba55d77f|pass|200705|saper@cpan.org|CPAN-WWW-Testers|0.33|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200705211119
491091|491091-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200705210907
490312|490312-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200705192332
489962|489962-b19f-3f77-b713-d32bba55d77f|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200705190429
489283|489283-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200705180941
488822|488822-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|cygwin-thread-multi-64int|5.9.5 patch 31192|cygwin|1.5.24(0.15642)|200705172355
488667|488667-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.9.5 patch 31209|netbsd|3.1|200705172106
488251|488251-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200705171217
488160|488160-b19f-3f77-b713-d32bba55d77f|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.04|i686-linux-64int|5.9.5|linux|2.6.18-4-k7|200705170801
487970|487970-b19f-3f77-b713-d32bba55d77f|pass|200705|srezic@cpan.org|Test-YAML-Meta|0.04|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200705162113
487953|487953-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200705162145
487871|487871-b19f-3f77-b713-d32bba55d77f|pass|200705|david@cantrell.org.uk|Test-YAML-Meta|0.04|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200705162131
487840|487840-b19f-3f77-b713-d32bba55d77f|pass|200705|saper@cpan.org|Test-YAML-Meta|0.04|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200705162015
487557|487557-b19f-3f77-b713-d32bba55d77f|pass|200705|imacat@mail.imacat.idv.tw|Test-YAML-Meta|0.04|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.18-4-amd64|200705162054
487489|487489-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-pc-solaris2.11|5.8.7|solaris|2.11|200705161250
487312|487312-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200705160504
486873|486873-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200705151935
486848|486848-b19f-3f77-b713-d32bba55d77f|pass|200705|chris@bingosnet.co.uk|Test-YAML-Meta|0.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200705151926
486317|486317-b19f-3f77-b713-d32bba55d77f|cpan|200705|BARBIE|Test-YAML-Meta|0.04||0|||200705151310
483684|483684-b19f-3f77-b713-d32bba55d77f|na|200705|ferreira@cpan.org ("Adriano Ferreira")|Mail-Outlook|0.13|cygwin|5.8.8|cygwin|1.5.22(0.15642)|200705121651
483153|483153-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Phrasebook-Loader-XML|0.12|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705121606
483152|483152-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Phrasebook|0.29|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705121606
483151|483151-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705121606
483149|483149-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705121606
483148|483148-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705121606
478929|478929-b19f-3f77-b713-d32bba55d77f|pass|200705|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.33|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200705091120
478487|478487-b19f-3f77-b713-d32bba55d77f|cpan|200705|BARBIE|Mail-Outlook|0.13||0|||200705090841
478358|478358-b19f-3f77-b713-d32bba55d77f|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.03|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200705082349
477639|477639-b19f-3f77-b713-d32bba55d77f|fail|200705|bsmith@cpan.org|CPAN-WWW-Testers-Generator|0.22|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705071840
477294|477294-b19f-3f77-b713-d32bba55d77f|na|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-WWW-Testers|0.33|i686-linux-64int|5.9.5|linux|2.6.18-4-k7|200705072228
476974|476974-b19f-3f77-b713-d32bba55d77f|cpan|200705|LBROCARD|CPAN-WWW-Testers|0.33||0|||200705071537
475389|475389-b19f-3f77-b713-d32bba55d77f|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Test-YAML-Meta|0.03|i686-linux-64int|5.9.5|linux|2.6.18-4-k7|200705061122
473868|473868-b19f-3f77-b713-d32bba55d77f|cpan|200705|BARBIE|Mail-Outlook|0.12||0|||200705041143
473054|473054-b19f-3f77-b713-d32bba55d77f|cpan|200705|BARBIE|Mail-Outlook|0.11||0|||200705031922
450362|450362-b19f-3f77-b713-d32bba55d77f|pass|200703|david@landgren.net|Calendar-List|0.18|i386-freebsd-64int|5.8.6|freebsd|5.2.1-release|200703302317
443085|443085-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703211911
443080|443080-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703211911
443077|443077-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703211911
441702|441702-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|alpha-freebsd|5.8.7|freebsd|6.0-release|200703200902
441263|441263-b19f-3f77-b713-d32bba55d77f|pass|200703|jrockway@cpan.org|CPAN-WWW-Testers|0.32|i486-linux-gnu|5.8.8|linux|2.6.18.3|200703181659
441086|441086-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190920
441085|441085-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190917
441082|441082-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190914
441079|441079-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190910
441078|441078-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190907
441077|441077-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190903
441076|441076-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190903
441075|441075-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190857
441074|441074-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703190850
440099|440099-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172012
440098|440098-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172009
439366|439366-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170751
439363|439363-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170749
439359|439359-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170747
439357|439357-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170746
439356|439356-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170744
439355|439355-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170743
439354|439354-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170743
439353|439353-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170740
438730|438730-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161142
438727|438727-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161138
438721|438721-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161135
438719|438719-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161131
438711|438711-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161128
438708|438708-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161125
438707|438707-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161124
438702|438702-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161118
438700|438700-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703161112
438510|438510-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703151950
438506|438506-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703151947
438402|438402-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703151647
438381|438381-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151534
438262|438262-b19f-3f77-b713-d32bba55d77f|fail|200703|david@cantrell.org.uk|WWW-UsePerl-Journal|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703151532
438112|438112-b19f-3f77-b713-d32bba55d77f|fail|200703|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.16|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703152026
437958|437958-b19f-3f77-b713-d32bba55d77f|fail|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.16|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703150955
437940|437940-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i386-openbsd|5.8.8|openbsd|4.0|200703150927
437939|437939-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i386-openbsd|5.8.8|openbsd|4.0|200703150923
437938|437938-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|i386-openbsd|5.8.8|openbsd|4.0|200703150920
437937|437937-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|i386-openbsd|5.8.8|openbsd|4.0|200703150915
437936|437936-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i386-openbsd|5.8.8|openbsd|4.0|200703150910
437931|437931-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-openbsd|5.8.8|openbsd|4.0|200703150905
437930|437930-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-openbsd|5.8.8|openbsd|4.0|200703150904
437929|437929-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i386-openbsd|5.8.8|openbsd|4.0|200703150857
437915|437915-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-openbsd|5.8.8|openbsd|4.0|200703150849
437810|437810-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703141928
437808|437808-b19f-3f77-b713-d32bba55d77f|pass|200703|corion-cpanplus@corion.net|WWW-Scraper-ISBN-Amazon_Driver|0.08|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703142035
437793|437793-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.16|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703141831
437707|437707-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|i686-linux|5.8.8|linux|2.4.27-3-686|200703141750
437577|437577-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.08|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703141720
437491|437491-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger@ruhr-uni-bochum.de|CPAN-YACSmoke-Plugin-WebList|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141624
437485|437485-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger@ruhr-uni-bochum.de|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141614
437483|437483-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger@ruhr-uni-bochum.de|CPAN-YACSmoke-Plugin-NNTP|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141555
437431|437431-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-UsePerl-Journal|0.16||0|||200703141306
437421|437421-b19f-3f77-b713-d32bba55d77f|fail|200703|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.15|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703141951
437420|437420-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|CPAN-YACSmoke-Plugin-NNTP|0.05|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703141948
437349|437349-b19f-3f77-b713-d32bba55d77f|fail|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.15|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141010
437348|437348-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Amazon_Driver|0.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141008
437347|437347-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-WebList|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141007
437346|437346-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-Outlook|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141004
437345|437345-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141004
437344|437344-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-YACSmoke-Plugin-NNTP|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141001
437069|437069-b19f-3f77-b713-d32bba55d77f|pass|200703|corion-cpanplus@corion.net|WWW-UsePerl-Journal|0.15|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703132102
437067|437067-b19f-3f77-b713-d32bba55d77f|fail|200703|corion-cpanplus@corion.net|WWW-Scraper-ISBN-Amazon_Driver|0.07|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703132059
437066|437066-b19f-3f77-b713-d32bba55d77f|pass|200703|corion-cpanplus@corion.net|Finance-Currency-Convert-XE|0.13|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703132059
437032|437032-b19f-3f77-b713-d32bba55d77f|fail|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703131447
436982|436982-b19f-3f77-b713-d32bba55d77f|fail|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|i686-linux|5.8.8|linux|2.4.27-3-686|200703131754
436931|436931-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131717
436926|436926-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131713
436921|436921-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131706
436918|436918-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131658
436916|436916-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131657
436912|436912-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131648
436905|436905-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131637
436833|436833-b19f-3f77-b713-d32bba55d77f|fail|200703|david@cantrell.org.uk|WWW-UsePerl-Journal|0.15|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703131622
436803|436803-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-UsePerl-Journal|0.15|i686-linux|5.6.2|linux|2.4.27-3-686|200703131607
436564|436564-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.08||0|||200703131207
436487|436487-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130905
436486|436486-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130901
436484|436484-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130855
436479|436479-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130848
436477|436477-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130847
436470|436470-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130839
436462|436462-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130830
436453|436453-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger@ruhr-uni-bochum.de|Mail-File|0.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703130818
436238|436238-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703130130
436223|436223-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703130122
436160|436160-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703130033
436148|436148-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703130024
436147|436147-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-UsePerl-Journal|0.15|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703130023
436143|436143-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTPWeb|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703130021
436072|436072-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703122332
436070|436070-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703122331
436060|436060-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703122321
436057|436057-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-NNTP|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703122320
436054|436054-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-WebList|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703122320
436052|436052-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|CPAN-YACSmoke-Plugin-Outlook|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703122318
435794|435794-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|CPAN-YACSmoke-Plugin-NNTPWeb|0.06||0|||200703121934
435747|435747-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|CPAN-YACSmoke-Plugin-NNTPWeb|0.05||0|||200703121844
435739|435739-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-UsePerl-Journal|0.15||0|||200703121830
435710|435710-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|CPAN-YACSmoke-Plugin-NNTP|0.05||0|||200703121802
435668|435668-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|CPAN-YACSmoke-Plugin-WebList|0.05||0|||200703121742
435661|435661-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|CPAN-YACSmoke-Plugin-Outlook|0.06||0|||200703121737
435257|435257-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.07||0|||200703121243
434514|434514-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703111745
433719|433719-b19f-3f77-b713-d32bba55d77f|pass|200703|james@mastros.biz|Finance-Currency-Convert-XE|0.13|i486-linux-gnu|5.8.8|linux|2.6.18.3|200703091542
433345|433345-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703091914
433171|433171-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.32|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703091720
433093|433093-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i386-openbsd|5.8.8|openbsd|4.0|200703091612
433092|433092-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i386-openbsd|5.8.8|openbsd|4.0|200703091612
433091|433091-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i386-openbsd|5.8.8|openbsd|4.0|200703091611
433090|433090-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i386-openbsd|5.8.8|openbsd|4.0|200703091611
433088|433088-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i386-openbsd|5.8.8|openbsd|4.0|200703091610
433085|433085-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-openbsd|5.8.8|openbsd|4.0|200703091608
433084|433084-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i386-openbsd|5.8.8|openbsd|4.0|200703091608
432649|432649-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703091029
432474|432474-b19f-3f77-b713-d32bba55d77f|pass|200703|smueller@cpan.org ("Steffen Mueller")|Regexp-Log-Common|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200703082240
432438|432438-b19f-3f77-b713-d32bba55d77f|pass|200703|smueller@cpan.org ("Steffen Mueller")|Regexp-Log-Common|0.05|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200703082244
432375|432375-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090058
432374|432374-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090052
432373|432373-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090047
432368|432368-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090040
432367|432367-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090037
432366|432366-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090034
432365|432365-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090032
432364|432364-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090029
432359|432359-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090026
432350|432350-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090022
432340|432340-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090019
432334|432334-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090016
432333|432333-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090012
432332|432332-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090009
432331|432331-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090006
432305|432305-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|i686-linux|5.8.8|linux|2.4.27-3-686|200703082330
432165|432165-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.13|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703082158
431755|431755-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703082136
431701|431701-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|alpha-freebsd|5.8.7|freebsd|6.0-release|200703081156
431648|431648-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Regexp-Log-Common|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703081107
431647|431647-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Mail-File|0.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703081107
431646|431646-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Games-Trackword|1.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703081106
431645|431645-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.13|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703081105
431644|431644-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.29|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703081105
431643|431643-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.18|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703081104
431430|431430-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080635
431429|431429-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Calendar-List|0.18|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080634
431394|431394-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080639
431393|431393-b19f-3f77-b713-d32bba55d77f|fail|200703|njh@bandsman.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080639
431392|431392-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080638
431387|431387-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Test-YAML-Meta|0.03|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080637
431384|431384-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Regexp-Log-Common|0.05|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080636
431382|431382-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Mail-File|0.08|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080636
431380|431380-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Games-Trackword|1.05|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080636
431379|431379-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Finance-Currency-Convert-XE|0.13|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080636
431378|431378-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Data-Phrasebook-Loader-XML|0.12|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080635
431377|431377-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Data-Phrasebook-Loader-Ini|0.10|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080635
431376|431376-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Data-Phrasebook-Loader-DBI|0.11|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080635
431375|431375-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Data-Phrasebook|0.29|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080634
431143|431143-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703072223
431141|431141-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703072221
431139|431139-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.13|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703072218
431046|431046-b19f-3f77-b713-d32bba55d77f|pass|200703|peterson146@gmail.com|Finance-Currency-Convert-XE|0.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200703071006
431033|431033-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Finance-Currency-Convert-XE|0.13||0|||200703071626
430230|430230-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061640
430228|430228-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061639
430225|430225-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061638
430222|430222-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061637
430220|430220-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061635
430219|430219-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061634
430218|430218-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061634
430217|430217-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061633
430215|430215-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061627
430201|430201-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061627
430200|430200-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061626
429889|429889-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061355
429886|429886-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061348
429850|429850-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061341
429839|429839-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061333
429837|429837-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061329
429836|429836-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061326
429835|429835-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061323
429833|429833-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061320
429822|429822-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061316
429809|429809-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061312
429807|429807-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061309
429798|429798-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061302
429796|429796-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061259
429058|429058-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051649
429052|429052-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051647
429050|429050-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051646
429048|429048-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051645
429046|429046-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051644
429045|429045-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051643
429044|429044-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051642
429043|429043-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051642
429041|429041-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051640
429040|429040-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051639
429037|429037-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051638
429035|429035-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051637
429032|429032-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051635
429029|429029-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051634
429027|429027-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051633
429026|429026-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051632
429011|429011-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051626
429006|429006-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051624
429003|429003-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051623
428999|428999-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051621
428996|428996-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051619
428995|428995-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051618
428994|428994-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051617
428993|428993-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051614
428992|428992-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051613
428991|428991-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051612
428990|428990-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051610
428986|428986-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051607
428984|428984-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051606
428982|428982-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051605
428451|428451-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050908
428450|428450-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050903
428449|428449-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050859
428443|428443-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050853
428442|428442-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050852
428441|428441-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050850
428440|428440-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050849
428439|428439-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050848
428438|428438-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050847
428436|428436-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050845
428435|428435-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050844
428434|428434-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050844
428433|428433-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050843
428432|428432-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050842
428431|428431-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050841
428430|428430-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|alpha-freebsd|5.8.7|freebsd|6.0-release|200703050841
428091|428091-b19f-3f77-b713-d32bba55d77f|cpan|200703|LBROCARD|CPAN-WWW-Testers|0.32||0|||200703041756
428019|428019-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.12|i686-linux|5.8.8|linux|2.4.27-3-686|200703040131
428017|428017-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Calendar-List|0.18|i686-linux|5.8.8|linux|2.4.27-3-686|200703040129
427989|427989-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Games-Trackword|1.05|i686-linux|5.8.8|linux|2.4.27-3-686|200703040130
427975|427975-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Mail-File|0.08|i686-linux|5.8.8|linux|2.4.27-3-686|200703040129
427974|427974-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux|5.8.8|linux|2.4.27-3-686|200703040130
427944|427944-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Regexp-Log-Common|0.05|i686-linux|5.8.8|linux|2.4.27-3-686|200703040130
427796|427796-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Regexp-Log-Common|0.05|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703040000
427793|427793-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.12|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703040001
427774|427774-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Games-Trackword|1.05|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703040000
427760|427760-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Calendar-List|0.18|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703040014
427759|427759-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Mail-File|0.08|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703040014
427758|427758-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.29|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703040000
427725|427725-b19f-3f77-b713-d32bba55d77f|fail|200703|david@cantrell.org.uk|Finance-Currency-Convert-XE|0.12|i686-linux|5.6.2|linux|2.4.27-3-686|200703032355
427721|427721-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.29|i686-linux|5.6.2|linux|2.4.27-3-686|200703032354
427719|427719-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Games-Trackword|1.05|i686-linux|5.6.2|linux|2.4.27-3-686|200703032354
427717|427717-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Regexp-Log-Common|0.05|i686-linux|5.6.2|linux|2.4.27-3-686|200703032354
427714|427714-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Mail-File|0.08|i686-linux|5.6.2|linux|2.4.27-3-686|200703032353
427574|427574-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.12|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703040054
427573|427573-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.29|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703040053
427572|427572-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Games-Trackword|1.05|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703040052
427571|427571-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Regexp-Log-Common|0.05|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703040052
427570|427570-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Mail-File|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703040052
427569|427569-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Calendar-List|0.18|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703040052
427399|427399-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030958
427398|427398-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030956
427394|427394-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030954
427393|427393-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030953
427392|427392-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030953
427391|427391-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030953
427390|427390-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030953
427389|427389-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030953
427388|427388-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030952
427387|427387-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030952
427386|427386-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030952
427385|427385-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703030952
427306|427306-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703022122
427304|427304-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703022120
427303|427303-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703022118
427263|427263-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703022021
427262|427262-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703022019
427261|427261-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.29|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703022018
427244|427244-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703021922
427243|427243-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703021922
427242|427242-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703021921
427241|427241-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703021921
427240|427240-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703021921
427236|427236-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Mail-File|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703021920
427234|427234-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703021919
427232|427232-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Games-Trackword|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703021918
427231|427231-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Regexp-Log-Common|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703021918
427230|427230-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Calendar-List|0.18|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703021918
427100|427100-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i686-linux|5.8.8|linux|2.4.27-3-686|200703021539
427086|427086-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux|5.8.8|linux|2.4.27-3-686|200703021536
427085|427085-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.8.8|linux|2.4.27-3-686|200703021536
427083|427083-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.8.8|linux|2.4.27-3-686|200703021536
427081|427081-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.28|i686-linux|5.8.8|linux|2.4.27-3-686|200703021536
427077|427077-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200703021534
427076|427076-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.28|i686-linux|5.8.8|linux|2.4.27-3-686|200703021533
427045|427045-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Test-YAML-Meta|0.03|i686-linux|5.8.8|linux|2.4.27-3-686|200703021513
427030|427030-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021409
427029|427029-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021408
427028|427028-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021408
427027|427027-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021407
427026|427026-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021406
427025|427025-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021406
427024|427024-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021405
427023|427023-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021401
426996|426996-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021445
426984|426984-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i686-linux|5.6.2|linux|2.4.27-3-686|200703021438
426978|426978-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021435
426977|426977-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-XML|0.12|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021435
426975|426975-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021435
426974|426974-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.28|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021434
426969|426969-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.11|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021428
426967|426967-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.28|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021426
426944|426944-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022222
426943|426943-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.12|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022221
426942|426942-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022221
426940|426940-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Finance-Currency-Convert-XE|0.12||0|||200703021520
426939|426939-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022220
426938|426938-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.28|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022219
426920|426920-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-XML|0.12|i686-linux|5.6.2|linux|2.4.27-3-686|200703021405
426919|426919-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.10|i686-linux|5.6.2|linux|2.4.27-3-686|200703021405
426917|426917-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.28|i686-linux|5.6.2|linux|2.4.27-3-686|200703021404
426902|426902-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Test-YAML-Meta|0.03|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021349
426899|426899-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Phrasebook|0.28|i686-linux|5.6.2|linux|2.4.27-3-686|200703021350
426840|426840-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Data-Phrasebook|0.29||0|||200703021421
426839|426839-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Games-Trackword|1.05||0|||200703021405
426838|426838-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Regexp-Log-Common|0.05||0|||200703021336
426837|426837-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Mail-File|0.08||0|||200703021334
426836|426836-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Calendar-List|0.18||0|||200703021333
426783|426783-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Yahoo_Driver|0.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021139
426782|426782-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021138
426781|426781-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021138
426780|426780-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.09|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021137
426779|426779-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.12|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021136
426778|426778-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.10|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021136
426777|426777-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.11|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021136
426776|426776-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.28|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703021135
426756|426756-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Phrasebook|0.28|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021133
426755|426755-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Test-YAML-Meta|0.03|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021132
426747|426747-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Phrasebook-Loader-YAML|0.09|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021130
426746|426746-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Phrasebook-Loader-XML|0.12|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021130
426745|426745-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.10|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021130
426744|426744-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.11|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021129
426742|426742-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Phrasebook|0.28|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021124
426574|426574-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703020422
426572|426572-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Pearson_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703020419
426518|426518-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703020036
426494|426494-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703020020
426437|426437-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703012224
426423|426423-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Yahoo_Driver|0.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703012220
426406|426406-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.08||0|||200703012217
426402|426402-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703012022
426401|426401-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703012021
426392|426392-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703011927
426391|426391-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703011927
426390|426390-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703012022
426389|426389-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703012021
426388|426388-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703012020
426387|426387-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703012019
426383|426383-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703012018
426382|426382-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703012018
426381|426381-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703012018
426379|426379-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703012005
426378|426378-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703012002
426376|426376-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703011958
426370|426370-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703011926
426366|426366-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703011920
426365|426365-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.28|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703011919
426361|426361-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703011918
426341|426341-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.08||0|||200703011905
426174|426174-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703011421
426119|426119-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.05||0|||200703011615
426011|426011-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703011418
425946|425946-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Data-Phrasebook-Loader-YAML|0.09||0|||200703011441
425925|425925-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Data-Phrasebook-Loader-XML|0.12||0|||200703011434
425914|425914-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Data-Phrasebook-Loader-Ini|0.10||0|||200703011431
425894|425894-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Data-Phrasebook|0.28||0|||200703011416
425878|425878-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Data-Phrasebook-Loader-DBI|0.11||0|||200703011358
425601|425601-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Test-YAML-Meta|0.02|i686-linux|5.8.8|linux|2.4.27-3-686|200703011038
425511|425511-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i386-openbsd|5.8.8|openbsd|4.0|200703010939
425509|425509-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i386-openbsd|5.8.8|openbsd|4.0|200703010937
425508|425508-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-openbsd|5.8.8|openbsd|4.0|200703010936
425507|425507-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-openbsd|5.8.8|openbsd|4.0|200703010935
425505|425505-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-openbsd|5.8.8|openbsd|4.0|200703010933
425500|425500-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-openbsd|5.8.8|openbsd|4.0|200703010931
425275|425275-b19f-3f77-b713-d32bba55d77f|cpan|200703|BARBIE|Test-YAML-Meta|0.03||0|||200703010841
424934|424934-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282251
424933|424933-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282250
424931|424931-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282249
424930|424930-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282248
424929|424929-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282247
424928|424928-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282247
424927|424927-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282246
424926|424926-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282242
424924|424924-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702282237
424722|424722-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Test-YAML-Meta|0.02|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702281457
424617|424617-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Test-YAML-Meta|0.01|i686-linux|5.8.8|linux|2.4.27-3-686|200702281620
424442|424442-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Test-YAML-Meta|0.01|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702281438
424143|424143-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Test-YAML-Meta|0.02|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702280908
424142|424142-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Test-YAML-Meta|0.01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702280905
424095|424095-b19f-3f77-b713-d32bba55d77f|pass|200702|corion-cpanplus@corion.net|Data-Phrasebook-Loader-YAML|0.08|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280832
424094|424094-b19f-3f77-b713-d32bba55d77f|pass|200702|corion-cpanplus@corion.net|Data-Phrasebook-Loader-XML|0.11|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280831
424093|424093-b19f-3f77-b713-d32bba55d77f|pass|200702|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.09|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280831
424092|424092-b19f-3f77-b713-d32bba55d77f|pass|200702|corion-cpanplus@corion.net|Data-Phrasebook-Loader-DBI|0.10|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280830
424091|424091-b19f-3f77-b713-d32bba55d77f|pass|200702|corion-cpanplus@corion.net|Data-Phrasebook|0.27|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280830
423420|423420-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Test-YAML-Meta|0.02||0|||200702271534
423213|423213-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Test-YAML-Meta|0.01||0|||200702271327
423002|423002-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270759
423001|423001-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270759
423000|423000-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270758
422999|422999-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270758
422997|422997-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270757
422777|422777-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702262303
422775|422775-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702262300
422773|422773-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702262256
422770|422770-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702262253
422764|422764-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702262246
422751|422751-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702262238
422571|422571-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-YAML|0.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702261653
422570|422570-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.11|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702261653
422569|422569-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.09|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702261652
422568|422568-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.10|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702261652
422567|422567-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.27|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702261651
422015|422015-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261031
422014|422014-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261031
422013|422013-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261030
422012|422012-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261030
422011|422011-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261030
421935|421935-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260956
421934|421934-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260955
421932|421932-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260954
421930|421930-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260953
421928|421928-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260952
421926|421926-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260951
421923|421923-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|alpha-freebsd|5.8.7|freebsd|6.0-release|200702260951
421921|421921-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702260949
421918|421918-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702260948
421914|421914-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702260946
421911|421911-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702260944
421378|421378-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251135
421377|421377-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251134
421376|421376-b19f-3f77-b713-d32bba55d77f|fail|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251134
421374|421374-b19f-3f77-b713-d32bba55d77f|fail|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251132
421373|421373-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251130
421371|421371-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251130
421370|421370-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.27|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702251130
420871|420871-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook|0.27|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241352
420864|420864-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.08|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241356
420793|420793-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241543
420791|420791-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241542
420789|420789-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241541
420786|420786-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241541
420785|420785-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241540
420780|420780-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.09|i686-linux|5.6.2|linux|2.4.27-3-686|200702241352
420779|420779-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-XML|0.11|i686-linux|5.6.2|linux|2.4.27-3-686|200702241352
420777|420777-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-YAML|0.07|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241354
420770|420770-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241536
420769|420769-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-Ini|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241402
420763|420763-b19f-3f77-b713-d32bba55d77f|fail|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.09|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241358
420756|420756-b19f-3f77-b713-d32bba55d77f|fail|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-DBI|0.10|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241400
420755|420755-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241532
420695|420695-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook-Loader-XML|0.11|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702241404
420580|420580-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Phrasebook|0.27|i686-linux|5.6.2|linux|2.4.27-3-686|200702241346
420316|420316-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240937
420314|420314-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240936
420313|420313-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240935
420311|420311-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240933
420310|420310-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240932
420308|420308-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240929
420306|420306-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702240926
419992|419992-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702240022
419991|419991-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702240019
419986|419986-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702240015
419985|419985-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702240012
419984|419984-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702240005
419981|419981-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702232358
419800|419800-b19f-3f77-b713-d32bba55d77f|fail|200702|peterson146@gmail.com|Data-Phrasebook-Loader-DBI|0.09|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200702230709
419799|419799-b19f-3f77-b713-d32bba55d77f|pass|200702|peterson146@gmail.com|Data-Phrasebook|0.26|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200702230709
419784|419784-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Data-Phrasebook-Loader-XML|0.11|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702231439
419783|419783-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.09|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702231438
419782|419782-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Data-Phrasebook-Loader-YAML|0.08|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702231439
419781|419781-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.10|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702231438
419780|419780-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Data-Phrasebook|0.27|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702231438
419703|419703-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702230046
419702|419702-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702230045
419701|419701-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702230045
419700|419700-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702230044
419699|419699-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702230043
419698|419698-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702230043
419682|419682-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702230025
419681|419681-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702230024
419680|419680-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702230022
419678|419678-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702230021
419677|419677-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-XML|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702230021
419676|419676-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702230020
419675|419675-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-Ini|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702230020
419674|419674-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702230020
419673|419673-b19f-3f77-b713-d32bba55d77f|fail|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-DBI|0.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702230019
419672|419672-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702230018
419671|419671-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702230018
419532|419532-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702222320
419515|419515-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702222318
419514|419514-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Phrasebook|0.27|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702222313
418984|418984-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook-Loader-XML|0.11||0|||200702221909
418975|418975-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook-Loader-Ini|0.09||0|||200702221901
418970|418970-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook-Loader-DBI|0.10||0|||200702221858
418965|418965-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook-Loader-DBI|0.09||0|||200702221850
418962|418962-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook-Loader-YAML|0.08||0|||200702221842
418958|418958-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook-Loader-YAML|0.07||0|||200702221831
418953|418953-b19f-3f77-b713-d32bba55d77f|cpan|200702|BARBIE|Data-Phrasebook|0.27||0|||200702221743
418395|418395-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Finance-Currency-Convert-XE|0.11|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702211203
408795|408795-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311923
408794|408794-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311922
408477|408477-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-openbsd|5.8.8|openbsd|4.0|200701311210
408476|408476-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-openbsd|5.8.8|openbsd|4.0|200701311209
407785|407785-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701301320
407783|407783-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701301319
407742|407742-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|alpha-freebsd|5.8.7|freebsd|6.0-release|200701301306
407741|407741-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|alpha-freebsd|5.8.7|freebsd|6.0-release|200701301305
407356|407356-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701292253
407355|407355-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701292252
407265|407265-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701292011
407264|407264-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701292011
407003|407003-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701291451
407001|407001-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701291451
406948|406948-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701291352
406947|406947-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701291351
403032|403032-b19f-3f77-b713-d32bba55d77f|fail|200701|james@mastros.biz|Finance-Currency-Convert-XE|0.11|i486-linux-gnu|5.8.8|linux|2.6.18.3|200701220211
398012|398012-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|CPAN-WWW-Testers|0.31|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701111113
375951|375951-b19f-3f77-b713-d32bba55d77f|pass|200611|jrockway@cpan.org|CPAN-WWW-Testers|0.31|i486-linux-gnu|5.8.8|linux|2.6.15-1-686|200611201057
373925|373925-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200611151804
373924|373924-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook|0.26|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200611151804
373675|373675-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200611150942
373674|373674-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook|0.26|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200611150942
373550|373550-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200611150803
373549|373549-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200611150803
373466|373466-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200611150000
373465|373465-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200611150000
373460|373460-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200611142344
373459|373459-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200611142343
369122|369122-b19f-3f77-b713-d32bba55d77f|cpan|200611|LBROCARD|CPAN-WWW-Testers|0.31||0|||200611041934
361635|361635-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181328
361634|361634-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181328
361382|361382-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181113
361381|361381-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181112
361373|361373-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181059
361301|361301-b19f-3f77-b713-d32bba55d77f|pass|200610|jrockway@cpan.org|CPAN-WWW-Testers|0.30|i486-linux-gnu|5.8.8|linux|2.6.15-1-686|200610171451
360376|360376-b19f-3f77-b713-d32bba55d77f|pass|200610|corion-cpanplus@corion.net|WWW-Scraper-ISBN-ORA_Driver|0.07|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200610151219
360375|360375-b19f-3f77-b713-d32bba55d77f|pass|200610|corion-cpanplus@corion.net|WWW-Scraper-ISBN-Amazon_Driver|0.06|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200610151218
360374|360374-b19f-3f77-b713-d32bba55d77f|pass|200610|corion-cpanplus@corion.net|Finance-Currency-Convert-XE|0.11|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200610151217
359368|359368-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.07|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610121916
359367|359367-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.06|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610121908
359361|359361-b19f-3f77-b713-d32bba55d77f|pass|200610|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200610130156
359341|359341-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.11|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610121846
358989|358989-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.11|alpha-freebsd|5.8.7|freebsd|6.0-release|200610121152
358799|358799-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200610120925
358794|358794-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200610120923
358716|358716-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-Amazon_Driver|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200610120355
358706|358706-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|WWW-Scraper-ISBN-ORA_Driver|0.07|i486-linux|5.8.4|linux|2.4.26|200610120218
358701|358701-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Finance-Currency-Convert-XE|0.11|i486-linux|5.8.4|linux|2.4.26|200610120118
358487|358487-b19f-3f77-b713-d32bba55d77f|cpan|200610|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.06||0|||200610111729
358415|358415-b19f-3f77-b713-d32bba55d77f|cpan|200610|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.07||0|||200610111531
358371|358371-b19f-3f77-b713-d32bba55d77f|cpan|200610|BARBIE|Finance-Currency-Convert-XE|0.11||0|||200610111442
357383|357383-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-freebsd-64int|5.8.5|freebsd|5.3-release|200610091554
357382|357382-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-freebsd-64int|5.8.5|freebsd|5.3-release|200610091554
356851|356851-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610090109
356850|356850-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook|0.26|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610090109
355466|355466-b19f-3f77-b713-d32bba55d77f|fail|200610|corion-cpanplus@corion.net|Mail-Outlook|0.10|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200610042213
355465|355465-b19f-3f77-b713-d32bba55d77f|pass|200610|corion-cpanplus@corion.net|Data-Phrasebook-Loader-YAML|0.06|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200610042213
355453|355453-b19f-3f77-b713-d32bba55d77f|pass|200610|corion-cpanplus@corion.net|Data-Phrasebook|0.26|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200610042212
354788|354788-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|alpha-freebsd|5.8.7|freebsd|6.0-release|200610031858
354787|354787-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook|0.26|alpha-freebsd|5.8.7|freebsd|6.0-release|200610031857
353870|353870-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i486-linux|5.8.4|linux|2.4.26|200610021422
353869|353869-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i486-linux|5.8.4|linux|2.4.26|200610021421
353676|353676-b19f-3f77-b713-d32bba55d77f|pass|200610|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-YAML|0.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200610020411
353674|353674-b19f-3f77-b713-d32bba55d77f|pass|200610|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.26|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200610020411
353433|353433-b19f-3f77-b713-d32bba55d77f|pass|200610|saper@cpan.org|Data-Phrasebook-Loader-YAML|0.06|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200610010237
353432|353432-b19f-3f77-b713-d32bba55d77f|pass|200610|saper@cpan.org|Data-Phrasebook|0.26|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200610010237
353167|353167-b19f-3f77-b713-d32bba55d77f|cpan|200609|BARBIE|Mail-Outlook|0.10||0|||200609291449
353090|353090-b19f-3f77-b713-d32bba55d77f|pass|200609|chris@bingosnet.co.uk|Data-Phrasebook-Loader-YAML|0.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200609290722
353089|353089-b19f-3f77-b713-d32bba55d77f|pass|200609|chris@bingosnet.co.uk|Data-Phrasebook|0.25|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200609290722
353088|353088-b19f-3f77-b713-d32bba55d77f|pass|200609|chris@bingosnet.co.uk|Data-Phrasebook|0.26|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200609290722
352948|352948-b19f-3f77-b713-d32bba55d77f|cpan|200609|BARBIE|Data-Phrasebook-Loader-YAML|0.06||0|||200609282359
352947|352947-b19f-3f77-b713-d32bba55d77f|cpan|200609|BARBIE|Data-Phrasebook|0.26||0|||200609282353
351791|351791-b19f-3f77-b713-d32bba55d77f|fail|200609|gabor@pti.co.il ("Gabor Szabo")|WWW-UsePerl-Journal|0.14|i486-linux-gnu|5.8.7|linux|2.6.10|200609251544
351789|351789-b19f-3f77-b713-d32bba55d77f|pass|200609|gabor@pti.co.il ("Gabor Szabo")|Calendar-List|0.17|i486-linux-gnu|5.8.7|linux|2.6.10|200609251542
351787|351787-b19f-3f77-b713-d32bba55d77f|pass|200609|gabor@pti.co.il ("Gabor Szabo")|Mail-File|0.07|i486-linux-gnu|5.8.7|linux|2.6.10|200609251542
351784|351784-b19f-3f77-b713-d32bba55d77f|pass|200609|gabor@pti.co.il ("Gabor Szabo")|Data-Phrasebook|0.25|i486-linux-gnu|5.8.7|linux|2.6.10|200609251538
341641|341641-b19f-3f77-b713-d32bba55d77f|fail|200608|mthurn@cpan.org|CPAN-WWW-Testers|0.30|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200608061744
340437|340437-b19f-3f77-b713-d32bba55d77f|fail|200608|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.30|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200608031334
339905|339905-b19f-3f77-b713-d32bba55d77f|pass|200608|saper@cpan.org|CPAN-WWW-Testers|0.30|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200608020937
339319|339319-b19f-3f77-b713-d32bba55d77f|fail|200607|Perl_Test@LogicalChaos.org|CPAN-WWW-Testers|0.30|i386-linux|5.8.7|linux|2.6.12-8mdksmp|200607310057
339177|339177-b19f-3f77-b713-d32bba55d77f|cpan|200607|LBROCARD|CPAN-WWW-Testers|0.30||0|||200607301026
336980|336980-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607270121
336486|336486-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Calendar-List|0.17|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607261219
336046|336046-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.14|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607252131
336043|336043-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607252130
335690|335690-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607251519
335104|335104-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607242224
335084|335084-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607242209
335083|335083-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607242207
335082|335082-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.25|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607242207
335076|335076-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607242159
334473|334473-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.25|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607240301
333810|333810-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607231311
332602|332602-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Calendar-List|0.17|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607211720
331486|331486-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.24|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607200715
330474|330474-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607191058
330472|330472-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.23|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607191057
330216|330216-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607190319
329422|329422-b19f-3f77-b713-d32bba55d77f|fail|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607172257
327688|327688-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.25|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607102051
321536|321536-b19f-3f77-b713-d32bba55d77f|pass|200606|saper@cpan.org|CPAN-WWW-Testers|0.29|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200606061049
316204|316204-b19f-3f77-b713-d32bba55d77f|pass|200605|leeym@utopia.leeym.com ((Yen-Ming Lee))|Finance-Currency-Convert-XE|0.10|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200605221221
303638|303638-b19f-3f77-b713-d32bba55d77f|pass|200603|corion-cpanplus@corion.net|Data-Phrasebook|0.25|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200603291906
303294|303294-b19f-3f77-b713-d32bba55d77f|pass|200603|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.25|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200603281723
301718|301718-b19f-3f77-b713-d32bba55d77f|pass|200603|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.25|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.6.14.3|200603232350
301642|301642-b19f-3f77-b713-d32bba55d77f|pass|200603|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.25|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200603231856
301591|301591-b19f-3f77-b713-d32bba55d77f|pass|200603|Perl_Test@LogicalChaos.org|Data-Phrasebook|0.25|i386-linux|5.8.7|linux|2.6.12-8mdksmp|200603230636
296346|296346-b19f-3f77-b713-d32bba55d77f|pass|200603|mthurn@cpan.org|CPAN-WWW-Testers|0.29|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200603100323
291720|291720-b19f-3f77-b713-d32bba55d77f|pass|200602|imacat@mail.imacat.idv.tw|Finance-Currency-Convert-XE|0.10|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.6.14.3|200602212201
287213|287213-b19f-3f77-b713-d32bba55d77f|pass|200602|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.29|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200602011532
286763|286763-b19f-3f77-b713-d32bba55d77f|cpan|200601|LBROCARD|CPAN-WWW-Testers|0.29||0|||200601311111
284678|284678-b19f-3f77-b713-d32bba55d77f|pass|200601|leeym@utopia.leeym.com ((Yen-Ming Lee))|Finance-Currency-Convert-XE|0.10|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200601220909
284457|284457-b19f-3f77-b713-d32bba55d77f|pass|200601|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Finance-Currency-Convert-XE|0.10|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200601210957
284361|284361-b19f-3f77-b713-d32bba55d77f|pass|200601|leeym@utopia.leeym.com ((Yen-Ming Lee))|Finance-Currency-Convert-XE|0.10|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200601210456
283692|283692-b19f-3f77-b713-d32bba55d77f|pass|200601|saper@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.04|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200601180247
283689|283689-b19f-3f77-b713-d32bba55d77f|pass|200601|saper@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.04|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200601180247
283688|283688-b19f-3f77-b713-d32bba55d77f|pass|200601|saper@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.04|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200601180247
280460|280460-b19f-3f77-b713-d32bba55d77f|pass|200601|nicolaw@cpan.org|Finance-Currency-Convert-XE|0.10|i686-linux|5.8.7|linux|2.4.21-20.el|200601040027
280459|280459-b19f-3f77-b713-d32bba55d77f|pass|200601|nicolaw@cpan.org|Finance-Currency-Convert-XE|0.10|i386-linux|5.8.5|linux|2.4.21-27.0.2.elsmp|200601040028
272687|272687-b19f-3f77-b713-d32bba55d77f|pass|200512|david@landgren.net|Calendar-List|0.17|i386-freebsd-64int|5.8.6|freebsd|5.2.1-release|200512021706
272254|272254-b19f-3f77-b713-d32bba55d77f|pass|200512|njh@despammed.com|Data-Phrasebook|0.25|i386-linux|5.8.6|linux|2.6.9-22.elsmp|200512010603
271471|271471-b19f-3f77-b713-d32bba55d77f|pass|200511|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.25|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200511292002
271278|271278-b19f-3f77-b713-d32bba55d77f|pass|200511|njh@despammed.com|Data-Phrasebook|0.25|darwin-thread-multi|5.8.7|darwin|5.5|200511272036
271277|271277-b19f-3f77-b713-d32bba55d77f|fail|200511|njh@despammed.com|Calendar-List|0.17|darwin-thread-multi|5.8.7|darwin|5.5|200511272036
270664|270664-b19f-3f77-b713-d32bba55d77f|pass|200511|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.25|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200511241604
270622|270622-b19f-3f77-b713-d32bba55d77f|pass|200511|njh@despammed.com|Calendar-List|0.17|i386-linux|5.8.6|linux|2.6.9-22.elsmp|200511240635
270423|270423-b19f-3f77-b713-d32bba55d77f|pass|200511|saper@cpan.org|Calendar-List|0.17|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200511240001
270411|270411-b19f-3f77-b713-d32bba55d77f|pass|200511|saper@cpan.org|Data-Phrasebook|0.25|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200511240000
270395|270395-b19f-3f77-b713-d32bba55d77f|pass|200511|saper@cpan.org|Data-Phrasebook|0.25|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200511232354
270227|270227-b19f-3f77-b713-d32bba55d77f|cpan|200511|BARBIE|Data-Phrasebook|0.25||0|||200511222348
269868|269868-b19f-3f77-b713-d32bba55d77f|pass|200511|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.17|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200511210752
269787|269787-b19f-3f77-b713-d32bba55d77f|pass|200511|imacat@mail.imacat.idv.tw|Calendar-List|0.17|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200511210113
269780|269780-b19f-3f77-b713-d32bba55d77f|pass|200511|imacat@mail.imacat.idv.tw|Calendar-List|0.17|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200511210109
269633|269633-b19f-3f77-b713-d32bba55d77f|pass|200511|njh@despammed.com|Calendar-List|0.17|i486-linux-gnu|5.8.7|linux|2.6.14-rc4|200511200037
269475|269475-b19f-3f77-b713-d32bba55d77f|pass|200511|leeym@utopia.leeym.com ((Yen-Ming Lee))|Calendar-List|0.17|i386-freebsd-thread-multi-64int|5.8.7|freebsd|6.0-stable|200511191215
269415|269415-b19f-3f77-b713-d32bba55d77f|cpan|200511|BARBIE|Calendar-List|0.17||0|||200511181807
259452|259452-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Data-Phrasebook|0.24|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200510140302
259451|259451-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Data-Phrasebook-Loader-XML|0.10|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200510140302
259227|259227-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Data-Phrasebook-Loader-XML|0.10|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510140051
259226|259226-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.08|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510140051
259225|259225-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Data-Phrasebook|0.24|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510140051
259085|259085-b19f-3f77-b713-d32bba55d77f|fail|200510|saper@cpan.org|WWW-UsePerl-Journal|0.14|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510132352
259081|259081-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|WWW-Scraper-ISBN-ORA_Driver|0.06|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510132347
253066|253066-b19f-3f77-b713-d32bba55d77f|pass|200509|corion-cpanplus@corion.net|WWW-UsePerl-Journal|0.14|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200509272013
253065|253065-b19f-3f77-b713-d32bba55d77f|pass|200509|corion-cpanplus@corion.net|Data-Phrasebook-Loader-DBI|0.08|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200509272012
253064|253064-b19f-3f77-b713-d32bba55d77f|pass|200509|corion-cpanplus@corion.net|Data-Phrasebook|0.24|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200509272011
252341|252341-b19f-3f77-b713-d32bba55d77f|pass|200509|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.14|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200509260936
252338|252338-b19f-3f77-b713-d32bba55d77f|pass|200509|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.10|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200509260933
252337|252337-b19f-3f77-b713-d32bba55d77f|pass|200509|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.08|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200509260932
252336|252336-b19f-3f77-b713-d32bba55d77f|pass|200509|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.24|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200509260930
251999|251999-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|WWW-UsePerl-Journal|0.14|i386-freebsd|5.8.6|freebsd|5.4-stable|200509251857
251998|251998-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|WWW-UsePerl-Journal|0.14|i386-freebsd|5.8.5|freebsd|5.4-stable|200509251856
251997|251997-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|WWW-UsePerl-Journal|0.14|i386-freebsd|5.8.4|freebsd|5.4-stable|200509251855
251994|251994-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|WWW-UsePerl-Journal|0.14|i386-freebsd|5.8.3|freebsd|5.4-stable|200509251854
251993|251993-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|WWW-UsePerl-Journal|0.14|i386-freebsd|5.8.2|freebsd|5.4-stable|200509251853
251992|251992-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|WWW-UsePerl-Journal|0.14|i386-freebsd|5.8.1|freebsd|5.4-stable|200509251852
251511|251511-b19f-3f77-b713-d32bba55d77f|pass|200509|njh@despammed.com|WWW-UsePerl-Journal|0.14|i386-linux|5.8.7|linux|2.4.27-ti1211|200509250028
251510|251510-b19f-3f77-b713-d32bba55d77f|pass|200509|njh@despammed.com|Data-Phrasebook-Loader-XML|0.10|i386-linux|5.8.7|linux|2.4.27-ti1211|200509250027
251509|251509-b19f-3f77-b713-d32bba55d77f|fail|200509|njh@despammed.com|Data-Phrasebook-Loader-DBI|0.08|i386-linux|5.8.7|linux|2.4.27-ti1211|200509250026
251508|251508-b19f-3f77-b713-d32bba55d77f|pass|200509|njh@despammed.com|Data-Phrasebook|0.24|i386-linux|5.8.7|linux|2.4.27-ti1211|200509250026
250701|250701-b19f-3f77-b713-d32bba55d77f|pass|200509|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.14|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200509240617
250595|250595-b19f-3f77-b713-d32bba55d77f|pass|200509|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.14|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200509240432
250111|250111-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook-Loader-XML|0.10|i386-freebsd|5.8.6|freebsd|5.4-stable|200509231512
250110|250110-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook-Loader-XML|0.10|i386-freebsd|5.8.5|freebsd|5.4-stable|200509231511
250109|250109-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook-Loader-XML|0.10|i386-freebsd|5.8.4|freebsd|5.4-stable|200509231510
250108|250108-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook-Loader-XML|0.10|i386-freebsd|5.8.3|freebsd|5.4-stable|200509231510
250107|250107-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook-Loader-XML|0.10|i386-freebsd|5.8.2|freebsd|5.4-stable|200509231509
250106|250106-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook-Loader-XML|0.10|i386-freebsd|5.8.1|freebsd|5.4-stable|200509231508
250105|250105-b19f-3f77-b713-d32bba55d77f|fail|200509|david@landgren.net|Data-Phrasebook-Loader-DBI|0.07|i386-freebsd|5.8.6|freebsd|5.4-stable|200509231507
250104|250104-b19f-3f77-b713-d32bba55d77f|fail|200509|david@landgren.net|Data-Phrasebook-Loader-DBI|0.07|i386-freebsd|5.8.5|freebsd|5.4-stable|200509231506
250103|250103-b19f-3f77-b713-d32bba55d77f|fail|200509|david@landgren.net|Data-Phrasebook-Loader-DBI|0.07|i386-freebsd|5.8.4|freebsd|5.4-stable|200509231506
250099|250099-b19f-3f77-b713-d32bba55d77f|fail|200509|david@landgren.net|Data-Phrasebook-Loader-DBI|0.07|i386-freebsd|5.8.3|freebsd|5.4-stable|200509231505
250096|250096-b19f-3f77-b713-d32bba55d77f|fail|200509|david@landgren.net|Data-Phrasebook-Loader-DBI|0.07|i386-freebsd|5.8.2|freebsd|5.4-stable|200509231505
250093|250093-b19f-3f77-b713-d32bba55d77f|fail|200509|david@landgren.net|Data-Phrasebook-Loader-DBI|0.07|i386-freebsd|5.8.1|freebsd|5.4-stable|200509231504
250092|250092-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.23|i386-freebsd|5.8.1|freebsd|5.4-stable|200509231504
250091|250091-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.24|i386-freebsd|5.8.6|freebsd|5.4-stable|200509231503
250090|250090-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.24|i386-freebsd|5.8.5|freebsd|5.4-stable|200509231502
250089|250089-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.24|i386-freebsd|5.8.4|freebsd|5.4-stable|200509231502
250088|250088-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.24|i386-freebsd|5.8.3|freebsd|5.4-stable|200509231501
250087|250087-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.24|i386-freebsd|5.8.2|freebsd|5.4-stable|200509231500
250086|250086-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Phrasebook|0.24|i386-freebsd|5.8.1|freebsd|5.4-stable|200509231459
249958|249958-b19f-3f77-b713-d32bba55d77f|pass|200509|leeym@utopia.leeym.com ((Yen-Ming Lee))|WWW-UsePerl-Journal|0.14|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200509231813
249243|249243-b19f-3f77-b713-d32bba55d77f|pass|200509|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.24|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200509230946
249011|249011-b19f-3f77-b713-d32bba55d77f|cpan|200509|BARBIE|WWW-UsePerl-Journal|0.14||0|||200509230105
248890|248890-b19f-3f77-b713-d32bba55d77f|fail|200509|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.08|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200509230155
248889|248889-b19f-3f77-b713-d32bba55d77f|pass|200509|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.24|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200509230154
248782|248782-b19f-3f77-b713-d32bba55d77f|cpan|200509|BARBIE|Data-Phrasebook-Loader-DBI|0.08||0|||200509221641
248781|248781-b19f-3f77-b713-d32bba55d77f|cpan|200509|BARBIE|Data-Phrasebook-Loader-XML|0.10||0|||200509221639
248780|248780-b19f-3f77-b713-d32bba55d77f|cpan|200509|BARBIE|Data-Phrasebook|0.24||0|||200509221637
244768|244768-b19f-3f77-b713-d32bba55d77f|pass|200509|njh@despammed.com|WWW-Scraper-ISBN-ORA_Driver|0.06|mips-linux|5.8.4|linux|2.4.25-r4k-ip22|200509171936
243479|243479-b19f-3f77-b713-d32bba55d77f|fail|200509|corion-cpanplus@corion.net|WWW-Scraper-ISBN-ORA_Driver|0.06|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200509142036
242950|242950-b19f-3f77-b713-d32bba55d77f|pass|200509|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-ORA_Driver|0.06|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200509130728
242840|242840-b19f-3f77-b713-d32bba55d77f|cpan|200509|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.06||0|||200509121526
235909|235909-b19f-3f77-b713-d32bba55d77f|pass|200508|michael_lee_squires@pobox.com|Regexp-Log-Common|0.04|i386-linux|5.8.6|linux|2.4.21-27.0.2.elsmp|200508210037
233850|233850-b19f-3f77-b713-d32bba55d77f|fail|200508|corion-cpanplus@corion.net|Mail-Outlook|0.09|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200508141727
233849|233849-b19f-3f77-b713-d32bba55d77f|pass|200508|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.08|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200508141726
233848|233848-b19f-3f77-b713-d32bba55d77f|pass|200508|corion-cpanplus@corion.net|Data-Phrasebook|0.23|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200508141726
233259|233259-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.09|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508112104
233257|233257-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.08|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508112052
233256|233256-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.09|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200508112050
233252|233252-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508112049
233243|233243-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.08|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200508112045
233242|233242-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.23|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508112044
233241|233241-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.23|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200508112042
233240|233240-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Mail-Outlook|0.09|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508112040
233239|233239-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Mail-Outlook|0.09|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200508112039
233194|233194-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.08|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508111954
233193|233193-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508111954
233192|233192-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.23|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508111953
233116|233116-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.08|sun4-solaris|5.8.5|solaris|2.9|200508111122
233115|233115-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook-Loader-XML|0.09|sun4-solaris|5.8.5|solaris|2.9|200508111121
233114|233114-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook|0.23|sun4-solaris|5.8.5|solaris|2.9|200508111121
233072|233072-b19f-3f77-b713-d32bba55d77f|pass|200508|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.09|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200508110755
233071|233071-b19f-3f77-b713-d32bba55d77f|pass|200508|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.08|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200508110754
233070|233070-b19f-3f77-b713-d32bba55d77f|pass|200508|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.23|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200508110754
232951|232951-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.08|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200508110049
232950|232950-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook-Loader-XML|0.09|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200508110048
232949|232949-b19f-3f77-b713-d32bba55d77f|fail|200508|saper@cpan.org|Data-Phrasebook|0.23|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200508110048
232826|232826-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.08|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200508102354
232824|232824-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook-Loader-XML|0.09|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200508102353
232823|232823-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Data-Phrasebook|0.23|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200508102353
232556|232556-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook-Loader-Ini|0.08|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508101751
232555|232555-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.23|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508101751
232554|232554-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.23|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508101749
232466|232466-b19f-3f77-b713-d32bba55d77f|cpan|200508|BARBIE|Data-Phrasebook-Loader-XML|0.09||0|||200508100104
232451|232451-b19f-3f77-b713-d32bba55d77f|cpan|200508|BARBIE|Data-Phrasebook-Loader-Ini|0.08||0|||200508100043
232450|232450-b19f-3f77-b713-d32bba55d77f|cpan|200508|BARBIE|Data-Phrasebook|0.23||0|||200508100041
232425|232425-b19f-3f77-b713-d32bba55d77f|cpan|200508|BARBIE|Mail-Outlook|0.09||0|||200508092330
230089|230089-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|WWW-UsePerl-Journal|0.13|sun4-solaris|5.8.5|solaris|2.9|200508021205
229553|229553-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|WWW-UsePerl-Journal|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508011924
228090|228090-b19f-3f77-b713-d32bba55d77f|pass|200507|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.13|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200507272053
227985|227985-b19f-3f77-b713-d32bba55d77f|pass|200507|imacat@mail.imacat.idv.tw|WWW-UsePerl-Journal|0.13|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200507271110
227926|227926-b19f-3f77-b713-d32bba55d77f|pass|200507|corion-cpanplus@corion.net|WWW-UsePerl-Journal|0.13|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200507261811
227834|227834-b19f-3f77-b713-d32bba55d77f|fail|200507|saper@cpan.org|WWW-UsePerl-Journal|0.13|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200507261122
227719|227719-b19f-3f77-b713-d32bba55d77f|pass|200507|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.13|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200507260700
227663|227663-b19f-3f77-b713-d32bba55d77f|cpan|200507|BARBIE|WWW-UsePerl-Journal|0.13||0|||200507260040
221102|221102-b19f-3f77-b713-d32bba55d77f|pass|200507|mthurn@cpan.org|CPAN-WWW-Testers|0.28|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200507040340
221098|221098-b19f-3f77-b713-d32bba55d77f|fail|200507|mthurn@cpan.org|CPAN-WWW-Testers|0.28|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200507040336
218016|218016-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.07|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221424
218015|218015-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.07|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221424
218014|218014-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook|0.22|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221423
217999|217999-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.07|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221403
217998|217998-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.07|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221403
217997|217997-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook|0.22|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221402
217970|217970-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.07|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221238
217969|217969-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.07|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221237
217968|217968-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook|0.22|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506221236
217688|217688-b19f-3f77-b713-d32bba55d77f|pass|200506|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.07|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506211817
217686|217686-b19f-3f77-b713-d32bba55d77f|pass|200506|corion-cpanplus@corion.net|Data-Phrasebook-Loader-DBI|0.07|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506211817
217685|217685-b19f-3f77-b713-d32bba55d77f|pass|200506|corion-cpanplus@corion.net|Data-Phrasebook|0.22|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506211816
217186|217186-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|CPAN-WWW-Testers|0.28|sun4-solaris|5.8.5|solaris|2.9|200506201052
217178|217178-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.07|sun4-solaris|5.8.5|solaris|2.9|200506201010
216980|216980-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|CPAN-WWW-Testers|0.28|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506191638
216837|216837-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.07|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506182006
216759|216759-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.07|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200506182108
216755|216755-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.07|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506182019
216594|216594-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers|0.28|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506172012
216410|216410-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.28|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506170654
216398|216398-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.07|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506170618
216385|216385-b19f-3f77-b713-d32bba55d77f|pass|200506|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.22|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200506171233
216323|216323-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|CPAN-WWW-Testers|0.28|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506162040
216314|216314-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-DBI|0.07||0|||200506161924
216296|216296-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.08|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162350
216295|216295-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.06|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162349
216294|216294-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.07|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162348
216277|216277-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.08|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506162333
216273|216273-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.07|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506162332
216267|216267-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.06|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200506162331
216264|216264-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.07|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200506162331
216249|216249-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.07|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162324
216247|216247-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.06|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162324
216244|216244-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.05|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162323
216240|216240-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.07|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506162321
216237|216237-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.06|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506162320
216235|216235-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506162319
216230|216230-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506162317
216224|216224-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-Ini|0.06|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200506162316
216223|216223-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-DBI|0.05|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200506162316
216222|216222-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.22|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200506162315
216175|216175-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.06|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506161540
216174|216174-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.05|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506161540
216173|216173-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook|0.21|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506161539
216172|216172-b19f-3f77-b713-d32bba55d77f|pass|200506|rrwo@cpan.org|Data-Phrasebook|0.22|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200506161539
216170|216170-b19f-3f77-b713-d32bba55d77f|cpan|200506|LBROCARD|CPAN-WWW-Testers|0.28||0|||200506161549
216116|216116-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-XML|0.08|sun4-solaris|5.8.5|solaris|2.9|200506160928
216114|216114-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.07|sun4-solaris|5.8.5|solaris|2.9|200506160928
216113|216113-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.06|sun4-solaris|5.8.5|solaris|2.9|200506160927
216102|216102-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.08|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506160659
216101|216101-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.07|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506160657
216100|216100-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.06|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506160654
216069|216069-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.07|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506160111
216068|216068-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-XML|0.08|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506160111
216067|216067-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.06|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506160111
216066|216066-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook|0.22|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506160110
215942|215942-b19f-3f77-b713-d32bba55d77f|fail|200506|imacat@mail.imacat.idv.tw|CPAN-WWW-Testers|0.27|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200506152137
215865|215865-b19f-3f77-b713-d32bba55d77f|fail|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.27|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506151200
215851|215851-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.07|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506151126
215850|215850-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-Ini|0.06|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506151124
215849|215849-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-DBI|0.05|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506151123
215848|215848-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.22|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506151121
215843|215843-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-XML|0.08||0|||200506151301
215842|215842-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-DBI|0.06||0|||200506151251
215841|215841-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-Ini|0.07||0|||200506151234
215817|215817-b19f-3f77-b713-d32bba55d77f|fail|200506|saper@cpan.org|CPAN-WWW-Testers|0.27|sun4-solaris|5.8.5|solaris|2.9|200506150858
215808|215808-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-XML|0.07|sun4-solaris|5.8.5|solaris|2.9|200506150850
215807|215807-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook|0.22|sun4-solaris|5.8.5|solaris|2.9|200506150849
215806|215806-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.06|sun4-solaris|5.8.5|solaris|2.9|200506150849
215805|215805-b19f-3f77-b713-d32bba55d77f|fail|200506|saper@cpan.org|Data-Phrasebook-Loader-XML|0.07|sun4-solaris|5.8.5|solaris|2.9|200506150849
215804|215804-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.05|sun4-solaris|5.8.5|solaris|2.9|200506150848
215789|215789-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-XML|0.07||0|||200506142030
215787|215787-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-Ini|0.06||0|||200506142024
215786|215786-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook-Loader-DBI|0.05||0|||200506142024
215776|215776-b19f-3f77-b713-d32bba55d77f|cpan|200506|BARBIE|Data-Phrasebook|0.22||0|||200506142009
215647|215647-b19f-3f77-b713-d32bba55d77f|cpan|200506|LBROCARD|CPAN-WWW-Testers|0.27||0|||200506141143
213200|213200-b19f-3f77-b713-d32bba55d77f|pass|200506|cpantest@dacht.net|CPAN-WWW-Testers|0.26|i386-freebsd|5.8.7|freebsd|5.4-stable|200506062027
211764|211764-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.26|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506022046
211700|211700-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|CPAN-WWW-Testers|0.26|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200506022202
211507|211507-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|CPAN-WWW-Testers|0.26|sun4-solaris|5.8.5|solaris|2.9|200506021115
211230|211230-b19f-3f77-b713-d32bba55d77f|cpan|200505|LBROCARD|CPAN-WWW-Testers|0.26||0|||200505312333
209224|209224-b19f-3f77-b713-d32bba55d77f|pass|200505|rrwo@cpan.org|Data-Phrasebook-Loader-XML|0.06|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200505212359
209223|209223-b19f-3f77-b713-d32bba55d77f|pass|200505|rrwo@cpan.org|Data-Phrasebook|0.21|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200505212358
209218|209218-b19f-3f77-b713-d32bba55d77f|pass|200505|saper@cpan.org|Data-Phrasebook-Loader-XML|0.06|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200505220055
209217|209217-b19f-3f77-b713-d32bba55d77f|pass|200505|saper@cpan.org|Data-Phrasebook|0.21|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200505220055
208918|208918-b19f-3f77-b713-d32bba55d77f|pass|200505|corion-cpanplus@corion.net|Data-Phrasebook|0.21|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200505202137
208868|208868-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.20|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200505210014
208824|208824-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.06|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200505202113
208821|208821-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.21|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200505202112
208809|208809-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Data-Phrasebook-Loader-XML|0.06|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200505202107
208802|208802-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.21|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200505202105
208796|208796-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Data-Phrasebook|0.21|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200505202100
208757|208757-b19f-3f77-b713-d32bba55d77f|pass|200505|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook-Loader-XML|0.06|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200505201208
208756|208756-b19f-3f77-b713-d32bba55d77f|pass|200505|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.20|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200505201207
208755|208755-b19f-3f77-b713-d32bba55d77f|pass|200505|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Phrasebook|0.21|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200505201207
208672|208672-b19f-3f77-b713-d32bba55d77f|pass|200505|saper@cpan.org|Data-Phrasebook-Loader-XML|0.06|sun4-solaris|5.8.5|solaris|2.9|200505201007
208671|208671-b19f-3f77-b713-d32bba55d77f|pass|200505|saper@cpan.org|Data-Phrasebook|0.21|sun4-solaris|5.8.5|solaris|2.9|200505201006
208501|208501-b19f-3f77-b713-d32bba55d77f|cpan|200505|BARBIE|Data-Phrasebook-Loader-XML|0.06||0|||200505192002
208500|208500-b19f-3f77-b713-d32bba55d77f|cpan|200505|BARBIE|Data-Phrasebook|0.21||0|||200505191947
202286|202286-b19f-3f77-b713-d32bba55d77f|pass|200504|corion-cpanplus@corion.net|Regexp-Log-Common|0.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504291913
202168|202168-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|Regexp-Log-Common|0.04|sun4-solaris|5.8.5|solaris|2.9|200504291020
202134|202134-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Regexp-Log-Common|0.04|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504290908
202037|202037-b19f-3f77-b713-d32bba55d77f|pass|200504|corion-cpanplus@corion.net|Finance-Currency-Convert-XE|0.10|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504282315
202028|202028-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|Regexp-Log-Common|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200504282253
202005|202005-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|Finance-Currency-Convert-XE|0.10|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200504282233
201937|201937-b19f-3f77-b713-d32bba55d77f|pass|200504|imacat@mail.imacat.idv.tw|Regexp-Log-Common|0.04|i686-linux-thread-multi-ld|5.8.6|linux|2.4.30|200504282332
201918|201918-b19f-3f77-b713-d32bba55d77f|cpan|200504|BARBIE|Regexp-Log-Common|0.04||0|||200504281559
201728|201728-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Finance-Currency-Convert-XE|0.10|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504281045
201587|201587-b19f-3f77-b713-d32bba55d77f|cpan|200504|BARBIE|Finance-Currency-Convert-XE|0.10||0|||200504271737
199963|199963-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|WWW-UsePerl-Journal-Thread|0.08|sun4-solaris|5.8.5|solaris|2.9|200504201012
199961|199961-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|WWW-UsePerl-Journal|0.12|sun4-solaris|5.8.5|solaris|2.9|200504201011
199821|199821-b19f-3f77-b713-d32bba55d77f|fail|200504|corion-cpanplus@corion.net|WWW-UsePerl-Journal|0.11|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504191644
199820|199820-b19f-3f77-b713-d32bba55d77f|pass|200504|corion-cpanplus@corion.net|WWW-UsePerl-Journal|0.12|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504191644
199796|199796-b19f-3f77-b713-d32bba55d77f|pass|200504|Jost.Krieger@ruhr-uni-bochum.de|WWW-UsePerl-Journal|0.12|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200504190943
199754|199754-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|WWW-UsePerl-Journal|0.12|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504190920
199633|199633-b19f-3f77-b713-d32bba55d77f|cpan|200504|BARBIE|WWW-UsePerl-Journal-Thread|0.08||0|||200504181620
199625|199625-b19f-3f77-b713-d32bba55d77f|cpan|200504|BARBIE|WWW-UsePerl-Journal|0.12||0|||200504181610
198540|198540-b19f-3f77-b713-d32bba55d77f|pass|200504|Jost.Krieger@ruhr-uni-bochum.de|CPAN-WWW-Testers-Generator|0.22|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200504131612
198537|198537-b19f-3f77-b713-d32bba55d77f|pass|200504|Jost.Krieger@ruhr-uni-bochum.de|CPAN-WWW-Testers|0.25|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200504131611
198428|198428-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|CPAN-WWW-Testers|0.25|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200504122010
198399|198399-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|CPAN-WWW-Testers|0.25|sun4-solaris|5.8.5|solaris|2.9|200504121157
198289|198289-b19f-3f77-b713-d32bba55d77f|cpan|200504|LBROCARD|CPAN-WWW-Testers|0.25||0|||200504112302
197154|197154-b19f-3f77-b713-d32bba55d77f|pass|200504|Jost.Krieger@ruhr-uni-bochum.de|Mail-File|0.07|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200504061450
196587|196587-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|Data-Phrasebook-Loader-YAML|0.05|i686-linux|5.8.6|linux|2.6.11.6|200504041753
196585|196585-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|Data-Phrasebook-Loader-XML|0.05|i686-linux|5.8.6|linux|2.6.11.6|200504041753
196583|196583-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|Data-Phrasebook-Loader-Ini|0.05|i686-linux|5.8.6|linux|2.6.11.6|200504041752
196582|196582-b19f-3f77-b713-d32bba55d77f|fail|200504|shlomif@iglu.org.il|Data-Phrasebook-Loader-DBI|0.04|i686-linux|5.8.6|linux|2.6.11.6|200504041751
196581|196581-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|Data-Phrasebook|0.20|i686-linux|5.8.6|linux|2.6.11.6|200504041751
196579|196579-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|CPAN-YACSmoke-Plugin-WebList|0.04|i686-linux|5.8.6|linux|2.6.11.6|200504041750
196578|196578-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|CPAN-YACSmoke-Plugin-NNTPWeb|0.04|i686-linux|5.8.6|linux|2.6.11.6|200504041749
196575|196575-b19f-3f77-b713-d32bba55d77f|pass|200504|shlomif@iglu.org.il|CPAN-YACSmoke-Plugin-NNTP|0.04|i686-linux|5.8.6|linux|2.6.11.6|200504041745
195346|195346-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Mail-Outlook|0.08|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503310008
195345|195345-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-Outlook|0.05|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503310008
194933|194933-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Mail-Outlook|0.08||0|||200503291932
194932|194932-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-Outlook|0.05||0|||200503291930
194778|194778-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Regexp-Log-Common|0.03|sun4-solaris|5.8.5|solaris|2.9|200503291541
194572|194572-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-YAML|0.05|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503282329
194571|194571-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-XML|0.05|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503282328
194570|194570-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.05|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503282328
194569|194569-b19f-3f77-b713-d32bba55d77f|fail|200503|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.04|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503282327
194568|194568-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.04|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503282324
194498|194498-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-YAML|0.05|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503282038
194497|194497-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-XML|0.05|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503282038
194496|194496-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-Ini|0.05|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503282038
194495|194495-b19f-3f77-b713-d32bba55d77f|fail|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-DBI|0.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503282037
194494|194494-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|CPAN-YACSmoke-Plugin-NNTP|0.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503282036
194426|194426-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503282045
194425|194425-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503282045
194401|194401-b19f-3f77-b713-d32bba55d77f|fail|200503|corion-cpanplus@corion.net|Mail-Outlook|0.07|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503282027
194400|194400-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-YAML|0.05|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503282026
194399|194399-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.05|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503282026
194398|194398-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-DBI|0.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503282026
194397|194397-b19f-3f77-b713-d32bba55d77f|fail|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-Outlook|0.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503282026
194395|194395-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-NNTP|0.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503282025
194370|194370-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503281834
194328|194328-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook-Loader-Ini|0.05|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503281648
194324|194324-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook-Loader-XML|0.05|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503281646
194322|194322-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook-Loader-YAML|0.05|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503281645
194321|194321-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Phrasebook|0.20|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503281645
194253|194253-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-YAML|0.05|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503280206
194252|194252-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-XML|0.05|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503280206
194251|194251-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.05|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503280206
194250|194250-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503280206
194241|194241-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Mail-Outlook|0.07||0|||200503272300
194240|194240-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-WebList|0.04||0|||200503272259
194239|194239-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-Outlook|0.04||0|||200503272259
194238|194238-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-NNTPWeb|0.04||0|||200503272259
194237|194237-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-NNTP|0.04||0|||200503272258
194200|194200-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-YAML|0.05||0|||200503271357
194199|194199-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-XML|0.05||0|||200503271356
194198|194198-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-Ini|0.05||0|||200503271356
194197|194197-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-DBI|0.04||0|||200503271356
194130|194130-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Games-Trackword|1.04|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503261910
193750|193750-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Regexp-Log-Common|0.03|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503251606
193749|193749-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Mail-File|0.07|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503251606
193372|193372-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Regexp-Log-Common|0.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503231806
193371|193371-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Mail-File|0.07|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503231806
193370|193370-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Games-Trackword|1.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503231806
193355|193355-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Mail-File|0.06|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503231540
193211|193211-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Regexp-Log-Common|0.03|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503222134
193210|193210-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Mail-File|0.07|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503222134
193151|193151-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Regexp-Log-Common|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503222048
193144|193144-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Mail-File|0.07|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503222047
193138|193138-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Games-Trackword|1.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503222046
193062|193062-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Regexp-Log-Common|0.03|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503221758
193061|193061-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Mail-File|0.07|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503221758
193060|193060-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Games-Trackword|1.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503221758
193017|193017-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Regexp-Log-Common|0.03|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503221947
193004|193004-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Mail-File|0.07|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503221723
193001|193001-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Games-Trackword|1.04|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503221658
192948|192948-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Regexp-Log-Common|0.03||0|||200503220139
192889|192889-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Mail-File|0.06|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503212317
192888|192888-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Games-Trackword|1.03|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503212317
192879|192879-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Mail-File|0.07||0|||200503212315
192877|192877-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Games-Trackword|1.04||0|||200503212250
192765|192765-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Mail-File|0.06|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503211844
192764|192764-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Games-Trackword|1.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503211844
192727|192727-b19f-3f77-b713-d32bba55d77f|pass|200503|david@landgren.net|Calendar-List|0.16|i386-freebsd-64int|5.8.6|freebsd|5.2.1-release|200503211519
192562|192562-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Mail-File|0.06|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503210543
192561|192561-b19f-3f77-b713-d32bba55d77f|pass|200503|leeym@utopia.leeym.com ((Yen-Ming Lee))|Games-Trackword|1.03|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200503210540
192553|192553-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Mail-File|0.06|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503202042
192545|192545-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Games-Trackword|1.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503202032
192311|192311-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Mail-File|0.06||0|||200503201136
192310|192310-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Games-Trackword|1.03||0|||200503201132
188842|188842-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.04|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082125
188841|188841-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.07|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082124
188840|188840-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|WWW-Scraper-ISBN-Amazon_Driver|0.05|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082123
188836|188836-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Regexp-Log-Common|0.02|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082121
188834|188834-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-YAML|0.04|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082120
188833|188833-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-XML|0.04|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082120
188832|188832-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.04|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082119
188831|188831-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.03|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082119
188830|188830-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook|0.20|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082118
188829|188829-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Calendar-List|0.16|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082118
188825|188825-b19f-3f77-b713-d32bba55d77f|fail|200503|rrwo@cpan.org|CPAN-YACSmoke-Plugin-Outlook|0.03|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082104
188824|188824-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.03|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082103
188822|188822-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.03|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200503082100
188332|188332-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-YAML|0.04|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503062117
188329|188329-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-XML|0.04|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503062116
188328|188328-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-Ini|0.04|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503062116
188327|188327-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook-Loader-DBI|0.03|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503062115
188326|188326-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook|0.20|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503062115
188325|188325-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Calendar-List|0.16|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503062114
188062|188062-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-YAML|0.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061831
188061|188061-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-XML|0.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061831
188060|188060-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-Ini|0.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061830
188059|188059-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook-Loader-DBI|0.03|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061830
188058|188058-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Data-Phrasebook|0.20|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061830
188057|188057-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Calendar-List|0.16|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061830
188055|188055-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|CPAN-YACSmoke-Plugin-WebList|0.03|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061829
188054|188054-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|CPAN-YACSmoke-Plugin-NNTPWeb|0.01|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061827
188050|188050-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|CPAN-YACSmoke-Plugin-NNTP|0.03|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061820
188042|188042-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|WWW-Scraper-ISBN-Pearson_Driver|0.07|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061833
188040|188040-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|WWW-Scraper-ISBN-Yahoo_Driver|0.04|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061834
188039|188039-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|WWW-Scraper-ISBN-Amazon_Driver|0.05|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061833
188036|188036-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Regexp-Log-Common|0.02|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061832
188034|188034-b19f-3f77-b713-d32bba55d77f|pass|200503|cpan@calaquendi.net|Finance-Currency-Convert-XE|0.09|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200503061831
187893|187893-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Finance-Currency-Convert-XE|0.09|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503052055
187892|187892-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-YAML|0.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503052055
187891|187891-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.04|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503052054
187890|187890-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-DBI|0.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503052054
187862|187862-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Finance-Currency-Convert-XE|0.09|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503051559
187849|187849-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-YAML|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503051552
187848|187848-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-XML|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503051552
187847|187847-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503051551
187845|187845-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503051551
187844|187844-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook|0.20|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503051551
187730|187730-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook|0.20|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503041840
187729|187729-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Calendar-List|0.16|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503041840
187728|187728-b19f-3f77-b713-d32bba55d77f|fail|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-Outlook|0.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503041840
187727|187727-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-NNTP|0.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503041839
187720|187720-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Finance-Currency-Convert-XE|0.09||0|||200503041715
187714|187714-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-YAML|0.04||0|||200503041645
187711|187711-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-XML|0.04||0|||200503041633
187710|187710-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-Ini|0.04||0|||200503041629
187708|187708-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-DBI|0.03||0|||200503041551
187699|187699-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.03|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503041307
187599|187599-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Data-Phrasebook|0.19|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503032345
187596|187596-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.01|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503032341
187584|187584-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|WWW-Scraper-ISBN-Yahoo_Driver|0.04|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032342
187583|187583-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|WWW-Scraper-ISBN-Pearson_Driver|0.07|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032342
187554|187554-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Finance-Currency-Convert-XE|0.08|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032326
187549|187549-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-XML|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032325
187548|187548-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-YAML|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032325
187547|187547-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook-Loader-Ini|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032325
187546|187546-b19f-3f77-b713-d32bba55d77f|fail|200503|saper@cpan.org|Data-Phrasebook-Loader-DBI|0.02|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032325
187545|187545-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Phrasebook|0.19|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032325
187544|187544-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|CPAN-YACSmoke-Plugin-WebList|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032324
187543|187543-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|CPAN-YACSmoke-Plugin-NNTPWeb|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032323
187541|187541-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|CPAN-YACSmoke-Plugin-NNTP|0.03|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032323
187532|187532-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Calendar-List|0.16|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503032321
187499|187499-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Finance-Currency-Convert-XE|0.08|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032102
187498|187498-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-YAML|0.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032102
187497|187497-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032102
187496|187496-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-DBI|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032101
187495|187495-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook|0.19|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032101
187494|187494-b19f-3f77-b713-d32bba55d77f|fail|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-Outlook|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032101
187493|187493-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|CPAN-YACSmoke-Plugin-NNTP|0.01|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503032101
187486|187486-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook|0.20||0|||200503031937
187418|187418-b19f-3f77-b713-d32bba55d77f|pass|200503|root@ESMTP.bpinet.com ((root at bechet))|Calendar-List|0.15|i386-freebsd-64int|5.8.6|freebsd|5.2.1-release|200503031716
187397|187397-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-WebList|0.03||0|||200503031403
187396|187396-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-Outlook|0.03||0|||200503031356
187395|187395-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-NNTPWeb|0.03||0|||200503031348
187394|187394-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-NNTP|0.03||0|||200503031336
187393|187393-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Calendar-List|0.16||0|||200503031314
187356|187356-b19f-3f77-b713-d32bba55d77f|pass|200503|schubiger@cpan.org ((Steven Schubiger))|CPAN-YACSmoke-Plugin-NNTP|0.01|i386-openbsd|5.8.5|openbsd|3.6|200503030158
187354|187354-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-YAML|0.03||0|||200503030147
187353|187353-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-XML|0.03||0|||200503030147
187352|187352-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-Ini|0.03||0|||200503030145
187351|187351-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook|0.19||0|||200503030143
187323|187323-b19f-3f77-b713-d32bba55d77f|pass|200503|rrwo@cpan.org|Regexp-Log-Common|0.02|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503022323
187321|187321-b19f-3f77-b713-d32bba55d77f|fail|200503|rrwo@cpan.org|Data-Phrasebook|0.18|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503022322
187320|187320-b19f-3f77-b713-d32bba55d77f|fail|200503|rrwo@cpan.org|Calendar-List|0.15|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200503022322
187268|187268-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Regexp-Log-Common|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503022344
187266|187266-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-YAML|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503022343
187265|187265-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook-Loader-Ini|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503022343
187264|187264-b19f-3f77-b713-d32bba55d77f|pass|200503|corion-cpanplus@corion.net|Data-Phrasebook|0.18|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503022343
187263|187263-b19f-3f77-b713-d32bba55d77f|fail|200503|corion-cpanplus@corion.net|Calendar-List|0.15|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200503022343
187242|187242-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Finance-Currency-Convert-XE|0.08||0|||200503021954
187235|187235-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Regexp-Log-Common|0.02|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503021926
187229|187229-b19f-3f77-b713-d32bba55d77f|fail|200503|saper@cpan.org|Data-Phrasebook|0.18|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503021923
187226|187226-b19f-3f77-b713-d32bba55d77f|fail|200503|saper@cpan.org|Calendar-List|0.15|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503021922
187223|187223-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.07||0|||200503021857
187222|187222-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-WebList|0.02||0|||200503021836
187221|187221-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-Outlook|0.02||0|||200503021833
187220|187220-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-NNTPWeb|0.01||0|||200503021829
187219|187219-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|CPAN-YACSmoke-Plugin-NNTP|0.01||0|||200503021826
187217|187217-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.04||0|||200503021806
187200|187200-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-DBI|0.02||0|||200503021758
187181|187181-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-XML|0.02||0|||200503021503
187003|187003-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.05||0|||200503012048
186998|186998-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Calendar-List|0.15||0|||200503011837
186997|186997-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Regexp-Log-Common|0.02||0|||200503011827
186996|186996-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-YAML|0.02||0|||200503011824
186994|186994-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook-Loader-Ini|0.02||0|||200503011820
186991|186991-b19f-3f77-b713-d32bba55d77f|cpan|200503|BARBIE|Data-Phrasebook|0.18||0|||200503011811
183650|183650-b19f-3f77-b713-d32bba55d77f|pass|200502|saper@cpan.org|CPAN-WWW-Testers|0.24|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200502122102
183443|183443-b19f-3f77-b713-d32bba55d77f|pass|200502|saperghis@aacom.fr|CPAN-WWW-Testers|0.24|i386-linux|5.8.3|linux|2.6.0-1mdkenterprise|200502111158
183324|183324-b19f-3f77-b713-d32bba55d77f|cpan|200502|LBROCARD|CPAN-WWW-Testers|0.24||0|||200502102129
183179|183179-b19f-3f77-b713-d32bba55d77f|pass|200502|rrwo@cpan.org|CPAN-WWW-Testers-Generator|0.22|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200502091039
182479|182479-b19f-3f77-b713-d32bba55d77f|pass|200502|saperghis@aacom.fr|CPAN-WWW-Testers-Generator|0.22|i386-linux|5.8.3|linux|2.6.0-1mdkenterprise|200502041413
182475|182475-b19f-3f77-b713-d32bba55d77f|pass|200502|saperghis@aacom.fr|CPAN-WWW-Testers|0.23|i386-linux|5.8.3|linux|2.6.0-1mdkenterprise|200502041413
182432|182432-b19f-3f77-b713-d32bba55d77f|pass|200502|cpantester@thr.msu.edu|Mail-File|0.05|i386-freebsd-64int|5.8.6|freebsd|5.3-stable|200502040610
182373|182373-b19f-3f77-b713-d32bba55d77f|pass|200502|cpantester@thr.msu.edu|Regexp-Log-Common|0.01|i386-freebsd-64int|5.8.6|freebsd|5.3-stable|200502040259
182107|182107-b19f-3f77-b713-d32bba55d77f|pass|200502|saper@cpan.org|CPAN-WWW-Testers-Generator|0.22|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200502032046
182105|182105-b19f-3f77-b713-d32bba55d77f|pass|200502|saper@cpan.org|CPAN-WWW-Testers|0.23|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200502032045
182054|182054-b19f-3f77-b713-d32bba55d77f|cpan|200502|LBROCARD|CPAN-WWW-Testers|0.23||0|||200502031701
182053|182053-b19f-3f77-b713-d32bba55d77f|cpan|200502|LBROCARD|CPAN-WWW-Testers-Generator|0.22||0|||200502031701
181001|181001-b19f-3f77-b713-d32bba55d77f|pass|200501|corion-cpansmoker@corion.net|Mail-File|0.05|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200501271940
181000|181000-b19f-3f77-b713-d32bba55d77f|fail|200501|corion-cpansmoker@corion.net|Mail-Outlook|0.06|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200501271939
180908|180908-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|Mail-Outlook|0.06||0|||200501261855
180907|180907-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|Mail-File|0.05||0|||200501261853
180597|180597-b19f-3f77-b713-d32bba55d77f|pass|200501|corion-cpansmoker@corion.net|Regexp-Log-Common|0.01|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200501241907
180531|180531-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|Regexp-Log-Common|0.01||0|||200501241206
179508|179508-b19f-3f77-b713-d32bba55d77f|pass|200501|rrwo@cpan.org|Finance-Currency-Convert-XE|0.07|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200501191941
178173|178173-b19f-3f77-b713-d32bba55d77f|pass|200501|cpantester@thr.msu.edu|Finance-Currency-Convert-XE|0.07|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501100244
178162|178162-b19f-3f77-b713-d32bba55d77f|pass|200501|cpantester@thr.msu.edu|Calendar-List|0.14|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501100141
177413|177413-b19f-3f77-b713-d32bba55d77f|pass|200501|corion-cpansmoker@corion.net|Calendar-List|0.14|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200501072134
177279|177279-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|Finance-Currency-Convert-XE|0.07||0|||200501071739
177255|177255-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.06||0|||200501071442
177254|177254-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.04||0|||200501071434
177253|177253-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.05||0|||200501071432
177251|177251-b19f-3f77-b713-d32bba55d77f|cpan|200501|BARBIE|Calendar-List|0.14||0|||200501071417
176545|176545-b19f-3f77-b713-d32bba55d77f|pass|200501|cpanplus@urth.org|WWW-Scraper-ISBN-Amazon_Driver|0.03|i386-linux|5.8.4|linux|2.4.27-ti1211|200501010017
156329|156329-b19f-3f77-b713-d32bba55d77f|pass|200409|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Amazon_Driver|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409060730
156328|156328-b19f-3f77-b713-d32bba55d77f|pass|200409|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-ORA_Driver|0.04|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409060731
156320|156320-b19f-3f77-b713-d32bba55d77f|pass|200409|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Yahoo_Driver|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409060730
155847|155847-b19f-3f77-b713-d32bba55d77f|pass|200409|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Pearson_Driver|0.05|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409030812
155715|155715-b19f-3f77-b713-d32bba55d77f|pass|200409|Jost.Krieger+perl@rub.de|WWW-Scraper-ISBN-Yahoo_Driver|0.03|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409030445
155712|155712-b19f-3f77-b713-d32bba55d77f|pass|200409|Jost.Krieger+perl@rub.de|WWW-Scraper-ISBN-Amazon_Driver|0.03|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409030441
155659|155659-b19f-3f77-b713-d32bba55d77f|cpan|200409|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.03||0|||200409021732
155656|155656-b19f-3f77-b713-d32bba55d77f|cpan|200409|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.03||0|||200409021658
155369|155369-b19f-3f77-b713-d32bba55d77f|pass|200408|Jost.Krieger+perl@rub.de|WWW-Scraper-ISBN-Pearson_Driver|0.05|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200408312319
155366|155366-b19f-3f77-b713-d32bba55d77f|pass|200408|Jost.Krieger+perl@rub.de|WWW-Scraper-ISBN-ORA_Driver|0.04|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200408312302
155350|155350-b19f-3f77-b713-d32bba55d77f|cpan|200408|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.05||0|||200408312014
155349|155349-b19f-3f77-b713-d32bba55d77f|cpan|200408|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.04||0|||200408311956
150808|150808-b19f-3f77-b713-d32bba55d77f|fail|200407|Jost.Krieger+perl@rub.de|GD-Chart-Radial|0.01|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200407261636
150369|150369-b19f-3f77-b713-d32bba55d77f|pass|200407|barbie@missbarbell.co.uk (Barbie)|GD-Chart-Radial|0.01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200407230836
150151|150151-b19f-3f77-b713-d32bba55d77f|pass|200407|rrwo@cpan.org|GD-Chart-Radial|0.01|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200407211713
150121|150121-b19f-3f77-b713-d32bba55d77f|pass|200407|martin.thurn@ngc.com ("Thurn, Martin")|GD-Chart-Radial|0.01|sun4-solaris|5.9.1|solaris|2.8|200407211334
149969|149969-b19f-3f77-b713-d32bba55d77f|pass|200407|cpansmoke@alternation.net|GD-Chart-Radial|0.01|i586-linux|5.8.0|linux|2.4.22-4tr|200407210007
149858|149858-b19f-3f77-b713-d32bba55d77f|cpan|200407|TEEJAY|GD-Chart-Radial|0.01||0|||200407201250
147559|147559-b19f-3f77-b713-d32bba55d77f|pass|200407|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-Scraper-ISBN-Pearson_Driver|0.04|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200407072024
145297|145297-b19f-3f77-b713-d32bba55d77f|pass|200406|rjbs@cpan.org|WWW-UsePerl-Journal|0.11|darwin-2level|5.8.4|darwin|7.3.0|200406230331
145032|145032-b19f-3f77-b713-d32bba55d77f|pass|200406|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Pearson_Driver|0.04|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200406210814
143445|143445-b19f-3f77-b713-d32bba55d77f|pass|200406|cpansmoke@alternation.net|WWW-Scraper-ISBN-Pearson_Driver|0.04|i586-linux|5.8.0|linux|2.4.22-4tr|200406080508
143357|143357-b19f-3f77-b713-d32bba55d77f|cpan|200406|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.04||0|||200406072002
138844|138844-b19f-3f77-b713-d32bba55d77f|pass|200405|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Pearson_Driver|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200405130752
138816|138816-b19f-3f77-b713-d32bba55d77f|pass|200405|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-ORA_Driver|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200405130752
138647|138647-b19f-3f77-b713-d32bba55d77f|pass|200405|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Pearson_Driver|0.03|sun4-solaris|5.8.1|solaris|2.8|200405120941
138646|138646-b19f-3f77-b713-d32bba55d77f|pass|200405|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-ORA_Driver|0.03|sun4-solaris|5.8.1|solaris|2.8|200405120940
138382|138382-b19f-3f77-b713-d32bba55d77f|cpan|200405|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.03||0|||200405111549
138378|138378-b19f-3f77-b713-d32bba55d77f|cpan|200405|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.03||0|||200405111530
134554|134554-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|Calendar-List|0.13|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404232137
134549|134549-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|Calendar-List|0.12|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404232137
134545|134545-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-UsePerl-Journal-Thread|0.07|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404232136
134534|134534-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|Calendar-List|0.13|i386-freebsd|5.8.2|freebsd|5.2-current|200404231628
134528|134528-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|Calendar-List|0.12|i386-freebsd|5.8.2|freebsd|5.2-current|200404231621
134527|134527-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|WWW-UsePerl-Journal-Thread|0.07|i386-freebsd|5.8.2|freebsd|5.2-current|200404231620
134484|134484-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|WWW-UsePerl-Journal-Thread|0.06|i386-freebsd|5.8.2|freebsd|5.2-current|200404231334
134467|134467-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|Games-Trackword|1.02|i386-freebsd|5.8.2|freebsd|5.2-current|200404231149
134466|134466-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|Finance-Currency-Convert-XE|0.06|i386-freebsd|5.8.2|freebsd|5.2-current|200404231149
134465|134465-b19f-3f77-b713-d32bba55d77f|pass|200404|webmaster@thr.msu.edu|WWW-UsePerl-Journal-Thread|0.05|i386-freebsd|5.8.2|freebsd|5.2-current|200404231149
134453|134453-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|Calendar-List|0.13|i586-linux|5.8.0|linux|2.4.22-4tr|200404231207
134409|134409-b19f-3f77-b713-d32bba55d77f|pass|200404|martin.thurn@ngc.com ("Thurn, Martin")|Calendar-List|0.13|sun4-solaris-thread-multi|5.9.0|solaris|2.8|200404230954
134358|134358-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|Calendar-List|0.12|i586-linux|5.8.0|linux|2.4.22-4tr|200404230907
134354|134354-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|WWW-UsePerl-Journal-Thread|0.07|i586-linux|5.8.0|linux|2.4.22-4tr|200404230808
134310|134310-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Calendar-List|0.13|sun4-solaris|5.8.1|solaris|2.8|200404230939
134305|134305-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Calendar-List|0.12|sun4-solaris|5.8.1|solaris|2.8|200404230928
134210|134210-b19f-3f77-b713-d32bba55d77f|pass|200404|nothingmuch@woobling.org|Calendar-List|0.13|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200404222214
134186|134186-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|Calendar-List|0.13||0|||200404221913
134178|134178-b19f-3f77-b713-d32bba55d77f|fail|200404|nothingmuch@woobling.org|Calendar-List|0.12|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200404221946
134153|134153-b19f-3f77-b713-d32bba55d77f|pass|200404|nothingmuch@woobling.org|WWW-UsePerl-Journal-Thread|0.07|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200404221904
134148|134148-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|Calendar-List|0.12||0|||200404221644
134143|134143-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-UsePerl-Journal-Thread|0.07||0|||200404221603
134053|134053-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Amazon_Driver|0.01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220737
134052|134052-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Yahoo_Driver|0.01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220737
134039|134039-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|Finance-Currency-Convert-XE|0.06|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220736
134036|134036-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Pearson_Driver|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220736
134030|134030-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|Calendar-List|0.11|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220736
134019|134019-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|Games-Trackword|1.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220736
134010|134010-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Yahoo_Driver|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220735
134009|134009-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-ORA_Driver|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220735
133989|133989-b19f-3f77-b713-d32bba55d77f|pass|200404|barbie@missbarbell.co.uk (Barbie)|WWW-Scraper-ISBN-Amazon_Driver|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200404220735
133851|133851-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-UsePerl-Journal-Thread|0.06|sun4-solaris|5.8.1|solaris|2.8|200404210919
133821|133821-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|WWW-UsePerl-Journal-Thread|0.06|i586-linux|5.8.0|linux|2.4.22-4tr|200404210109
133785|133785-b19f-3f77-b713-d32bba55d77f|pass|200404|martin.thurn@ngc.com ("Thurn, Martin")|Games-Trackword|1.02|sun4-solaris-thread-multi|5.9.0|solaris|2.8|200404201700
133783|133783-b19f-3f77-b713-d32bba55d77f|fail|200404|martin.thurn@ngc.com ("Thurn, Martin")|Calendar-List|0.11|sun4-solaris-thread-multi|5.9.0|solaris|2.8|200404201656
133749|133749-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-UsePerl-Journal-Thread|0.06||0|||200404201615
133716|133716-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-ORA_Driver|0.02|sun4-solaris|5.8.1|solaris|2.8|200404200945
133715|133715-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Pearson_Driver|0.02|sun4-solaris|5.8.1|solaris|2.8|200404200944
133714|133714-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Yahoo_Driver|0.02|sun4-solaris|5.8.1|solaris|2.8|200404200943
133713|133713-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Amazon_Driver|0.02|sun4-solaris|5.8.1|solaris|2.8|200404200942
133712|133712-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Games-Trackword|1.02|sun4-solaris|5.8.1|solaris|2.8|200404200940
133711|133711-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Finance-Currency-Convert-XE|0.06|sun4-solaris|5.8.1|solaris|2.8|200404200940
133710|133710-b19f-3f77-b713-d32bba55d77f|fail|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-UsePerl-Journal-Thread|0.05|sun4-solaris|5.8.1|solaris|2.8|200404200939
133709|133709-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Calendar-List|0.11|sun4-solaris|5.8.1|solaris|2.8|200404200937
133640|133640-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|WWW-Scraper-ISBN-Pearson_Driver|0.02|i586-linux|5.8.0|linux|2.4.22-4tr|200404200408
133638|133638-b19f-3f77-b713-d32bba55d77f|fail|200404|cpansmoke@alternation.net|Calendar-List|0.11|i586-linux|5.8.0|linux|2.4.22-4tr|200404200007
133634|133634-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|Finance-Currency-Convert-XE|0.06|i586-linux|5.8.0|linux|2.4.22-4tr|200404200109
133631|133631-b19f-3f77-b713-d32bba55d77f|fail|200404|cpansmoke@alternation.net|WWW-Scraper-ISBN-Amazon_Driver|0.02|i586-linux|5.8.0|linux|2.4.22-4tr|200404200307
133630|133630-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|WWW-Scraper-ISBN-Yahoo_Driver|0.02|i586-linux|5.8.0|linux|2.4.22-4tr|200404200308
133625|133625-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|Games-Trackword|1.02|i586-linux|5.8.0|linux|2.4.22-4tr|200404200207
133604|133604-b19f-3f77-b713-d32bba55d77f|pass|200404|nothingmuch@woobling.org|Games-Trackword|1.02|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200404192025
133599|133599-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.02||0|||200404191824
133597|133597-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.02||0|||200404191802
133596|133596-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.02||0|||200404191800
133595|133595-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.02||0|||200404191743
133593|133593-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|Games-Trackword|1.02||0|||200404191724
133591|133591-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|Finance-Currency-Convert-XE|0.06||0|||200404191712
133588|133588-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-UsePerl-Journal-Thread|0.05||0|||200404191704
133587|133587-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|Calendar-List|0.11||0|||200404191656
133102|133102-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Yahoo_Driver|0.01|sun4-solaris|5.8.1|solaris|2.8|200404160920
133101|133101-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Amazon_Driver|0.01|sun4-solaris|5.8.1|solaris|2.8|200404160919
133082|133082-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|WWW-Scraper-ISBN-Yahoo_Driver|0.01|i586-linux|5.8.0|linux|2.4.22-4tr|200404160208
133000|133000-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-Yahoo_Driver|0.01||0|||200404151902
132999|132999-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-Amazon_Driver|0.01||0|||200404151857
131993|131993-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-Pearson_Driver|0.01|sun4-solaris|5.8.1|solaris|2.8|200404081027
131992|131992-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-Scraper-ISBN-ORA_Driver|0.01|sun4-solaris|5.8.1|solaris|2.8|200404081021
131641|131641-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-Pearson_Driver|0.01||0|||200404071918
131639|131639-b19f-3f77-b713-d32bba55d77f|cpan|200404|BARBIE|WWW-Scraper-ISBN-ORA_Driver|0.01||0|||200404071915
127458|127458-b19f-3f77-b713-d32bba55d77f|pass|200403|barbie@missbarbell.co.uk (Barbie)|WWW-UsePerl-Journal-Thread|0.04|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200403152146
126712|126712-b19f-3f77-b713-d32bba55d77f|pass|200403|webmaster@thr.msu.edu|WWW-UsePerl-Journal-Thread|0.04|i386-freebsd|5.8.2|freebsd|5.2-current|200403111431
126632|126632-b19f-3f77-b713-d32bba55d77f|pass|200403|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|WWW-UsePerl-Journal-Thread|0.04|sun4-solaris|5.8.1|solaris|2.8|200403111031
126582|126582-b19f-3f77-b713-d32bba55d77f|pass|200403|cpansmoke@alternation.net|WWW-UsePerl-Journal-Thread|0.04|i586-linux|5.8.0|linux|2.4.22-4tr|200403110308
126502|126502-b19f-3f77-b713-d32bba55d77f|pass|200403|nothingmuch@woobling.org|WWW-UsePerl-Journal|0.11|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200403101854
126481|126481-b19f-3f77-b713-d32bba55d77f|cpan|200403|BARBIE|WWW-UsePerl-Journal-Thread|0.04||0|||200403101551
126408|126408-b19f-3f77-b713-d32bba55d77f|pass|200403|barbie@missbarbell.co.uk (Barbie)|CPAN-WWW-Testers-Generator|0.21|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200403100759
126326|126326-b19f-3f77-b713-d32bba55d77f|pass|200403|barbie@missbarbell.co.uk (Barbie)|Finance-Currency-Convert-XE|0.05|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200403100756
126043|126043-b19f-3f77-b713-d32bba55d77f|pass|200403|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|CPAN-WWW-Testers-Generator|0.21|sun4-solaris|5.8.1|solaris|2.8|200403081102
125941|125941-b19f-3f77-b713-d32bba55d77f|pass|200403|nothingmuch@woobling.org|CPAN-WWW-Testers-Generator|0.21|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200403072101
125903|125903-b19f-3f77-b713-d32bba55d77f|pass|200403|webmaster@thr.msu.edu|Finance-Currency-Convert-XE|0.05|i386-freebsd|5.8.2|freebsd|5.2-current|200403071232
125893|125893-b19f-3f77-b713-d32bba55d77f|cpan|200403|LBROCARD|CPAN-WWW-Testers-Generator|0.21||0|||200403071759
125671|125671-b19f-3f77-b713-d32bba55d77f|pass|200403|cpansmoke@alternation.net|Finance-Currency-Convert-XE|0.05|i586-linux|5.8.0|linux|2.4.22-4tr|200403060307
125522|125522-b19f-3f77-b713-d32bba55d77f|pass|200403|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Finance-Currency-Convert-XE|0.05|sun4-solaris|5.8.1|solaris|2.8|200403051049
125385|125385-b19f-3f77-b713-d32bba55d77f|pass|200403|nothingmuch@woobling.org|Finance-Currency-Convert-XE|0.05|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200403042207
125373|125373-b19f-3f77-b713-d32bba55d77f|cpan|200403|BARBIE|Finance-Currency-Convert-XE|0.05||0|||200403041903
122719|122719-b19f-3f77-b713-d32bba55d77f|pass|200402|cpansmoke@alternation.net|Finance-Currency-Convert-XE|0.04|i586-linux|5.8.0|linux|2.4.22-4tr|200402151608
122413|122413-b19f-3f77-b713-d32bba55d77f|pass|200402|Jost.Krieger@ruhr-uni-bochum.de|Finance-Currency-Convert-XE|0.04|sun4-solaris|5.8.1|solaris|2.8|200402131721
122371|122371-b19f-3f77-b713-d32bba55d77f|cpan|200402|BARBIE|Finance-Currency-Convert-XE|0.04||0|||200402131331
115374|115374-b19f-3f77-b713-d32bba55d77f|pass|200312|barbie@missbarbell.co.uk (Barbie)|Calendar-List|0.10|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312190737
115167|115167-b19f-3f77-b713-d32bba55d77f|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Calendar-List|0.10|sun4-solaris|5.8.1|solaris|2.8|200312171036
115110|115110-b19f-3f77-b713-d32bba55d77f|cpan|200312|BARBIE|Calendar-List|0.10||0|||200312161929
111291|111291-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Finance-Currency-Convert-XE|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311132252
111240|111240-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Calendar-List|0.08|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311132252
111233|111233-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Games-Trackword|1.01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311132252
110544|110544-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Calendar-List|0.08|sun4-solaris|5.8.1|solaris|2.8|200311071518
110539|110539-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Calendar-List|0.08|darwin|5.8.1|darwin|6.8|200311071514
110536|110536-b19f-3f77-b713-d32bba55d77f|cpan|200311|BARBIE|Calendar-List|0.08||0|||200311071212
110509|110509-b19f-3f77-b713-d32bba55d77f|pass|200311|webmaster@thr.msu.edu|Games-Trackword|1.01|i386-freebsd|5.8.1|freebsd|5.1-current|200311061851
110461|110461-b19f-3f77-b713-d32bba55d77f|fail|200311|mthurn@unknown|Calendar-List|0.06|sun4-solaris|5.8.0|solaris|2.8|200311061015
110446|110446-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Games-Trackword|1.01|sun4-solaris|5.8.1|solaris|2.8|200311061433
110443|110443-b19f-3f77-b713-d32bba55d77f|fail|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Calendar-List|0.07|sun4-solaris|5.8.1|solaris|2.8|200311061430
110442|110442-b19f-3f77-b713-d32bba55d77f|fail|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|WWW-UsePerl-Journal-Thread|0.03|sun4-solaris|5.8.1|solaris|2.8|200311061428
110436|110436-b19f-3f77-b713-d32bba55d77f|pass|200311|Perl_Test@LogicalChaos.org|Games-Trackword|1.01|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311060613
110435|110435-b19f-3f77-b713-d32bba55d77f|pass|200311|Perl_Test@LogicalChaos.org|WWW-UsePerl-Journal-Thread|0.03|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311060602
110427|110427-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Finance-Currency-Convert-XE|0.03|darwin|5.8.1|darwin|6.8|200311061423
110426|110426-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Games-Trackword|1.01|darwin|5.8.1|darwin|6.8|200311061423
110425|110425-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Calendar-List|0.07|darwin|5.8.1|darwin|6.8|200311061420
110424|110424-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|WWW-UsePerl-Journal-Thread|0.03|darwin|5.8.1|darwin|6.8|200311061420
110423|110423-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|WWW-UsePerl-Journal|0.11|darwin|5.8.1|darwin|6.8|200311061419
110409|110409-b19f-3f77-b713-d32bba55d77f|cpan|200311|BARBIE|Games-Trackword|1.01||0|||200311061121
110408|110408-b19f-3f77-b713-d32bba55d77f|cpan|200311|BARBIE|Finance-Currency-Convert-XE|0.03||0|||200311061121
110407|110407-b19f-3f77-b713-d32bba55d77f|cpan|200311|BARBIE|Calendar-List|0.07||0|||200311061119
110406|110406-b19f-3f77-b713-d32bba55d77f|cpan|200311|BARBIE|WWW-UsePerl-Journal-Thread|0.03||0|||200311061117
110245|110245-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|WWW-UCC|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311051952
109808|109808-b19f-3f77-b713-d32bba55d77f|pass|200311|webmaster@thr.msu.edu|WWW-UCC|0.02|i386-freebsd|5.8.1|freebsd|5.1-current|200311020345
109609|109609-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|WWW-UCC|0.02|sun4-solaris|5.8.1|solaris|2.8|200311010113
109537|109537-b19f-3f77-b713-d32bba55d77f|cpan|200310|BARBIE|WWW-UCC|0.02||0|||200310311335
105096|105096-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|WWW-UsePerl-Journal-Thread|0.02|i386-freebsd|5.6.1|freebsd|5.1-current|200310090000
103331|103331-b19f-3f77-b713-d32bba55d77f|pass|200309|Perl_Test@LogicalChaos.org|WWW-UsePerl-Journal-Thread|0.02|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200309280158
103298|103298-b19f-3f77-b713-d32bba55d77f|pass|200309|Perl_Test@LogicalChaos.org|WWW-UsePerl-Journal-Thread|0.01|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200309280127
103297|103297-b19f-3f77-b713-d32bba55d77f|pass|200309|Perl_Test@LogicalChaos.org|WWW-UsePerl-Journal|0.11|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200309280127
101118|101118-b19f-3f77-b713-d32bba55d77f|pass|200309|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Games-Trackword|1.0|sun4-solaris|5.8.0|solaris|2.8|200309091408
101112|101112-b19f-3f77-b713-d32bba55d77f|pass|200309|jlatour@calaquendi.net|Games-Trackword|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200309091319
101107|101107-b19f-3f77-b713-d32bba55d77f|cpan|200309|BARBIE|Games-Trackword|1.0||0|||200309091148
100384|100384-b19f-3f77-b713-d32bba55d77f|pass|200309|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.22|sun4-solaris|5.8.0|solaris|2.8|200309022011
100330|100330-b19f-3f77-b713-d32bba55d77f|pass|200309|crazyinsomniac@yahoo.com|CPAN-WWW-Testers|0.22|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200309021533
100181|100181-b19f-3f77-b713-d32bba55d77f|cpan|200309|LBROCARD|CPAN-WWW-Testers|0.22||0|||200309012107
98995|98995-b19f-3f77-b713-d32bba55d77f|pass|200308|crazyinsomniac@yahoo.com|CPAN-WWW-Testers|0.20|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200308210300
98612|98612-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.21|sun4-solaris|5.8.0|solaris|2.8|200308151939
98563|98563-b19f-3f77-b713-d32bba55d77f|cpan|200308|LBROCARD|CPAN-WWW-Testers|0.21||0|||200308151737
98539|98539-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.20|sun4-solaris|5.8.0|solaris|2.8|200308150619
98518|98518-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.02|sun4-solaris|5.8.0|solaris|2.8|200308150544
98509|98509-b19f-3f77-b713-d32bba55d77f|cpan|200308|LBROCARD|CPAN-WWW-Testers|0.20||0|||200308150139
98457|98457-b19f-3f77-b713-d32bba55d77f|pass|200308|mrodrigu@mirlin.xmltwig.com ((root))|CPAN-WWW-Testers-Generator|0.20|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200308141026
98445|98445-b19f-3f77-b713-d32bba55d77f|cpan|200308|BARBIE|WWW-UsePerl-Journal-Thread|0.02||0|||200308141500
98402|98402-b19f-3f77-b713-d32bba55d77f|pass|200308|crazyinsomniac@yahoo.com|WWW-UsePerl-Journal-Thread|0.01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200308140334
98327|98327-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers-Generator|0.20|sun4-solaris|5.8.0|solaris|2.8|200308140124
98314|98314-b19f-3f77-b713-d32bba55d77f|cpan|200308|LBROCARD|CPAN-WWW-Testers-Generator|0.20||0|||200308132318
98302|98302-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal-Thread|0.01|sun4-solaris|5.8.0|solaris|2.8|200308131906
98256|98256-b19f-3f77-b713-d32bba55d77f|cpan|200308|BARBIE|WWW-UsePerl-Journal-Thread|0.01||0|||200308131702
97787|97787-b19f-3f77-b713-d32bba55d77f|pass|200308|cpantester@calaquendi.net ((Jeroen Latour))|CPAN-WWW-Testers|0.10|i586-linux|5.8.0|linux|2.2.16c32_iii|200308090736
97581|97581-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.06|sun4-solaris|5.8.0|solaris|2.8|200308071537
97559|97559-b19f-3f77-b713-d32bba55d77f|cpan|200308|BARBIE|Calendar-List|0.06||0|||200308071330
97525|97525-b19f-3f77-b713-d32bba55d77f|fail|200308|crazyinsomniac@yahoo.com|Calendar-List|0.05|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200308070359
97441|97441-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Calendar-List|0.05|sun4-solaris|5.8.0|solaris|2.8|200308062046
97409|97409-b19f-3f77-b713-d32bba55d77f|cpan|200308|BARBIE|Calendar-List|0.05||0|||200308061837
96770|96770-b19f-3f77-b713-d32bba55d77f|pass|200308|crazyinsomniac@yahoo.com|CPAN-WWW-Testers|0.10|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200308010634
96705|96705-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-WWW-Testers|0.10|sun4-solaris|5.8.0|solaris|2.8|200308010218
96694|96694-b19f-3f77-b713-d32bba55d77f|cpan|200308|LBROCARD|CPAN-WWW-Testers|0.10||0|||200308010015
77459|77459-b19f-3f77-b713-d32bba55d77f|pass|200301|alian@cpan.org ((CPAN Tester; CPAN++ automate ))|WWW-UsePerl-Journal|0.11|i386-freebsd|5.8.0|freebsd|4.6.2-release|200301300711
77382|77382-b19f-3f77-b713-d32bba55d77f|pass|200301|alian@cpan.org ((CPAN Tester = CPAN++ automate))|WWW-UsePerl-Journal|0.11|ppc-linux|5.8.0|linux|2.4.18-0.9a|200301300441
77266|77266-b19f-3f77-b713-d32bba55d77f|fail|200301|alian@cpan.org ((CPAN Tester_CPAN++ automate))|WWW-UsePerl-Journal|0.11|ppc-linux|5.8.0|linux|2.2.16|200301300153
77257|77257-b19f-3f77-b713-d32bba55d77f|pass|200301|alian@cpan.org ((CPAN Tester''CPAN++ automate))|WWW-UsePerl-Journal|0.11|sun4-solaris|5.8.0|solaris|2.7|200301300146
77165|77165-b19f-3f77-b713-d32bba55d77f|pass|200301|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|WWW-UsePerl-Journal|0.11|i386-netbsd-thread-multi|5.8.0|netbsd|1.6|200301291520
76806|76806-b19f-3f77-b713-d32bba55d77f|pass|200301|jlatour@localhost ((Jeroen Latour))|WWW-UsePerl-Journal|0.11|i586-linux|5.8.0|linux|2.2.16c32_iii|200301270801
76707|76707-b19f-3f77-b713-d32bba55d77f|pass|200301|Jost.Krieger+smokeback@ruhr-uni-bochum.de ((Jost Krieger))|WWW-UsePerl-Journal|0.11|sun4-solaris|5.8.0|solaris|2.8|200301270631
76643|76643-b19f-3f77-b713-d32bba55d77f|cpan|200301|IDORU|WWW-UsePerl-Journal|0.11||0|||200301271128
66609|66609-b19f-3f77-b713-d32bba55d77f|fail|200211|root@ouroboros.anu.edu.au (root)|WWW-UsePerl-Journal|0.10|i686-linux|5.8.0|linux|2.4.18-3|200211041129
64433|64433-b19f-3f77-b713-d32bba55d77f|pass|200210|iain@ouroboros.anu.edu.au|WWW-UsePerl-Journal|0.10|i686-linux|5.8.0|linux|2.4.18-3|200210151032
64409|64409-b19f-3f77-b713-d32bba55d77f|pass|200210|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.10|sun4-solaris|5.8.0|solaris|2.8|200210141406
64405|64405-b19f-3f77-b713-d32bba55d77f|pass|200210|perl_test@logicalchaos.org ((Automated Perl Test Account))|WWW-UsePerl-Journal|0.10|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200210140546
64404|64404-b19f-3f77-b713-d32bba55d77f|pass|200210|jlatour@www.arens.nl (Jeroen Latour)|WWW-UsePerl-Journal|0.10|i586-linux|5.8.0|linux|2.2.16c32_iii|200210141346
64396|64396-b19f-3f77-b713-d32bba55d77f|cpan|200210|IDORU|WWW-UsePerl-Journal|0.10||0|||200210141202
64072|64072-b19f-3f77-b713-d32bba55d77f|pass|200210|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.09|sun4-solaris|5.8.0|solaris|2.8|200210091828
64064|64064-b19f-3f77-b713-d32bba55d77f|pass|200210|jlatour@www.arens.nl (Jeroen Latour)|WWW-UsePerl-Journal|0.09|i586-linux|5.8.0|linux|2.2.16c32_iii|200210091905
64055|64055-b19f-3f77-b713-d32bba55d77f|pass|200210|perl_test@logicalchaos.org ((Automated Perl Test Account))|WWW-UsePerl-Journal|0.09|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200210090958
64050|64050-b19f-3f77-b713-d32bba55d77f|pass|200210|iain@ouroboros.anu.edu.au|WWW-UsePerl-Journal|0.09|i686-linux|5.8.0|linux|2.4.18-3|200210100027
64049|64049-b19f-3f77-b713-d32bba55d77f|cpan|200210|IDORU|WWW-UsePerl-Journal|0.09||0|||200210091623
63616|63616-b19f-3f77-b713-d32bba55d77f|pass|200210|root@ouroboros.anu.edu.au (root)|WWW-UsePerl-Journal|0.08|i686-linux|5.8.0|linux|2.4.18-3|200210061751
63198|63198-b19f-3f77-b713-d32bba55d77f|pass|200210|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.08|sun4-solaris|5.8.0|solaris|2.8|200210041838
63193|63193-b19f-3f77-b713-d32bba55d77f|pass|200210|jlatour@www.arens.nl (Jeroen Latour)|WWW-UsePerl-Journal|0.08|i586-linux|5.8.0|linux|2.2.16c32_iii|200210042027
63169|63169-b19f-3f77-b713-d32bba55d77f|pass|200210|perl_test@logicalchaos.org ((Automated Perl Test Account))|WWW-UsePerl-Journal|0.08|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200210041004
63166|63166-b19f-3f77-b713-d32bba55d77f|cpan|200210|IDORU|WWW-UsePerl-Journal|0.08||0|||200210041624
61220|61220-b19f-3f77-b713-d32bba55d77f|pass|200209|root@ostend.org (root)|WWW-UsePerl-Journal|0.07|i686-linux|5.8.0|linux|2.4.10-4gb|200209290358
61181|61181-b19f-3f77-b713-d32bba55d77f|pass|200209|root@ouroboros.anu.edu.au (root)|WWW-UsePerl-Journal|0.06|i686-linux|5.8.0|linux|2.4.18-3|200209290030
61127|61127-b19f-3f77-b713-d32bba55d77f|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|WWW-UsePerl-Journal|0.07|i586-linux|5.8.0|linux|2.2.16c32_iii|200209272255
61122|61122-b19f-3f77-b713-d32bba55d77f|pass|200209|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.07|sun4-solaris|5.8.0|solaris|2.8|200209272052
61097|61097-b19f-3f77-b713-d32bba55d77f|pass|200209|perl_test@logicalchaos.org ((Automated Perl Test Account))|WWW-UsePerl-Journal|0.07|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200209271230
61090|61090-b19f-3f77-b713-d32bba55d77f|cpan|200209|IDORU|WWW-UsePerl-Journal|0.07||0|||200209271849
61061|61061-b19f-3f77-b713-d32bba55d77f|pass|200209|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.06|sun4-solaris|5.8.0|solaris|2.8|200209271209
61015|61015-b19f-3f77-b713-d32bba55d77f|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|WWW-UsePerl-Journal|0.06|i586-linux|5.8.0|linux|2.2.16c32_iii|200209261552
60999|60999-b19f-3f77-b713-d32bba55d77f|pass|200209|perl_test@logicalchaos.org ((Automated Perl Test Account))|WWW-UsePerl-Journal|0.06|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200209260546
60987|60987-b19f-3f77-b713-d32bba55d77f|cpan|200209|IDORU|WWW-UsePerl-Journal|0.06||0|||200209261206
59126|59126-b19f-3f77-b713-d32bba55d77f|pass|200209|root@ouroboros.anu.edu.au|WWW-UsePerl-Journal|0.05|i686-linux|5.8.0|linux|2.4.18-3|200209050056
53881|53881-b19f-3f77-b713-d32bba55d77f|pass|200208|Jost.Krieger@ruhr-uni-bochum.de|WWW-UsePerl-Journal|0.05|sun4-solaris|5.8.0|solaris|2.8|200208151012
50864|50864-b19f-3f77-b713-d32bba55d77f|fail|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|WWW-UsePerl-Journal|0.05|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208070429
50837|50837-b19f-3f77-b713-d32bba55d77f|fail|200208|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|WWW-UsePerl-Journal|0.05|sun4-solaris|5.8.0|solaris|2.8|200208070842
34921|34921-b19f-3f77-b713-d32bba55d77f|pass|200203|riechert@pobox.com (Andreas Marcel Riechert)|WWW-UsePerl-Journal|0.05|i686-linux|5.6.1|linux|2.2.14-5.0|200203041653
34903|34903-b19f-3f77-b713-d32bba55d77f|pass|200203|arnaud@underlands.org (ASSAD Arnaud)|WWW-UsePerl-Journal|0.05|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200203051208
34865|34865-b19f-3f77-b713-d32bba55d77f|pass|200203|alphamethyl@mac.com (Jason Leane)|WWW-UsePerl-Journal|0.03|darwin|5.6.0|darwin|5.3|200203031201
34864|34864-b19f-3f77-b713-d32bba55d77f|cpan|200203|IDORU|WWW-UsePerl-Journal|0.05||0|||200203032121
34861|34861-b19f-3f77-b713-d32bba55d77f|cpan|200203|IDORU|WWW-UsePerl-Journal|0.04||0|||200203031914
34017|34017-b19f-3f77-b713-d32bba55d77f|pass|200202|arnaud@underlands.org (ASSAD Arnaud)|WWW-UsePerl-Journal|0.03|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200202131418
34016|34016-b19f-3f77-b713-d32bba55d77f|cpan|200202|IDORU|WWW-UsePerl-Journal|0.03||0|||200202131354
33283|33283-b19f-3f77-b713-d32bba55d77f|pass|200201|riechert@pobox.com (Andreas Marcel Riechert)|WWW-UsePerl-Journal|0.02|i686-linux|5.6.1|linux|2.2.14-5.0|200201311823
33153|33153-b19f-3f77-b713-d32bba55d77f|pass|200201|piers@selsyn.co.uk (P Kent)|WWW-UsePerl-Journal|0.02|ppc-linux-multi|5.6.1|linux|2.2.14|200201290533
33105|33105-b19f-3f77-b713-d32bba55d77f|pass|200201|arnaud@romeconcept.com ((ASSAD Arnaud))|WWW-UsePerl-Journal|0.02|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200201280851
33101|33101-b19f-3f77-b713-d32bba55d77f|cpan|200201|IDORU|WWW-UsePerl-Journal|0.02||0|||200201280401
33073|33073-b19f-3f77-b713-d32bba55d77f|fail|200201|riechert@pobox.com (Andreas Marcel Riechert)|WWW-UsePerl-Journal|0.01|i686-linux|5.6.1|linux|2.2.14-5.0|200201261755
33035|33035-b19f-3f77-b713-d32bba55d77f|fail|200201|piers@selsyn.co.uk (P Kent)|WWW-UsePerl-Journal|0.01|ppc-linux-multi|5.6.1|linux|2.2.14|200201260134
32973|32973-b19f-3f77-b713-d32bba55d77f|pass|200201|arnaud@romeconcept.com ((ASSAD Arnaud))|WWW-UsePerl-Journal|0.01|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200201241617
32969|32969-b19f-3f77-b713-d32bba55d77f|cpan|200201|IDORU|WWW-UsePerl-Journal|0.01||0|||200201241603