#!perl

use strict;
use warnings;
$|=1;
use Test::More tests => 1;
use DBI;
#use DBD::SQLite;
use File::Spec;
use File::Path;
use File::Basename;

# rebuild cpanstats db

my $f = File::Spec->catfile('t','_DBDIR','test.db');
unlink $f if -f $f;
mkpath( dirname($f) );

my $dbh = DBI->connect("dbi:SQLite:dbname=$f", '', '', {AutoCommit=>1});
$dbh->do(q{
  CREATE TABLE cpanstats (
                          id            INTEGER PRIMARY KEY,
                          guid          TEXT,
                          state         TEXT,
                          postdate      TEXT,
                          tester        TEXT,
                          dist          TEXT,
                          version       TEXT,
                          platform      TEXT,
                          perl          TEXT,
                          osname        TEXT,
                          osvers        TEXT,
                          fulldate      TEXT
  )
});

while(<DATA>){
  chomp;
  $dbh->do('INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate ) VALUES ( ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ? )', {}, split(/\|/,$_) );
}

$dbh->do(q{ CREATE INDEX distverstate ON cpanstats (dist, version, state) });
$dbh->do(q{ CREATE INDEX ixdate ON cpanstats (postdate) });
$dbh->do(q{ CREATE INDEX ixperl ON cpanstats (perl) });
$dbh->do(q{ CREATE INDEX ixplat ON cpanstats (platform) });

my ($ct) = $dbh->selectrow_array('select count(*) from cpanstats');

$dbh->disconnect;

is($ct, 14034, "row count for cpanstats");

#select * from cpanstats where state='cpan' and dist in (SELECT dist from ixlatest where author='DCANTRELL')
# sqlite> select * from cpanstats where postdate=200901 order by dist limit 20;
# id|guid|state|postdate|tester|dist|version|platform|perl|osname|osvers|date
__DATA__
3031|3031-b19f-3f77-b713-d32bba55d77f|pass|199910|schinder@pobox.com|Statistics-ChiSquare|0.2|PA-RISC1.1|5.4.4|hpux|10.20|199910191643
3032|3032-b19f-3f77-b713-d32bba55d77f|pass|199910|schinder@pobox.com|Statistics-ChiSquare|0.2|sun4-solaris|5.5.3|solaris|2.7|199910191644
3121|3121-b19f-3f77-b713-d32bba55d77f|pass|199910|schinder@pobox.com|Statistics-ChiSquare|0.2|ppc-linux|5.5.3|linux|2.2.10|199910221334
3147|3147-b19f-3f77-b713-d32bba55d77f|pass|199910|ljmoore@freespace.net (Larry Moore)|Statistics-ChiSquare|0.2|MacOS_CFM68K|5.4.0|MacOS|7.6|199910230929
18566|18566-b19f-3f77-b713-d32bba55d77f|pass|200102|a.calpini@alos.it ("alos.it/a.calpini")|Data-Compare|0.01|MSWin32-x86-multi-thread|5.6.0|MSWin32|4.0|200102091428
18584|18584-b19f-3f77-b713-d32bba55d77f|pass|200102|schinder@pobox.com|Data-Hexdumper|0.01|ppc-linux|5.6.0|linux|2.2.14|200102091544
18585|18585-b19f-3f77-b713-d32bba55d77f|pass|200102|schinder@pobox.com|Data-Hexdumper|0.01|sun4-solaris|5.6.0|solaris|2.7|200102091544
18586|18586-b19f-3f77-b713-d32bba55d77f|pass|200102|schinder@pobox.com|Data-Hexdumper|0.01|PA-RISC1.1|5.6.0|hpux|10.20|200102091544
18661|18661-b19f-3f77-b713-d32bba55d77f|pass|200102|a.calpini@alos.it ("alos.it/a.calpini")|Data-Hexdumper|0.01|MSWin32-x86-multi-thread|5.6.0|MSWin32|4.0|200102121237
19470|19470-b19f-3f77-b713-d32bba55d77f|pass|200103|a.calpini@alos.it ("alos.it/a.calpini")|Statistics-ChiSquare|0.2|MSWin32-x86-multi-thread|5.6.0|MSWin32|4.0|200103011637
21002|21002-b19f-3f77-b713-d32bba55d77f|unknown|200104|cpantest@quaday.com (Tim Ayers)|Pony|1.01|sparc-openbsd|5.6.0|openbsd|2.8|200104050832
21167|21167-b19f-3f77-b713-d32bba55d77f|pass|200104|cpantest@quaday.com (Tim Ayers)|Tie-Scalar-Decay|1.0|sparc-openbsd|5.6.0|openbsd|2.8|200104110838
22016|22016-b19f-3f77-b713-d32bba55d77f|pass|200104|kriegjcb@CMC01SE.rz.ruhr-uni-bochum.de|Tie-Scalar-Decay|1.1|i686-linux|5.7.1|linux|2.2.16|200104251735
22040|22040-b19f-3f77-b713-d32bba55d77f|unknown|200104|kriegjcb@sunu991.ruhr-uni-bochum.de|Data-Compare|0.02|sun4-solaris|5.6.1|solaris|2.8|200104260801
22045|22045-b19f-3f77-b713-d32bba55d77f|pass|200104|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.02|sun4-solaris|5.6.1|solaris|2.8|200104260812
22158|22158-b19f-3f77-b713-d32bba55d77f|pass|200104|cpantest@quaday.com (Tim Ayers)|Data-Compare|0.02|sparc-openbsd|5.6.0|openbsd|2.8|200104270739
22176|22176-b19f-3f77-b713-d32bba55d77f|pass|200104|kriegjcb@CMC01SE.rz.ruhr-uni-bochum.de|Data-Compare|0.02|i686-linux|5.7.1|linux|2.2.16|200104271607
22192|22192-b19f-3f77-b713-d32bba55d77f|pass|200104|schinder@pobox.com|Tie-Scalar-Decay|1.1|sun4-solaris|5.6.1|solaris|2.7|200104271416
22193|22193-b19f-3f77-b713-d32bba55d77f|pass|200104|schinder@pobox.com|Tie-Scalar-Decay|1.1|PA-RISC1.1|5.6.1|hpux|10.20|200104271416
22194|22194-b19f-3f77-b713-d32bba55d77f|fail|200104|schinder@pobox.com|Tie-Scalar-Decay|1.1|ppc-linux|5.6.1|linux|2.4.2|200104271420
23486|23486-b19f-3f77-b713-d32bba55d77f|pass|200105|Jost.Krieger@ruhr-uni-bochum.de|Tie-Scalar-Decay|1.1.1|sun4-solaris|5.6.1|solaris|2.8|200105221052
23554|23554-b19f-3f77-b713-d32bba55d77f|pass|200105|cpantest@quaday.com (Tim Ayers)|Tie-Scalar-Decay|1.1.1|OpenBSD.sparc-openbsd|5.6.1|openbsd|2.8|200105230932
24779|24779-b19f-3f77-b713-d32bba55d77f|unknown|200106|code@leegoddard.com (Lee Goddard)|Acme-Pony|1.1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200106202115
24988|24988-b19f-3f77-b713-d32bba55d77f|pass|200106|Jost.Krieger@ruhr-uni-bochum.de|Tie-Hash-Rank|1.0.1|sun4-solaris|5.6.1|solaris|2.8|200106281517
25189|25189-b19f-3f77-b713-d32bba55d77f|unknown|200107|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.1|sun4-solaris|5.6.1|solaris|2.8|200107091033
27937|27937-b19f-3f77-b713-d32bba55d77f|unknown|200110|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris|5.6.1|solaris|2.8|200110101407
29413|29413-b19f-3f77-b713-d32bba55d77f|pass|200111|gellyfish@gellyfish.com (Jonathan Stowe)|Tie-Hash-Transactional|1.0|i686-linux|5.6.1|linux|2.2.16-22|200111112039
30073|30073-b19f-3f77-b713-d32bba55d77f|pass|200111|ethan@r220-1.rz.RWTH-Aachen.DE (Tassilo von Parseval)|Statistics-ChiSquare|0.3|i686-linux-thread|5.7.2|linux|2.4.13|200111240806
30092|30092-b19f-3f77-b713-d32bba55d77f|pass|200111|riechert@pobox.com (Andreas Marcel Riechert)|Statistics-ChiSquare|0.3|i686-linux|5.6.1|linux|2.2.14-5.0|200111241833
30240|30240-b19f-3f77-b713-d32bba55d77f|pass|200111|randy@theoryx5.uwinnipeg.ca (Randy Kobes)|Statistics-ChiSquare|0.3|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200111252029
31844|31844-b19f-3f77-b713-d32bba55d77f|unknown|200201|riechert@pobox.com (Andreas Marcel Riechert)|Acme-Pony|1.1.2|i686-linux|5.6.1|linux|2.2.14-5.0|200201051646
32918|32918-b19f-3f77-b713-d32bba55d77f|pass|200201|easmith@beatrice.rutgers.edu (Ed Allen Smith)|Data-Compare|0.02|IP30-R12000-irix|5.6.0|irix|6.5|200201231304
36386|36386-b19f-3f77-b713-d32bba55d77f|pass|200204|autrijus@www.autrijus.org (Autrijus Tang)|Data-Compare|0.02|i386-freebsd|5.7.3 patch 15354|freebsd|4.5-release|200204011435
36442|36442-b19f-3f77-b713-d32bba55d77f|unknown|200204|autrijus@www.autrijus.org (Autrijus Tang)|Acme-Pony|1.1.2|i386-freebsd|5.7.3 patch 15354|freebsd|4.5-release|200204021614
48917|48917-b19f-3f77-b713-d32bba55d77f|pass|200207|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-ChiSquare|0.3|sun4-solaris|5.8.0|solaris|2.8|200207310932
48959|48959-b19f-3f77-b713-d32bba55d77f|pass|200207|perl_test@logicalchaos.org ((Automated Perl Test Account))|Statistics-ChiSquare|0.3|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200207310518
50072|50072-b19f-3f77-b713-d32bba55d77f|pass|200208|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|0.01|sun4-solaris|5.8.0|solaris|2.8|200208051136
50073|50073-b19f-3f77-b713-d32bba55d77f|pass|200208|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Transactional|1.0|sun4-solaris|5.8.0|solaris|2.8|200208051138
50115|50115-b19f-3f77-b713-d32bba55d77f|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Hexdumper|0.01|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208050731
50116|50116-b19f-3f77-b713-d32bba55d77f|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Tie-Hash-Transactional|1.0|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208050731
50564|50564-b19f-3f77-b713-d32bba55d77f|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Compare|0.02|i386-linux|5.6.1|linux|2.4.8-11mdkenterprise|200208060203
53617|53617-b19f-3f77-b713-d32bba55d77f|pass|200208|alian@cpan.org|Data-Compare|0.02|i386-netbsd|5.8.0|netbsd|1.5.2|200208141515
54328|54328-b19f-3f77-b713-d32bba55d77f|pass|200208|smoke@nambit.net (Dans Testorama)|Data-Compare|0.02|i386-freebsd|5.6.1|freebsd|4.2-release|200208162340
54333|54333-b19f-3f77-b713-d32bba55d77f|pass|200208|smoke@nambit.net (Dans Testorama)|Data-Compare|0.02|i386-freebsd-thread-multi|5.8.0|freebsd|4.2-release|200208162342
54350|54350-b19f-3f77-b713-d32bba55d77f|unknown|200208|smoke@nambit.net (Dans Testorama)|Acme-Pony|1.1.2|i386-freebsd|5.5.3|freebsd|4.0-current|200208170011
54351|54351-b19f-3f77-b713-d32bba55d77f|unknown|200208|smoke@nambit.net (Dans Testorama)|Acme-Pony|1.1.2|i386-freebsd|5.6.1|freebsd|4.2-release|200208170011
54352|54352-b19f-3f77-b713-d32bba55d77f|unknown|200208|smoke@nambit.net (Dans Testorama)|Acme-Pony|1.1.2|i386-freebsd-thread-multi|5.8.0|freebsd|4.2-release|200208170012
54628|54628-b19f-3f77-b713-d32bba55d77f|pass|200208|smoke@nambit.net (Dans Testorama)|Statistics-ChiSquare|0.3|i386-freebsd|5.5.3|freebsd|4.0-current|200208170322
54629|54629-b19f-3f77-b713-d32bba55d77f|pass|200208|smoke@nambit.net (Dans Testorama)|Statistics-ChiSquare|0.3|i386-freebsd|5.6.1|freebsd|4.2-release|200208170322
54630|54630-b19f-3f77-b713-d32bba55d77f|pass|200208|smoke@nambit.net (Dans Testorama)|Statistics-ChiSquare|0.3|i386-freebsd-thread-multi|5.8.0|freebsd|4.2-release|200208170322
55844|55844-b19f-3f77-b713-d32bba55d77f|pass|200208|alian@cpan.org|Data-Hexdumper|0.01|i386-netbsd|5.8.0|netbsd|1.5.2|200208190038
56068|56068-b19f-3f77-b713-d32bba55d77f|pass|200208|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Compare|0.02|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200208191423
56910|56910-b19f-3f77-b713-d32bba55d77f|pass|200208|alian@cpan.org (alian)|Data-Compare|0.02|OpenBSD.i386-openbsd|5.8.0|openbsd|3.0|200208221001
56921|56921-b19f-3f77-b713-d32bba55d77f|pass|200208|alian@cpan.org (alian)|Data-Hexdumper|0.01|OpenBSD.i386-openbsd|5.8.0|openbsd|3.0|200208221028
58539|58539-b19f-3f77-b713-d32bba55d77f|pass|200208|alian@cpan.org (alian)|Data-Compare|0.02|i386-freebsd|5.8.0|freebsd|4.6.2-release|200208301816
58554|58554-b19f-3f77-b713-d32bba55d77f|pass|200208|alian@cpan.org (alian)|Data-Hexdumper|0.01|i386-freebsd|5.8.0|freebsd|4.6.2-release|200208301832
60246|60246-b19f-3f77-b713-d32bba55d77f|unknown|200209|perl_test@logicalchaos.org ((Automated Perl Test Account))|Acme-Licence|1.0|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200209190454
60251|60251-b19f-3f77-b713-d32bba55d77f|unknown|200209|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Licence|1.0|sun4-solaris|5.8.0|solaris|2.8|200209191322
60401|60401-b19f-3f77-b713-d32bba55d77f|pass|200209|perl_test@logicalchaos.org ((Automated Perl Test Account))|Data-Hexdumper|1.0.1|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200209200810
60428|60428-b19f-3f77-b713-d32bba55d77f|pass|200209|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.0.1|sun4-solaris|5.8.0|solaris|2.8|200209201635
61369|61369-b19f-3f77-b713-d32bba55d77f|pass|200209|root@thesafrans.com ((root))|Statistics-ChiSquare|0.3|i686-linux|5.8.0|linux|2.4.7-10|200209290847
61871|61871-b19f-3f77-b713-d32bba55d77f|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|Statistics-ChiSquare|0.3|i586-linux|5.8.0|linux|2.2.16c32_iii|200209301534
61914|61914-b19f-3f77-b713-d32bba55d77f|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|Data-Compare|0.02|i586-linux|5.8.0|linux|2.2.16c32_iii|200209301558
61923|61923-b19f-3f77-b713-d32bba55d77f|pass|200209|jlatour@www.arens.nl (Jeroen Latour)|Data-Hexdumper|1.0.1|i586-linux|5.8.0|linux|2.2.16c32_iii|200209301602
62459|62459-b19f-3f77-b713-d32bba55d77f|unknown|200210|jlatour@www.arens.nl (Jeroen Latour)|Acme-Pony|1.1.2|i586-linux|5.8.0|linux|2.2.16c32_iii|200210012348
62470|62470-b19f-3f77-b713-d32bba55d77f|unknown|200210|jlatour@www.arens.nl (Jeroen Latour)|Acme-Licence|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200210020052
62479|62479-b19f-3f77-b713-d32bba55d77f|unknown|200210|perl_test@logicalchaos.org ((Automated Perl Test Account))|Acme-Pony|1.1.2|i386-linux|5.6.1|linux|2.4.16-6mdksmp|200210011738
64602|64602-b19f-3f77-b713-d32bba55d77f|unknown|200210|root@godzilla.uni.to (root)|Acme-Pony|1.1.2|i386-linux|5.6.1|linux|2.4.17-0.13smp|200210161825
68081|68081-b19f-3f77-b713-d32bba55d77f|pass|200211|alian@cpan.org|Statistics-ChiSquare|0.3|i386-netbsd|5.8.0|netbsd|1.5.2|200211151932
68422|68422-b19f-3f77-b713-d32bba55d77f|pass|200211|alian@cpan.org (Alian - CPANPLUS/auto)|Statistics-ChiSquare|0.3|OpenBSD.i386-openbsd|5.8.0|openbsd|3.0|200211152330
70145|70145-b19f-3f77-b713-d32bba55d77f|pass|200211|alian@cpan.org (Alian - CPANPLUS/auto)|Data-Hexdumper|1.0.1|i386-netbsd|5.8.0|netbsd|1.5.2|200211210114
70469|70469-b19f-3f77-b713-d32bba55d77f|pass|200211|alian@cpan.org|Data-Compare|0.02|sparc-netbsd|5.6.1|netbsd|1.5.1|200211211430
70495|70495-b19f-3f77-b713-d32bba55d77f|pass|200211|alian@cpan.org (Alian - CPANPLUS/auto)|Statistics-ChiSquare|0.3|i386-freebsd|5.8.0|freebsd|4.6.2-release|200211211354
70505|70505-b19f-3f77-b713-d32bba55d77f|pass|200211|alian@cpan.org|Data-Hexdumper|1.0.1|sparc-netbsd|5.6.1|netbsd|1.5.1|200211211512
78607|78607-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|Data-Compare|0.02|i386-netbsd-thread-multi|5.8.0|netbsd|1.6|200302110230
78663|78663-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org ((CPAN Tester = CPAN++ automate))|Data-Compare|0.02|ppc-linux|5.8.0|linux|2.4.18-0.9a|200302110322
78789|78789-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org ((CPAN Tester''CPAN++ automate))|Data-Compare|0.02|sun4-solaris|5.8.0|solaris|2.7|200302110526
79039|79039-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org ((CPAN Tester_CPAN++ automate))|Data-Compare|0.02|ppc-linux|5.8.0|linux|2.2.16|200302110959
79143|79143-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org|Data-Compare|0.02|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200302111124
79430|79430-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org ((alian))|Data-Compare|0.02|sparc-linux|5.6.1|linux|2.4.18|200302120456
79656|79656-b19f-3f77-b713-d32bba55d77f|pass|200302|alian@cpan.org ((CPAN Tester / CPAN++ automate))|Data-Compare|0.02|sparc-netbsd|5.8.0|netbsd|1.5.3|200302130551
86049|86049-b19f-3f77-b713-d32bba55d77f|pass|200303|root@localhost.localdomain ((root))|Data-Compare|0.02|i386-linux|5.8.0|linux|2.4.18-11smp|200303300513
90155|90155-b19f-3f77-b713-d32bba55d77f|pass|200305|alian@cpan.org ((alian))|Data-Hexdumper|1.0.1|i686-linux-thread-multi-64all-ld|5.8.0|linux|2.4.20|200305131230
91242|91242-b19f-3f77-b713-d32bba55d77f|pass|200305|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|1.0|sun4-solaris|5.8.0|solaris|2.8|200305242112
91335|91335-b19f-3f77-b713-d32bba55d77f|pass|200305|cpantester@calaquendi.net ((Jeroen Latour))|Bryar|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200305260746
91402|91402-b19f-3f77-b713-d32bba55d77f|fail|200305|crazyinsomniac@yahoo.com (DH)|Bryar|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200305270008
92820|92820-b19f-3f77-b713-d32bba55d77f|pass|200306|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|1.2|sun4-solaris|5.8.0|solaris|2.8|200306150155
94030|94030-b19f-3f77-b713-d32bba55d77f|pass|200306|cpantester@calaquendi.net ((Jeroen Latour))|NestedMap|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200306261252
94034|94034-b19f-3f77-b713-d32bba55d77f|pass|200306|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|NestedMap|1.0|sun4-solaris|5.8.0|solaris|2.8|200306261239
94252|94252-b19f-3f77-b713-d32bba55d77f|pass|200306|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Find-Rule-Permissions|1.0|sun4-solaris|5.8.0|solaris|2.8|200306300842
94315|94315-b19f-3f77-b713-d32bba55d77f|pass|200306|cpantester@calaquendi.net ((Jeroen Latour))|File-Find-Rule-Permissions|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200306302104
95944|95944-b19f-3f77-b713-d32bba55d77f|pass|200307|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Find-Rule-Permissions|1.1|sun4-solaris|5.8.0|solaris|2.8|200307230034
97303|97303-b19f-3f77-b713-d32bba55d77f|pass|200308|cpantester@calaquendi.net ((Jeroen Latour))|File-Find-Rule-Permissions|1.1|i586-linux|5.8.0|linux|2.2.16c32_iii|200308061042
97862|97862-b19f-3f77-b713-d32bba55d77f|pass|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.1|sun4-solaris|5.8.0|solaris|2.8|200308101707
98649|98649-b19f-3f77-b713-d32bba55d77f|fail|200308|cpantester@calaquendi.net ((Jeroen Latour))|Bryar|2.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200308161636
98691|98691-b19f-3f77-b713-d32bba55d77f|fail|200308|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|2.0|sun4-solaris|5.8.0|solaris|2.8|200308161658
99060|99060-b19f-3f77-b713-d32bba55d77f|pass|200308|root@dropbear ((root))|Data-Hexdumper|1.1|i586-linux|5.8.0|linux|2.4.20-22em|200308221803
99725|99725-b19f-3f77-b713-d32bba55d77f|pass|200308|cpantester@calaquendi.net ((Jeroen Latour))|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|i586-linux|5.8.0|linux|2.2.16c32_iii|200308290931
99860|99860-b19f-3f77-b713-d32bba55d77f|pass|200308|crazyinsomniac@yahoo.com|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200308310346
100133|100133-b19f-3f77-b713-d32bba55d77f|pass|200309|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|sun4-solaris|5.8.0|solaris|2.8|200309011741
100444|100444-b19f-3f77-b713-d32bba55d77f|pass|200309|jlatour@calaquendi.net|Acme-Scurvy-Whoreson-BilgeRat|1.0|i586-linux|5.8.0|linux|2.2.16c32_iii|200309030257
100450|100450-b19f-3f77-b713-d32bba55d77f|pass|200309|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.0|sun4-solaris|5.8.0|solaris|2.8|200309030244
103212|103212-b19f-3f77-b713-d32bba55d77f|pass|200309|Perl_Test@LogicalChaos.org|Data-Hexdumper|1.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200309280407
104500|104500-b19f-3f77-b713-d32bba55d77f|unknown|200310|kriegjcb@mi.ruhr-uni-bochum.de ((Jost Krieger))|Acme-Pony|1.1.2|sun4-solaris|5.8.1|solaris|2.8|200310061309
105242|105242-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Data-Compare|0.02|i386-freebsd|5.6.1|freebsd|5.1-current|200310091009
105391|105391-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Data-Hexdumper|1.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310091842
105564|105564-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|File-Find-Rule-Permissions|1.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310100200
107669|107669-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid|i386-freebsd|5.6.1|freebsd|5.1-current|200310191312
107670|107670-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Tie-Hash-Transactional|1.0|i386-freebsd|5.6.1|freebsd|5.1-current|200310191312
107671|107671-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Tie-Hash-Rank|1.0.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310191312
107672|107672-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.6.1|freebsd|5.1-current|200310191313
107712|107712-b19f-3f77-b713-d32bba55d77f|pass|200310|Perl_Test@LogicalChaos.org|Tie-Hash-Rank|1.0.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200310191223
107713|107713-b19f-3f77-b713-d32bba55d77f|pass|200310|Perl_Test@LogicalChaos.org|Tie-Scalar-Decay|1.1.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200310191223
107906|107906-b19f-3f77-b713-d32bba55d77f|pass|200310|nothingmuch@woobling.org|Games-Dice-Advanced|1.0|darwin|5.8.1|darwin|6.8|200310210201
108039|108039-b19f-3f77-b713-d32bba55d77f|pass|200310|webmaster@thr.msu.edu|Games-Dice-Advanced|1.0|i386-freebsd|5.6.1|freebsd|5.1-current|200310211714
108140|108140-b19f-3f77-b713-d32bba55d77f|pass|200310|Perl_Test@LogicalChaos.org|Games-Dice-Advanced|1.0|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200310220104
108339|108339-b19f-3f77-b713-d32bba55d77f|pass|200310|barbie@missbarbell.co.uk (Barbie)|Games-Dice-Advanced|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200310222256
108348|108348-b19f-3f77-b713-d32bba55d77f|pass|200310|nothingmuch@woobling.org|Net-Random|1.0|darwin|5.8.1|darwin|6.8|200310230107
108357|108357-b19f-3f77-b713-d32bba55d77f|pass|200310|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Net-Random|1.0|sun4-solaris|5.8.1|solaris|2.8|200310230036
108976|108976-b19f-3f77-b713-d32bba55d77f|fail|200310|barbie@missbarbell.co.uk (Barbie)|Net-Random|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200310280741
111603|111603-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Sub-WrapPackages|1.0|darwin|5.8.1|darwin|6.8|200311152328
111628|111628-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Sub-WrapPackages|1.0|sun4-solaris|5.8.1|solaris|2.8|200311161149
111640|111640-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Statistics-ChiSquare|0.5|darwin|5.8.1|darwin|6.8|200311161944
111706|111706-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Statistics-ChiSquare|0.5|powerpc-linux|5.8.0|linux|2.4.23-pre5|200311172329
111711|111711-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Tie-Hash-Longest|1.1|darwin|5.8.1|darwin|6.8|200311180043
111714|111714-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Tie-Hash-Longest|1.1|powerpc-linux|5.8.0|linux|2.4.23-pre5|200311180020
111767|111767-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Statistics-ChiSquare|0.5|sun4-solaris|5.8.1|solaris|2.8|200311181021
111776|111776-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Tie-Hash-Longest|1.1|sun4-solaris|5.8.1|solaris|2.8|200311181049
111919|111919-b19f-3f77-b713-d32bba55d77f|pass|200311|webmaster@thr.msu.edu|Sub-WrapPackages|1.0|i386-freebsd|5.8.2|freebsd|5.1-current|200311191538
111932|111932-b19f-3f77-b713-d32bba55d77f|pass|200311|webmaster@thr.msu.edu|Statistics-ChiSquare|0.5|i386-freebsd|5.8.2|freebsd|5.1-current|200311191552
111946|111946-b19f-3f77-b713-d32bba55d77f|pass|200311|webmaster@thr.msu.edu|Tie-Hash-Longest|1.1|i386-freebsd|5.8.2|freebsd|5.1-current|200311191635
111994|111994-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Tie-Hash-Longest|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311200824
112009|112009-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Statistics-ChiSquare|0.5|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311200824
112018|112018-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Sub-WrapPackages|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311200824
112080|112080-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Statistics-SerialCorrelation|1.0|darwin|5.8.1|darwin|6.8|200311211439
112103|112103-b19f-3f77-b713-d32bba55d77f|pass|200311|nothingmuch@woobling.org|Statistics-SerialCorrelation|1.0|powerpc-linux|5.8.0|linux|2.4.23-pre5|200311211803
112146|112146-b19f-3f77-b713-d32bba55d77f|pass|200311|webmaster@thr.msu.edu|Statistics-SerialCorrelation|1.0|i386-freebsd|5.8.2|freebsd|5.1-current|200311220119
112172|112172-b19f-3f77-b713-d32bba55d77f|pass|200311|Perl_Test@LogicalChaos.org|Sub-WrapPackages|1.0|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220236
112185|112185-b19f-3f77-b713-d32bba55d77f|pass|200311|Perl_Test@LogicalChaos.org|Statistics-ChiSquare|0.5|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220248
112197|112197-b19f-3f77-b713-d32bba55d77f|pass|200311|Perl_Test@LogicalChaos.org|Tie-Hash-Longest|1.1|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220323
112240|112240-b19f-3f77-b713-d32bba55d77f|pass|200311|Perl_Test@LogicalChaos.org|Statistics-SerialCorrelation|1.0|i386-linux|5.8.0|linux|2.4.20-2mdkenterprise|200311220439
112272|112272-b19f-3f77-b713-d32bba55d77f|pass|200311|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Statistics-SerialCorrelation|1.0|sun4-solaris|5.8.1|solaris|2.8|200311221038
112788|112788-b19f-3f77-b713-d32bba55d77f|pass|200311|barbie@missbarbell.co.uk (Barbie)|Statistics-SerialCorrelation|1.0|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200311270726
113523|113523-b19f-3f77-b713-d32bba55d77f|pass|200312|root@uk-wrk-0017 ((root))|Sub-WrapPackages|1.0|i386-linux|5.8.1|linux|2.4.22-xfs+ti1211|200312021956
114594|114594-b19f-3f77-b713-d32bba55d77f|fail|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Bryar|2.1|sun4-solaris|5.8.1|solaris|2.8|200312121042
115002|115002-b19f-3f77-b713-d32bba55d77f|pass|200312|barbie@missbarbell.co.uk (Barbie)|Bryar|2.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312152024
115405|115405-b19f-3f77-b713-d32bba55d77f|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|File-Find-Rule-Permissions|1.2|sun4-solaris|5.8.1|solaris|2.8|200312191034
115506|115506-b19f-3f77-b713-d32bba55d77f|pass|200312|webmaster@thr.msu.edu|File-Find-Rule-Permissions|1.2|i386-freebsd|5.6.1|freebsd|5.2-beta|200312200410
115565|115565-b19f-3f77-b713-d32bba55d77f|na|200312|barbie@missbarbell.co.uk (Barbie)|File-Find-Rule-Permissions|1.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312201228
115890|115890-b19f-3f77-b713-d32bba55d77f|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.03|sun4-solaris|5.8.1|solaris|2.8|200312241039
115892|115892-b19f-3f77-b713-d32bba55d77f|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.04|sun4-solaris|5.8.1|solaris|2.8|200312241040
115938|115938-b19f-3f77-b713-d32bba55d77f|pass|200312|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.04|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312242048
115941|115941-b19f-3f77-b713-d32bba55d77f|pass|200312|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.03|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200312242048
115967|115967-b19f-3f77-b713-d32bba55d77f|pass|200312|lithron@bellsouth.net|Data-Compare|0.04|cygwin-thread-multi-64int|5.8.2|cygwin|1.5.5(0.9432)|200312250300
115981|115981-b19f-3f77-b713-d32bba55d77f|pass|200312|webmaster@thr.msu.edu|Data-Compare|0.03|i386-freebsd|5.8.2|freebsd|5.2-current|200312251145
115983|115983-b19f-3f77-b713-d32bba55d77f|pass|200312|webmaster@thr.msu.edu|Data-Compare|0.04|i386-freebsd|5.8.2|freebsd|5.2-current|200312251146
116371|116371-b19f-3f77-b713-d32bba55d77f|pass|200312|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.05|sun4-solaris|5.8.1|solaris|2.8|200312311027
116578|116578-b19f-3f77-b713-d32bba55d77f|pass|200401|webmaster@thr.msu.edu|Data-Compare|0.05|i386-freebsd|5.8.2|freebsd|5.2-current|200401021841
117144|117144-b19f-3f77-b713-d32bba55d77f|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.05|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401062214
117236|117236-b19f-3f77-b713-d32bba55d77f|pass|200401|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.06|sun4-solaris|5.8.1|solaris|2.8|200401070853
117337|117337-b19f-3f77-b713-d32bba55d77f|pass|200401|jlatour@calaquendi.net|Data-Compare|0.06|i586-linux|5.8.2|linux|2.2.16c37_iii|200401080005
117380|117380-b19f-3f77-b713-d32bba55d77f|pass|200401|webmaster@thr.msu.edu|Data-Compare|0.06|i386-freebsd|5.8.2|freebsd|5.2-current|200401080041
117485|117485-b19f-3f77-b713-d32bba55d77f|pass|200401|jlatour@calaquendi.net|Data-Compare|0.07|i586-linux|5.8.2|linux|2.2.16c37_iii|200401081057
117505|117505-b19f-3f77-b713-d32bba55d77f|pass|200401|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.07|sun4-solaris|5.8.1|solaris|2.8|200401081034
117607|117607-b19f-3f77-b713-d32bba55d77f|pass|200401|webmaster@thr.msu.edu|Data-Compare|0.07|i386-freebsd|5.8.2|freebsd|5.2-current|200401090408
117898|117898-b19f-3f77-b713-d32bba55d77f|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.07|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401100851
117907|117907-b19f-3f77-b713-d32bba55d77f|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.06|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401100851
119387|119387-b19f-3f77-b713-d32bba55d77f|pass|200401|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.08|sun4-solaris|5.8.1|solaris|2.8|200401210824
119444|119444-b19f-3f77-b713-d32bba55d77f|pass|200401|steve@gandalf.workpc.tds.net ((root))|Data-Compare|0.08|i386-linux|5.8.1|linux|2.4.21-2.elsmp|200401211242
119557|119557-b19f-3f77-b713-d32bba55d77f|pass|200401|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.08|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200401222135
119724|119724-b19f-3f77-b713-d32bba55d77f|pass|200401|steve@gandalf.workpc.tds.net ((root))|Bryar|2.3|i386-linux|5.8.1|linux|2.4.21-2.elsmp|200401231111
119747|119747-b19f-3f77-b713-d32bba55d77f|pass|200401|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Bryar|2.2|sun4-solaris|5.8.1|solaris|2.8|200401241057
119757|119757-b19f-3f77-b713-d32bba55d77f|pass|200401|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Statistics-SerialCorrelation|1.1|sun4-solaris|5.8.1|solaris|2.8|200401241132
119881|119881-b19f-3f77-b713-d32bba55d77f|pass|200401|webmaster@thr.msu.edu|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.2|freebsd|5.2-current|200401260203
120817|120817-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402030754
120850|120850-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.3|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402030754
120895|120895-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Statistics-SerialCorrelation|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402030755
121670|121670-b19f-3f77-b713-d32bba55d77f|pass|200402|nothingmuch@woobling.org|Bryar|2.4|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402081917
121763|121763-b19f-3f77-b713-d32bba55d77f|pass|200402|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Bryar|2.5|sun4-solaris|5.8.1|solaris|2.8|200402091052
122036|122036-b19f-3f77-b713-d32bba55d77f|pass|200402|nothingmuch@woobling.org|Bryar|2.6|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402111538
122175|122175-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.5|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402120813
122192|122192-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.4|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402120813
122308|122308-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Bryar|2.6|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402130742
123333|123333-b19f-3f77-b713-d32bba55d77f|pass|200402|nothingmuch@woobling.org|Data-Hexdumper|1.2|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402201702
123394|123394-b19f-3f77-b713-d32bba55d77f|pass|200402|cpansmoke@alternation.net|Data-Hexdumper|1.2|i586-linux|5.8.0|linux|2.4.22-4tr|200402210507
123399|123399-b19f-3f77-b713-d32bba55d77f|pass|200402|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Hexdumper|1.2|sun4-solaris|5.8.1|solaris|2.8|200402211022
123609|123609-b19f-3f77-b713-d32bba55d77f|pass|200402|webmaster@thr.msu.edu|Data-Hexdumper|1.2|i386-freebsd|5.8.2|freebsd|5.2-current|200402221849
123735|123735-b19f-3f77-b713-d32bba55d77f|pass|200402|nothingmuch@woobling.org|Data-Compare|0.09|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200402240107
123796|123796-b19f-3f77-b713-d32bba55d77f|pass|200402|Jost.Krieger+smokeback@sunu991.rz.ruhr-uni-bochum.de ((Jost Krieger))|Data-Compare|0.09|sun4-solaris|5.8.1|solaris|2.8|200402241052
123817|123817-b19f-3f77-b713-d32bba55d77f|pass|200402|cpansmoke@alternation.net|Data-Compare|0.09|i586-linux|5.8.0|linux|2.4.22-4tr|200402240807
123896|123896-b19f-3f77-b713-d32bba55d77f|pass|200402|webmaster@thr.msu.edu|Data-Compare|0.09|i386-freebsd|5.8.2|freebsd|5.2-current|200402241850
124187|124187-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Data-Hexdumper|1.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402260808
124420|124420-b19f-3f77-b713-d32bba55d77f|pass|200402|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.09|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200402270721
127016|127016-b19f-3f77-b713-d32bba55d77f|pass|200403|nothingmuch@woobling.org|Data-Compare|0.1|ppc-darwin-thread-multi|5.8.3|darwin|7.2.0|200403131335
127052|127052-b19f-3f77-b713-d32bba55d77f|pass|200403|cpansmoke@alternation.net|Data-Compare|0.1|i586-linux|5.8.0|linux|2.4.22-4tr|200403131807
127114|127114-b19f-3f77-b713-d32bba55d77f|pass|200403|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Data-Compare|0.1|sun4-solaris|5.8.1|solaris|2.8|200403141030
127238|127238-b19f-3f77-b713-d32bba55d77f|pass|200403|webmaster@thr.msu.edu|Data-Compare|0.1|i386-freebsd|5.8.2|freebsd|5.2-current|200403141830
128050|128050-b19f-3f77-b713-d32bba55d77f|pass|200403|barbie@missbarbell.co.uk (Barbie)|Data-Compare|0.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200403180756
129983|129983-b19f-3f77-b713-d32bba55d77f|pass|200403|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200403291616
132100|132100-b19f-3f77-b713-d32bba55d77f|pass|200404|cpansmoke@alternation.net|Bryar|2.6|i586-linux|5.8.0|linux|2.4.22-4tr|200404090008
132861|132861-b19f-3f77-b713-d32bba55d77f|pass|200404|kriegjcb@sunu991.rz.ruhr-uni-bochum.de|Bryar|2.6|sun4-solaris|5.8.1|solaris|2.8|200404150923
142676|142676-b19f-3f77-b713-d32bba55d77f|pass|200406|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.11|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200406030737
142964|142964-b19f-3f77-b713-d32bba55d77f|pass|200406|rrwo@cpan.org|Data-Compare|0.11|MSWin32-x86-multi-thread|5.8.3|MSWin32|4.0|200406040942
146822|146822-b19f-3f77-b713-d32bba55d77f|pass|200407|cpansmoke@alternation.net|Data-Compare|0.11|i586-linux|5.8.0|linux|2.4.22-4tr|200407050908
147721|147721-b19f-3f77-b713-d32bba55d77f|pass|200407|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-ChiSquare|0.5|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200407080346
148267|148267-b19f-3f77-b713-d32bba55d77f|pass|200407|rrwo@cpan.org|Class-CanBeA|1.0|MSWin32-x86-multi-thread|5.8.3|MSWin32|4.0|200407110109
148277|148277-b19f-3f77-b713-d32bba55d77f|pass|200407|rrwo@cpan.org|Class-CanBeA|1.0|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200407110250
148287|148287-b19f-3f77-b713-d32bba55d77f|pass|200407|cpansmoke@alternation.net|Class-CanBeA|1.0|i586-linux|5.8.0|linux|2.4.22-4tr|200407110408
148986|148986-b19f-3f77-b713-d32bba55d77f|pass|200407|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Class-CanBeA|1.0|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200407140502
151471|151471-b19f-3f77-b713-d32bba55d77f|pass|200407|webmaster@thr.msu.edu|Data-Compare|0.11|i386-freebsd-64int|5.8.4|freebsd|5.2-current|200407301504
154082|154082-b19f-3f77-b713-d32bba55d77f|pass|200408|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.0|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200408182140
154114|154114-b19f-3f77-b713-d32bba55d77f|pass|200408|cpantester@thr.msu.edu|Number-Phone|1.0|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200408190127
154121|154121-b19f-3f77-b713-d32bba55d77f|pass|200408|rrwo@cpan.org|Number-Phone|1.0|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200408190341
154183|154183-b19f-3f77-b713-d32bba55d77f|pass|200408|martin.thurn@ngc.com ("Thurn, Martin")|Number-Phone|1.0|sun4-solaris|5.9.1|solaris|2.8|200408190754
155673|155673-b19f-3f77-b713-d32bba55d77f|unknown|200409|jim@jimandkoka.com|Acme-Pony|1.1.2|darwin-2level|5.8.4|darwin|7.3.0|200409021509
156532|156532-b19f-3f77-b713-d32bba55d77f|pass|200409|Jost.Krieger+perl@rub.de|Net-Random|1.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409071326
156605|156605-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((CPAN Tester + CPAN++ automate))|Net-Random|1.1|ppc-linux|5.8.4|linux|2.4.19-4a|200409072209
156606|156606-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((CPAN Tester. CPAN++ automate))|Net-Random|1.1|OpenBSD.i386-openbsd|5.8.4|openbsd|3.5|200409080011
156917|156917-b19f-3f77-b713-d32bba55d77f|fail|200409|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|Net-Random|1.1|i386-netbsd-64int|5.8.4|netbsd|1.6|200409090006
157366|157366-b19f-3f77-b713-d32bba55d77f|pass|200409|barbie@missbarbell.co.uk (Barbie)|Net-Random|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409110708
158211|158211-b19f-3f77-b713-d32bba55d77f|pass|200409|Jost.Krieger+perl@rub.de|Number-Phone|1.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409160411
158232|158232-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((Cpan Tester - CPAN++ Automate ))|Number-Phone|1.1|i386-netbsd-64int|5.8.4|netbsd|1.6|200409161150
158233|158233-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((CPAN Tester. CPAN++ automate))|Number-Phone|1.1|OpenBSD.i386-openbsd|5.8.4|openbsd|3.5|200409161349
158237|158237-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((alian))|Number-Phone|1.1|sparc64-linux|5.8.5|linux|2.4.18|200409161204
158254|158254-b19f-3f77-b713-d32bba55d77f|pass|200409|martin.thurn@ngc.com ("Thurn, Martin")|Number-Phone|1.1|sun4-solaris|5.9.1|solaris|2.8|200409160520
158727|158727-b19f-3f77-b713-d32bba55d77f|pass|200409|cpantester@thr.msu.edu|Net-Random|1.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200409171223
158921|158921-b19f-3f77-b713-d32bba55d77f|pass|200409|cpantester@thr.msu.edu|Number-Phone|1.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200409180135
159531|159531-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((CPAN Tester + CPAN++ automate))|Number-Phone|1.1|ppc-linux|5.8.4|linux|2.4.19-4a|200409210855
159704|159704-b19f-3f77-b713-d32bba55d77f|pass|200409|barbie@missbarbell.co.uk (Barbie)|Number-Phone|1.1|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200409220830
160038|160038-b19f-3f77-b713-d32bba55d77f|pass|200409|Jost.Krieger+perl@rub.de|Number-Phone|1.2|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200409230357
160051|160051-b19f-3f77-b713-d32bba55d77f|pass|200409|alian@cpan.org ((CPAN Tester + CPAN++ automate))|Number-Phone|1.2|ppc-linux|5.8.4|linux|2.4.19-4a|200409230919
160093|160093-b19f-3f77-b713-d32bba55d77f|pass|200409|martin.thurn@ngc.com ("Thurn, Martin")|Number-Phone|1.2|sun4-solaris|5.9.1|solaris|2.8|200409230617
162192|162192-b19f-3f77-b713-d32bba55d77f|pass|200410|Jost.Krieger+perl@rub.de|Number-Phone|1.2001|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410132331
162785|162785-b19f-3f77-b713-d32bba55d77f|pass|200410|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|2.8_01|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410190938
162948|162948-b19f-3f77-b713-d32bba55d77f|pass|200410|Jost.Krieger+perl@rub.de|Number-Phone|1.3|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410210359
163103|163103-b19f-3f77-b713-d32bba55d77f|pass|200410|Jost.Krieger+perl@rub.de|Bryar|2.6|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410230659
163394|163394-b19f-3f77-b713-d32bba55d77f|pass|200410|Jost.Krieger+perl@rub.de|Acme-Scurvy-Whoreson-BilgeRat|1.1|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200410260359
163426|163426-b19f-3f77-b713-d32bba55d77f|pass|200410|shlomif@iglu.org.il (Shlomi Fish)|Number-Phone|1.3|i686-linux|5.8.5|linux|2.6.8.1-10mdksmp|200410261443
163536|163536-b19f-3f77-b713-d32bba55d77f|pass|200410|barbie@missbarbell.co.uk|Number-Phone|1.2|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200410270912
164481|164481-b19f-3f77-b713-d32bba55d77f|pass|200411|cpantester@thr.msu.edu|Number-Phone|1.2|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411021233
164948|164948-b19f-3f77-b713-d32bba55d77f|pass|200411|cpantester@thr.msu.edu|Number-Phone|1.2001|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411031032
165117|165117-b19f-3f77-b713-d32bba55d77f|pass|200411|corion+cpansmoker@corion.net|Acme-Scurvy-Whoreson-BilgeRat|1.1|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411031909
165645|165645-b19f-3f77-b713-d32bba55d77f|pass|200411|saper@cpan.org|Data-Compare|0.11|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200411071232
165739|165739-b19f-3f77-b713-d32bba55d77f|pass|200411|corion-cpansmoker@corion.net|Data-Transactional|0.1|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411071010
165993|165993-b19f-3f77-b713-d32bba55d77f|pass|200411|cpantester@thr.msu.edu|Data-Transactional|0.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411090940
166096|166096-b19f-3f77-b713-d32bba55d77f|pass|200411|saper@cpan.org|Data-Compare|0.13|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200411110826
166129|166129-b19f-3f77-b713-d32bba55d77f|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.12|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200411100845
166130|166130-b19f-3f77-b713-d32bba55d77f|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.13|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200411100846
166207|166207-b19f-3f77-b713-d32bba55d77f|pass|200411|barbie@missbarbell.co.uk|Number-Phone|1.2001|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411101259
166420|166420-b19f-3f77-b713-d32bba55d77f|pass|200411|rrwo@cpan.org|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200411110047
166421|166421-b19f-3f77-b713-d32bba55d77f|pass|200411|rrwo@cpan.org|Data-Compare|0.12|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200411110048
166465|166465-b19f-3f77-b713-d32bba55d77f|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.3001|sun4-solaris-thread-multi|5.8.3|solaris|2.8|200411111217
166521|166521-b19f-3f77-b713-d32bba55d77f|pass|200411|barbie@missbarbell.co.uk|Number-Phone|1.3|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411111855
166525|166525-b19f-3f77-b713-d32bba55d77f|fail|200411|barbie@missbarbell.co.uk|Bryar|2.8_01|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411111855
166546|166546-b19f-3f77-b713-d32bba55d77f|fail|200411|barbie@missbarbell.co.uk|Data-Compare|0.13|MSWin32-x86-multi-thread|5.6.1|MSWin32|4.0|200411111855
166588|166588-b19f-3f77-b713-d32bba55d77f|pass|200411|cpantester@thr.msu.edu|Data-Compare|0.12|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411111416
166590|166590-b19f-3f77-b713-d32bba55d77f|pass|200411|cpantester@thr.msu.edu|Data-Compare|0.13|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411111416
166610|166610-b19f-3f77-b713-d32bba55d77f|pass|200411|corion-cpansmoker@corion.net|Number-Phone|1.3001|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411112036
166652|166652-b19f-3f77-b713-d32bba55d77f|pass|200411|cpantester@thr.msu.edu|Number-Phone|1.3001|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200411111530
166717|166717-b19f-3f77-b713-d32bba55d77f|pass|200411|Jost.Krieger+cpanplus@rub.de|Data-Transactional|0.1|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200411120929
167036|167036-b19f-3f77-b713-d32bba55d77f|pass|200411|shlomif@iglu.org.il (Shlomi Fish)|Number-Phone|1.3001|i686-linux|5.8.5|linux|2.6.8.1-10mdksmp|200411132058
169429|169429-b19f-3f77-b713-d32bba55d77f|pass|200411|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.3002|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200411261633
169442|169442-b19f-3f77-b713-d32bba55d77f|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.9.1|linux|2.6.8.1|200411262046
169444|169444-b19f-3f77-b713-d32bba55d77f|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i386-linux-thread|5.8.4|linux|2.6.7-gentoo-r11|200411262047
169521|169521-b19f-3f77-b713-d32bba55d77f|fail|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.5.4|linux|2.6.8.1|200411262045
169522|169522-b19f-3f77-b713-d32bba55d77f|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.6.2|linux|2.6.8.1|200411262046
169524|169524-b19f-3f77-b713-d32bba55d77f|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux-thread-multi|5.9.1|linux|2.6.8.1|200411262047
169526|169526-b19f-3f77-b713-d32bba55d77f|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux|5.8.5|linux|2.6.8.1|200411262048
169528|169528-b19f-3f77-b713-d32bba55d77f|pass|200411|nothingmuch@woobling.org|Number-Phone|1.3002|i686-linux-thread-multi|5.8.5|linux|2.6.8.1|200411262048
169559|169559-b19f-3f77-b713-d32bba55d77f|pass|200411|corion-cpansmoker@corion.net|Number-Phone|1.3002|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200411270047
169740|169740-b19f-3f77-b713-d32bba55d77f|pass|200411|saper@cpan.org|Number-Phone|1.3002|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200411271546
169753|169753-b19f-3f77-b713-d32bba55d77f|pass|200411|saper@cpan.org|Number-Phone|1.3002|darwin|5.6.0|darwin|6.0|200411271602
172027|172027-b19f-3f77-b713-d32bba55d77f|pass|200412|Jost.Krieger+cpanplus@rub.de|Number-Phone|1.3003|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200412060512
172039|172039-b19f-3f77-b713-d32bba55d77f|fail|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.5.4|linux|2.6.8.1|200412061054
172045|172045-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.6.2|linux|2.6.8.1|200412061106
172055|172055-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.9.2 patch 23609|linux|2.6.8.1|200412061115
172072|172072-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux-thread-multi|5.9.2 patch 23609|linux|2.6.8.1|200412061138
172080|172080-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux|5.8.6|linux|2.6.8.1|200412061149
172095|172095-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412061203
172107|172107-b19f-3f77-b713-d32bba55d77f|pass|200412|saper@cpan.org|Number-Phone|1.3003|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200412061110
172118|172118-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Number-Phone|1.3003|i386-linux-thread|5.8.4|linux|2.6.7-gentoo-r11|200412061222
172178|172178-b19f-3f77-b713-d32bba55d77f|pass|200412|corion-cpansmoker@corion.net|Number-Phone|1.3003|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200412061934
172666|172666-b19f-3f77-b713-d32bba55d77f|pass|200412|foo@bar.com|Acme-Pony|1.1.2|darwin-thread-multi-2level|5.8.1 RC3|darwin|7.0|200412081422
172735|172735-b19f-3f77-b713-d32bba55d77f|fail|200412|nothingmuch@woobling.org|Data-Compare|0.13|i686-linux|5.6.2|linux|2.6.8.1|200412090318
172774|172774-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Data-Compare|0.13|i686-linux|5.8.6|linux|2.6.8.1|200412090439
172783|172783-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Data-Compare|0.13|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412090454
174147|174147-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux|5.6.2|linux|2.6.8.1|200412151759
174466|174466-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux|5.9.2 patch 23656|linux|2.6.8.1|200412170002
174476|174476-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux-thread-multi|5.9.2 patch 23656|linux|2.6.8.1|200412170021
174501|174501-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Sub-WrapPackages|1.0|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412170049
174828|174828-b19f-3f77-b713-d32bba55d77f|pass|200412|saper@cpan.org|Sub-WrapPackages|1.0|darwin|5.6.0|darwin|6.0|200412190038
175191|175191-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux|5.6.2|linux|2.6.8.1|200412211016
175207|175207-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux|5.9.2 patch 23662|linux|2.6.8.1|200412211029
175225|175225-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux-thread-multi|5.9.2 patch 23662|linux|2.6.8.1|200412211043
175238|175238-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i386-linux-thread|5.8.4|linux|2.6.7-gentoo-r11|200412211101
175264|175264-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux|5.8.6|linux|2.6.8.1|200412211123
175282|175282-b19f-3f77-b713-d32bba55d77f|pass|200412|nothingmuch@woobling.org|Class-CanBeA|1.1|i686-linux-thread-multi|5.8.6|linux|2.6.8.1|200412211139
175392|175392-b19f-3f77-b713-d32bba55d77f|pass|200412|rrwo@cpan.org|Class-CanBeA|1.1|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200412211514
175604|175604-b19f-3f77-b713-d32bba55d77f|pass|200412|Jost.Krieger@ruhr-uni-bochum.de|Class-CanBeA|1.1|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200412221554
175780|175780-b19f-3f77-b713-d32bba55d77f|pass|200412|saper@cpan.org|Class-CanBeA|1.1|i386-linux|5.8.1|linux|2.4.18-23mdksmp|200412230008
176594|176594-b19f-3f77-b713-d32bba55d77f|pass|200501|rrwo@cpan.org|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200501011906
176599|176599-b19f-3f77-b713-d32bba55d77f|pass|200501|rrwo@cpan.org|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200501011908
177521|177521-b19f-3f77-b713-d32bba55d77f|pass|200501|cpantester@thr.msu.edu|Number-Phone|1.3003|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501080223
177682|177682-b19f-3f77-b713-d32bba55d77f|pass|200501|cpantester@thr.msu.edu|Sub-WrapPackages|1.0|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501080846
177830|177830-b19f-3f77-b713-d32bba55d77f|pass|200501|cpantester@thr.msu.edu|Class-CanBeA|1.1|i386-freebsd-64int|5.8.5|freebsd|5.2-current|200501090029
178996|178996-b19f-3f77-b713-d32bba55d77f|pass|200501|saper@cpan.org|Data-Compare|0.13|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200501162222
179170|179170-b19f-3f77-b713-d32bba55d77f|pass|200501|root@fisharerojo.org ((Charlie &))|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-openbsd|5.8.5|openbsd|3.6|200501180850
179209|179209-b19f-3f77-b713-d32bba55d77f|pass|200501|shlomif@iglu.org.il (Shlomi Fish)|Sub-WrapPackages|1.0|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200501181930
179679|179679-b19f-3f77-b713-d32bba55d77f|pass|200501|rrwo@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200501201640
180545|180545-b19f-3f77-b713-d32bba55d77f|pass|200501|saperghis@aacom.fr|Data-Compare|0.13|i386-linux|5.8.3|linux|2.6.0-1mdkenterprise|200501241408
180718|180718-b19f-3f77-b713-d32bba55d77f|pass|200501|root@fisharerojo.org ((Charlie &))|Bryar|2.6|i386-openbsd|5.8.5|openbsd|3.6|200501250751
181235|181235-b19f-3f77-b713-d32bba55d77f|fail|200501|corion-cpansmoker@corion.net|Palm-SMS|0.02|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200501290957
181709|181709-b19f-3f77-b713-d32bba55d77f|pass|200502|cpansmoke@alternation.net|Sub-WrapPackages|1.0|i586-linux|5.8.3|linux|2.4.21-13trfirewallsmp|200502020612
181897|181897-b19f-3f77-b713-d32bba55d77f|pass|200502|saper@cpan.org|Sub-WrapPackages|1.0|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200502022306
182231|182231-b19f-3f77-b713-d32bba55d77f|pass|200502|cpantester@thr.msu.edu|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-64int|5.8.6|freebsd|5.3-stable|200502031858
185115|185115-b19f-3f77-b713-d32bba55d77f|pass|200502|rrwo@cpan.org|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200502182335
189095|189095-b19f-3f77-b713-d32bba55d77f|pass|200503|saper@cpan.org|Data-Hexdumper|1.2|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200503100108
196329|196329-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504032333
196772|196772-b19f-3f77-b713-d32bba55d77f|pass|200504|cpan@calaquendi.net|Data-Compare|0.13|i386-freebsd-64int|5.8.6|freebsd|4.10-release-p3|200504042125
197527|197527-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.3003|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504081244
197600|197600-b19f-3f77-b713-d32bba55d77f|pass|200504|rrwo@cpan.org|Number-Phone|1.3003|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200504081254
197676|197676-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|Number-Phone|1.3003|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200504082105
197683|197683-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.3003|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504090406
198129|198129-b19f-3f77-b713-d32bba55d77f|pass|200504|saper@cpan.org|Number-Phone|1.3003|sun4-solaris|5.8.5|solaris|2.9|200504111111
198209|198209-b19f-3f77-b713-d32bba55d77f|pass|200504|corion-cpanplus@corion.net|Number-Phone|1.3003|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504111758
198491|198491-b19f-3f77-b713-d32bba55d77f|pass|200504|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.3004|i386-freebsd-64int|5.8.6|freebsd|5.4-prerelease|200504131128
198591|198591-b19f-3f77-b713-d32bba55d77f|pass|200504|corion-cpanplus@corion.net|Number-Phone|1.3004|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200504132021
208372|208372-b19f-3f77-b713-d32bba55d77f|pass|200505|saper@cpan.org|Number-Phone|1.4|sun4-solaris|5.8.5|solaris|2.9|200505191028
208402|208402-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Number-Phone|1.4|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200505192028
208414|208414-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Number-Phone|1.4|MSWin32-x86-multi-thread|5.8.6|MSWin32|4.0|200505192055
208419|208419-b19f-3f77-b713-d32bba55d77f|pass|200505|imacat@mail.imacat.idv.tw|Number-Phone|1.4|i686-linux-thread-multi-64int-ld|5.8.6|linux|2.4.30|200505192057
208639|208639-b19f-3f77-b713-d32bba55d77f|pass|200505|Jost.Krieger@ruhr-uni-bochum.de|Number-Phone|1.4|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200505200649
208931|208931-b19f-3f77-b713-d32bba55d77f|pass|200505|corion-cpanplus@corion.net|Number-Phone|1.4|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200505202142
209198|209198-b19f-3f77-b713-d32bba55d77f|pass|200505|saper@cpan.org|Number-Phone|1.4|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200505220037
211199|211199-b19f-3f77-b713-d32bba55d77f|pass|200505|root@houseabsolute.urth.org ((root))|Data-Compare|0.13|i386-linux|5.8.4|linux|2.4.27-ti1211|200505310008
211443|211443-b19f-3f77-b713-d32bba55d77f|fail|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-SMS|0.01|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506020717
214964|214964-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Number-Phone|1.4|darwin|5.6.0|darwin|6.0|200506120128
219764|219764-b19f-3f77-b713-d32bba55d77f|pass|200506|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.4001|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200506281457
220045|220045-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Number-Phone|1.4001|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200506291710
220096|220096-b19f-3f77-b713-d32bba55d77f|pass|200506|saper@cpan.org|Number-Phone|1.4001|sun4-solaris|5.8.5|solaris|2.9|200506291213
220127|220127-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Number-Phone|1.4001|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506292034
220138|220138-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Number-Phone|1.4001|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200506292041
220280|220280-b19f-3f77-b713-d32bba55d77f|pass|200506|corion-cpanplus@corion.net|Number-Phone|1.4001|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506300845
220308|220308-b19f-3f77-b713-d32bba55d77f|pass|200506|corion-cpanplus@corion.net|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200506300919
220438|220438-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Compare|0.13|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200506302053
220485|220485-b19f-3f77-b713-d32bba55d77f|pass|200506|imacat@mail.imacat.idv.tw|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.6|cygwin|1.5.12(0.11642)|200506302147
220553|220553-b19f-3f77-b713-d32bba55d77f|pass|200507|saper@cpan.org|Number-Phone|1.4001|i386-linux|5.8.5|linux|2.4.19-44mdkenterprise|200507010001
220664|220664-b19f-3f77-b713-d32bba55d77f|pass|200507|root@berthoudwireless.net ((root))|Data-Compare|0.13|i686-linux|5.8.7|linux|2.6.12-gentoo-r2|200507010103
223927|223927-b19f-3f77-b713-d32bba55d77f|pass|200507|saper@cpan.org|Data-Compare|0.13|sun4-solaris|5.8.5|solaris|2.9|200507130954
226474|226474-b19f-3f77-b713-d32bba55d77f|pass|200507|saper@cpan.org|Number-Phone|1.4001|darwin|5.6.0|darwin|6.0|200507210008
228104|228104-b19f-3f77-b713-d32bba55d77f|pass|200507|imacat@mail.imacat.idv.tw|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200507272149
229324|229324-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508011634
230507|230507-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4002|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508032142
230641|230641-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4002|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508042018
230643|230643-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4002|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200508042019
231459|231459-b19f-3f77-b713-d32bba55d77f|pass|200508|corion-cpanplus@corion.net|Number-Phone|1.4002|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200508072159
232232|232232-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Number-Phone|1.4002|sun4-solaris|5.8.5|solaris|2.9|200508091108
233794|233794-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Hexdumper|1.2|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508141701
234470|234470-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.2|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508170017
236166|236166-b19f-3f77-b713-d32bba55d77f|pass|200508|gwood@email.mot.com ((George W Wood))|Data-Compare|0.13|i686-linux|5.8.6|linux|2.4.21-20.elsmp|200508220342
236819|236819-b19f-3f77-b713-d32bba55d77f|pass|200508|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.4003|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200508241729
236907|236907-b19f-3f77-b713-d32bba55d77f|pass|200508|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.4003|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200508241616
236968|236968-b19f-3f77-b713-d32bba55d77f|pass|200508|saper@cpan.org|Number-Phone|1.4003|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200508242102
237109|237109-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4003|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200508250747
237124|237124-b19f-3f77-b713-d32bba55d77f|pass|200508|imacat@mail.imacat.idv.tw|Number-Phone|1.4003|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200508250805
237270|237270-b19f-3f77-b713-d32bba55d77f|pass|200508|rrwo@cpan.org|Number-Phone|1.4003|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.1|200508251439
244310|244310-b19f-3f77-b713-d32bba55d77f|pass|200509|meneldor@metallibrary.ru|Data-Hexdumper|1.2|i386-linux|5.8.3|linux|2.4.21-9.elsmp|200509161951
244808|244808-b19f-3f77-b713-d32bba55d77f|pass|200509|ultradm@cpan.org|Data-Compare|0.13|i686-linux-thread|5.8.6|linux|2.6.11-gentoo-r6|200509172039
245054|245054-b19f-3f77-b713-d32bba55d77f|pass|200509|corion-cpanplus@corion.net|Data-Hexdumper|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200509172204
245305|245305-b19f-3f77-b713-d32bba55d77f|pass|200509|njh@despammed.com|Data-Hexdumper|1.2|ppc-linux|5.8.3|linux|2.6.6-1.1326smp|200509171902
246450|246450-b19f-3f77-b713-d32bba55d77f|pass|200509|david@landgren.net|Data-Hexdumper|1.2|i386-freebsd|5.8.1|freebsd|5.4-stable|200509191213
247422|247422-b19f-3f77-b713-d32bba55d77f|pass|200509|njh@despammed.com|Data-Compare|0.13|i386-linux|5.8.7|linux|2.4.27-ti1211|200509201402
258137|258137-b19f-3f77-b713-d32bba55d77f|pass|200510|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.4004|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200510121351
258161|258161-b19f-3f77-b713-d32bba55d77f|pass|200510|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.4004|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200510120819
258306|258306-b19f-3f77-b713-d32bba55d77f|pass|200510|corion-cpanplus@corion.net|Number-Phone|1.4004|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200510122021
258774|258774-b19f-3f77-b713-d32bba55d77f|pass|200510|njh@despammed.com|Number-Phone|1.4004|i386-linux|5.8.5|linux|2.4.21-25.elsmp|200510131058
258922|258922-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Number-Phone|1.4004|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510132040
259968|259968-b19f-3f77-b713-d32bba55d77f|pass|200510|saper@cpan.org|Number-Phone|1.5|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200510161745
260021|260021-b19f-3f77-b713-d32bba55d77f|pass|200510|imacat@mail.imacat.idv.tw|Number-Phone|1.5|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.30|200510170414
260029|260029-b19f-3f77-b713-d32bba55d77f|pass|200510|imacat@mail.imacat.idv.tw|Number-Phone|1.5|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200510170421
260051|260051-b19f-3f77-b713-d32bba55d77f|pass|200510|leeym@utopia.leeym.com ((Yen-Ming Lee))|Number-Phone|1.5|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200510170844
260191|260191-b19f-3f77-b713-d32bba55d77f|pass|200510|imacat@mail.imacat.idv.tw|Number-Phone|1.4004|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200510180825
260587|260587-b19f-3f77-b713-d32bba55d77f|pass|200510|corion-cpanplus@corion.net|Number-Phone|1.5|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200510192027
260898|260898-b19f-3f77-b713-d32bba55d77f|pass|200510|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.5|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200510202001
261368|261368-b19f-3f77-b713-d32bba55d77f|pass|200510|njh@despammed.com|Number-Phone|1.5|i386-linux|5.8.6|linux|2.4.21-27.0.2.elsmp|200510221455
261541|261541-b19f-3f77-b713-d32bba55d77f|pass|200510|njh@despammed.com|Number-Phone|1.5|ppc-linux|5.8.3|linux|2.6.6-1.1326smp|200510221844
262207|262207-b19f-3f77-b713-d32bba55d77f|pass|200510|njh@despammed.com|Number-Phone|1.5|i486-linux-gnu|5.8.7|linux|2.6.14-rc4|200510251548
264405|264405-b19f-3f77-b713-d32bba55d77f|pass|200511|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200511010235
265861|265861-b19f-3f77-b713-d32bba55d77f|pass|200511|njh@despammed.com|Data-Compare|0.13|ppc-linux|5.8.3|linux|2.6.6-1.1326smp|200511051614
267538|267538-b19f-3f77-b713-d32bba55d77f|pass|200511|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.7|freebsd|5.4-stable|200511120225
269770|269770-b19f-3f77-b713-d32bba55d77f|pass|200511|postmaster@amsfep18-int.chello.nl|Data-Compare|0.13|MSWin32-x86-multi-thread|5.8.4|MSWin32|4.0|200511201354
275357|275357-b19f-3f77-b713-d32bba55d77f|pass|200512|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|1.2|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200512140828
275393|275393-b19f-3f77-b713-d32bba55d77f|pass|200512|leeym@utopia.leeym.com ((Yen-Ming Lee))|Net-Random|1.2|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200512141740
275676|275676-b19f-3f77-b713-d32bba55d77f|pass|200512|njh@despammed.com|Net-Random|1.2|i386-linux|5.8.6|linux|2.6.9-22.18.bz155725.elsmp|200512150658
275830|275830-b19f-3f77-b713-d32bba55d77f|pass|200512|corion-cpanplus@corion.net|Net-Random|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200512151939
279001|279001-b19f-3f77-b713-d32bba55d77f|pass|200512|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Class-CanBeA|1.2|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200512291152
279781|279781-b19f-3f77-b713-d32bba55d77f|pass|200601|corion-cpanplus@corion.net|Class-CanBeA|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200601011841
281710|281710-b19f-3f77-b713-d32bba55d77f|pass|200601|saper@cpan.org|Class-CanBeA|1.2|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200601110339
281711|281711-b19f-3f77-b713-d32bba55d77f|pass|200601|saper@cpan.org|Class-CanBeA|1.2|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200601110339
286555|286555-b19f-3f77-b713-d32bba55d77f|pass|200601|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Overwrite|1.0|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200601301202
287234|287234-b19f-3f77-b713-d32bba55d77f|pass|200602|leeym@utopia.leeym.com ((Yen-Ming Lee))|File-Overwrite|1.0|i386-freebsd-64int|5.8.7|freebsd|6.0-stable|200602012357
289121|289121-b19f-3f77-b713-d32bba55d77f|pass|200602|gam3-cpanplus@gam3.net|Data-Compare|0.13|i486-linux-gnu|5.8.7|linux|2.6.14-rc4|200602101344
300432|300432-b19f-3f77-b713-d32bba55d77f|pass|200603|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200603200436
305984|305984-b19f-3f77-b713-d32bba55d77f|pass|200604|edepagne@184dhcp145.pl.eso.org ((root))|Statistics-ChiSquare|0.5|i386-linux|5.8.7|linux|2.6.3-28mdk-i686-up-4gb|200604080602
308015|308015-b19f-3f77-b713-d32bba55d77f|pass|200604|root@chorny.net|Statistics-ChiSquare|0.5|i686-linux|5.8.8|linux|2.4.20-8smp|200604180521
312967|312967-b19f-3f77-b713-d32bba55d77f|pass|200605|leeym@utopia.leeym.com ((Yen-Ming Lee))|Data-Compare|0.13|i386-freebsd-64int|5.8.8|freebsd|6.1-prerelease|200605092239
314112|314112-b19f-3f77-b713-d32bba55d77f|pass|200605|Jost.Krieger+perl@rub.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200605151414
326166|326166-b19f-3f77-b713-d32bba55d77f|pass|200606|root@webigail.pooq.com ((root))|Data-Compare|0.13|i386-linux|5.8.8|linux|2.6.12-12mdksmp|200606301715
326827|326827-b19f-3f77-b713-d32bba55d77f|pass|200607|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.01|sun4-solaris-thread-multi|5.8.5|solaris|2.9|200607041255
326894|326894-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607050456
326896|326896-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607050458
327028|327028-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607060241
327156|327156-b19f-3f77-b713-d32bba55d77f|pass|200607|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.02|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200607061747
330218|330218-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Compare|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607190322
331278|331278-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607200146
331975|331975-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Number-Phone|1.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607202026
332024|332024-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Number-Phone|1.4004|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607201820
333143|333143-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Net-Random|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607220710
333371|333371-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607221801
334134|334134-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607231648
335574|335574-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Data-Compare|0.13|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607251327
336203|336203-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Number-Phone|1.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607260008
336692|336692-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Net-Random|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607261742
336789|336789-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607262132
337018|337018-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607270205
337872|337872-b19f-3f77-b713-d32bba55d77f|pass|200607|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sub-WrapPackages|1.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200607271444
338614|338614-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607281708
338982|338982-b19f-3f77-b713-d32bba55d77f|pass|200607|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200607291323
340236|340236-b19f-3f77-b713-d32bba55d77f|pass|200608|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608030100
340401|340401-b19f-3f77-b713-d32bba55d77f|pass|200608|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sub-WrapPackages|1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200608031203
340715|340715-b19f-3f77-b713-d32bba55d77f|pass|200608|jworkman@pimpworks.org (Jeff Workman)|Acme-Licence|1.0|i386-netbsd|5.8.3|netbsd|1.6.2|200608031600
341364|341364-b19f-3f77-b713-d32bba55d77f|pass|200608|corion-cpanplus@corion.net|Sub-WrapPackages|1.2|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200608050855
342214|342214-b19f-3f77-b713-d32bba55d77f|pass|200608|cogent@cpan.org|Data-Compare|0.13|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200608100437
344460|344460-b19f-3f77-b713-d32bba55d77f|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.51|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608240204
344713|344713-b19f-3f77-b713-d32bba55d77f|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.52|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250509
344714|344714-b19f-3f77-b713-d32bba55d77f|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.54|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250524
344715|344715-b19f-3f77-b713-d32bba55d77f|fail|200608|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250524
344716|344716-b19f-3f77-b713-d32bba55d77f|fail|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.53|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608250527
344828|344828-b19f-3f77-b713-d32bba55d77f|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone|1.55|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608260505
344829|344829-b19f-3f77-b713-d32bba55d77f|pass|200608|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200608260515
348551|348551-b19f-3f77-b713-d32bba55d77f|pass|200609|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200609140041
348707|348707-b19f-3f77-b713-d32bba55d77f|pass|200609|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200609140529
349313|349313-b19f-3f77-b713-d32bba55d77f|pass|200609|alexchorny@gmail.com (Alexandr Ciornii)|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.4.20-8smp|200609141102
351783|351783-b19f-3f77-b713-d32bba55d77f|pass|200609|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|0.13|i486-linux-gnu|5.8.7|linux|2.6.10|200609251531
353009|353009-b19f-3f77-b713-d32bba55d77f|pass|200609|mark.gardner@bms.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.4.21-37.0.1.el|200609281424
356781|356781-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200610082338
357072|357072-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-freebsd-64int|5.8.5|freebsd|5.3-release|200610091142
358244|358244-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i686-linux-thread-multi-64int-ld|5.8.7|linux|2.4.20-8|200610111335
358966|358966-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|alpha-freebsd|5.8.7|freebsd|6.0-release|200610121131
359236|359236-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200610121735
361330|361330-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610181038
365977|365977-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200610301814
366628|366628-b19f-3f77-b713-d32bba55d77f|pass|200610|chris@bingosnet.co.uk|Data-Compare|0.13|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200610311115
367382|367382-b19f-3f77-b713-d32bba55d77f|pass|200611|andreas.koenig.gmwojprw@franz.ak.mind.de ((Andreas J. Koenig))|Data-Compare|0.14|i686-linux-64int|5.9.5|linux|2.6.17-2-k7|200611012205
367439|367439-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200611020324
367783|367783-b19f-3f77-b713-d32bba55d77f|pass|200611|imacat@mail.imacat.idv.tw|Data-Compare|0.14|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200611030258
367810|367810-b19f-3f77-b713-d32bba55d77f|pass|200611|alexchorny@gmail.com|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200611020952
367872|367872-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200611022046
368276|368276-b19f-3f77-b713-d32bba55d77f|pass|200611|fayland@gmail.com|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200611030209
368354|368354-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200611031157
368655|368655-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Data-Compare|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200611031750
370342|370342-b19f-3f77-b713-d32bba55d77f|pass|200611|davidp@preshweb.co.uk ("David Precious")|Data-Compare|0.14|i486-linux|5.8.7|linux|2.4.31|200611081605
370768|370768-b19f-3f77-b713-d32bba55d77f|pass|200611|bladebrown@mail.ru|Data-Hexdumper|1.2|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200611110950
370898|370898-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200611112020
371195|371195-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200611121102
371918|371918-b19f-3f77-b713-d32bba55d77f|fail|200611|alexchorny@gmail.com|Bryar|2.6|MSWin32-x86-multi-thread|5.8.7|MSWin32|5.0|200611121255
372376|372376-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.18(0.13242)|200611132232
373000|373000-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200611141002
373148|373148-b19f-3f77-b713-d32bba55d77f|pass|200611|chris@bingosnet.co.uk|Bryar|2.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200611140821
381086|381086-b19f-3f77-b713-d32bba55d77f|pass|200612|gooba42@gmail.com|Games-Dice-Advanced|1.1|cygwin-thread-multi-64int|5.8.7|cygwin|1.5.18(0.13242)|200612010507
382411|382411-b19f-3f77-b713-d32bba55d77f|pass|200612|cogent@cpan.org|Data-Compare|0.14|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200612030522
383534|383534-b19f-3f77-b713-d32bba55d77f|unknown|200612|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200612052257
385883|385883-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200612130007
386086|386086-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200612132153
386324|386324-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200612141113
386332|386332-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200612141052
386341|386341-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200612141125
386581|386581-b19f-3f77-b713-d32bba55d77f|pass|200612|corion-cpanplus@corion.net|Number-Phone|1.56|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200612142241
387488|387488-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|sun4-solaris-64int|5.8.8|solaris|2.7|200612161308
388186|388186-b19f-3f77-b713-d32bba55d77f|pass|200612|chris@bingosnet.co.uk|Number-Phone|1.56|alpha-freebsd|5.8.7|freebsd|6.0-release|200612181024
393599|393599-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|Sub-WrapPackages|1.2|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701021141
393934|393934-b19f-3f77-b713-d32bba55d77f|pass|200701|autarch@urth.org|Data-Compare|0.14|i486-linux-gnu|5.8.8|linux|2.6.15.7|200701030556
394575|394575-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701041619
395005|395005-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|sun4-solaris-64int|5.8.8|solaris|2.7|200701060943
395212|395212-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|alpha-freebsd|5.8.7|freebsd|6.0-release|200701061407
395489|395489-b19f-3f77-b713-d32bba55d77f|pass|200701|njh@despammed.com|Data-Compare|0.14|i486-linux-gnu|5.8.7|linux|2.6.10|200701070017
395731|395731-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701071231
396008|396008-b19f-3f77-b713-d32bba55d77f|pass|200701|claco@chrislaco.com|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200701080049
396170|396170-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701081709
396447|396447-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701090751
398116|398116-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|Data-Compare|0.14|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701111152
400138|400138-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200701161135
401271|401271-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701171904
401652|401652-b19f-3f77-b713-d32bba55d77f|pass|200701|james@mastros.biz|Number-Phone|1.56|i486-linux-gnu|5.8.8|linux|2.6.18.3|200701180143
402258|402258-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200701191454
402576|402576-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701210243
402577|402577-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701210247
402614|402614-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701211110
402616|402616-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701211114
402617|402617-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701211115
402745|402745-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Bryar|3.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701212346
402746|402746-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701212348
402878|402878-b19f-3f77-b713-d32bba55d77f|fail|200701|saper@cpan.org|Net-Random|1.3|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701220934
403051|403051-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701221027
403054|403054-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|alpha-freebsd|5.8.7|freebsd|6.0-release|200701221135
403141|403141-b19f-3f77-b713-d32bba55d77f|pass|200701|imacat@mail.imacat.idv.tw|Net-Random|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200701222020
403217|403217-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Net-Random|1.3|alpha-freebsd|5.8.7|freebsd|6.0-release|200701221247
403247|403247-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701221245
403469|403469-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701221428
403807|403807-b19f-3f77-b713-d32bba55d77f|fail|200701|corion-cpanplus@corion.net|Bryar|3.0|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200701221903
403808|403808-b19f-3f77-b713-d32bba55d77f|fail|200701|corion-cpanplus@corion.net|Net-Random|1.3|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200701221903
404101|404101-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701231253
404652|404652-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-openbsd|5.8.8|openbsd|4.0|200701241445
404654|404654-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-openbsd|5.8.8|openbsd|4.0|200701241445
404727|404727-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701241624
404728|404728-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701241624
404938|404938-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Bryar|3.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701242140
404939|404939-b19f-3f77-b713-d32bba55d77f|fail|200701|chris@bingosnet.co.uk|Net-Random|1.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701242143
405024|405024-b19f-3f77-b713-d32bba55d77f|fail|200701|bricas@cpan.org|Net-Random|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200701241254
405090|405090-b19f-3f77-b713-d32bba55d77f|fail|200701|bricas@cpan.org|Bryar|3.0|i486-linux-gnu|5.8.8|linux|2.6.15.7|200701241253
406240|406240-b19f-3f77-b713-d32bba55d77f|pass|200701|corion-cpanplus@corion.net|XML-Tiny|1.0|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200701271603
406297|406297-b19f-3f77-b713-d32bba55d77f|pass|200701|imacat@mail.imacat.idv.tw|XML-Tiny|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200701280232
406369|406369-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701281727
406372|406372-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701281730
406388|406388-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701281814
406449|406449-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|Number-Phone|1.56|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701282030
406568|406568-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|XML-Tiny|1.0|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701291002
406701|406701-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200701291118
406775|406775-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701291146
407142|407142-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200701291804
407210|407210-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200701291938
407352|407352-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701292244
407472|407472-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701300837
407503|407503-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|XML-Tiny|1.01|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701301003
407507|407507-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701300910
407521|407521-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200701300936
407580|407580-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|alpha-freebsd|5.8.7|freebsd|6.0-release|200701301052
407581|407581-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|alpha-freebsd|5.8.7|freebsd|6.0-release|200701301053
407664|407664-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701301210
407864|407864-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701301354
408226|408226-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200701310829
408246|408246-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200701310844
408304|408304-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200701310925
408321|408321-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-openbsd|5.8.8|openbsd|4.0|200701310943
408322|408322-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-openbsd|5.8.8|openbsd|4.0|200701310944
408323|408323-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-openbsd|5.8.8|openbsd|4.0|200701310944
408325|408325-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200701310944
408457|408457-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|Data-Compare|0.14|i386-openbsd|5.8.8|openbsd|4.0|200701311200
408469|408469-b19f-3f77-b713-d32bba55d77f|pass|200701|imacat@mail.imacat.idv.tw|XML-Tiny|1.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200701312008
408518|408518-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|XML-Tiny|1.02|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200701311345
408519|408519-b19f-3f77-b713-d32bba55d77f|pass|200701|saper@cpan.org|XML-Tiny|1.02|i686-linux|5.4.4|linux|2.6.8.1-10mdk|200701311346
408662|408662-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311611
408663|408663-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311611
408664|408664-b19f-3f77-b713-d32bba55d77f|pass|200701|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200701311611
408851|408851-b19f-3f77-b713-d32bba55d77f|pass|200701|castaway@desert-island.dynodns.net|Data-Compare|0.14|i686-linux-thread|5.8.7|linux|2.6.15.1|200701311544
409022|409022-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702010958
409023|409023-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702010958
409131|409131-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.14|200702012013
409233|409233-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702011557
409389|409389-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702011906
409390|409390-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702011906
409399|409399-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702012025
409400|409400-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702012025
409816|409816-b19f-3f77-b713-d32bba55d77f|pass|200702|jrockway@cpan.org|Data-Compare|0.14|i486-linux-gnu|5.8.8|linux|2.6.18.3|200702021305
409919|409919-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200702030740
409976|409976-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702031408
409980|409980-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702031502
410113|410113-b19f-3f77-b713-d32bba55d77f|pass|200702|smueller@cpan.org ("Steffen Mueller")|XML-Tiny|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200702032114
410364|410364-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-openbsd|5.8.8|openbsd|4.0|200702041215
410380|410380-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702041245
410746|410746-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|XML-Tiny|1.03|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702051015
410765|410765-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702050953
410944|410944-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.02|alpha-freebsd|5.8.7|freebsd|6.0-release|200702051437
410945|410945-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|alpha-freebsd|5.8.7|freebsd|6.0-release|200702051437
411263|411263-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702060952
411314|411314-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702062123
411349|411349-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702062145
411552|411552-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702062002
411568|411568-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702062036
411918|411918-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200702071720
413290|413290-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200702112331
413292|413292-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|i686-linux|5.8.8|linux|2.4.27-3-686|200702112335
413328|413328-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702120203
413330|413330-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702120204
413341|413341-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702120314
413385|413385-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|XML-Tiny|1.04|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702121120
413428|413428-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|XML-Tiny|1.04|i686-linux|5.4.4|linux|2.6.8.1-10mdk|200702121203
413448|413448-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|alpha-freebsd|5.8.7|freebsd|6.0-release|200702121122
413729|413729-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702121534
413903|413903-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200702121813
414124|414124-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Compare|0.14|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702122206
414424|414424-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|XML-Tiny|1.04|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702132233
414887|414887-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702140850
415005|415005-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702140853
415088|415088-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|XML-Tiny|1.04|i686-linux|5.6.2|linux|2.6.8.1-10mdk|200702141401
415282|415282-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702142048
415613|415613-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-openbsd|5.8.8|openbsd|4.0|200702151026
416151|416151-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Number-Phone|1.56|i686-linux|5.6.2|linux|2.4.27-3-686|200702160107
416160|416160-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200702160110
416168|416168-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Number-Phone|1.56|i686-linux|5.6.2|linux|2.4.27-3-686|200702160110
416390|416390-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.04|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702161340
420805|420805-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Data-Compare|0.14|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200702241548
421144|421144-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200702242015
421152|421152-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702242018
421157|421157-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702242023
421523|421523-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Compare|0.14|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702251914
421525|421525-b19f-3f77-b713-d32bba55d77f|fail|200702|david@cantrell.org.uk|Data-Compare|0.14|i686-linux|5.6.2|linux|2.4.27-3-686|200702251914
421552|421552-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Number-Phone|1.5601|i686-linux|5.6.2|linux|2.4.27-3-686|200702251920
421581|421581-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Number-Phone|1.5601|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702251927
421634|421634-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Compare|0.14|i686-linux|5.8.8|linux|2.4.27-3-686|200702251941
421661|421661-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Number-Phone|1.5601|i686-linux|5.8.8|linux|2.4.27-3-686|200702251947
422037|422037-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|alpha-freebsd|5.8.7|freebsd|6.0-release|200702261104
422104|422104-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200702261121
422151|422151-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200702261228
422169|422169-b19f-3f77-b713-d32bba55d77f|pass|200702|imacat@mail.imacat.idv.tw|Number-Phone|1.5601|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200702262037
422879|422879-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200702270133
423054|423054-b19f-3f77-b713-d32bba55d77f|pass|200702|saper@cpan.org|Data-Compare|0.15|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200702271007
423090|423090-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.15|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702270927
423091|423091-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.5601|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702270928
423199|423199-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|Number-Phone|1.5601|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200702270958
423480|423480-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Compare|0.15|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702271507
423670|423670-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Compare|0.15|i686-linux|5.8.8|linux|2.4.27-3-686|200702271636
424064|424064-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200702280418
424067|424067-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200702280420
424100|424100-b19f-3f77-b713-d32bba55d77f|pass|200702|corion-cpanplus@corion.net|Data-Compare|0.16|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200702280837
424204|424204-b19f-3f77-b713-d32bba55d77f|pass|200702|Jost.Krieger@ruhr-uni-bochum.de|Data-Compare|0.16|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702281107
424249|424249-b19f-3f77-b713-d32bba55d77f|pass|200702|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-pc-solaris2.11|5.8.7|solaris|2.11|200702281202
424258|424258-b19f-3f77-b713-d32bba55d77f|fail|200702|Jost.Krieger@ruhr-uni-bochum.de|Net-Random|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200702281235
424590|424590-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|XML-Tiny|1.05|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702281549
424641|424641-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200702281449
424664|424664-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200702281502
424839|424839-b19f-3f77-b713-d32bba55d77f|pass|200702|david@cantrell.org.uk|XML-Tiny|1.05|i686-linux|5.6.2|linux|2.4.27-3-686|200702281459
425056|425056-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703010144
425143|425143-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703010319
425147|425147-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703010323
425457|425457-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Data-Compare|0.16|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703011023
425610|425610-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703011040
425615|425615-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-Tiny|1.05|i686-linux|5.8.8|linux|2.4.27-3-686|200703011042
425718|425718-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.16|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703011108
425719|425719-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|1.4|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703011109
425723|425723-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.05|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703011109
425770|425770-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703011115
425784|425784-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703011121
425799|425799-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-openbsd|5.8.8|openbsd|4.0|200703011122
425819|425819-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-openbsd|5.8.8|openbsd|4.0|200703011129
425969|425969-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|XML-Tiny|1.05|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703012155
425979|425979-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703011402
426002|426002-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Net-Random|1.4|i686-linux|5.6.2|linux|2.4.27-3-686|200703011412
426092|426092-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703011503
426155|426155-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Net-Random|1.4|i686-linux|5.8.8|linux|2.4.27-3-686|200703011528
426308|426308-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Net-Random|1.4|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703011415
426482|426482-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703012329
426483|426483-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703012335
426651|426651-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|Net-Random|1.4|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021008
426712|426712-b19f-3f77-b713-d32bba55d77f|pass|200703|saper@cpan.org|XML-Tiny|1.05|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200703021050
426868|426868-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Net-Random|1.4|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703022135
426952|426952-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703021425
426980|426980-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703021435
427087|427087-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703021536
427212|427212-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021558
427213|427213-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703021559
427431|427431-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703031108
427432|427432-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703031108
428389|428389-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703050518
428390|428390-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703050520
428391|428391-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703050521
428489|428489-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|alpha-freebsd|5.8.7|freebsd|6.0-release|200703051004
428490|428490-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|alpha-freebsd|5.8.7|freebsd|6.0-release|200703051005
428491|428491-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|alpha-freebsd|5.8.7|freebsd|6.0-release|200703051005
428598|428598-b19f-3f77-b713-d32bba55d77f|pass|200703|srezic@iconmobile.com (Slaven Rezic)|Data-Compare|0.16|i686-linux|5.8.7|linux|2.4.20-18.8|200703051233
428962|428962-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-Tiny|1.06|i686-linux|5.8.8|linux|2.4.27-3-686|200703051539
429094|429094-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-Tiny|1.06|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703051734
429161|429161-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051912
429162|429162-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051912
429163|429163-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703051913
429176|429176-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Net-Random|1.4|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051926
429179|429179-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051927
429180|429180-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703051928
429695|429695-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703061105
429805|429805-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|XML-Tiny|1.06|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703062107
430026|430026-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703061525
430283|430283-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.05|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061713
430284|430284-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i686-linux-thread-multi-64int-ld|5.9.4|linux|2.4.26|200703061714
430700|430700-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703070516
431402|431402-b19f-3f77-b713-d32bba55d77f|pass|200703|njh@bandsman.co.uk|Data-Compare|0.16|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200703080651
432496|432496-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703090229
432921|432921-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.06|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703091413
433143|433143-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-openbsd|5.8.8|openbsd|4.0|200703091651
433802|433802-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-Tiny|1.06|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703101135
436498|436498-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703130946
436583|436583-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger@ruhr-uni-bochum.de|Net-Random|1.4|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703131155
436826|436826-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200703131620
436857|436857-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703131628
436923|436923-b19f-3f77-b713-d32bba55d77f|fail|200703|david@cantrell.org.uk|Number-Phone|1.5601|i686-linux|5.8.8|linux|2.4.27-3-686|200703131515
437019|437019-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200703131809
437354|437354-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703141014
437425|437425-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703141958
437858|437858-b19f-3f77-b713-d32bba55d77f|fail|200703|chris@bingosnet.co.uk|Number-Phone|1.5601|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703150458
437859|437859-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703150506
437965|437965-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-openbsd|5.8.8|openbsd|4.0|200703150950
437967|437967-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.57|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703151000
437969|437969-b19f-3f77-b713-d32bba55d77f|pass|200703|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200703151001
437970|437970-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-openbsd|5.8.8|openbsd|4.0|200703150952
437971|437971-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-openbsd|5.8.8|openbsd|4.0|200703150953
438217|438217-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703151453
438220|438220-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703151453
438278|438278-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|i686-linux|5.6.2|linux|2.4.27-3-686|200703151537
438279|438279-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200703151539
438390|438390-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151638
438391|438391-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151638
438441|438441-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|i686-linux|5.8.8|linux|2.4.27-3-686|200703151714
438442|438442-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200703151716
438515|438515-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703151958
438516|438516-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703152000
438527|438527-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Number-Phone|1.57|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703151616
439309|439309-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Number-Phone|1.57|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703170044
439389|439389-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170812
439391|439391-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170813
439392|439392-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703170813
439763|439763-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703171627
439973|439973-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703171908
440130|440130-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703171754
440280|440280-b19f-3f77-b713-d32bba55d77f|fail|200703|corion-cpanplus@corion.net|Number-Phone|1.57|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703172321
440293|440293-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172124
440294|440294-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172126
440295|440295-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-rc1|200703172126
440390|440390-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703181013
440713|440713-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703181558
440867|440867-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703181921
441193|441193-b19f-3f77-b713-d32bba55d77f|pass|200703|jrockway@cpan.org|Data-Compare|0.16|i486-linux-gnu|5.8.8|linux|2.6.18.3|200703181659
441296|441296-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703191312
441475|441475-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200703192317
441520|441520-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703192340
441568|441568-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.8.8|linux|2.4.27-3-686|200703200007
441785|441785-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|alpha-freebsd|5.8.7|freebsd|6.0-release|200703201026
441798|441798-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|alpha-freebsd|5.8.7|freebsd|6.0-release|200703201027
441880|441880-b19f-3f77-b713-d32bba55d77f|pass|200703|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200703201956
441964|441964-b19f-3f77-b713-d32bba55d77f|pass|200703|davidp@preshweb.co.uk ("David Precious")|Data-Compare|0.16|i486-linux|5.8.7|linux|2.4.31|200703201224
442206|442206-b19f-3f77-b713-d32bba55d77f|pass|200703|corion-cpanplus@corion.net|Number-Phone|1.57|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703202030
442207|442207-b19f-3f77-b713-d32bba55d77f|pass|200703|corion-cpanplus@corion.net|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200703202030
442408|442408-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703210008
442410|442410-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703210010
442474|442474-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200703210214
442479|442479-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200703210218
442482|442482-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200703210224
442587|442587-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200703210706
442624|442624-b19f-3f77-b713-d32bba55d77f|pass|200703|wyant@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.8|darwin|7.9.0|200703210259
442968|442968-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703211540
442976|442976-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200703211618
443027|443027-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200703211731
443143|443143-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone|1.57|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703212141
443144|443144-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703212142
443425|443425-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703220318
443561|443561-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200703220515
444751|444751-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.4-release|200703232117
444790|444790-b19f-3f77-b713-d32bba55d77f|pass|200703|dither@gmail.com|Data-Compare|0.16|i386-freebsd-64int|5.8.8|freebsd|5.4-release|200703231735
444941|444941-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.0|200703240104
445126|445126-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-openbsd|5.8.8|openbsd|4.0|200703240725
445864|445864-b19f-3f77-b713-d32bba55d77f|pass|200703|chris@bingosnet.co.uk|Data-Hexdumper|1.2|i386-pc-solaris2.11|5.8.7|solaris|2.11|200703242336
447207|447207-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200703261737
447526|447526-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.8.8|linux|2.4.27-3-686|200703262159
447776|447776-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200703271458
447879|447879-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703271609
449979|449979-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200703301451
450622|450622-b19f-3f77-b713-d32bba55d77f|pass|200703|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200703302101
454327|454327-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Acme-Pony|1.1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200704051030
454539|454539-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200704051512
454755|454755-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704051622
458609|458609-b19f-3f77-b713-d32bba55d77f|pass|200704|tom@eborcom.com ("Tom Hukins")|Sub-WrapPackages|1.2|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200704121137
458708|458708-b19f-3f77-b713-d32bba55d77f|pass|200704|tom@eborcom.com ("Tom Hukins")|XML-Tiny|1.06|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200704121420
459149|459149-b19f-3f77-b713-d32bba55d77f|pass|200704|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|2.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200704130952
459445|459445-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200704131703
459556|459556-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200704131846
459577|459577-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.23(0.15642)|200704131927
460125|460125-b19f-3f77-b713-d32bba55d77f|pass|200704|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.16.29|200704142351
460308|460308-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Net-Random|2.0|i686-linux|5.6.2|linux|2.4.27-3-686|200704142209
460619|460619-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Net-Random|2.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704151540
461008|461008-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200704161042
461251|461251-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200704161338
462048|462048-b19f-3f77-b713-d32bba55d77f|pass|200704|saper@cpan.org|Net-Random|2.0|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200704171032
462055|462055-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200704170903
462970|462970-b19f-3f77-b713-d32bba55d77f|pass|200704|alexchorny@gmail.com (Alexandr Ciornii)|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.20-8smp|200704180113
463006|463006-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.21(0.15642)|200704181224
463921|463921-b19f-3f77-b713-d32bba55d77f|pass|200704|chris@bingosnet.co.uk|Net-Random|2.0|i386-openbsd|5.8.8|openbsd|4.0|200704190037
465406|465406-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Net-Random|2.0|i686-linux|5.8.3|linux|2.4.22-physmem-patch3-5um|200704201622
466836|466836-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|File-Overwrite|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704231400
468218|468218-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Class-CanBeA|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200704251738
468223|468223-b19f-3f77-b713-d32bba55d77f|pass|200704|david@cantrell.org.uk|Class-CanBeA|1.2|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200704251844
474057|474057-b19f-3f77-b713-d32bba55d77f|pass|200705|xdg@hyperbolic.net (DAGOLDEN)|Net-Random|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200705040829
475133|475133-b19f-3f77-b713-d32bba55d77f|pass|200705|chaddai.fouche@gmail.com ("Chaddai Fouche")|Data-Compare|0.16|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200705052338
475141|475141-b19f-3f77-b713-d32bba55d77f|pass|200705|chaddai.fouche@gmail.com ("Chaddai Fouche")|Data-Compare|0.16|MSWin32-x86-multi-thread|5.9.5|MSWin32|4.0|200705052344
475387|475387-b19f-3f77-b713-d32bba55d77f|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.9.5|linux|2.6.18-4-k7|200705061119
475972|475972-b19f-3f77-b713-d32bba55d77f|pass|200705|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200705070015
476806|476806-b19f-3f77-b713-d32bba55d77f|fail|200705|bsmith@cpan.org|Bryar|3.0|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705061925
476985|476985-b19f-3f77-b713-d32bba55d77f|pass|200705|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.6.2|linux|2.4.27-3-686|200705071450
477045|477045-b19f-3f77-b713-d32bba55d77f|pass|200705|david@cantrell.org.uk|Data-Compare|0.16|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200705071614
478961|478961-b19f-3f77-b713-d32bba55d77f|fail|200705|bsmith@cpan.org|Bryar|3.0|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705091231
483520|483520-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Compare|0.16|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705131130
484000|484000-b19f-3f77-b713-d32bba55d77f|pass|200705|bsmith@cpan.org|Data-Hexdumper|1.2|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705131435
484013|484013-b19f-3f77-b713-d32bba55d77f|fail|200705|bsmith@cpan.org|Data-Transactional|0.1|i486-linux-gnu|5.9.5 patch 31148|linux|2.6.17.13.vtrl22.01|200705131441
498580|498580-b19f-3f77-b713-d32bba55d77f|pass|200705|tom@eborcom.com ("Tom Hukins")|Data-Compare|0.16|i686-linux|5.9.5 patch 30836|linux|2.6.17-11-generic|200705301013
499954|499954-b19f-3f77-b713-d32bba55d77f|pass|200705|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200705311327
499957|499957-b19f-3f77-b713-d32bba55d77f|pass|200705|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200705311330
500760|500760-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.4.26|200706020634
500763|500763-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200706020637
501025|501025-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|Number-Phone|1.58|i686-linux|5.6.2|linux|2.4.27-3-686|200706031142
501028|501028-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|Number-Phone|1.58|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200706031245
501042|501042-b19f-3f77-b713-d32bba55d77f|pass|200706|imacat@mail.imacat.idv.tw|Number-Phone|1.58|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200706031911
501405|501405-b19f-3f77-b713-d32bba55d77f|pass|200706|saper@cpan.org|Number-Phone|1.58|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200706041055
501492|501492-b19f-3f77-b713-d32bba55d77f|pass|200706|stro@cpan.org|Number-Phone|1.58|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200706031924
501643|501643-b19f-3f77-b713-d32bba55d77f|pass|200706|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.58|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200706041402
501841|501841-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i386-pc-solaris2.11|5.8.7|solaris|2.11|200706041812
502234|502234-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200706050932
502780|502780-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200706060804
503556|503556-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200706061615
503784|503784-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.9.5 patch 31335|linux|2.4.27-3-686|200706062047
504111|504111-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200706071044
504704|504704-b19f-3f77-b713-d32bba55d77f|pass|200706|chris@bingosnet.co.uk|Number-Phone|1.58|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200706071858
519559|519559-b19f-3f77-b713-d32bba55d77f|pass|200706|david@cantrell.org.uk|NestedMap|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200706261547
527714|527714-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|Tie-Hash-Rank|1.0.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707041839
527792|527792-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|Data-Compare|0.16|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707041757
528095|528095-b19f-3f77-b713-d32bba55d77f|pass|200707|stro@cpan.org|Acme-Pony|1.1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200707041749
532760|532760-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.8.8|linux|2.4.27-3-686|200707101103
532768|532768-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Compare|0.16|i686-linux|5.9.5 patch 31416|linux|2.4.27-3-686|200707101104
536645|536645-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Class-CanBeA|1.2|i686-linux|5.9.5|linux|2.4.27-3-686|200707142021
537892|537892-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200707152130
538989|538989-b19f-3f77-b713-d32bba55d77f|pass|200707|overlordq@gmail.com|Data-Compare|0.16|i486-linux-gnu|5.8.8|linux|2.6.18.3|200707161626
541445|541445-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200707182344
541446|541446-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200707182344
541447|541447-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux|5.9.5|linux|2.4.27-3-686|200707182345
541450|541450-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707190052
546402|546402-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707250634
546525|546525-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707250749
551041|551041-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i686-linux|5.9.5|linux|2.4.27-3-686|200707301143
551134|551134-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i686-linux|5.8.8|linux|2.4.27-3-686|200707301418
551151|551151-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707301537
551157|551157-b19f-3f77-b713-d32bba55d77f|fail|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i686-linux|5.6.2|linux|2.4.27-3-686|200707301412
551158|551158-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Data-Hexdumper|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200707301408
551428|551428-b19f-3f77-b713-d32bba55d77f|pass|200707|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200707310541
551444|551444-b19f-3f77-b713-d32bba55d77f|pass|200707|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-TreoPhoneCallDB|1.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200707310704
551498|551498-b19f-3f77-b713-d32bba55d77f|pass|200707|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200707310826
551733|551733-b19f-3f77-b713-d32bba55d77f|pass|200707|ferreira@cpan.org ("Adriano Ferreira")|Data-Compare|0.16|cygwin|5.9.5|cygwin|1.5.24(0.15642)|200707311148
551763|551763-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200707311721
551794|551794-b19f-3f77-b713-d32bba55d77f|pass|200707|tom@eborcom.com ("Tom Hukins")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.9.5 patch 31576|linux|2.6.17-11-generic|200707311337
551801|551801-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200707311725
551813|551813-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200707311818
551815|551815-b19f-3f77-b713-d32bba55d77f|pass|200707|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux|5.9.5|linux|2.4.27-3-686|200707311828
552449|552449-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708020036
552542|552542-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708011914
553871|553871-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708032142
553873|553873-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708032144
554693|554693-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708041837
554699|554699-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708041840
555029|555029-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708050148
555030|555030-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708050150
555430|555430-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708051356
555431|555431-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708051400
555684|555684-b19f-3f77-b713-d32bba55d77f|fail|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.16|i686-linux-64int|5.8.3|linux|2.4.22-rc2-ac2|200708051931
555827|555827-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708052212
555828|555828-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708052214
556260|556260-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708061125
556303|556303-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708061143
558672|558672-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708072108
558814|558814-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200708080159
558828|558828-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|i686-linux|5.8.3|linux|2.4.22-physmem-patch3-5um|200708071720
558868|558868-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708080137
558881|558881-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708080141
559090|559090-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708080854
559174|559174-b19f-3f77-b713-d32bba55d77f|pass|200708|saper@cpan.org|Data-Compare|0.17|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200708081011
559259|559259-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|OpenBSD.i386-openbsd|5.8.8|openbsd|3.5|200708081147
559501|559501-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i686-linux|5.8.8|linux|2.4.27-3-686|200708081457
559543|559543-b19f-3f77-b713-d32bba55d77f|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.17|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708081416
559576|559576-b19f-3f77-b713-d32bba55d77f|pass|200708|tom@eborcom.com ("Tom Hukins")|Data-Compare|0.17|i686-linux|5.9.5 patch 31576|linux|2.6.17-11-generic|200708080757
559775|559775-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708081635
559788|559788-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i686-linux|5.6.2|linux|2.4.27-3-686|200708081706
559811|559811-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i686-linux|5.9.5|linux|2.4.27-3-686|200708081751
559866|559866-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200708081955
559868|559868-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.3|linux|2.6.14|200708081956
559872|559872-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 30961|linux|2.6.18-4-k7|200708081958
559876|559876-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200708081959
559878|559878-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200708082000
559880|559880-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.4|linux|2.6.18-4-k7|200708082001
559882|559882-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.3|linux|2.6.18-4-k7|200708082002
559883|559883-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200708082003
559905|559905-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.9.1 patch 21538|linux|2.4.22-rc2-ac2|200708081957
559906|559906-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.9.2|linux|2.6.18-4-k7|200708081956
559907|559907-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200708081958
560131|560131-b19f-3f77-b713-d32bba55d77f|pass|200708|feldt@nhn.ou.edu|Data-Compare|0.17|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200708081419
560273|560273-b19f-3f77-b713-d32bba55d77f|pass|200708|g.grigelionis@computer.org|Data-Compare|0.17|i586-linux-thread-multi|5.8.8|linux|2.6.16|200708081741
561378|561378-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708091302
561436|561436-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708092112
561571|561571-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708091651
561620|561620-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708091620
561639|561639-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708091626
561654|561654-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708091612
561872|561872-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708092054
562017|562017-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708092047
562255|562255-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708092050
563659|563659-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|darwin-2level|5.9.5|darwin|8.10.1|200708101841
563736|563736-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708101903
564951|564951-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708111221
565096|565096-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708111422
566789|566789-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200708121117
567459|567459-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200708121328
569962|569962-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.9.5 patch 31701|netbsd|3.1|200708131004
570482|570482-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708131205
571994|571994-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708131852
573512|573512-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.9.5 patch 31711|linux|2.6.16.19|200708141248
574134|574134-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708141634
577657|577657-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|darwin-2level|5.9.5|darwin|8.10.1|200708160846
577933|577933-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708161122
578018|578018-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|i686-linux|5.8.8|linux|2.4.27-3-686|200708161225
578081|578081-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|i686-linux|5.9.5|linux|2.4.27-3-686|200708161239
578089|578089-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Number-Phone|1.58|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708161137
581816|581816-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708172240
582029|582029-b19f-3f77-b713-d32bba55d77f|pass|200708|tony@develop-help.com|Number-Phone|1.58|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708181009
582646|582646-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708190002
582647|582647-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708190003
582649|582649-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708190004
582650|582650-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708190005
582652|582652-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708190006
582653|582653-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708190007
582654|582654-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708190009
582655|582655-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708190010
583002|583002-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200708190601
583066|583066-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708190837
583126|583126-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200708191235
583431|583431-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708191551
583694|583694-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708191732
583699|583699-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200708191734
583850|583850-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708191937
584790|584790-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708201327
584903|584903-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708200824
584909|584909-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708200827
584915|584915-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708200829
584924|584924-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708200832
584932|584932-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708200834
584938|584938-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708200837
584941|584941-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708200841
584952|584952-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200342
585019|585019-b19f-3f77-b713-d32bba55d77f|pass|200708|saper@cpan.org|CPAN-FindDependencies|1.02|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200708201042
585127|585127-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200543
585132|585132-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200545
585137|585137-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-freebsd-thread-multi-64int|5.9.5|freebsd|6.2-release|200708200547
585170|585170-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201137
585345|585345-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708201950
585388|585388-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201318
585397|585397-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201321
585398|585398-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708202021
585401|585401-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200708201324
585417|585417-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708201331
585420|585420-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708201334
585423|585423-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708201338
585425|585425-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708201341
585428|585428-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708201344
585430|585430-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708201348
585431|585431-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708201350
585436|585436-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708201353
585809|585809-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708201719
585816|585816-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708201722
585822|585822-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708201724
585836|585836-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708201727
585840|585840-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708201729
585844|585844-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708201731
585847|585847-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708201733
585854|585854-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708201736
586798|586798-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708210028
586800|586800-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708210031
586802|586802-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708210034
587051|587051-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708210635
587052|587052-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708210635
587053|587053-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708210636
587054|587054-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708210636
587055|587055-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708210636
587056|587056-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708210636
587057|587057-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708210636
587058|587058-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708210637
587059|587059-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708210637
587240|587240-b19f-3f77-b713-d32bba55d77f|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|1.02|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708210843
587241|587241-b19f-3f77-b713-d32bba55d77f|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708210844
587255|587255-b19f-3f77-b713-d32bba55d77f|pass|200708|saper@cpan.org|Data-Hexdumper|1.3|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200708211047
587301|587301-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|Data-Compare|0.17|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211044
587322|587322-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211012
587418|587418-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Compare|0.17|i386-freebsd|5.9.5|freebsd|6.2-release|200708211028
587508|587508-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211103
587652|587652-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211244
587655|587655-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211245
587656|587656-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211247
587657|587657-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|alpha-linux-thread-multi|5.9.5 patch 31739|linux|2.6.16.19|200708211247
587803|587803-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200708211459
587851|587851-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200708211525
587855|587855-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux|5.9.5|linux|2.4.27-3-686|200708211529
587856|587856-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211534
587942|587942-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|Number-Phone|1.58|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211120
588007|588007-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|Data-Compare|0.17|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211358
588093|588093-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|darwin-2level|5.9.5|darwin|8.10.1|200708211615
588147|588147-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|CPAN-FindDependencies|1.01|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211533
588180|588180-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|Number-Phone|1.58|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211424
588194|588194-b19f-3f77-b713-d32bba55d77f|pass|200708|tom@eborcom.com ("Tom Hukins")|Data-Hexdumper|1.3|i686-linux|5.9.5 patch 31576|linux|2.6.17-11-generic|200708211135
588231|588231-b19f-3f77-b713-d32bba55d77f|fail|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211653
588253|588253-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211656
588256|588256-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211658
588258|588258-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200708211658
588287|588287-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|CPAN-FindDependencies|1.02|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211533
588363|588363-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|i386-freebsd|5.9.5|freebsd|6.2-release|200708211830
588480|588480-b19f-3f77-b713-d32bba55d77f|fail|200708|plu@pqpq.de|CPAN-FindDependencies|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211532
588481|588481-b19f-3f77-b713-d32bba55d77f|pass|200708|plu@pqpq.de|Data-Hexdumper|1.3|i386-freebsd|5.8.8|freebsd|6.1-release-p6|200708211534
588709|588709-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212106
588724|588724-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Bryar|3.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212109
588730|588730-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.0.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588735|588735-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|File-Overwrite|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588736|588736-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|0.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588738|588738-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200708212110
588739|588739-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Games-Dice-Advanced|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212111
588740|588740-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|NestedMap|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212111
588744|588744-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Net-Random|2.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708212113
588751|588751-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200708212116
588764|588764-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Statistics-ChiSquare|0.5|i686-linux|5.6.2|linux|2.4.27-3-686|200708212117
588765|588765-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Sub-WrapPackages|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200708212118
588766|588766-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212117
588767|588767-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Hash-Longest|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212118
588768|588768-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212118
588819|588819-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|Tie-STDOUT|1.02|i686-linux|5.6.2|linux|2.4.27-3-686|200708212145
588820|588820-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212146
588822|588822-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200708212146
588824|588824-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|i686-linux|5.6.2|linux|2.4.27-3-686|200708212146
588886|588886-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212205
589058|589058-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212319
589059|589059-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212319
589061|589061-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212320
589063|589063-b19f-3f77-b713-d32bba55d77f|unknown|200708|david@cantrell.org.uk|Acme-Licence|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212318
589066|589066-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212318
589067|589067-b19f-3f77-b713-d32bba55d77f|unknown|200708|david@cantrell.org.uk|Acme-Pony|1.1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212318
589072|589072-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200708212320
589087|589087-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|Bryar|3.0|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589089|589089-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Class-CanBeA|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589093|589093-b19f-3f77-b713-d32bba55d77f|fail|200708|david@cantrell.org.uk|Data-Transactional|0.1|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589095|589095-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|File-Overwrite|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589096|589096-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589099|589099-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Net-Random|2.0|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589100|589100-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Games-Dice-Advanced|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589102|589102-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|NestedMap|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212324
589105|589105-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-2level|5.9.5|darwin|8.10.1|200708212327
589106|589106-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589107|589107-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589110|589110-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Statistics-ChiSquare|0.5|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589112|589112-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589114|589114-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Hash-Longest|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589115|589115-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Sub-WrapPackages|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589116|589116-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.02|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589117|589117-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|darwin-2level|5.9.5|darwin|8.10.1|200708212328
589119|589119-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589120|589120-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589121|589121-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589122|589122-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|XML-Tiny|1.06|darwin-2level|5.9.5|darwin|8.10.1|200708212329
589147|589147-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.2|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589149|589149-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.0.1|darwin-2level|5.9.5|darwin|8.10.1|200708212323
589707|589707-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Hexdumper|1.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708220732
589902|589902-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708221013
589905|589905-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|CPAN-FindDependencies|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708220951
589906|589906-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|CPAN-FindDependencies|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708220952
589960|589960-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|CPAN-FindDependencies|1.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708220951
590091|590091-b19f-3f77-b713-d32bba55d77f|pass|200708|chaddai.fouche@gmail.com ("Chaddai Fouche")|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708221618
590117|590117-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221558
590120|590120-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221600
590122|590122-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221601
590124|590124-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i386-pc-solaris2.11|5.8.7|solaris|2.11|200708221601
590675|590675-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708230522
591020|591020-b19f-3f77-b713-d32bba55d77f|pass|200708|tony@develop-help.com|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708230944
591446|591446-b19f-3f77-b713-d32bba55d77f|pass|200708|bob@randomness.org.uk ("bob walker")|Bryar|3.0|i86pc-solaris|5.8.8|solaris|2.10|200708231015
591701|591701-b19f-3f77-b713-d32bba55d77f|pass|200708|cpan@pqpq.de|CPAN-FindDependencies|1.02|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231335
591731|591731-b19f-3f77-b713-d32bba55d77f|pass|200708|cpan@pqpq.de|Data-Hexdumper|1.3|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231335
591734|591734-b19f-3f77-b713-d32bba55d77f|pass|200708|cpan@pqpq.de|CPAN-FindDependencies|1.0|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231334
591735|591735-b19f-3f77-b713-d32bba55d77f|pass|200708|cpan@pqpq.de|CPAN-FindDependencies|1.01|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231335
591769|591769-b19f-3f77-b713-d32bba55d77f|pass|200708|cpan@pqpq.de|Data-Compare|0.17|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200708231210
592026|592026-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231648
592027|592027-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231649
592028|592028-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231651
592029|592029-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708231651
592644|592644-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200708232350
592919|592919-b19f-3f77-b713-d32bba55d77f|pass|200708|cogent@cpan.org|Data-Compare|0.17|darwin-thread-multi-64int-2level|5.8.8|darwin|8.7.0|200708231440
593087|593087-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708240501
593443|593443-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241048
593448|593448-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241050
593461|593461-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.0|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241047
593475|593475-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200708241050
594276|594276-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708250644
594281|594281-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708250648
594282|594282-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200708250649
594391|594391-b19f-3f77-b713-d32bba55d77f|pass|200708|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.02|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200708250940
594684|594684-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708251155
594685|594685-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708251156
594686|594686-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200708251156
595047|595047-b19f-3f77-b713-d32bba55d77f|pass|200708|srezic@cpan.org|CPAN-FindDependencies|1.02|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200708251106
595064|595064-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708251908
595274|595274-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.01|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708260006
595275|595275-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708260007
595276|595276-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.16.38|200708260007
595889|595889-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|CPAN-FindDependencies|1.02|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708262118
595890|595890-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Hexdumper|1.3|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200708262118
597202|597202-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708281836
597204|597204-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708281837
597205|597205-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708281837
597207|597207-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708281837
597208|597208-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708281838
597209|597209-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708281838
597210|597210-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708281838
597211|597211-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708281839
597213|597213-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708281839
597630|597630-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200708290537
597669|597669-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708290641
597670|597670-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708290642
597671|597671-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708290643
597672|597672-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708290643
597673|597673-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708290644
597674|597674-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708290644
597675|597675-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708290645
597676|597676-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708290646
597713|597713-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|darwin-2level|5.9.5|darwin|8.10.1|200708290946
597716|597716-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.4.27-3-686|200708290951
597730|597730-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|i686-linux|5.9.5|linux|2.4.27-3-686|200708290959
597780|597780-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200708291105
597790|597790-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|darwin-2level|5.9.5|darwin|8.10.1|200708291109
597795|597795-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200708291110
597813|597813-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux|5.9.5|linux|2.4.27-3-686|200708291219
597905|597905-b19f-3f77-b713-d32bba55d77f|pass|200708|stro@cpan.org|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708291330
597961|597961-b19f-3f77-b713-d32bba55d77f|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Transactional|1.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708291427
597962|597962-b19f-3f77-b713-d32bba55d77f|pass|200708|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.03|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200708291427
598003|598003-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|i386-freebsd|5.9.5|freebsd|6.2-release|200708290937
598061|598061-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708292348
598091|598091-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200708291141
598406|598406-b19f-3f77-b713-d32bba55d77f|pass|200708|imacat@mail.imacat.idv.tw|Data-Transactional|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200708301923
598875|598875-b19f-3f77-b713-d32bba55d77f|pass|200708|tony@develop-help.com|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708311047
598876|598876-b19f-3f77-b713-d32bba55d77f|na|200708|tony@develop-help.com|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200708311048
598901|598901-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200708310354
598903|598903-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200708310355
598905|598905-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200708310356
598907|598907-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200708310358
598909|598909-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200708310359
598911|598911-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200708310400
598913|598913-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200708310401
598915|598915-b19f-3f77-b713-d32bba55d77f|pass|200708|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200708310402
599214|599214-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Tie-STDOUT|1.03|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708311420
599278|599278-b19f-3f77-b713-d32bba55d77f|pass|200708|david@cantrell.org.uk|Data-Transactional|1.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200708311520
599522|599522-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Data-Transactional|1.0|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200709010933
599523|599523-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Tie-STDOUT|1.03|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200709010933
599621|599621-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709010951
599788|599788-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709011328
599789|599789-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709011328
599841|599841-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200709011415
599842|599842-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200709011417
599847|599847-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200709011421
599849|599849-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200709011422
599850|599850-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200709011423
599851|599851-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.4|linux|2.6.18-4-k7|200709011424
599852|599852-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.3|linux|2.6.18-4-k7|200709011425
599853|599853-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200709011426
599857|599857-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.9.3|linux|2.6.14|200709011418
599858|599858-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200709011420
600229|600229-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200709011840
600617|600617-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709012018
600618|600618-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709012018
600620|600620-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709012019
600828|600828-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200709012036
601889|601889-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Acme-Licence|1.0|i386-netbsd-thread-multi-64int|5.9.5|netbsd|3.1|200709021301
602062|602062-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Acme-Pony|1.1.2|i386-netbsd-thread-multi-64int|5.9.5|netbsd|3.1|200709021344
602128|602128-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-netbsd-thread-multi-64int|5.9.5|netbsd|3.1|200709021403
602983|602983-b19f-3f77-b713-d32bba55d77f|pass|200709|bob@randomness.org.uk ("bob walker")|Tie-STDOUT|1.03|i86pc-solaris|5.8.8|solaris|2.10|200709021453
603004|603004-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200709020706
603202|603202-b19f-3f77-b713-d32bba55d77f|pass|200709|jrockway@cpan.org|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.18.3|200709011804
603343|603343-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200709021923
603344|603344-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200709021923
603532|603532-b19f-3f77-b713-d32bba55d77f|pass|200709|corion-cpanplus@corion.net|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200709022206
603534|603534-b19f-3f77-b713-d32bba55d77f|pass|200709|corion-cpanplus@corion.net|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200709022207
603536|603536-b19f-3f77-b713-d32bba55d77f|fail|200709|corion-cpanplus@corion.net|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.8.5|MSWin32|4.0|200709022208
603917|603917-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200709030032
604525|604525-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.9.5 patch 31749|freebsd|6.1-release-p6|200709031103
604902|604902-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200709031349
604903|604903-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200709031350
604907|604907-b19f-3f77-b713-d32bba55d77f|pass|200709|saper@cpan.org|Tie-STDOUT|1.03|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200709031450
605243|605243-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200709031624
605244|605244-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200709031624
605308|605308-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200709031812
605309|605309-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200709031813
606619|606619-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200709040455
606840|606840-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709040750
606845|606845-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709040750
607296|607296-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709041124
607298|607298-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709041124
607602|607602-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200709041352
607854|607854-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200709041631
607857|607857-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200709041631
607951|607951-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200709041750
609071|609071-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Transactional|1.0|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200709050035
609076|609076-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Tie-STDOUT|1.03|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200709050036
609166|609166-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Tie-STDOUT|1.03|i86pc-solaris|5.9.5 patch 31788|solaris|2.10|200709042059
609202|609202-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Data-Transactional|1.0|i86pc-solaris|5.9.5 patch 31788|solaris|2.10|200709042059
609215|609215-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Data-Compare|0.17|i86pc-solaris|5.9.5 patch 31788|solaris|2.10|200709042059
610943|610943-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200709052027
611293|611293-b19f-3f77-b713-d32bba55d77f|pass|200709|perlgeek@perlgeek.net|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.6.9-42.0.3.elsmp|200709060223
611964|611964-b19f-3f77-b713-d32bba55d77f|pass|200709|davidp@preshweb.co.uk ("David Precious")|Data-Compare|0.17|i486-linux|5.8.7|linux|2.4.31|200709061158
612850|612850-b19f-3f77-b713-d32bba55d77f|pass|200709|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200709062106
616595|616595-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@0x64.nl|XML-Tiny|1.06|x86_64-linux-gnu|5.8.8|linux|2.6.18-1-amd64|200709081211
617035|617035-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Compare|0.02|i686-linux|5.6.2|linux|2.4.27-3-686|200709090041
617180|617180-b19f-3f77-b713-d32bba55d77f|pass|200709|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709090338
617430|617430-b19f-3f77-b713-d32bba55d77f|pass|200709|smueller@cpan.org ("Steffen Mueller")|XML-Tiny|1.06|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200709091052
620597|620597-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Compare|0.02|darwin-2level|5.9.5|darwin|8.10.1|200709102055
622464|622464-b19f-3f77-b713-d32bba55d77f|pass|200709|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|0.17|sun4-solaris|5.8.8|solaris|2.8|200709111136
623174|623174-b19f-3f77-b713-d32bba55d77f|pass|200709|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709112108
625331|625331-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Compare|0.17|sun4-solaris|5.9.5|solaris|2.9|200709121723
631722|631722-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.8.8|freebsd|5.3-release|200709151723
632261|632261-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151533
632453|632453-b19f-3f77-b713-d32bba55d77f|pass|200709|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|0.17|i686-linux|5.8.8|linux|2.6.20-16-generic|200709151221
634970|634970-b19f-3f77-b713-d32bba55d77f|pass|200709|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200709160900
636217|636217-b19f-3f77-b713-d32bba55d77f|pass|200709|cpan@pqpq.de|Data-Compare|0.17|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200709162224
644503|644503-b19f-3f77-b713-d32bba55d77f|pass|200709|srezic@cpan.org|CPAN-FindDependencies|1.02|amd64-freebsd|5.10.0 patch 31894|freebsd|6.2-release|200709200002
645430|645430-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.10.0 patch 31906|linux|2.6.16.38|200709201232
647235|647235-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200709210757
649448|649448-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200709220425
649692|649692-b19f-3f77-b713-d32bba55d77f|pass|200709|srezic@cpan.org|CPAN-FindDependencies|1.02|i386-freebsd|5.10.0 patch 31938|freebsd|6.1-release|200709220244
650269|650269-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200709221114
651644|651644-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200709230013
653290|653290-b19f-3f77-b713-d32bba55d77f|unknown|200709|david@cantrell.org.uk|Acme-Licence|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231412
653303|653303-b19f-3f77-b713-d32bba55d77f|unknown|200709|david@cantrell.org.uk|Acme-Pony|1.1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231415
653315|653315-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231416
653355|653355-b19f-3f77-b713-d32bba55d77f|fail|200709|david@cantrell.org.uk|Bryar|3.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231422
653360|653360-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Class-CanBeA|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231423
653373|653373-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Hexdumper|1.0.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231425
653383|653383-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Data-Hexdumper|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231426
653410|653410-b19f-3f77-b713-d32bba55d77f|fail|200709|david@cantrell.org.uk|Data-Transactional|0.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231428
653422|653422-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231429
653424|653424-b19f-3f77-b713-d32bba55d77f|pass|200709|chris@bingosnet.co.uk|Acme-Pony|1.1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200709231454
653426|653426-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|File-Overwrite|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231431
653429|653429-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Games-Dice-Advanced|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231432
653434|653434-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|NestedMap|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231434
653448|653448-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Net-Random|2.0|i386-freebsd|5.9.5|freebsd|6.2-release|200709231438
653454|653454-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Number-Phone|1.58|i386-freebsd|5.9.5|freebsd|6.2-release|200709231439
653465|653465-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.9.5|freebsd|6.2-release|200709231442
653473|653473-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231444
653479|653479-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231446
653484|653484-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Statistics-ChiSquare|0.5|i386-freebsd|5.9.5|freebsd|6.2-release|200709231449
653494|653494-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231450
653506|653506-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Tie-Hash-Longest|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231453
653512|653512-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231454
653518|653518-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Tie-STDOUT|1.02|i386-freebsd|5.9.5|freebsd|6.2-release|200709231456
653529|653529-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231457
653534|653534-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200709231459
653538|653538-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|XML-Tiny|1.06|i386-freebsd|5.9.5|freebsd|6.2-release|200709231500
653652|653652-b19f-3f77-b713-d32bba55d77f|pass|200709|david@cantrell.org.uk|Sub-WrapPackages|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200709231452
663263|663263-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|0.9|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710012251
663600|663600-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710012338
663601|663601-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710012335
663602|663602-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710012334
663613|663613-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710012336
663622|663622-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710012337
663623|663623-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710012337
663624|663624-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|0.92|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710012336
664271|664271-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|Devel-CheckOS|0.92|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710020911
664272|664272-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710020710
664273|664273-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|Devel-CheckOS|0.91|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710020911
664275|664275-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|Devel-CheckOS|0.9|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710020911
664608|664608-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|darwin-2level|5.9.5|darwin|8.10.1|200710021141
664666|664666-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|darwin-2level|5.9.5|darwin|8.10.1|200710021152
664742|664742-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Data-Compare|0.17|i686-linux|5.10.0 patch 31937|linux|2.6.18-4-486|200710021313
664771|664771-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|sun4-solaris|5.9.5|solaris|2.9|200710020627
664779|664779-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i386-freebsd|5.9.5|freebsd|6.2-release|200710021131
664789|664789-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i686-linux|5.8.8|linux|2.4.27-3-686|200710021233
664790|664790-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i686-linux|5.9.5|linux|2.4.27-3-686|200710021234
665010|665010-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i686-linux|5.9.5|linux|2.4.27-3-686|200710021358
665011|665011-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710021258
665091|665091-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i686-linux|5.8.8|linux|2.4.27-3-686|200710021421
665092|665092-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.91|i686-linux|5.6.2|linux|2.4.27-3-686|200710021421
665097|665097-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i386-freebsd|5.9.5|freebsd|6.2-release|200710021324
665102|665102-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|sun4-solaris|5.9.5|solaris|2.9|200710020824
665182|665182-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|i686-linux|5.6.2|linux|2.4.27-3-686|200710021445
665351|665351-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|0.92|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710020837
665385|665385-b19f-3f77-b713-d32bba55d77f|pass|200710|saper@cpan.org|Devel-CheckOS|0.92|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710021621
665491|665491-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|0.92|amd64-freebsd|5.10.0 patch 31995|freebsd|6.2-release|200710020837
665546|665546-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|0.92|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710021501
665823|665823-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710021809
665827|665827-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710021807
665828|665828-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710021808
665829|665829-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710021808
665831|665831-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710021806
665832|665832-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710021805
665833|665833-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710021804
666004|666004-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux|5.10.0|linux|2.6.22-1-k7|200710021710
666037|666037-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710021839
666053|666053-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710021846
666078|666078-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710021853
666102|666102-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710021958
666107|666107-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710021959
666113|666113-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710021901
666149|666149-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710021908
666179|666179-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710021915
666199|666199-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710022002
666204|666204-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710021922
666222|666222-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710022000
666228|666228-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710022001
666229|666229-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710022001
666230|666230-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710022000
666239|666239-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710021929
666247|666247-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.9|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710021931
666540|666540-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux|5.10.0|linux|2.6.22-1-k7|200710022105
667743|667743-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.0|i686-linux|5.10.0|linux|2.6.22-1-k7|200710031215
667823|667823-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|0.91|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710031934
667829|667829-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|0.92|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710031944
667886|667886-b19f-3f77-b713-d32bba55d77f|pass|200710|saper@cpan.org|File-Find-Rule-Permissions|1.3|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710031453
668899|668899-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200710032339
668904|668904-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200710032341
668977|668977-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|darwin-2level|5.9.5|darwin|8.10.1|200710040024
668982|668982-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|sun4-solaris|5.9.5|solaris|2.9|200710040024
668983|668983-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|darwin-2level|5.9.5|darwin|8.10.1|200710040024
668985|668985-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i386-freebsd|5.9.5|freebsd|6.2-release|200710040025
668989|668989-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|sun4-solaris|5.9.5|solaris|2.9|200710040027
668990|668990-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i386-freebsd|5.9.5|freebsd|6.2-release|200710040028
669006|669006-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i686-linux|5.9.5|linux|2.4.27-3-686|200710040037
669009|669009-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i686-linux|5.9.5|linux|2.4.27-3-686|200710040038
669010|669010-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710040038
669019|669019-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710040043
669023|669023-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200710040045
669026|669026-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200710040046
669230|669230-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.22-1-k7|200710040801
669588|669588-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710042126
669592|669592-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710042127
669812|669812-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710041746
669813|669813-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710041744
669814|669814-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710041748
669815|669815-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710041750
669816|669816-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710041752
669817|669817-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710041754
669818|669818-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710041756
669820|669820-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710041758
669822|669822-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.91|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710041800
670143|670143-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710042349
670144|670144-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710042352
670145|670145-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710042353
670146|670146-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710042355
670148|670148-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710042358
670150|670150-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710050004
670153|670153-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710050007
670155|670155-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710050009
670157|670157-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|0.92|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710050012
670386|670386-b19f-3f77-b713-d32bba55d77f|pass|200710|alexchorny@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710040629
670692|670692-b19f-3f77-b713-d32bba55d77f|pass|200710|alexchorny@gmail.com|Devel-CheckOS|1.0|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710040629
670971|670971-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710051147
671194|671194-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710051318
671198|671198-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710051320
671199|671199-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710051323
671200|671200-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710051325
671201|671201-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710051327
671202|671202-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710051329
671215|671215-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710051331
671220|671220-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710051333
671223|671223-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710051335
671243|671243-b19f-3f77-b713-d32bba55d77f|pass|200710|rlane10@wi.rr.com|Number-Phone|1.58|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200710050721
671301|671301-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710051410
671306|671306-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710051413
671308|671308-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710051415
671312|671312-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710051417
671318|671318-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710051420
671322|671322-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710051422
671325|671325-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710051425
671326|671326-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710051427
671328|671328-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710051429
671367|671367-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710051606
671369|671369-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710051607
671370|671370-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.8 patch 31223|linux|2.6.22-1-k7|200710051608
671371|671371-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710051608
671374|671374-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710051609
671377|671377-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710051609
671400|671400-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.1|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710051610
671477|671477-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710051757
673261|673261-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710061431
674252|674252-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710061335
674519|674519-b19f-3f77-b713-d32bba55d77f|fail|200710|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.1|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710061502
674615|674615-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|darwin-2level|5.9.5|darwin|8.10.1|200710062344
674617|674617-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|sun4-solaris|5.9.5|solaris|2.9|200710061745
674669|674669-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710070004
674672|674672-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i686-linux|5.9.5|linux|2.4.27-3-686|200710070004
674674|674674-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i386-freebsd|5.9.5|freebsd|6.2-release|200710070005
674727|674727-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200710070039
674728|674728-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200710070039
675923|675923-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710080206
676370|676370-b19f-3f77-b713-d32bba55d77f|pass|200710|alexchorny@gmail.com|Devel-CheckOS|1.1|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200710071351
676967|676967-b19f-3f77-b713-d32bba55d77f|pass|200710|saper@cpan.org|Devel-CheckOS|1.1|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710081119
677780|677780-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32039|freebsd|6.2-release|200710082304
677917|677917-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.6.2|freebsd|6.2-release|200710082309
679862|679862-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710101039
679863|679863-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710101041
679870|679870-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710101043
679875|679875-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710101045
679883|679883-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710101048
679889|679889-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710101050
679894|679894-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710101052
679895|679895-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710101054
679896|679896-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710101056
680299|680299-b19f-3f77-b713-d32bba55d77f|pass|200710|david@valuesofn.com|Data-Compare|0.17|darwin-2level|5.8.8|darwin|8.8.2|200710101043
681705|681705-b19f-3f77-b713-d32bba55d77f|pass|200710|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.1|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710111716
682486|682486-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710121126
683801|683801-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710131421
683802|683802-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.6.2|freebsd|6.2-release|200710131422
683803|683803-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710131421
683804|683804-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.06|amd64-freebsd|5.5.5|freebsd|6.2-release|200710131422
685543|685543-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710141046
685544|685544-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|1.1|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710141045
685545|685545-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|1.1|amd64-freebsd|5.6.2|freebsd|6.2-release|200710141046
686176|686176-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710141723
686178|686178-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710141723
686180|686180-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710141724
686183|686183-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710141724
686207|686207-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710141723
686209|686209-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710141723
686210|686210-b19f-3f77-b713-d32bba55d77f|unknown|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710141724
686293|686293-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710141815
686295|686295-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710141815
686300|686300-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710141815
686304|686304-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710141816
686308|686308-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200710141816
686373|686373-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710141816
686378|686378-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.2|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710141815
686488|686488-b19f-3f77-b713-d32bba55d77f|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710141935
686622|686622-b19f-3f77-b713-d32bba55d77f|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710142014
686730|686730-b19f-3f77-b713-d32bba55d77f|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.6.2|freebsd|6.2-release|200710142111
686818|686818-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|1.2|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710150044
686938|686938-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckOS|1.2|amd64-freebsd|5.6.2|freebsd|6.2-release|200710150113
686952|686952-b19f-3f77-b713-d32bba55d77f|unknown|200710|srezic@cpan.org|Devel-AssertLib|0.1|amd64-freebsd|5.5.5|freebsd|6.2-release|200710150117
687066|687066-b19f-3f77-b713-d32bba55d77f|pass|200710|andy@hexten.net|Data-Hexdumper|1.3|i86pc-solaris-64int|5.8.4|solaris|2.11|200710150226
687689|687689-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200710151304
687691|687691-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|alpha-linux-thread-multi|5.8.8|linux|2.6.16.19|200710151305
687712|687712-b19f-3f77-b713-d32bba55d77f|pass|200710|xdg@hyperbolic.net (DAGOLDEN)|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710150820
687716|687716-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710151333
687717|687717-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710151334
688024|688024-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i686-linux|5.9.5|linux|2.4.27-3-686|200710151516
688025|688025-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i686-linux|5.8.8|linux|2.4.27-3-686|200710151516
688026|688026-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|darwin-2level|5.9.5|darwin|8.10.1|200710151508
688030|688030-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i686-linux|5.6.2|linux|2.4.27-3-686|200710151507
688096|688096-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|sun4-solaris|5.9.5|solaris|2.9|200710150937
688180|688180-b19f-3f77-b713-d32bba55d77f|pass|200710|saper@cpan.org|Devel-AssertLib|0.1|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710151711
688233|688233-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-AssertLib|0.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710152339
688356|688356-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|i386-freebsd|5.9.5|freebsd|6.2-release|200710151316
688419|688419-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckOS|1.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710151750
689795|689795-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710160742
689801|689801-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710160743
690422|690422-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710162118
690817|690817-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.10.0 patch 31906|linux|2.6.16.38|200710161710
690828|690828-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.10.0 patch 31906|linux|2.6.16.38|200710161711
691859|691859-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710170645
691860|691860-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710170645
691861|691861-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710170645
691862|691862-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710170646
691863|691863-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710170646
691864|691864-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710170646
691865|691865-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710170646
691866|691866-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710170647
691867|691867-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710170647
691868|691868-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710170647
691869|691869-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710170648
691870|691870-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710170649
691871|691871-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710170649
691872|691872-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710170650
691873|691873-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710170650
691874|691874-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710170651
691875|691875-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710170651
691876|691876-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710170652
692213|692213-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710171009
692214|692214-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710171010
692388|692388-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|Devel-CheckOS|1.2|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710171254
692389|692389-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|Devel-AssertLib|0.1|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710171254
693524|693524-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710180053
693559|693559-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710180055
693630|693630-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710180016
693641|693641-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710180017
693720|693720-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.10.0 patch 31938|freebsd|6.1-release|200710180126
693798|693798-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710180126
693802|693802-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200710180127
695204|695204-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710181755
695210|695210-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710181758
695352|695352-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|sun4-solaris|5.9.5|solaris|2.9|200710181429
695818|695818-b19f-3f77-b713-d32bba55d77f|pass|200710|xdg@hyperbolic.net (DAGOLDEN)|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710181841
695827|695827-b19f-3f77-b713-d32bba55d77f|pass|200710|xdg@hyperbolic.net (DAGOLDEN)|Devel-CheckLib|0.2|i686-linux-64int-ld|5.8.8|linux|2.6.17-10-generic|200710181845
695959|695959-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710190300
696149|696149-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710190702
696435|696435-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@pqpq.de|Devel-CheckLib|0.2|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200710190814
696830|696830-b19f-3f77-b713-d32bba55d77f|pass|200710|saper@cpan.org|Devel-CheckLib|0.2|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710191054
696970|696970-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191005
696972|696972-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191005
696974|696974-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191006
697028|697028-b19f-3f77-b713-d32bba55d77f|pass|200710|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.2|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710190612
697605|697605-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710191626
697844|697844-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710191859
697845|697845-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710191900
697846|697846-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710191900
698349|698349-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710200033
698350|698350-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710200035
698351|698351-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710200037
698796|698796-b19f-3f77-b713-d32bba55d77f|fail|200710|mr.muskrat@perlgeek.net ("Mr. Muskrat")|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200031
698896|698896-b19f-3f77-b713-d32bba55d77f|unknown|200710|mr.muskrat@perlgeek.net ("Mr. Muskrat")|Devel-AssertLib|0.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200030
698912|698912-b19f-3f77-b713-d32bba55d77f|pass|200710|mr.muskrat@perlgeek.net ("Mr. Muskrat")|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200032
699054|699054-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710201144
699218|699218-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710200134
699476|699476-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|darwin-2level|5.9.5|darwin|8.10.1|200710201531
699498|699498-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i686-linux|5.9.5|linux|2.4.27-3-686|200710201535
699502|699502-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i686-linux|5.8.8|linux|2.4.27-3-686|200710201535
699537|699537-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710202240
699565|699565-b19f-3f77-b713-d32bba55d77f|pass|200710|icerider70@gmail.com ("ICERIDER")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710200957
699613|699613-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200902
699617|699617-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710200937
699640|699640-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i686-linux|5.6.2|linux|2.4.27-3-686|200710201631
699764|699764-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|i386-freebsd|5.9.5|freebsd|6.2-release|200710201454
699784|699784-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|sun4-solaris|5.9.5|solaris|2.9|200710201118
699895|699895-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.2|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710201649
700529|700529-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710202034
700532|700532-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710202035
700533|700533-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710202036
700907|700907-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710201315
701122|701122-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710202334
701123|701123-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710202335
701125|701125-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710202336
701127|701127-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710202336
701130|701130-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710202337
701131|701131-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710202337
701133|701133-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710202338
701134|701134-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710202339
701136|701136-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710202339
701604|701604-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710210601
702100|702100-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-AssertLib|0.1|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710211441
702101|702101-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710211441
702102|702102-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710211442
702158|702158-b19f-3f77-b713-d32bba55d77f|pass|200710|bob@randomness.org.uk ("bob walker")|Devel-CheckLib|0.2|i86pc-solaris|5.8.8|solaris|2.10|200710211502
702598|702598-b19f-3f77-b713-d32bba55d77f|fail|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-AssertLib|0.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710211728
702757|702757-b19f-3f77-b713-d32bba55d77f|fail|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd|5.10.0 patch 31938|freebsd|6.1-release|200710212020
702758|702758-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710212020
702759|702759-b19f-3f77-b713-d32bba55d77f|fail|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd|5.6.2|freebsd|6.1-release|200710212021
702855|702855-b19f-3f77-b713-d32bba55d77f|fail|200710|srezic@cpan.org|Devel-CheckLib|0.2|i386-freebsd|5.5.5|freebsd|6.1-release|200710212111
703302|703302-b19f-3f77-b713-d32bba55d77f|pass|200710|bob@randomness.org.uk|Devel-CheckOS|1.2|i386-openbsd|5.8.8|openbsd|4.2|200710212258
703306|703306-b19f-3f77-b713-d32bba55d77f|pass|200710|bob@randomness.org.uk|Devel-CheckLib|0.2|i386-openbsd|5.8.8|openbsd|4.2|200710212259
704075|704075-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710221130
704614|704614-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710221350
705556|705556-b19f-3f77-b713-d32bba55d77f|pass|200710|andy@hexten.net|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.15.7|200710222023
706080|706080-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710222325
707010|707010-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.2|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230655
707013|707013-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.06|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230655
707652|707652-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230718
708218|708218-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200710230351
708858|708858-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710231428
708917|708917-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710231407
708922|708922-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|File-Find-Rule-Permissions|1.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710231407
709511|709511-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710231759
710694|710694-b19f-3f77-b713-d32bba55d77f|fail|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.2|200710241103
710738|710738-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckOS|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.2|200710241111
711237|711237-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710241518
711238|711238-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710241519
711240|711240-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710241519
711243|711243-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710241520
711245|711245-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710241519
711247|711247-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710241519
711778|711778-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200710242156
711936|711936-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710242158
711937|711937-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710242158
711939|711939-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710242158
711940|711940-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710242159
711941|711941-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710242159
711942|711942-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710242200
711943|711943-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710242200
711944|711944-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710242200
711945|711945-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710242201
712027|712027-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd|5.10.0 patch 32171|freebsd|6.1-release|200710242237
712321|712321-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd|5.5.5|freebsd|6.1-release|200710250037
712334|712334-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.07|i386-freebsd|5.6.2|freebsd|6.1-release|200710242345
712381|712381-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250128
713464|713464-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250735
713625|713625-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250848
713802|713802-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710250829
714082|714082-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710251121
714083|714083-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710251121
714227|714227-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.07|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710251225
714305|714305-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|darwin-2level|5.9.5|darwin|8.10.1|200710251427
714319|714319-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i686-linux|5.6.2|linux|2.4.27-3-686|200710251428
714330|714330-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i686-linux|5.9.5|linux|2.4.27-3-686|200710251430
714400|714400-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710251353
714407|714407-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|sun4-solaris|5.9.5|solaris|2.9|200710250851
714443|714443-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i686-linux|5.8.8|linux|2.4.27-3-686|200710251513
714470|714470-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.07|i386-freebsd|5.9.5|freebsd|6.2-release|200710251113
714489|714489-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.10.0|linux|2.6.22-1-k7|200710251631
714490|714490-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710251633
714492|714492-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710251633
714493|714493-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710251634
714498|714498-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710251632
714500|714500-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710251632
714524|714524-b19f-3f77-b713-d32bba55d77f|pass|200710|andy@hexten.net|Data-Hexdumper|1.3|powerpc-linux-gnu|5.8.8|linux|2.6.17-10-powerpc64-smp|200710251645
714870|714870-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|XML-Tiny|1.07|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710260119
714943|714943-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710252029
715122|715122-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710252155
715413|715413-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710252223
715420|715420-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710252224
715423|715423-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710252225
715425|715425-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710252225
715427|715427-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710252226
715428|715428-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710252227
715432|715432-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710252227
715434|715434-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710252228
715435|715435-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710252229
715463|715463-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.6.2|freebsd|6.2-release|200710252317
715653|715653-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.08|amd64-freebsd|5.5.5|freebsd|6.2-release|200710260039
715764|715764-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710260041
715840|715840-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.08|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710260247
715852|715852-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.2|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710260233
715853|715853-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710260233
716103|716103-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.08|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710260752
716290|716290-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710260935
716541|716541-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710261317
716957|716957-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|darwin-2level|5.9.5|darwin|8.10.1|200710261635
716962|716962-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i686-linux|5.9.5|linux|2.4.27-3-686|200710261636
716977|716977-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i686-linux|5.8.8|linux|2.4.27-3-686|200710261638
716993|716993-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i386-freebsd|5.9.5|freebsd|6.2-release|200710261351
717087|717087-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|i686-linux|5.6.2|linux|2.4.27-3-686|200710261725
717191|717191-b19f-3f77-b713-d32bba55d77f|pass|200710|imacat@mail.imacat.idv.tw|XML-Tiny|1.08|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200710270055
717424|717424-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.08|sun4-solaris|5.9.5|solaris|2.9|200710261445
717447|717447-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710262045
717448|717448-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200710262046
717474|717474-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710262133
717475|717475-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200710262134
717581|717581-b19f-3f77-b713-d32bba55d77f|pass|200710|icerider70@gmail.com ("ICERIDER")|XML-Tiny|1.07|i486-linux-gnu|5.8.8|linux|2.6.18.3|200710261644
718615|718615-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710271354
718617|718617-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710271354
719002|719002-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710270712
719003|719003-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200710270712
719671|719671-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|XML-Tiny|1.08|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710280102
719929|719929-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710280342
719930|719930-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200710280342
721013|721013-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-netbsd-thread-multi-64int|5.10.0 patch 32199|netbsd|3.1|200710281256
721014|721014-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.10.0 patch 32199|netbsd|3.1|200710281256
721312|721312-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710281527
721313|721313-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-pc-solaris2.11|5.8.7|solaris|2.11|200710281528
722085|722085-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0 patch 32199|netbsd|3.1|200710281954
722872|722872-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710290333
723241|723241-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710291142
723243|723243-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200710291142
723796|723796-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710291858
723799|723799-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710291859
723801|723801-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710291900
723806|723806-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710291901
723808|723808-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710291902
723809|723809-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710291903
724183|724183-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710292135
724187|724187-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200710292136
724259|724259-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710292255
724288|724288-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710292317
724381|724381-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710292352
724384|724384-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.6.2|freebsd|6.2-release|200710292347
724386|724386-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710292353
724392|724392-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710292353
724403|724403-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710292353
724404|724404-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710292353
724405|724405-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710292354
724510|724510-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.09|amd64-freebsd|5.5.5|freebsd|6.2-release|200710300021
724537|724537-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.5.5|freebsd|6.2-release|200710300027
724568|724568-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.6.2|freebsd|6.2-release|200710300026
724572|724572-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710300026
724585|724585-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.10.0 patch 32096|freebsd|6.2-release|200710300025
724754|724754-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710300127
724755|724755-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710300128
724756|724756-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710300128
724757|724757-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710300128
724758|724758-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710300129
724759|724759-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710300129
724761|724761-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710300129
724762|724762-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710300130
724767|724767-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710300130
725114|725114-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710300556
725116|725116-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710300556
725117|725117-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710300557
725118|725118-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710300557
725119|725119-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710300557
725120|725120-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710300558
725123|725123-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710300558
725125|725125-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710300558
725127|725127-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710300559
725167|725167-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.10|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710300816
725313|725313-b19f-3f77-b713-d32bba55d77f|pass|200710|cpan@0x64.nl|Bryar|3.0|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200710300124
725387|725387-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301051
725389|725389-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301051
725391|725391-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301052
725392|725392-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200710301051
725433|725433-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i686-linux|5.8.8|linux|2.4.27-3-686|200710301118
725438|725438-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|darwin-2level|5.9.5|darwin|8.10.1|200710301119
725448|725448-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i686-linux|5.9.5|linux|2.4.27-3-686|200710301124
725561|725561-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i686-linux|5.9.5|linux|2.4.27-3-686|200710301228
725576|725576-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i686-linux|5.6.2|linux|2.4.27-3-686|200710301230
725595|725595-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i686-linux|5.8.8|linux|2.4.27-3-686|200710301232
725596|725596-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|darwin-2level|5.9.5|darwin|8.10.1|200710301232
725706|725706-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710301302
725747|725747-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i686-linux|5.6.2|linux|2.4.27-3-686|200710301249
725750|725750-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|sun4-solaris|5.9.5|solaris|2.9|200710300813
725806|725806-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.09|i386-freebsd|5.9.5|freebsd|6.2-release|200710301029
725849|725849-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710301411
725881|725881-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|sun4-solaris|5.9.5|solaris|2.9|200710300937
725967|725967-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200710301630
725968|725968-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200710301631
725969|725969-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200710301631
725970|725970-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200710301632
725978|725978-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200710301631
725980|725980-b19f-3f77-b713-d32bba55d77f|pass|200710|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200710301631
726169|726169-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.07|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301718
726170|726170-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301718
726171|726171-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301718
726172|726172-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710301719
726508|726508-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200710302036
726675|726675-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200710302055
726727|726727-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200710302109
726791|726791-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200710302200
726828|726828-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|XML-Tiny|1.10|i386-freebsd|5.9.5|freebsd|6.2-release|200710301059
726836|726836-b19f-3f77-b713-d32bba55d77f|pass|200710|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.5.5|freebsd|6.2-release|200710302227
726852|726852-b19f-3f77-b713-d32bba55d77f|fail|200710|srezic@cpan.org|XML-Tiny|1.10|amd64-freebsd|5.5.5|freebsd|6.2-release|200710302232
727114|727114-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200710310013
727115|727115-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200710310014
727116|727116-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200710310014
727117|727117-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200710310014
727118|727118-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200710310015
727120|727120-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200710310015
727121|727121-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200710310015
727122|727122-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200710310016
727123|727123-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200710310016
727192|727192-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200710310050
727341|727341-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|XML-Tiny|1.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310337
727446|727446-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|XML-Tiny|1.10|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310008
727554|727554-b19f-3f77-b713-d32bba55d77f|pass|200710|mmusgrove@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200710310116
727762|727762-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311018
727763|727763-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311019
727764|727764-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311019
727765|727765-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200710311020
727781|727781-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.3|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710311052
727820|727820-b19f-3f77-b713-d32bba55d77f|pass|200710|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200710311203
728112|728112-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|XML-Tiny|1.09|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010038
728139|728139-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|XML-Tiny|1.10|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010058
728217|728217-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711010151
728275|728275-b19f-3f77-b713-d32bba55d77f|pass|200710|saper@cpan.org|XML-Tiny|1.08|i386-linux|5.8.5|linux|2.6.3-25mdk-i686-up-4gb|200710311957
728443|728443-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux|5.9.5|linux|2.4.27-3-686|200710312032
728512|728512-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|Devel-CheckLib|0.3|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312101
728514|728514-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.08|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312101
728517|728517-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.09|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312102
728518|728518-b19f-3f77-b713-d32bba55d77f|pass|200710|chris@bingosnet.co.uk|XML-Tiny|1.10|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200710312102
728552|728552-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux|5.6.2|linux|2.4.27-3-686|200710312115
728555|728555-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|darwin-2level|5.9.5|darwin|8.10.1|200710312116
728567|728567-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux|5.8.8|linux|2.4.27-3-686|200710312117
728568|728568-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|i386-freebsd|5.9.5|freebsd|6.2-release|200710312115
728604|728604-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|sun4-solaris|5.9.5|solaris|2.9|200710311636
728605|728605-b19f-3f77-b713-d32bba55d77f|pass|200710|david@cantrell.org.uk|Devel-CheckLib|0.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200710312136
728884|728884-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711010041
729616|729616-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|XML-Tiny|1.10|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010424
730066|730066-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711010550
730773|730773-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|Devel-CheckLib|0.3|i486-linux-gnu|5.8.8|linux|2.6.18.3|200711010651
731697|731697-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711011807
731701|731701-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711011807
731719|731719-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011714
731720|731720-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.08|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011714
731721|731721-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011715
731722|731722-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711011715
731730|731730-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711011808
731782|731782-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|Palm-SMS|0.02|darwin-2level|5.9.5|darwin|8.10.1|200711011729
732214|732214-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.6.2|freebsd|6.2-release|200711012140
732229|732229-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711012145
732356|732356-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711012145
732438|732438-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.5.5|freebsd|6.2-release|200711012223
732646|732646-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711012233
732819|732819-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012325
732820|732820-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.08|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012325
732821|732821-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012326
732822|732822-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711012326
733089|733089-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711020241
733397|733397-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711020511
733409|733409-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711020026
733855|733855-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux|5.6.2|linux|2.4.27-3-686|200711021208
733946|733946-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711021252
734213|734213-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711021542
734243|734243-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|darwin-2level|5.9.5|darwin|8.10.1|200711021558
734247|734247-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux|5.9.5|linux|2.4.27-3-686|200711021559
734259|734259-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i386-freebsd|5.9.5|freebsd|6.2-release|200711021552
734350|734350-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.10.0 patchlevel 32202|MSWin32|5.2|200711021633
734384|734384-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux|5.8.8|linux|2.4.27-3-686|200711021559
734440|734440-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021640
734442|734442-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021640
734443|734443-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021641
734445|734445-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711021641
734649|734649-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Devel-CheckOS|1.2|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711021844
734964|734964-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711022109
734969|734969-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711022109
734970|734970-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711022110
734983|734983-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711022111
734990|734990-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711022111
734991|734991-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711022111
734996|734996-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711022112
735000|735000-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711022110
735001|735001-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711022110
735073|735073-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|sun4-solaris|5.9.5|solaris|2.9|200711021627
735204|735204-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@0x64.nl|XML-Tiny|1.11|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200711022008
735291|735291-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711022208
735637|735637-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Data-Compare|0.02|i386-freebsd|5.9.5|freebsd|6.2-release|200711030027
735719|735719-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030139
735720|735720-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030140
735721|735721-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030140
735724|735724-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711030141
735927|735927-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711030313
736341|736341-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.02|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711031033
736770|736770-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|Devel-CheckLib|0.3|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030412
736772|736772-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|XML-Tiny|1.11|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711030412
736795|736795-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711030733
737084|737084-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030337
737086|737086-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030337
737087|737087-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030338
737089|737089-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711030338
737280|737280-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|XML-Tiny|1.11|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.20.12|200711032258
738907|738907-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040155
738908|738908-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040155
738909|738909-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040155
738910|738910-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711040156
739569|739569-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041250
739570|739570-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041250
739571|739571-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041251
739572|739572-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711041251
740713|740713-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050044
740714|740714-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050044
740715|740715-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050044
740716|740716-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711050045
741522|741522-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|XML-Tiny|1.11|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741523|741523-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|XML-Tiny|1.10|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741524|741524-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|XML-Tiny|1.09|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741525|741525-b19f-3f77-b713-d32bba55d77f|pass|200711|cpan@pqpq.de|Devel-CheckLib|0.3|i386-freebsd|5.10.0 patch 31806|freebsd|6.1-release-p6|200711050851
741809|741809-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711051058
742656|742656-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|darwin-2level|5.9.5|darwin|9.0.0|200711051831
743026|743026-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.10|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052057
743028|743028-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052058
743035|743035-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.09|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052057
743052|743052-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i86pc-solaris-thread-multi-64int|5.9.5|solaris|2.10|200711052056
743914|743914-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711060535
745365|745365-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711061836
746713|746713-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckLib|0.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711070246
746714|746714-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711070246
747954|747954-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 32202|linux|2.6.16.38|200711071243
748739|748739-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711071835
749141|749141-b19f-3f77-b713-d32bba55d77f|pass|200711|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.2|i86pc-solaris|5.8.8|solaris|2.10|200711072025
749292|749292-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711072209
749304|749304-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711072211
749306|749306-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711072212
749311|749311-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711072214
749312|749312-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711072215
749316|749316-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711072216
749324|749324-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711072218
749330|749330-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.3|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711072219
749605|749605-b19f-3f77-b713-d32bba55d77f|pass|200711|bob@randomness.org.uk ("bob walker")|CPAN-FindDependencies|1.02|i86pc-solaris|5.8.8|solaris|2.10|200711072344
749902|749902-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711080739
749905|749905-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711080739
749907|749907-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711080740
749909|749909-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711080741
749910|749910-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711080741
749912|749912-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711080742
749914|749914-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711080743
749917|749917-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200711080643
749954|749954-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.41|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711080738
750004|750004-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711080815
750021|750021-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711080824
750025|750025-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.9.4|linux|2.6.17-2-k7|200711080830
750026|750026-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711080834
750042|750042-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711080840
750060|750060-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711080848
750106|750106-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711080859
750197|750197-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|1.1|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711080817
750202|750202-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.41|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711080818
750450|750450-b19f-3f77-b713-d32bba55d77f|pass|200711|bob@randomness.org.uk ("bob walker")|CPAN-FindDependencies|1.1|i86pc-solaris|5.8.8|solaris|2.10|200711081027
751024|751024-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711081552
751025|751025-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|darwin-thread-multi-2level|5.10.0 patch 32245|darwin|9.0.0|200711081554
751606|751606-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|darwin-2level|5.9.5|darwin|8.10.1|200711081833
751640|751640-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|i686-linux|5.9.5|linux|2.4.27-3-686|200711081842
751643|751643-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|i686-linux|5.8.8|linux|2.4.27-3-686|200711081843
751647|751647-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|i686-linux|5.6.2|linux|2.4.27-3-686|200711081843
751663|751663-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711081939
751724|751724-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Devel-CheckOS|1.41|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711081941
751804|751804-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Devel-CheckOS|1.41|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711082040
751901|751901-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711082039
752045|752045-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Devel-CheckOS|1.41|amd64-freebsd|5.6.2|freebsd|6.2-release|200711082125
752282|752282-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|darwin-2level|5.9.5|darwin|8.10.1|200711090012
752289|752289-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|darwin-2level|5.9.5|darwin|8.10.1|200711090014
752314|752314-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090031
752315|752315-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090032
752317|752317-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090033
752318|752318-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.9.5|openbsd|4.1|200711090034
752322|752322-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|i686-linux|5.8.8|linux|2.4.27-3-686|200711090038
752326|752326-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|i686-linux|5.9.5|linux|2.4.27-3-686|200711090039
752338|752338-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i686-linux|5.8.8|linux|2.4.27-3-686|200711090045
752342|752342-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i686-linux|5.9.5|linux|2.4.27-3-686|200711090046
752367|752367-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.4|i686-linux|5.6.2|linux|2.4.27-3-686|200711090058
752369|752369-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i686-linux|5.6.2|linux|2.4.27-3-686|200711090100
752699|752699-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090104
752721|752721-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090112
752722|752722-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.41|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090113
752727|752727-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|CPAN-FindDependencies|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090120
753143|753143-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org|Devel-CheckOS|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090606
753276|753276-b19f-3f77-b713-d32bba55d77f|na|200711|mmusgrove@cpan.org|Devel-CheckOS|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090711
753277|753277-b19f-3f77-b713-d32bba55d77f|fail|200711|mmusgrove@cpan.org|Devel-CheckOS|1.41|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090713
753292|753292-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|CPAN-FindDependencies|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711090726
754375|754375-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.3|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711100554
754643|754643-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711100042
754646|754646-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711100044
754648|754648-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711100046
754981|754981-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.41|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711101304
754998|754998-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711101311
755487|755487-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|sun4-solaris|5.9.5|solaris|2.9|200711100348
755495|755495-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|Devel-CheckOS|1.3|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711100951
755563|755563-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711101013
755568|755568-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711101014
755573|755573-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711101015
758030|758030-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711110901
758033|758033-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711110907
758036|758036-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711110912
758039|758039-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711110918
758050|758050-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711110923
758056|758056-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711110928
758060|758060-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711110932
758061|758061-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711110937
758062|758062-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi|5.6.2|darwin|8.10.0|200711110938
758063|758063-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711110940
758065|758065-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711110941
758066|758066-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711110942
758068|758068-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711110943
758070|758070-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711110944
758072|758072-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711110946
758073|758073-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711110947
758074|758074-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711110948
758077|758077-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi|5.6.2|darwin|8.10.0|200711110952
758078|758078-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711110953
758081|758081-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711110955
758082|758082-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711110956
758083|758083-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711110958
758084|758084-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711110959
758085|758085-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711111000
758087|758087-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711111001
758088|758088-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711111002
758230|758230-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711111148
758232|758232-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711111149
758233|758233-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711111149
758235|758235-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711111151
758239|758239-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711111152
758242|758242-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711111153
758243|758243-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711111154
758246|758246-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711111155
758247|758247-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711111156
758365|758365-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111346
758366|758366-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111347
758367|758367-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711111348
758725|758725-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711111840
758726|758726-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711111840
758727|758727-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711111841
758728|758728-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711111841
758729|758729-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711111842
758730|758730-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711111842
758731|758731-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711111843
758732|758732-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711111844
758735|758735-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711111844
758765|758765-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711111859
758779|758779-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711111903
758783|758783-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711111907
758798|758798-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711111911
758810|758810-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711111914
758828|758828-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711111918
758842|758842-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711111922
758852|758852-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711111925
758997|758997-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711112053
759211|759211-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711112249
759785|759785-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|sun4-solaris|5.9.5|solaris|2.9|200711120107
759793|759793-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711120012
759916|759916-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711120108
760130|760130-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.8.8 patch 32273|linux|2.6.22-1-k7|200711120257
761118|761118-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120944
761122|761122-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120944
761123|761123-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i686-linux-thread-multi-64int|5.8.8|linux|2.6.21.5-smp|200711120945
761727|761727-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.41|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711121152
761946|761946-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121258
761955|761955-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121300
761962|761962-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711121301
762712|762712-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0 patch 32280|netbsd|3.1|200711121713
764083|764083-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.41|i386-freebsd|5.9.5|freebsd|6.2-release|200711122250
764588|764588-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130237
764591|764591-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i686-linux-thread-multi-64int|5.9.5|linux|2.6.21.5-smp|200711130237
764854|764854-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711130039
765192|765192-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711131007
765193|765193-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711131008
765194|765194-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711131009
765970|765970-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i386-linux|5.8.5|linux|2.6.9-42.elsmp|200711131828
766337|766337-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.10.0 patch 32200|freebsd|6.2-release|200711132151
766737|766737-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711140001
766767|766767-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711140002
767072|767072-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200711140233
767176|767176-b19f-3f77-b713-d32bba55d77f|pass|200711|bob@randomness.org.uk ("bob walker")|XML-Tiny|1.11|i86pc-solaris|5.8.8|solaris|2.10|200711140157
768950|768950-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711142150
769960|769960-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|CPAN-FindDependencies|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711150217
769974|769974-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.3|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711150218
770001|770001-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.41|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711150224
770227|770227-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711150336
771720|771720-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711151421
773882|773882-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Devel-CheckOS|1.41|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711160111
774066|774066-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200711160119
775025|775025-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Devel-CheckOS|1.41|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711161355
776151|776151-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0 patch 32330|linux|2.6.22-14-generic|200711161734
779725|779725-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd|5.10.0 patch 32367|freebsd|6.2-release|200711172259
779882|779882-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org ("Matthew Musgrove")|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711171714
780203|780203-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32367|freebsd|6.2-release|200711180053
780237|780237-b19f-3f77-b713-d32bba55d77f|pass|200711|mmusgrove@cpan.org|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200711171759
782724|782724-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|CPAN-FindDependencies|1.1|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200711181939
783177|783177-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200711182121
783899|783899-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int|5.10.0|linux|2.6.16.38|200711190054
784863|784863-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711191100
790887|790887-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711202149
790891|790891-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711202150
790893|790893-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711202150
790896|790896-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711202151
790898|790898-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711202151
790899|790899-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711202152
790900|790900-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711202153
791726|791726-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 32389|linux|2.6.22-1-k7|200711210525
791728|791728-b19f-3f77-b713-d32bba55d77f|pass|200711|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711210436
792257|792257-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711211005
792263|792263-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711211005
792268|792268-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711211006
792275|792275-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711211006
792278|792278-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711211007
792281|792281-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711211008
792287|792287-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711211008
792289|792289-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711211009
792294|792294-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711211009
792332|792332-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711211015
792411|792411-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711211155
792711|792711-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200711211315
792839|792839-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711211437
793079|793079-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711211551
793685|793685-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200711211914
793833|793833-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|darwin-2level|5.9.5|darwin|8.10.1|200711211958
793845|793845-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux|5.8.8|linux|2.4.27-3-686|200711212002
793890|793890-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux|5.6.2|linux|2.4.27-3-686|200711212013
793933|793933-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux|5.9.5|linux|2.4.27-3-686|200711212018
793969|793969-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i386-freebsd|5.9.5|freebsd|6.2-release|200711212013
794720|794720-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200711220351
794722|794722-b19f-3f77-b713-d32bba55d77f|fail|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200711220351
794724|794724-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200711220352
794732|794732-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200711220354
794757|794757-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200711220352
794758|794758-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200711220353
794759|794759-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200711220353
794883|794883-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.10.0 patch 32367|freebsd|6.2-release|200711220756
794928|794928-b19f-3f77-b713-d32bba55d77f|na|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.5.5|freebsd|6.2-release|200711220815
794967|794967-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200711220802
794968|794968-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200711220809
795134|795134-b19f-3f77-b713-d32bba55d77f|fail|200711|srezic@cpan.org|Bryar|3.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711221015
796071|796071-b19f-3f77-b713-d32bba55d77f|fail|200711|icerider70@gmail.com ("ICERIDER")|Bryar|3.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711220952
796188|796188-b19f-3f77-b713-d32bba55d77f|fail|200711|icerider70@gmail.com ("ICERIDER")|Bryar|3.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200711220952
796262|796262-b19f-3f77-b713-d32bba55d77f|pass|200711|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200711230041
796506|796506-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200711221727
796514|796514-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200711221732
796522|796522-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200711221737
796553|796553-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200711221742
796572|796572-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200711221748
796574|796574-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200711221753
796578|796578-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200711221758
796586|796586-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200711221803
796609|796609-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0_rc3|200711221805
796624|796624-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200711221809
796632|796632-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|sun4-solaris|5.9.5|solaris|2.9|200711221409
796633|796633-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711222008
796792|796792-b19f-3f77-b713-d32bba55d77f|pass|200711|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200711230101
796943|796943-b19f-3f77-b713-d32bba55d77f|pass|200711|taro-nishino@sam.hi-ho.ne.jp (Taro Nishino)|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200711230101
797187|797187-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230002
797200|797200-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|CPAN-FindDependencies|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230006
797203|797203-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Data-Compare|0.17|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230006
797204|797204-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Data-Transactional|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230007
797205|797205-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230006
797207|797207-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckLib|0.3|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230007
797208|797208-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230007
797226|797226-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|File-Overwrite|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230021
797227|797227-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230021
797228|797228-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|NestedMap|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230022
797240|797240-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Net-Random|2.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230026
797246|797246-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Number-Phone|1.58|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230028
797251|797251-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230029
797265|797265-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797266|797266-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797268|797268-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Tie-STDOUT|1.03|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797269|797269-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797270|797270-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230031
797271|797271-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711230032
797770|797770-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0_rc3|200711230741
798215|798215-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Bryar|3.0|i686-linux|5.8.8|linux|2.4.27-3-686|200711231110
798251|798251-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|Bryar|3.0|i686-linux-thread-multi|5.10.0 patch 32448|linux|2.4.27-3-686|200711231131
798475|798475-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711231503
799278|799278-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|Bryar|3.0|sun4-solaris|5.9.5|solaris|2.9|200711231241
799280|799280-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|Bryar|3.0|alpha-netbsd|5.9.5|netbsd|2.1.0_stable|200711231841
799737|799737-b19f-3f77-b713-d32bba55d77f|fail|200711|david@cantrell.org.uk|Bryar|3.0|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200711232131
799879|799879-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200711232234
800041|800041-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|CPAN-FindDependencies|1.1|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200711231702
800120|800120-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200711231717
800122|800122-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200711231717
800244|800244-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711240055
800714|800714-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200711240531
802110|802110-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200711241858
802164|802164-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0 patch 32478|linux|2.6.18-5-686|200711241915
804772|804772-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i386-freebsd-thread-multi|5.10.0 patch 32487|freebsd|6.2-release|200711251905
805243|805243-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711252121
805468|805468-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|ppc-linux-thread-multi|5.10.0 patch 32376|linux|2.6.20-16-powerpc|200711252222
805729|805729-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Tie-STDOUT|1.03|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200711260042
805754|805754-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200711260050
805787|805787-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Net-Random|2.0|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200711260103
806233|806233-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i386-pc-solaris2.11|5.8.7|solaris|2.11|200711260744
807683|807683-b19f-3f77-b713-d32bba55d77f|pass|200711|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200711261548
807867|807867-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711261640
807929|807929-b19f-3f77-b713-d32bba55d77f|pass|200711|stro@cpan.org|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200711261758
809202|809202-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Data-Hexdumper|1.3|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200711262249
810317|810317-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Bryar|3.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200711270828
811314|811314-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200711271352
811999|811999-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200711271804
813087|813087-b19f-3f77-b713-d32bba55d77f|pass|200711|andy@hexten.net|Data-Hexdumper|1.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200711280142
813495|813495-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|Bryar|3.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200711280649
813940|813940-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711281215
814046|814046-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711281320
814406|814406-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200711281443
814407|814407-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi|5.6.2|darwin|8.10.0|200711281444
814413|814413-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200711281445
814415|814415-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200711281446
814417|814417-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200711281447
814420|814420-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200711281448
814424|814424-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200711281449
814427|814427-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200711281450
814429|814429-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200711281451
814433|814433-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200711281452
815957|815957-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200711290131
816430|816430-b19f-3f77-b713-d32bba55d77f|fail|200711|chris@bingosnet.co.uk|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200711290454
818090|818090-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Data-Compare|0.17|i386-freebsd|5.10.0 patch 32478|freebsd|6.1-release|200711291851
818305|818305-b19f-3f77-b713-d32bba55d77f|pass|200711|srezic@cpan.org|Data-Compare|0.17|i386-freebsd|5.6.2|freebsd|6.1-release|200711292028
819571|819571-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711300129
819990|819990-b19f-3f77-b713-d32bba55d77f|pass|200711|chris@bingosnet.co.uk|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.2|200711301328
820335|820335-b19f-3f77-b713-d32bba55d77f|pass|200711|alexchorny@gmail.com|Data-Compare|0.17|i686-linux|5.10.0 patch 32015|linux|2.4.20-8smp|200711300740
820981|820981-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302032
821716|821716-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302146
821881|821881-b19f-3f77-b713-d32bba55d77f|pass|200711|david@cantrell.org.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200711302135
822556|822556-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302357
822812|822812-b19f-3f77-b713-d32bba55d77f|pass|200711|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.10.0|linux|2.6.22-1-k7|200711302254
823787|823787-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712010557
825915|825915-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200712012335
825953|825953-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712020017
826485|826485-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0_rc3|200712020732
828013|828013-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|sun4-solaris-thread-multi|5.10.0 patch 32468|solaris|2.9|200712021707
828319|828319-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0_rc3|200712030142
829840|829840-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux|5.10.0|linux|2.6.22-1-k7|200712031905
829850|829850-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200712031910
829873|829873-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200712031916
829878|829878-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200712031921
829881|829881-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200712031926
829889|829889-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200712031932
829908|829908-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200712031938
829926|829926-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Compare|0.17|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712031942
830133|830133-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712032137
830134|830134-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712032135
830173|830173-b19f-3f77-b713-d32bba55d77f|pass|200712|xdg@hyperbolic.net (DAGOLDEN)|CPAN-FindDependencies|1.99_01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712031555
830197|830197-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200712032138
831557|831557-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712040554
831803|831803-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712040900
831868|831868-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200712040923
831873|831873-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200712040927
831878|831878-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200712040930
831888|831888-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200712040934
831893|831893-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200712040938
831897|831897-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200712040942
831902|831902-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200712040946
831907|831907-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200712040949
831993|831993-b19f-3f77-b713-d32bba55d77f|pass|200712|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|1.99_01|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200712041045
832037|832037-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712041214
832173|832173-b19f-3f77-b713-d32bba55d77f|pass|200712|icerider70@gmail.com ("ICERIDER")|CPAN-FindDependencies|1.99_01|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712040644
832268|832268-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712041351
832504|832504-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712041628
832963|832963-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712040744
834171|834171-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712050347
834470|834470-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712050739
834935|834935-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712050000
835613|835613-b19f-3f77-b713-d32bba55d77f|pass|200712|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|1.99_01|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200712060104
835862|835862-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|1.99_01|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712051931
836161|836161-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712050931
836650|836650-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200712052301
836743|836743-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712051300
837303|837303-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200712061010
837491|837491-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-pc-solaris2.11|5.8.7|solaris|2.11|200712061102
838315|838315-b19f-3f77-b713-d32bba55d77f|pass|200712|dillman@ria.buffalo.edu|Devel-CheckOS|1.42|sun4-solaris|5.8.8|solaris|2.9|200712061058
838624|838624-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712062244
838827|838827-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712070122
839373|839373-b19f-3f77-b713-d32bba55d77f|pass|200712|notbenh@cpan.org|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712061109
839420|839420-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712070844
840134|840134-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.10.0 patch 32560|darwin|9.1.0|200712071523
840932|840932-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712072327
840955|840955-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712072337
840967|840967-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712072342
840982|840982-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712072348
841002|841002-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712080006
841011|841011-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712080012
841362|841362-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712080341
841879|841879-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712080232
841964|841964-b19f-3f77-b713-d32bba55d77f|pass|200712|g.grigelionis@computer.org|Devel-CheckOS|1.42|i586-linux-thread-multi|5.8.8|linux|2.6.16|200712080029
842674|842674-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Devel-CheckOS|1.42|alpha-netbsd|5.10.0 patch 31856|netbsd|2.1.0_stable|200712082045
842797|842797-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200712082257
843205|843205-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200712090321
843500|843500-b19f-3f77-b713-d32bba55d77f|pass|200712|cpan@pqpq.de|Data-Compare|0.17|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712090923
843671|843671-b19f-3f77-b713-d32bba55d77f|pass|200712|cpan@pqpq.de|CPAN-FindDependencies|1.99_01|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712091035
844619|844619-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200712091711
846267|846267-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712100820
846955|846955-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712101233
847107|847107-b19f-3f77-b713-d32bba55d77f|pass|200712|d@0x64.nl|Devel-CheckOS|1.42|x86_64-linux-gnu|5.8.8|linux|2.6.17-2-vserver-amd64|200712101305
847826|847826-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200712101833
848586|848586-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712110203
848851|848851-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712110636
849160|849160-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200712111048
849338|849338-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200712111202
850973|850973-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712112231
852048|852048-b19f-3f77-b713-d32bba55d77f|pass|200712|paranoid@sarpedon.site5.com ((Mike Bissett))|Data-Compare|0.17|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200712121210
852788|852788-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712121443
852849|852849-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200712120434
854890|854890-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712131119
855361|855361-b19f-3f77-b713-d32bba55d77f|pass|200712|rlane10@wi.rr.com|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.8.8|darwin|8.9.0|200712130738
857132|857132-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200712141556
857136|857136-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.22-1-k7|200712141557
857139|857139-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-1-k7|200712141558
857142|857142-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-64int|5.9.5|linux|2.6.22-1-k7|200712141559
857143|857143-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200712141600
857146|857146-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200712141601
857148|857148-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200712141602
857151|857151-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200712141604
857197|857197-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712141517
857215|857215-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712141525
857223|857223-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712141532
857243|857243-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712141540
857270|857270-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200712141547
857285|857285-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200712141555
857307|857307-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200712141603
857326|857326-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712141611
857348|857348-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|1.99_01|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712141620
857425|857425-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200712141822
857789|857789-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712142121
857887|857887-b19f-3f77-b713-d32bba55d77f|pass|200712|icerider70@gmail.com ("ICERIDER")|CPAN-FindDependencies|2.0|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200712141449
857999|857999-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712142200
858010|858010-b19f-3f77-b713-d32bba55d77f|fail|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200712142141
858011|858011-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200712142142
858012|858012-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200712142144
858013|858013-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200712142145
858014|858014-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200712142146
858016|858016-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200712142147
858018|858018-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200712142149
858020|858020-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200712142150
858175|858175-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd-thread-multi|5.10.0 patch 32367|freebsd|6.2-release|200712150009
859571|859571-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200712152036
860492|860492-b19f-3f77-b713-d32bba55d77f|pass|200712|overlordq@gmail.com|Net-Random|2.0|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712160142
860548|860548-b19f-3f77-b713-d32bba55d77f|pass|200712|overlordq@gmail.com|Data-Compare|0.17|i486-linux-gnu|5.8.8|linux|2.6.22.10|200712160211
861014|861014-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712161129
861340|861340-b19f-3f77-b713-d32bba55d77f|pass|200712|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200712170123
862554|862554-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Number-Phone|1.58|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862555|862555-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Class-CanBeA|1.2|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862556|862556-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Compare|0.17|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862557|862557-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Transactional|1.0|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862558|862558-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Net-Random|2.0|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170017
862559|862559-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170018
862561|862561-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170020
862562|862562-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Devel-CheckLib|0.3|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170020
862563|862563-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Games-Dice-Advanced|1.1|darwin-thread-multi-2level|5.10.0 patch 32604|darwin|9.1.0|200712170021
862763|862763-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi|5.6.2|darwin|8.10.0|200712170404
863091|863091-b19f-3f77-b713-d32bba55d77f|pass|200712|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|2.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200712170901
863578|863578-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200712170416
864697|864697-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712180430
865057|865057-b19f-3f77-b713-d32bba55d77f|pass|200712|cpan@pqpq.de|CPAN-FindDependencies|2.0|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712180921
865873|865873-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712181359
866599|866599-b19f-3f77-b713-d32bba55d77f|pass|200712|salvacpan@gmail.com|Data-Compare|0.17|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200712181435
866762|866762-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Devel-CheckLib|0.3|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181902
866770|866770-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Devel-CheckLib|0.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181803
866873|866873-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181751
866889|866889-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Games-Dice-Advanced|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181917
867078|867078-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Class-CanBeA|1.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712181849
867192|867192-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Number-Phone|1.58|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181931
867193|867193-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181931
867611|867611-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712181816
867648|867648-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182105
867785|867785-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Net-Random|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182123
868027|868027-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712182138
868129|868129-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|CPAN-FindDependencies|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182225
868221|868221-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Compare|0.17|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182234
868223|868223-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|Data-Transactional|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200712182235
868857|868857-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712190230
870729|870729-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200712191657
872660|872660-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200712200418
874234|874234-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0|linux|2.6.22-1-k7|200712202153
874402|874402-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0|linux|2.6.22-1-k7|200712202233
874775|874775-b19f-3f77-b713-d32bba55d77f|pass|200712|bricas@cpan.org ("Brian Cassidy")|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712201446
875337|875337-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux|5.11.0|linux|2.6.22-1-k7|200712210125
875730|875730-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200712210230
877394|877394-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0|linux|2.6.22-1-k7|200712210733
877531|877531-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.11.0|linux|2.6.22-1-k7|200712211038
878404|878404-b19f-3f77-b713-d32bba55d77f|pass|200712|bricas@cpan.org ("Brian Cassidy")|Devel-CheckLib|0.3|i486-linux-gnu|5.8.8|linux|2.6.15.7|200712210939
878801|878801-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200712211947
879522|879522-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712212314
879947|879947-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220025
880232|880232-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712220044
880595|880595-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220224
880734|880734-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220340
880776|880776-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200712220304
884030|884030-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Bryar|2.8_02|i686-linux|5.6.2|linux|2.4.27-3-686|200712222041
885997|885997-b19f-3f77-b713-d32bba55d77f|pass|200712|stro@cpan.org|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200712230141
888988|888988-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd|5.10.0|freebsd|6.2-release|200712241030
889201|889201-b19f-3f77-b713-d32bba55d77f|pass|200712|andy@hexten.net|XML-Tiny|1.11|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200712241127
890820|890820-b19f-3f77-b713-d32bba55d77f|pass|200712|cpan@pqpq.de|Devel-CheckOS|1.42|amd64-freebsd|5.10.0 patch 32559|freebsd|6.2-release|200712251539
891034|891034-b19f-3f77-b713-d32bba55d77f|pass|200712|rlane10@wi.rr.com|Devel-CheckOS|1.42|darwin-2level|5.10.0|darwin|8.11.0|200712250509
892422|892422-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200712260259
894567|894567-b19f-3f77-b713-d32bba55d77f|fail|200712|david@cantrell.org.uk|Bryar|2.8_02|darwin-thread-multi-2level|5.10.0 patch 32468|darwin|8.10.1|200712270027
894603|894603-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Data-Compare|0.17|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712270134
894628|894628-b19f-3f77-b713-d32bba55d77f|pass|200712|rlane10@wi.rr.com|XML-Tiny|1.11|darwin-2level|5.10.0|darwin|8.11.0|200712261305
894709|894709-b19f-3f77-b713-d32bba55d77f|pass|200712|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.42|i386-linux|5.8.8|linux|2.6.18-53.el5|200712270448
895423|895423-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271029
895613|895613-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271144
896014|896014-b19f-3f77-b713-d32bba55d77f|pass|200712|claco@chrislaco.com ("Christopher H. Laco")|Data-Compare|0.17|darwin-thread-multi-2level|5.8.6|darwin|8.0|200712270048
896291|896291-b19f-3f77-b713-d32bba55d77f|pass|200712|icerider70@gmail.com ("ICERIDER")|Data-Compare|0.17|i386-linux|5.8.8|linux|2.6.18-53.el5|200712270727
896293|896293-b19f-3f77-b713-d32bba55d77f|pass|200712|root@alysande.altrion.org ((System Administrator))|Devel-CheckOS|1.42|darwin-2level|5.10.0|darwin|8.11.1|200712271305
896347|896347-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271437
896767|896767-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271414
897406|897406-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200712271820
897407|897407-b19f-3f77-b713-d32bba55d77f|pass|200712|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|0.17|i686-linux-thread-multi-64int|5.11.0|linux|2.6.22-1-k7|200712271021
897430|897430-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200712271826
897445|897445-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712271817
897550|897550-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Net-Random|2.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200712271856
897601|897601-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Net-Random|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712271853
897769|897769-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Net-Random|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200712271354
897863|897863-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712271233
897915|897915-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Net-Random|2.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200712272028
897993|897993-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200712271258
898157|898157-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200712272144
898228|898228-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Net-Random|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200712272152
898271|898271-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|Data-Compare|0.17|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200712272143
899962|899962-b19f-3f77-b713-d32bba55d77f|pass|200712|david@cantrell.org.uk|XML-Tiny|1.11|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200712281636
900858|900858-b19f-3f77-b713-d32bba55d77f|pass|200712|imacat@mail.imacat.idv.tw|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200712290438
903334|903334-b19f-3f77-b713-d32bba55d77f|pass|200712|rlane10@wi.rr.com|Tie-STDOUT|1.03|darwin-2level|5.10.0|darwin|8.11.0|200712300053
904773|904773-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Statistics-ChiSquare|0.5|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712302026
904802|904802-b19f-3f77-b713-d32bba55d77f|pass|200712|srezic@cpan.org|Statistics-SerialCorrelation|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200712302034
905218|905218-b19f-3f77-b713-d32bba55d77f|pass|200712|rlane10@wi.rr.com|Devel-CheckOS|1.42|i686-linux|5.10.0|linux|2.6.23.1luckyseven|200712301444
906166|906166-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200712310730
906374|906374-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712310854
906487|906487-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200712311007
906696|906696-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200712311151
906698|906698-b19f-3f77-b713-d32bba55d77f|na|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.1|darwin|8.10.0|200712311154
906700|906700-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.2|darwin|8.10.0|200712311157
906701|906701-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.3|darwin|8.10.0|200712311159
906705|906705-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.4|darwin|8.10.0|200712311202
906707|906707-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.5|darwin|8.10.0|200712311204
906712|906712-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.6|darwin|8.10.0|200712311206
906715|906715-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.7|darwin|8.10.0|200712311208
906717|906717-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200712311210
907980|907980-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712310840
908298|908298-b19f-3f77-b713-d32bba55d77f|pass|200712|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200712310949
908891|908891-b19f-3f77-b713-d32bba55d77f|pass|200712|cpantester@zombie.org.uk|Data-Compare|0.17|x86_64-linux-ld|5.11.0 patch 32787|linux|2.6.22-3-amd64|200712311732
910528|910528-b19f-3f77-b713-d32bba55d77f|pass|200712|cpantester@zombie.org.uk|Data-Compare|0.17|x86_64-linux-ld|5.11.0 patch 32790|linux|2.6.22-3-amd64|200712312036
911392|911392-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200801011056
911683|911683-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@zombie.org.uk|Data-Compare|0.17|x86_64-linux-ld|5.11.0 patch 32790|linux|2.6.22-3-amd64|200801011209
912997|912997-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32792|linux|2.6.22-3-amd64|200801012023
914399|914399-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32792|linux|2.6.22-3-amd64|200801020106
914536|914536-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.18-5-686|200801021551
914904|914904-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200801021710
915075|915075-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200801021749
915506|915506-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Statistics-ChiSquare|0.5|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200801022013
915791|915791-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl|XML-Tiny|1.11|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801021048
916082|916082-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32805|linux|2.6.22-3-amd64|200801022238
917482|917482-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200801030803
918102|918102-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32800|linux|2.6.22-3-amd64|200801021356
918614|918614-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger@ruhr-uni-bochum.de|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200801031055
919916|919916-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Number-Phone|1.58|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200801040155
920490|920490-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl|Data-Compare|0.17|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801032352
921985|921985-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32809|linux|2.6.22-3-amd64|200801041016
923011|923011-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32824|linux|2.6.22-3-amd64|200801041358
923177|923177-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|i86pc-solaris|5.10.0|solaris|2.10|200801041601
923700|923700-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32832|linux|2.6.22-3-amd64|200801041845
923985|923985-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200801042006
924386|924386-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|0.17|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801042156
924870|924870-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|0.17|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801050035
926854|926854-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200801052014
927106|927106-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|0.17|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801051404
927629|927629-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.11.0 patch 32837|cygwin|1.5.24(0.15642)|200801060155
930316|930316-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.11.0 patch 32864|cygwin|1.5.24(0.15642)|200801070135
931226|931226-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801071157
931657|931657-b19f-3f77-b713-d32bba55d77f|pass|200801|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|0.17|sun4-solaris|5.10.0|solaris|2.8|200801070928
931974|931974-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200801071713
932623|932623-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200801072025
934822|934822-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|0.17|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801081334
938822|938822-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801091702
939607|939607-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|alpha-linux-thread-multi|5.11.0 patch 32908|linux|2.6.18-5-alpha-generic|200801092044
939664|939664-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Bryar|2.6|i686-linux|5.6.2|linux|2.4.27-3-686|200801092100
939750|939750-b19f-3f77-b713-d32bba55d77f|fail|200801|david@cantrell.org.uk|Bryar|3.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801092123
940465|940465-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|i86pc-solaris|5.8.8|solaris|2.10|200801100207
946793|946793-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|0.17|cygwin-thread-multi-64int|5.11.0 patch 32953|cygwin|1.5.24(0.15642)|200801120913
947178|947178-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|0.17|x86_64-linux-thread-multi-ld|5.11.0 patch 32966|linux|2.6.22-3-amd64|200801121142
953318|953318-b19f-3f77-b713-d32bba55d77f|fail|200801|rjbs@cpan.org|Bryar|3.0|darwin-2level|5.10.0|darwin|9.1.0|200801141030
955700|955700-b19f-3f77-b713-d32bba55d77f|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Data-Compare|0.17|i686-linux-64int-ld|5.8.8|linux|2.6.22-14-generic|200801150051
955762|955762-b19f-3f77-b713-d32bba55d77f|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Data-Compare|0.17|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-generic|200801150101
956019|956019-b19f-3f77-b713-d32bba55d77f|pass|200801|robertl@apnic.net ("Robert Loomans")|Data-Compare|0.17|darwin-thread-multi-2level|5.8.8|darwin|8.11.1|200801151755
958423|958423-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801152111
958437|958437-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|0.17|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801152114
958862|958862-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0|linux|2.6.22-1-k7|200801160016
958863|958863-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200801160016
958866|958866-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200801160016
958869|958869-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200801160017
958871|958871-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200801160017
958873|958873-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200801160018
958875|958875-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200801160019
959222|959222-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|i86pc-solaris|5.8.8|solaris|2.10|200801160124
959225|959225-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|i86pc-solaris|5.10.0|solaris|2.10|200801160125
959422|959422-b19f-3f77-b713-d32bba55d77f|pass|200801|icerider70@gmail.com ("ICERIDER")|Data-Compare|1.18|i386-linux|5.8.8|linux|2.6.18-53.el5|200801160210
960005|960005-b19f-3f77-b713-d32bba55d77f|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|CPAN-FindDependencies|1.99_01|i686-linux-64int-ld|5.8.8|linux|2.6.22-14-generic|200801160419
960006|960006-b19f-3f77-b713-d32bba55d77f|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.42|i686-linux-64int-ld|5.8.8|linux|2.6.22-14-generic|200801160419
960026|960026-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801160430
960030|960030-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi|5.6.2|darwin|8.10.0|200801160433
960035|960035-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-2level|5.8.8|darwin|8.10.0|200801160439
960318|960318-b19f-3f77-b713-d32bba55d77f|pass|200801|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200801161514
960472|960472-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+perl@rub.de|Data-Compare|1.18|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200801160920
960531|960531-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801160948
961467|961467-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801161415
961485|961485-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i686-linux|5.8.8|linux|2.4.27-3-686|200801161417
961502|961502-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801161347
961506|961506-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801160820
961509|961509-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801161420
961510|961510-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801161420
961520|961520-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Compare|1.18|i686-linux|5.6.2|linux|2.4.27-3-686|200801161421
961562|961562-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 32981|linux|2.6.18-5-alpha-generic|200801161431
961963|961963-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200801161638
962412|962412-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.11.0 patch 32982|linux|2.6.22-3-amd64|200801161929
962482|962482-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.10.0|freebsd|6.2-release|200801162046
963003|963003-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.6.2|freebsd|6.2-release|200801162135
963156|963156-b19f-3f77-b713-d32bba55d77f|pass|200801|g.grigelionis@computer.org|Data-Compare|1.18|i586-linux-thread-multi|5.8.8|linux|2.6.16|200801162212
963203|963203-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200801162221
963745|963745-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801162358
963770|963770-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Data-Compare|1.18|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801170006
964012|964012-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801170031
964037|964037-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200801170036
964040|964040-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200801170039
964071|964071-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200801170059
964084|964084-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200801170102
964087|964087-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200801170105
964091|964091-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200801170108
964106|964106-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200801170112
964125|964125-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200801170115
964127|964127-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200801170118
964635|964635-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801170756
964967|964967-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200801170952
965354|965354-b19f-3f77-b713-d32bba55d77f|pass|200801|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.18|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200801171203
966001|966001-b19f-3f77-b713-d32bba55d77f|pass|200801|imacat@mail.imacat.idv.tw|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200801180044
967324|967324-b19f-3f77-b713-d32bba55d77f|pass|200801|salve.nilsen@met.no ("Salve J Nilsen")|Data-Compare|1.18|i386-linux|5.8.8|linux|2.6.9-34.elsmp|200801171735
967365|967365-b19f-3f77-b713-d32bba55d77f|pass|200801|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.18|sun4-solaris|5.10.0|solaris|2.8|200801171332
968007|968007-b19f-3f77-b713-d32bba55d77f|pass|200801|overlordq@gmail.com|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.22.10|200801180317
968952|968952-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200801181450
969190|969190-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.22-3-486|200801181718
969205|969205-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200801181623
969783|969783-b19f-3f77-b713-d32bba55d77f|pass|200801|dillman@ria.buffalo.edu|Data-Compare|1.18|sun4-solaris|5.8.8|solaris|2.9|200801181347
970950|970950-b19f-3f77-b713-d32bba55d77f|pass|200801|mmusgrove@cpan.org ("Matthew Musgrove")|Devel-CheckOS|1.42|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-generic|200801190046
972266|972266-b19f-3f77-b713-d32bba55d77f|pass|200801|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801191057
972674|972674-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.42|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801191419
972689|972689-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.42|i686-linux|5.10.0|linux|2.6.22-3-486|200801191423
972692|972692-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.3|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801191423
972693|972693-b19f-3f77-b713-d32bba55d77f|pass|200801|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.3|i686-linux|5.10.0|linux|2.6.22-3-486|200801191425
974401|974401-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33004|cygwin|1.5.24(0.15642)|200801192233
974723|974723-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200801200019
974764|974764-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Class-CanBeA|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200048
974766|974766-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Hexdumper|1.0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200049
974769|974769-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Data-Hexdumper|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200050
974786|974786-b19f-3f77-b713-d32bba55d77f|fail|200801|david@cantrell.org.uk|Net-Random|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200104
974787|974787-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Number-Phone|1.58|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200105
974789|974789-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200106
974791|974791-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Statistics-ChiSquare|0.5|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200109
974793|974793-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200109
974795|974795-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Sub-WrapPackages|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200110
974797|974797-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Tie-Hash-Longest|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200111
974799|974799-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200111
974800|974800-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Tie-STDOUT|1.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200111
974803|974803-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200112
974806|974806-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Tie-Scalar-Decay|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200113
974809|974809-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200113
974811|974811-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|XML-Tiny|1.06|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801200114
975159|975159-b19f-3f77-b713-d32bba55d77f|pass|200801|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.18|i686-linux-64int-ld|5.10.0|linux|2.6.22-14-386|200801200355
975983|975983-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Data-Compare|1.18|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200801201242
976661|976661-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801201822
977539|977539-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801202155
977631|977631-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801202104
977717|977717-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|NestedMap|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202208
977792|977792-b19f-3f77-b713-d32bba55d77f|fail|200801|david@cantrell.org.uk|Bryar|3.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202224
977962|977962-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202248
978266|978266-b19f-3f77-b713-d32bba55d77f|unknown|200801|david@cantrell.org.uk|Acme-Licence|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801202350
978376|978376-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801210111
978612|978612-b19f-3f77-b713-d32bba55d77f|unknown|200801|david@cantrell.org.uk|Acme-Pony|1.1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210109
978852|978852-b19f-3f77-b713-d32bba55d77f|fail|200801|david@cantrell.org.uk|Data-Transactional|0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210149
978863|978863-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|File-Find-Rule-Permissions|1.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210151
978893|978893-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|File-Overwrite|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210158
978896|978896-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Games-Dice-Advanced|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210159
978966|978966-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210217
978970|978970-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801210219
979198|979198-b19f-3f77-b713-d32bba55d77f|pass|200801|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.8.8 patch 33008|linux|2.6.22-1-k7|200801210425
979494|979494-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200801210515
980641|980641-b19f-3f77-b713-d32bba55d77f|fail|200801|d@0x64.nl (DEVOGON)|Bryar|3.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200801211628
980947|980947-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33022|linux|2.6.18-5-alpha-generic|200801211712
982905|982905-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200801220618
983254|983254-b19f-3f77-b713-d32bba55d77f|pass|200801|fayland@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200801220922
983260|983260-b19f-3f77-b713-d32bba55d77f|pass|200801|rlane10@wi.rr.com|Data-Compare|1.18|darwin-2level-ld|5.10.0|darwin|8.11.0|200801220144
987518|987518-b19f-3f77-b713-d32bba55d77f|pass|200801|andy@hexten.net|Data-Compare|1.18|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200801231403
987884|987884-b19f-3f77-b713-d32bba55d77f|fail|200801|david@cantrell.org.uk|Bryar|2.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801231711
988738|988738-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801240003
989519|989519-b19f-3f77-b713-d32bba55d77f|pass|200801|callen@kpi-consulting.net|Devel-CheckOS|1.42|i386-linux|5.8.8|linux|2.6.9-42.0.3.elsmp|200801231502
989759|989759-b19f-3f77-b713-d32bba55d77f|pass|200801|stro@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200801240511
994236|994236-b19f-3f77-b713-d32bba55d77f|pass|200801|rjbs@cpan.org|Data-Compare|1.18|darwin-2level|5.10.0|darwin|9.1.0|200801261005
994237|994237-b19f-3f77-b713-d32bba55d77f|pass|200801|rjbs@cpan.org|Data-Compare|1.18|darwin-2level|5.10.0|darwin|9.1.0|200801261005
996329|996329-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|CPAN-FindDependencies|2.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801271620
998612|998612-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|i86pc-solaris|5.8.8|solaris|2.10|200801281301
998621|998621-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|i86pc-solaris|5.10.0|solaris|2.10|200801281302
999761|999761-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200801281923
1000713|1000713-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200801282355
1000716|1000716-b19f-3f77-b713-d32bba55d77f|pass|200801|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.42|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200801282358
1000819|1000819-b19f-3f77-b713-d32bba55d77f|pass|200801|g.grigelionis@computer.org|Devel-CheckOS|1.42|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200801282113
1000850|1000850-b19f-3f77-b713-d32bba55d77f|pass|200801|g.grigelionis@computer.org|Devel-CheckOS|1.42|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200801282117
1001686|1001686-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801290757
1001838|1001838-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200801291312
1001936|1001936-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200801291540
1002105|1002105-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200801291616
1002250|1002250-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33082|linux|2.6.18-5-alpha-generic|200801291819
1002345|1002345-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|Devel-CheckOS|1.42|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200801291841
1002699|1002699-b19f-3f77-b713-d32bba55d77f|pass|200801|cpantester@hotmail.co.uk|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.11.0 patch 33109|linux|2.6.22-3-amd64|200801292057
1002733|1002733-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200801292109
1006145|1006145-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.11.0 patch 33125|netbsd|4.0|200801310014
1006342|1006342-b19f-3f77-b713-d32bba55d77f|pass|200801|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200801310442
1008067|1008067-b19f-3f77-b713-d32bba55d77f|pass|200801|david@cantrell.org.uk|XML-Tiny|1.11|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200801311506
1008614|1008614-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200802010308
1008765|1008765-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200802010622
1009502|1009502-b19f-3f77-b713-d32bba55d77f|pass|200802|ferreira@cpan.org|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200802011257
1010498|1010498-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802020418
1010848|1010848-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.11.0 patch 33163|cygwin|1.5.24(0.15642)|200802021012
1010888|1010888-b19f-3f77-b713-d32bba55d77f|pass|200802|feldt@nhn.ou.edu|Data-Compare|1.18|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200802011342
1011511|1011511-b19f-3f77-b713-d32bba55d77f|pass|200802|andy@hexten.net|Devel-CheckOS|1.42|i486-linux-gnu|5.8.8|linux|2.6.15.7|200802021419
1012282|1012282-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8|linux|2.6.14|200802022222
1012807|1012807-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-CanBeA|1.2|i686-linux-64int|5.8.8|linux|2.6.14|200802030414
1013908|1013908-b19f-3f77-b713-d32bba55d77f|pass|200802|rjbs@cpan.org|Data-Compare|1.18|darwin-2level|5.10.0|darwin|9.1.0|200802031115
1014995|1014995-b19f-3f77-b713-d32bba55d77f|pass|200802|claco@chrislaco.com ("Christopher H. Laco")|Data-Compare|1.18|darwin-thread-multi-2level|5.8.6|darwin|8.0|200802031702
1016124|1016124-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.11.0 patch 33228|linux|2.6.16.38|200802041359
1017394|1017394-b19f-3f77-b713-d32bba55d77f|pass|200802|rlane10@wi.rr.com|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.23.1luckyseven|200802041337
1017716|1017716-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802050423
1021750|1021750-b19f-3f77-b713-d32bba55d77f|fail|200802|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckLib|0.3|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200802062240
1027183|1027183-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200802091719
1030279|1030279-b19f-3f77-b713-d32bba55d77f|pass|200802|autarch@urth.org|Devel-CheckOS|1.42|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200802101104
1031268|1031268-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200802110552
1031357|1031357-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200802110628
1033621|1033621-b19f-3f77-b713-d32bba55d77f|pass|200802|autarch@urth.org|Data-Compare|1.18|x86_64-linux-gnu|5.8.8|linux|2.6.15.7|200802111240
1036645|1036645-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802131211
1036650|1036650-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802131213
1036653|1036653-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802131215
1036660|1036660-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802131217
1036665|1036665-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802131220
1036669|1036669-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.58|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802131223
1038238|1038238-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Number-Phone|1.58|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802140759
1038319|1038319-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Number-Phone|1.58|i686-linux|5.10.0|linux|2.6.22-3-486|200802140931
1038655|1038655-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.58|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802141118
1038698|1038698-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.58|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802141225
1038987|1038987-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.58|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802141532
1040103|1040103-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802150401
1040104|1040104-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802150401
1040105|1040105-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802150401
1040106|1040106-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802150402
1040107|1040107-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802150402
1040108|1040108-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.0|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802150402
1040520|1040520-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.58|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802151127
1040656|1040656-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802151141
1040805|1040805-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802151235
1040850|1040850-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200802151310
1040931|1040931-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.42|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802151346
1041070|1041070-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|Number-Phone|1.58|x86_64-linux-thread-multi-ld|5.11.0 patch 33317|linux|2.6.22-3-amd64|200802151430
1041385|1041385-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|CPU-Emulator-Memory|1.0|x86_64-linux-thread-multi-ld|5.11.0 patch 33317|linux|2.6.22-3-amd64|200802151500
1041451|1041451-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200802151656
1041529|1041529-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802151718
1041778|1041778-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33314|netbsd|4.0|200802151914
1041836|1041836-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802151957
1041864|1041864-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802152026
1041899|1041899-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802152026
1041986|1041986-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802152119
1042830|1042830-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200802161045
1043635|1043635-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200802161908
1043680|1043680-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802162012
1043681|1043681-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802162012
1043682|1043682-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802162012
1043683|1043683-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802162012
1043684|1043684-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802162013
1043685|1043685-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802162013
1043686|1043686-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802162013
1043687|1043687-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802162014
1043688|1043688-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802162014
1043689|1043689-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802162014
1043725|1043725-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802170429
1044143|1044143-b19f-3f77-b713-d32bba55d77f|pass|200802|g.grigelionis@computer.org|Devel-CheckOS|1.42|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200802162101
1044165|1044165-b19f-3f77-b713-d32bba55d77f|pass|200802|g.grigelionis@computer.org|Data-Compare|1.18|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200802162129
1044281|1044281-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200802170216
1044955|1044955-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200802171216
1045272|1045272-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|cygwin-thread-multi-64int|5.11.0 patch 33318|cygwin|1.5.24(0.15642)|200802171534
1045402|1045402-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200802171038
1045403|1045403-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802171639
1045878|1045878-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200802171913
1045909|1045909-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.11.0 patch 33325|linux|2.6.22-3-amd64|200802171932
1046019|1046019-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.11.0 patch 33325|linux|2.6.22-3-amd64|200802171959
1046334|1046334-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802172212
1046421|1046421-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802172247
1046511|1046511-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200802180017
1046517|1046517-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802180019
1046529|1046529-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802180021
1046827|1046827-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.11.0 patch 33318|cygwin|1.5.24(0.15642)|200802180336
1047355|1047355-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.0|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200802180921
1047665|1047665-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.11.0 patch 33325|linux|2.6.18-5-alpha-generic|200802181229
1047818|1047818-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200802181324
1048072|1048072-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|alpha-linux-thread-multi|5.11.0 patch 33325|linux|2.6.18-5-alpha-generic|200802181442
1048201|1048201-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200802181524
1049215|1049215-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802182238
1049645|1049645-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802190111
1049667|1049667-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802190131
1050454|1050454-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200802191305
1050470|1050470-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200802191323
1050471|1050471-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802191323
1050472|1050472-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200802191324
1050914|1050914-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33325|linux|2.6.18-5-alpha-generic|200802191607
1051021|1051021-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int|5.11.0 patch 33334|linux|2.6.16.38|200802191639
1051219|1051219-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int|5.11.0 patch 33334|linux|2.6.16.38|200802191819
1051837|1051837-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0 patch 33334|linux|2.6.16.38|200802192329
1052526|1052526-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802201039
1053541|1053541-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.58|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200802201212
1053595|1053595-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200802201220
1053936|1053936-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200802201357
1054546|1054546-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.0|i686-linux|5.10.0|linux|2.6.22-3-486|200802201934
1057443|1057443-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200802211259
1059347|1059347-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl ("DEVOGON")|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802220038
1060654|1060654-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Class-CanBeA|1.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802211610
1061638|1061638-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Data-Hexdumper|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802220802
1061838|1061838-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802221641
1061925|1061925-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Devel-AssertLib|0.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802221016
1061941|1061941-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Devel-CheckLib|0.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802221018
1062177|1062177-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl ("DEVOGON")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802221926
1062313|1062313-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802221916
1062433|1062433-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802222043
1062487|1062487-b19f-3f77-b713-d32bba55d77f|unknown|200802|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230357
1062489|1062489-b19f-3f77-b713-d32bba55d77f|unknown|200802|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230358
1062491|1062491-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230358
1062503|1062503-b19f-3f77-b713-d32bba55d77f|fail|200802|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230401
1062507|1062507-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230402
1062510|1062510-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230403
1062512|1062512-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230403
1062516|1062516-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Data-Compare|1.18|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230404
1062517|1062517-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230404
1062521|1062521-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Data-Transactional|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230405
1062523|1062523-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230405
1062526|1062526-b19f-3f77-b713-d32bba55d77f|fail|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230406
1062529|1062529-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230407
1062532|1062532-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230407
1062534|1062534-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230408
1062537|1062537-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230409
1062544|1062544-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230412
1062554|1062554-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230413
1062556|1062556-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230414
1062561|1062561-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230414
1062567|1062567-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230415
1062571|1062571-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230415
1062573|1062573-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230416
1062576|1062576-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230416
1062581|1062581-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230417
1062582|1062582-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230417
1062583|1062583-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|XML-Tiny|1.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802230418
1062858|1062858-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802222106
1062932|1062932-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802222236
1062969|1062969-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802222147
1063197|1063197-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802222304
1063404|1063404-b19f-3f77-b713-d32bba55d77f|pass|200802|cpantester@hotmail.co.uk|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.11.0 patch 33346|linux|2.6.22-3-amd64|200802221902
1063577|1063577-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Games-Dice-Advanced|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802230059
1064682|1064682-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200802230840
1064703|1064703-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802230944
1066771|1066771-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Tie-Hash-Longest|1.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232046
1066779|1066779-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Tie-Hash-Rank|1.0.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232046
1067204|1067204-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232147
1067751|1067751-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.10.0|freebsd|6.2-release|200802232144
1069310|1069310-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Hexdumper|1.3|amd64-freebsd|5.10.0|freebsd|6.2-release|200802241047
1070548|1070548-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802242001
1070873|1070873-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802242125
1071241|1071241-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802242226
1071744|1071744-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802250102
1071782|1071782-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Data-Hexdumper|1.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802250116
1071902|1071902-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200802250138
1072310|1072310-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200802250340
1073849|1073849-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200802251738
1074148|1074148-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200802251900
1074970|1074970-b19f-3f77-b713-d32bba55d77f|fail|200802|srezic@cpan.org|CPU-Emulator-Memory|1.0|amd64-freebsd|5.5.5|freebsd|6.2-release|200802252312
1075214|1075214-b19f-3f77-b713-d32bba55d77f|fail|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.5.5|freebsd|6.2-release|200802252348
1075256|1075256-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802260012
1076381|1076381-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|alpha-linux-thread-multi|5.11.0 patch 33365|linux|2.6.18-5-alpha-generic|200802260931
1076900|1076900-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802260921
1077232|1077232-b19f-3f77-b713-d32bba55d77f|pass|200802|andy@hexten.net|Data-Hexdumper|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200802261643
1077815|1077815-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33365|linux|2.6.18-5-alpha-generic|200802261908
1078107|1078107-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.10.0|freebsd|6.2-release|200802262125
1078409|1078409-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802262304
1078638|1078638-b19f-3f77-b713-d32bba55d77f|pass|200802|andy@hexten.net|Data-Hexdumper|1.3|i386-netbsd|5.8.8|netbsd|3.1|200802262241
1078761|1078761-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.58|amd64-freebsd|5.6.2|freebsd|6.2-release|200802262356
1079212|1079212-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|NestedMap|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802270116
1079566|1079566-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802271221
1079567|1079567-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802271222
1079627|1079627-b19f-3f77-b713-d32bba55d77f|fail|200802|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.42|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802271247
1081377|1081377-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Number-Phone|1.58|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802271210
1082191|1082191-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802272252
1082196|1082196-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802272253
1082201|1082201-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802272254
1082205|1082205-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802272254
1082208|1082208-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802272256
1082209|1082209-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802272256
1082741|1082741-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200802280301
1082847|1082847-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Statistics-ChiSquare|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802280359
1083055|1083055-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Statistics-SerialCorrelation|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802280146
1083328|1083328-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|Number-Phone|1.581|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802280857
1083450|1083450-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.6.2|freebsd|6.2-release|200802281005
1083451|1083451-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802281005
1083456|1083456-b19f-3f77-b713-d32bba55d77f|na|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.5.5|freebsd|6.2-release|200802280849
1083536|1083536-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802281005
1083539|1083539-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd|5.10.0|freebsd|6.2-release|200802281005
1083913|1083913-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i686-linux|5.8.8|linux|2.4.27-3-686|200802281253
1083955|1083955-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.581|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200802281338
1083992|1083992-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i686-linux|5.6.2|linux|2.4.27-3-686|200802281357
1084043|1084043-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802281426
1084397|1084397-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802281624
1084412|1084412-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802281612
1084423|1084423-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|Number-Phone|1.581|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200802281043
1084809|1084809-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl|Number-Phone|1.581|i686-linux|5.10.0|linux|2.6.22-3-486|200802282044
1085311|1085311-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802282220
1085315|1085315-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802282220
1085318|1085318-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802282221
1085326|1085326-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802282222
1085331|1085331-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802282222
1085334|1085334-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802282223
1085752|1085752-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802290020
1085753|1085753-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802290020
1085754|1085754-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802290021
1085755|1085755-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802290021
1085756|1085756-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802290022
1085758|1085758-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.001|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802290022
1085783|1085783-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200802290024
1085784|1085784-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200802290024
1085785|1085785-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200802290025
1085786|1085786-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200802290025
1085810|1085810-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200802290024
1085811|1085811-b19f-3f77-b713-d32bba55d77f|pass|200802|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8 patch 32025|linux|2.6.22-1-k7|200802290024
1085818|1085818-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Tie-Hash-Longest|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290133
1085828|1085828-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Tie-Hash-Rank|1.0.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290135
1085940|1085940-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|Tie-Scalar-Decay|1.1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290003
1086158|1086158-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.581|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200802290102
1086808|1086808-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802291357
1086809|1086809-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Number-Phone|1.581|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200802291358
1086909|1086909-b19f-3f77-b713-d32bba55d77f|pass|200802|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.1001|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200802290725
1086987|1086987-b19f-3f77-b713-d32bba55d77f|pass|200802|stro@cpan.org|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200802290139
1087243|1087243-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802290837
1087254|1087254-b19f-3f77-b713-d32bba55d77f|na|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.5.5|freebsd|6.2-release|200802290841
1087257|1087257-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200802290841
1087392|1087392-b19f-3f77-b713-d32bba55d77f|pass|200802|imacat@mail.imacat.idv.tw|Number-Phone|1.581|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200802291728
1087462|1087462-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd|5.10.0|freebsd|6.2-release|200802290958
1087479|1087479-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.10.0|freebsd|6.2-release|200802291017
1087738|1087738-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802291223
1087808|1087808-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802291206
1087820|1087820-b19f-3f77-b713-d32bba55d77f|pass|200802|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.581|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200802291209
1088420|1088420-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i686-linux|5.8.8|linux|2.4.27-3-686|200802291542
1088421|1088421-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i686-linux|5.8.8|linux|2.4.27-3-686|200802291542
1088423|1088423-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.4.27-3-686|200802291542
1088438|1088438-b19f-3f77-b713-d32bba55d77f|fail|200802|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.10.0|freebsd|6.2-release|200802291520
1088488|1088488-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802291646
1088490|1088490-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802291647
1088491|1088491-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200802291647
1088496|1088496-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291626
1088497|1088497-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802291651
1088498|1088498-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291628
1088499|1088499-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802291652
1088501|1088501-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200802291652
1088502|1088502-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|i686-linux|5.6.2|linux|2.4.27-3-686|200802291653
1088503|1088503-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|i686-linux|5.6.2|linux|2.4.27-3-686|200802291653
1088504|1088504-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291629
1088505|1088505-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|i686-linux|5.6.2|linux|2.4.27-3-686|200802291654
1088757|1088757-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802291930
1089198|1089198-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802292052
1089200|1089200-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802292052
1089202|1089202-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802292053
1089203|1089203-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802292053
1089205|1089205-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802292054
1089207|1089207-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802292054
1089209|1089209-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802292054
1089210|1089210-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802292055
1089212|1089212-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802292055
1089213|1089213-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802292056
1089296|1089296-b19f-3f77-b713-d32bba55d77f|pass|200802|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200802292222
1089383|1089383-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292310
1089384|1089384-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292311
1089386|1089386-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292311
1089387|1089387-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|Number-Phone|1.581|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200802292312
1089556|1089556-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802292338
1089559|1089559-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802292339
1089561|1089561-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802292339
1089562|1089562-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802292339
1089563|1089563-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802292340
1089565|1089565-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802292340
1089566|1089566-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802292340
1089568|1089568-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802292341
1089569|1089569-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802292341
1089571|1089571-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802292342
1089572|1089572-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200802292342
1089573|1089573-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200802292342
1089574|1089574-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200802292343
1089576|1089576-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200802292343
1089578|1089578-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200802292344
1089580|1089580-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200802292344
1089581|1089581-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200802292344
1089583|1089583-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200802292345
1089586|1089586-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200802292345
1089588|1089588-b19f-3f77-b713-d32bba55d77f|pass|200802|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200802292345
1089617|1089617-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802292355
1089621|1089621-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802292356
1089625|1089625-b19f-3f77-b713-d32bba55d77f|pass|200802|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200802292356
1089803|1089803-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|Number-Phone|1.581|i386-linux|5.8.8|linux|2.6.18-53.el5|200803010151
1089978|1089978-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803010318
1089979|1089979-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803010319
1089983|1089983-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803010319
1091103|1091103-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.6.2|freebsd|6.2-release|200803011302
1091197|1091197-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.22-3-486|200803011427
1091212|1091212-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Number-Phone|1.581|i686-linux|5.10.0|linux|2.6.22-3-486|200803011443
1091352|1091352-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Memory|1.0|i386-linux|5.8.8|linux|2.6.18-53.el5|200803010851
1091742|1091742-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803011746
1091891|1091891-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-cygwin-thread-multi-64int|5.11.0 patch 33400|cygwin|1.5.24(0.15642)|200803011756
1092328|1092328-b19f-3f77-b713-d32bba55d77f|fail|200803|andy@hexten.net|Devel-CheckOS|1.42|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803012024
1092354|1092354-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803020435
1092383|1092383-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.001|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803020446
1092386|1092386-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803020446
1092659|1092659-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803012108
1092959|1092959-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.3|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020039
1093139|1093139-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.10.0|freebsd|6.2-release|200803020102
1094820|1094820-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803021432
1094966|1094966-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021600
1094968|1094968-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021600
1094970|1094970-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021601
1094978|1094978-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803021604
1095292|1095292-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803021652
1095759|1095759-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803021909
1095788|1095788-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021917
1095789|1095789-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021917
1095791|1095791-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021918
1095803|1095803-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021918
1095808|1095808-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021919
1095809|1095809-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021919
1095811|1095811-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021920
1095813|1095813-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021920
1095815|1095815-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021921
1095821|1095821-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803021922
1095822|1095822-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803021922
1095823|1095823-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803021923
1096373|1096373-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Hexdumper|1.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200803022143
1096416|1096416-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803022230
1096935|1096935-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Memory|1.001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803021712
1096946|1096946-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Memory|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803021713
1096963|1096963-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803021714
1096964|1096964-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Memory|1.1001|i386-linux|5.8.8|linux|2.6.18-53.el5|200803021714
1097054|1097054-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.10.0|freebsd|6.2-release|200803030000
1097084|1097084-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33408|openbsd|4.2|200803030214
1098112|1098112-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Number-Phone|1.581|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803031135
1098687|1098687-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|CPU-Emulator-Memory|1.1001|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803031242
1099024|1099024-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031447
1099026|1099026-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031448
1099029|1099029-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031448
1099031|1099031-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803031450
1099628|1099628-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803032027
1099664|1099664-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040107
1099666|1099666-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040108
1099669|1099669-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040108
1099674|1099674-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803040111
1100247|1100247-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Transactional|1.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200803032215
1100248|1100248-b19f-3f77-b713-d32bba55d77f|na|200803|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.6.2|freebsd|6.2-release|200803032215
1100533|1100533-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Compare|0.17|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040008
1100537|1100537-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040009
1100802|1100802-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803032326
1100928|1100928-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040020
1101250|1101250-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040142
1101756|1101756-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040434
1101874|1101874-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200803041208
1102093|1102093-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803040643
1103433|1103433-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803040929
1103711|1103711-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041016
1104229|1104229-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger@ruhr-uni-bochum.de|Devel-CheckOS|1.42|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803041047
1104296|1104296-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041207
1104629|1104629-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.3|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041241
1104915|1104915-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803041323
1105211|1105211-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Devel-CheckOS|1.42|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803041613
1105438|1105438-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8|linux|2.6.14|200803041602
1105779|1105779-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041713
1105891|1105891-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803041708
1105955|1105955-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Number-Phone|1.581|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803041654
1107340|1107340-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042222
1107362|1107362-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042255
1107366|1107366-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803042256
1107381|1107381-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803042257
1107382|1107382-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.8.8|linux|2.6.14|200803042257
1107384|1107384-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803042259
1107386|1107386-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803042259
1107387|1107387-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803042300
1107408|1107408-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803042257
1107423|1107423-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042251
1107614|1107614-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803042331
1108058|1108058-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042331
1108061|1108061-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042332
1108065|1108065-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042333
1108080|1108080-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200803042335
1109224|1109224-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803050548
1109254|1109254-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803050457
1109259|1109259-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803050458
1109263|1109263-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803050459
1109269|1109269-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803050500
1109275|1109275-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803050501
1109279|1109279-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803050501
1109282|1109282-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803050502
1109284|1109284-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803050503
1109288|1109288-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803050504
1109292|1109292-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803050504
1109373|1109373-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux|5.11.0 patch 33423|linux|2.6.22-1-k7|200803050617
1109863|1109863-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.6.2|freebsd|6.2-release|200803050722
1109864|1109864-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.10.0|freebsd|6.2-release|200803050722
1109984|1109984-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.5.5|freebsd|6.2-release|200803050836
1110587|1110587-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.4|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803051857
1110726|1110726-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803051124
1110843|1110843-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33411|linux|2.6.18-5-alpha-generic|200803051203
1111089|1111089-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051404
1111091|1111091-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051405
1111095|1111095-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051407
1111102|1111102-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051408
1111109|1111109-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Number-Phone|1.581|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051410
1111240|1111240-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200803051449
1111292|1111292-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.4|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803051454
1111491|1111491-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Number-Phone|1.581|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200803051556
1111498|1111498-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803051558
1111809|1111809-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803051707
1111850|1111850-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i686-linux|5.6.2|linux|2.4.27-3-686|200803051716
1111851|1111851-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i686-linux|5.8.8|linux|2.4.27-3-686|200803051717
1112005|1112005-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803051747
1112021|1112021-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.10.0|freebsd|6.2-release|200803051839
1112103|1112103-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803051758
1112105|1112105-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.4|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803051759
1112985|1112985-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803052123
1113234|1113234-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Number-Phone|1.581|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803052211
1113289|1113289-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.4|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803052224
1113959|1113959-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.8.8 patch 33436|linux|2.6.22-1-k7|200803060059
1114475|1114475-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.8.8 patch 33436|linux|2.6.22-1-k7|200803060313
1115303|1115303-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Net-Random|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803060814
1115390|1115390-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803060747
1115424|1115424-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803060744
1117012|1117012-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061219
1117025|1117025-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Number-Phone|1.581|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803061327
1117073|1117073-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.001|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061137
1117075|1117075-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061137
1117077|1117077-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061138
1117079|1117079-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061138
1117086|1117086-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803061340
1117231|1117231-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803061205
1117687|1117687-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803061318
1117693|1117693-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803061319
1117694|1117694-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803061320
1118024|1118024-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200803061412
1118753|1118753-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckLib|0.4|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803061721
1118838|1118838-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061739
1119041|1119041-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|CPAN-FindDependencies|2.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803061805
1119501|1119501-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.4|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803070159
1119566|1119566-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803062004
1119718|1119718-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803061924
1119800|1119800-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200803061839
1119955|1119955-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Data-Compare|1.18|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200803061932
1120096|1120096-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i386-netbsd-thread-multi-64int|5.11.0 patch 33445|netbsd|4.0|200803062000
1120629|1120629-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd|5.6.2|freebsd|6.2-release|200803062319
1120958|1120958-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070001
1121130|1121130-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803062341
1121862|1121862-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070301
1122380|1122380-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070500
1122639|1122639-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070021
1122686|1122686-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33450|linux|2.6.22-1-k7|200803070547
1123451|1123451-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200803070919
1123847|1123847-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071224
1123868|1123868-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071229
1124313|1124313-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071514
1124659|1124659-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071714
1124710|1124710-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.8.8 patch 33449|linux|2.6.22-1-k7|200803071711
1125157|1125157-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Devel-CheckLib|0.4|i686-linux|5.10.0|linux|2.6.22-3-486|200803071854
1125298|1125298-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.22-3-486|200803071916
1126853|1126853-b19f-3f77-b713-d32bba55d77f|fail|200803|d@0x64.nl ("DEVOGON")|Bryar|3.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803072259
1126885|1126885-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803071606
1126910|1126910-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.42|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803072306
1126958|1126958-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.4|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803072218
1127166|1127166-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803080007
1127202|1127202-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i686-cygwin-thread-multi-64int|5.11.0 patch 33450|cygwin|1.5.24(0.15642)|200803072324
1127604|1127604-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.22-3-486|200803080142
1127792|1127792-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-cygwin-thread-multi-64int|5.11.0 patch 33450|cygwin|1.5.24(0.15642)|200803080054
1128559|1128559-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200803080351
1128897|1128897-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080630
1129275|1129275-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.4|i686-linux|5.10.0|linux|2.6.22-3-486|200803080819
1129286|1129286-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|darwin-2level|5.8.8|darwin|8.10.1|200803080814
1129634|1129634-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080853
1129685|1129685-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080905
1130112|1130112-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803080921
1131122|1131122-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-cygwin-thread-multi-64int|5.11.0 patch 33450|cygwin|1.5.24(0.15642)|200803081156
1131719|1131719-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33451|linux|2.6.22-1-k7|200803081236
1132402|1132402-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081702
1132651|1132651-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081738
1132947|1132947-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081626
1133084|1133084-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|darwin-2level|5.8.8|darwin|8.10.1|200803081604
1133252|1133252-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803081858
1133258|1133258-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200803081629
1133307|1133307-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.42|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803081632
1134224|1134224-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33452|linux|2.6.22-1-k7|200803082210
1134295|1134295-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.22-3-486|200803082233
1134317|1134317-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Sub-WrapPackages|1.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803082331
1135446|1135446-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200803090046
1135548|1135548-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200803090105
1136200|1136200-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803090407
1137541|1137541-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|XML-Tiny|1.11|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803091228
1137905|1137905-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803090836
1137986|1137986-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803091335
1138137|1138137-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.4|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803091353
1138692|1138692-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803091548
1139225|1139225-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803091727
1139601|1139601-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803091824
1139874|1139874-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803091845
1140020|1140020-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803091835
1140224|1140224-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803091919
1140377|1140377-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803091942
1140430|1140430-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803092053
1140490|1140490-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.6.2|freebsd|6.2-release|200803092059
1140822|1140822-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803092158
1141239|1141239-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803092254
1141354|1141354-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33454|linux|2.6.22-1-k7|200803100000
1141393|1141393-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803100018
1141448|1141448-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803092324
1142886|1142886-b19f-3f77-b713-d32bba55d77f|pass|200803|daxim@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200803092241
1143297|1143297-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Devel-CheckLib|0.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803101156
1143388|1143388-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803101336
1144603|1144603-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|alpha-linux-thread-multi|5.11.0 patch 33456|linux|2.6.18-5-alpha-generic|200803101704
1144632|1144632-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803101810
1144753|1144753-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33456|linux|2.6.18-5-alpha-generic|200803101728
1145110|1145110-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803101835
1146007|1146007-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102130
1146153|1146153-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102210
1146201|1146201-b19f-3f77-b713-d32bba55d77f|pass|200803|schwern@pobox.com|Devel-CheckLib|0.4|darwin-thread-multi-2level|5.8.8|darwin|8.8.1|200803101116
1146230|1146230-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33457|linux|2.6.22-1-k7|200803102214
1147736|1147736-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.11.0 patch 33467|linux|2.6.16.38|200803110257
1147779|1147779-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33467|linux|2.6.16.38|200803110307
1147933|1147933-b19f-3f77-b713-d32bba55d77f|fail|200803|imacat@mail.imacat.idv.tw|Palm-SMS|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803111159
1148083|1148083-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|darwin-2level|5.8.8|darwin|8.10.1|200803110610
1148832|1148832-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111132
1148834|1148834-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111133
1148837|1148837-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111133
1148839|1148839-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803111133
1148988|1148988-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111231
1148993|1148993-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111232
1148994|1148994-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111233
1148995|1148995-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803111234
1149737|1149737-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0 patch 33467|linux|2.6.16.38|200803111346
1150508|1150508-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|File-Find-Rule-Permissions|1.3|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803111731
1151369|1151369-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.42|alpha-linux-thread-multi|5.11.0 patch 33456|linux|2.6.18-5-alpha-generic|200803111923
1151818|1151818-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112101
1152039|1152039-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112202
1152397|1152397-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803112317
1152971|1152971-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803120059
1153370|1153370-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803120240
1153517|1153517-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33470|linux|2.6.22-1-k7|200803120254
1153896|1153896-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200803120341
1154487|1154487-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803120848
1155279|1155279-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121135
1155343|1155343-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121113
1155416|1155416-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121030
1155581|1155581-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121207
1156349|1156349-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.11.0 patch 33485|linux|2.6.22-1-k7|200803121248
1157352|1157352-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122103
1157355|1157355-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122104
1157358|1157358-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803122104
1157363|1157363-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122105
1157366|1157366-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122105
1157369|1157369-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122106
1157374|1157374-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8|linux|2.6.14|200803122107
1157385|1157385-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803122107
1157390|1157390-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803122107
1157394|1157394-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803122108
1157434|1157434-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122119
1157436|1157436-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122120
1157438|1157438-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803122120
1157439|1157439-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122121
1157441|1157441-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122121
1157443|1157443-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122122
1157447|1157447-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8|linux|2.6.14|200803122122
1157449|1157449-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803122123
1157450|1157450-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803122124
1157454|1157454-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803122125
1157638|1157638-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|darwin-2level|5.8.8|darwin|8.10.1|200803122209
1157643|1157643-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|darwin-2level|5.8.8|darwin|8.10.1|200803122205
1158128|1158128-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803122231
1158271|1158271-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122351
1158283|1158283-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122353
1158286|1158286-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200803122354
1158289|1158289-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200803122355
1158291|1158291-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122355
1158292|1158292-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200803122356
1158310|1158310-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122359
1158312|1158312-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8|linux|2.6.14|200803130000
1158313|1158313-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.8.8|linux|2.6.14|200803130001
1158316|1158316-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803130003
1158400|1158400-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803130004
1158411|1158411-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122357
1158412|1158412-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803122359
1158422|1158422-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|i586-linux-thread-multi|5.8.8|linux|2.6.16|200803122325
1158434|1158434-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200803130003
1158441|1158441-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200803130011
1158519|1158519-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803122357
1158521|1158521-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200803122352
1158548|1158548-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.42|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803122351
1158832|1158832-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130127
1159673|1159673-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.4|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130437
1160079|1160079-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130539
1160098|1160098-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130545
1160108|1160108-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.8.8 patch 33497|linux|2.6.22-1-k7|200803130546
1160637|1160637-b19f-3f77-b713-d32bba55d77f|pass|200803|hohokus@gmail.com|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803121942
1160646|1160646-b19f-3f77-b713-d32bba55d77f|pass|200803|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200803130956
1160656|1160656-b19f-3f77-b713-d32bba55d77f|pass|200803|artur+cpan@niif.spb.su|Devel-CheckOS|1.43|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200803130833
1160961|1160961-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803130957
1160963|1160963-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803130957
1160965|1160965-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|CPU-Emulator-Z80|0.9|i686-linux|5.10.0|linux|2.6.22-3-486|200803131104
1160988|1160988-b19f-3f77-b713-d32bba55d77f|pass|200803|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200803130949
1160990|1160990-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803131109
1160994|1160994-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.22-3-486|200803131111
1161055|1161055-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200803131026
1161078|1161078-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|i686-linux|5.8.8|linux|2.4.27-3-686|200803131035
1161086|1161086-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i686-linux|5.8.8|linux|2.4.27-3-686|200803131036
1161091|1161091-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803131041
1161093|1161093-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803131039
1161099|1161099-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803131044
1161521|1161521-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803131308
1161673|1161673-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803131453
1161703|1161703-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803131500
1161788|1161788-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803131414
1161794|1161794-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.4.27-3-686|200803131415
1161800|1161800-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803131418
1161845|1161845-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200803131424
1161859|1161859-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|i686-linux|5.6.2|linux|2.4.27-3-686|200803131427
1161889|1161889-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|i686-linux|5.6.2|linux|2.4.27-3-686|200803131432
1161990|1161990-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.22-3-486|200803131558
1162040|1162040-b19f-3f77-b713-d32bba55d77f|fail|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803131611
1162060|1162060-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803131508
1162067|1162067-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803131616
1162156|1162156-b19f-3f77-b713-d32bba55d77f|pass|200803|justinr@pollackassociates.com|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803130840
1162359|1162359-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131154
1162362|1162362-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131155
1162405|1162405-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131204
1162419|1162419-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803131205
1162522|1162522-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803131630
1162536|1162536-b19f-3f77-b713-d32bba55d77f|pass|200803|rlane10@wi.rr.com|Devel-CheckOS|1.43|darwin-2level-ld|5.10.0|darwin|8.11.0|200803130855
1163299|1163299-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803131849
1163308|1163308-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803131851
1163319|1163319-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803131852
1163412|1163412-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132004
1163421|1163421-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132011
1163434|1163434-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Number-Phone|1.581|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803131922
1163766|1163766-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.10.0|freebsd|6.2-release|200803132120
1163769|1163769-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.10.0|freebsd|6.2-release|200803132120
1163771|1163771-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803132121
1163772|1163772-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803132121
1163818|1163818-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132126
1164045|1164045-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33501|linux|2.6.22-1-k7|200803132031
1164132|1164132-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd|5.8.8|freebsd|6.2-prerelease|200803132151
1164362|1164362-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803132246
1164411|1164411-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132303
1164413|1164413-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132302
1164476|1164476-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803132247
1164479|1164479-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803132250
1164492|1164492-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132301
1164500|1164500-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803132301
1164748|1164748-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803140009
1164865|1164865-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803131853
1164866|1164866-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckLib|0.5|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803131854
1164886|1164886-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803140006
1164887|1164887-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803140007
1164888|1164888-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803140008
1164889|1164889-b19f-3f77-b713-d32bba55d77f|pass|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200803140009
1164896|1164896-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803140013
1164899|1164899-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200803140014
1164902|1164902-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803140015
1164995|1164995-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200803140114
1165001|1165001-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803140118
1165072|1165072-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|0.9|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803141048
1165073|1165073-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803141048
1165074|1165074-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.43|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803141048
1165344|1165344-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140603
1165350|1165350-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140604
1165353|1165353-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140605
1165354|1165354-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200803140606
1165541|1165541-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803141620
1165549|1165549-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.43|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803141622
1165579|1165579-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|0.9|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803141634
1165909|1165909-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803141047
1166648|1166648-b19f-3f77-b713-d32bba55d77f|pass|200803|dillman@ria.buffalo.edu|Devel-CheckOS|1.43|sun4-solaris|5.10.0|solaris|2.9|200803141303
1167659|1167659-b19f-3f77-b713-d32bba55d77f|pass|200803|pjacklam@online.no|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803142333
1167878|1167878-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150009
1167910|1167910-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150015
1167915|1167915-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150016
1167924|1167924-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200803150018
1168085|1168085-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33523|linux|2.6.22-1-k7|200803150144
1168411|1168411-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33523|linux|2.6.22-1-k7|200803150255
1168612|1168612-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150315
1168614|1168614-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150316
1168616|1168616-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150318
1168618|1168618-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803150320
1168671|1168671-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803150345
1168674|1168674-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803150347
1168676|1168676-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803150349
1168679|1168679-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803150350
1168682|1168682-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803150352
1168773|1168773-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803150425
1168780|1168780-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803150426
1168783|1168783-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803150428
1168787|1168787-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803150429
1168791|1168791-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803150431
1168843|1168843-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200803150452
1168844|1168844-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200803150453
1168847|1168847-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200803150455
1168848|1168848-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200803150456
1168850|1168850-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200803150457
1168852|1168852-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200803150459
1168855|1168855-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200803150500
1168857|1168857-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200803150501
1168862|1168862-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200803150502
1168863|1168863-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200803150504
1169140|1169140-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.6.2|freebsd|6.2-release|200803150824
1169142|1169142-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.6.2|freebsd|6.2-release|200803150824
1170491|1170491-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33523|cygwin|1.5.24(0.15642)|200803151654
1171035|1171035-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803152243
1171036|1171036-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803152243
1171715|1171715-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803160058
1172433|1172433-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160609
1172435|1172435-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160609
1172436|1172436-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160610
1172438|1172438-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200803160611
1172467|1172467-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803160656
1172895|1172895-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803161138
1173125|1173125-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Compare|1.18|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803161212
1173183|1173183-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803161216
1173817|1173817-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161246
1174405|1174405-b19f-3f77-b713-d32bba55d77f|pass|200803|g.grigelionis@computer.org|Devel-CheckOS|1.43|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200803151032
1174545|1174545-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161404
1174714|1174714-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803161337
1174721|1174721-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803161338
1174724|1174724-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803161339
1174757|1174757-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161451
1176590|1176590-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161921
1176723|1176723-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8 patch 33536|linux|2.6.22-1-k7|200803161932
1176968|1176968-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161952
1176971|1176971-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161954
1176974|1176974-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161956
1176979|1176979-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200803161958
1177423|1177423-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162007
1177430|1177430-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162008
1177436|1177436-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162011
1177445|1177445-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200803162014
1178306|1178306-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|CPU-Emulator-Z80|0.9|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803170730
1178312|1178312-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803170734
1178317|1178317-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803170735
1179297|1179297-b19f-3f77-b713-d32bba55d77f|pass|200803|jrockway@cpan.org|Data-Compare|1.18|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200803170556
1179476|1179476-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803171456
1179553|1179553-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.581|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803170934
1180042|1180042-b19f-3f77-b713-d32bba55d77f|pass|200803|stro@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200803171718
1180067|1180067-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171523
1180073|1180073-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171524
1180076|1180076-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171525
1180083|1180083-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803171526
1181294|1181294-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803172316
1181486|1181486-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803172255
1182212|1182212-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180154
1182266|1182266-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180159
1182400|1182400-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180219
1182464|1182464-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.10.0 patch 33535|linux|2.6.22-1-k7|200803180238
1183117|1183117-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180413
1183120|1183120-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180414
1183122|1183122-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180415
1183125|1183125-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803180416
1183818|1183818-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803180856
1183820|1183820-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803180857
1183823|1183823-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris-thread-multi|5.8.8|solaris|2.9|200803180858
1184296|1184296-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200803181113
1184598|1184598-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33539|linux|2.6.18-5-alpha-generic|200803181322
1185299|1185299-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803181634
1185301|1185301-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Z80|0.9|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803181635
1185302|1185302-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.8|freebsd|6.3-stable|200803181634
1185643|1185643-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181710
1185646|1185646-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181711
1185669|1185669-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181713
1185676|1185676-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803181714
1186256|1186256-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.6.2|freebsd|6.2-release|200803182000
1186749|1186749-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Number-Phone|1.581|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803182152
1187699|1187699-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200803190210
1189947|1189947-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191518
1189953|1189953-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191519
1189956|1189956-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200803191520
1190402|1190402-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191634
1190403|1190403-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191635
1190405|1190405-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803191635
1190469|1190469-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803191916
1190666|1190666-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803191844
1191004|1191004-b19f-3f77-b713-d32bba55d77f|fail|200803|srezic@cpan.org|Bryar|3.0|amd64-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200803192109
1191974|1191974-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200158
1192362|1192362-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200342
1192598|1192598-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200803200110
1192731|1192731-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200339
1193708|1193708-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33542|linux|2.6.22-1-k7|200803200740
1193709|1193709-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193710|1193710-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193712|1193712-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193714|1193714-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201440
1193716|1193716-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193717|1193717-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193719|1193719-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193720|1193720-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201441
1193725|1193725-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803201442
1197084|1197084-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.18|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803202243
1197372|1197372-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.11.0 patch 33543|freebsd|7.0-release|200803201903
1198104|1198104-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210453
1198112|1198112-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210455
1198152|1198152-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210504
1198166|1198166-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803210507
1198952|1198952-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd-thread-multi|5.8.8|freebsd|6.2-release|200803210013
1198983|1198983-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Data-Transactional|1.0|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803210932
1198998|1198998-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl ("DEVOGON")|Tie-STDOUT|1.03|x86_64-linux|5.10.0|linux|2.6.23.1-slh64-smp-32|200803210934
1200386|1200386-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33543|cygwin|1.5.24(0.15642)|200803211349
1201926|1201926-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33547|linux|2.6.22-1-k7|200803212318
1202128|1202128-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33547|linux|2.6.22-1-k7|200803212309
1203286|1203286-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.11.0 patch 33544|solaris|2.11|200803221120
1204426|1204426-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803222136
1204805|1204805-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803230315
1205235|1205235-b19f-3f77-b713-d32bba55d77f|fail|200803|imacat@mail.imacat.idv.tw|Palm-SMS|0.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803231512
1205373|1205373-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200803231644
1207445|1207445-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-pc-solaris2.11-thread-multi-64int|5.10.0|solaris|2.11|200803240109
1208722|1208722-b19f-3f77-b713-d32bba55d77f|pass|200803|pjacklam@online.no|Statistics-ChiSquare|0.5|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803240946
1209414|1209414-b19f-3f77-b713-d32bba55d77f|pass|200803|pjacklam@online.no|Statistics-SerialCorrelation|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200803241042
1211329|1211329-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803242029
1211522|1211522-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803242028
1211793|1211793-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.6.2|freebsd|6.2-release|200803242136
1211844|1211844-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803241943
1211972|1211972-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803242157
1213162|1213162-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803250221
1213482|1213482-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33551|linux|2.6.22-1-k7|200803250005
1214140|1214140-b19f-3f77-b713-d32bba55d77f|pass|200803|victorg@hacktux.com|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.18-53.1.13.el5|200803250023
1219608|1219608-b19f-3f77-b713-d32bba55d77f|pass|200803|mthurn@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200803260359
1222775|1222775-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.6.2|freebsd|6.1-release|200803270221
1223051|1223051-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270427
1223335|1223335-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270607
1223339|1223339-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270608
1223390|1223390-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270618
1223398|1223398-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803270615
1224707|1224707-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33580|linux|2.6.22-1-k7|200803271100
1224842|1224842-b19f-3f77-b713-d32bba55d77f|pass|200803|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200803271844
1225443|1225443-b19f-3f77-b713-d32bba55d77f|pass|200803|andy@hexten.net|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200803271533
1227809|1227809-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281302
1227848|1227848-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281322
1228566|1228566-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281513
1228671|1228671-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281726
1228876|1228876-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200803281722
1228967|1228967-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200803281737
1229101|1229101-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803281854
1229520|1229520-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33576|linux|2.6.22-1-k7|200803282040
1230271|1230271-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803290030
1231970|1231970-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803291342
1232260|1232260-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200803291414
1232395|1232395-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33584|netbsd|4.0|200803291444
1232715|1232715-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Compare|1.18|i386-freebsd|5.10.0|freebsd|6.1-release|200803291728
1232969|1232969-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Compare|1.18|i386-freebsd|5.6.2|freebsd|6.1-release|200803291533
1233051|1233051-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33584|netbsd|4.0|200803291737
1233578|1233578-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|Devel-CheckLib|0.4|i386-linux|5.8.8|linux|2.6.18-53.el5|200803291440
1233672|1233672-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Data-Compare|1.18|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200803292004
1234280|1234280-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.581|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803292355
1234283|1234283-b19f-3f77-b713-d32bba55d77f|fail|200803|david@cantrell.org.uk|Devel-CheckOS|1.43|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200803292256
1234304|1234304-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33592|cygwin|1.5.24(0.15642)|200803292311
1235061|1235061-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200803301032
1235065|1235065-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200803301033
1235068|1235068-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8|linux|2.6.14|200803301034
1235070|1235070-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200803301035
1235073|1235073-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200803301036
1235078|1235078-b19f-3f77-b713-d32bba55d77f|pass|200803|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.6.2|linux|2.6.16-2-k7|200803301037
1236117|1236117-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200803301809
1236572|1236572-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200803301949
1236770|1236770-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.22-3-486|200803302143
1236800|1236800-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803302152
1237579|1237579-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200803302354
1237843|1237843-b19f-3f77-b713-d32bba55d77f|pass|200803|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200803310046
1238161|1238161-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|Devel-CheckLib|0.5|i386-linux|5.8.8|linux|2.6.18-53.el5|200803310322
1238163|1238163-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|Devel-CheckOS|1.43|i386-linux|5.8.8|linux|2.6.18-53.el5|200803310324
1238202|1238202-b19f-3f77-b713-d32bba55d77f|pass|200803|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Z80|0.9|i386-linux|5.8.8|linux|2.6.18-53.el5|200803310336
1239152|1239152-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.22-3-486|200803311156
1239517|1239517-b19f-3f77-b713-d32bba55d77f|pass|200803|flemming@ipk-gatersleben.de|Data-Compare|1.18|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200803311253
1240050|1240050-b19f-3f77-b713-d32bba55d77f|pass|200803|flemming@ipk-gatersleben.de|File-Find-Rule-Permissions|1.3|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200803311452
1240150|1240150-b19f-3f77-b713-d32bba55d77f|pass|200803|flemming@ipk-gatersleben.de|Devel-CheckOS|1.43|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200803311452
1240236|1240236-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803311522
1240361|1240361-b19f-3f77-b713-d32bba55d77f|pass|200803|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200803311646
1240809|1240809-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200803311748
1241129|1241129-b19f-3f77-b713-d32bba55d77f|pass|200803|d@0x64.nl (DEVOGON)|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200803311839
1241188|1241188-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200803311943
1241491|1241491-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.6.2|freebsd|6.1-release|200803312138
1241502|1241502-b19f-3f77-b713-d32bba55d77f|pass|200803|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.6.2|freebsd|6.1-release|200803312143
1241637|1241637-b19f-3f77-b713-d32bba55d77f|pass|200803|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33609|netbsd|3.1|200803312125
1242439|1242439-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 33609|netbsd|3.1|200804010218
1242549|1242549-b19f-3f77-b713-d32bba55d77f|pass|200804|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804010215
1242883|1242883-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010613
1243016|1243016-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010702
1243595|1243595-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010745
1244664|1244664-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804011204
1245283|1245283-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804011238
1245469|1245469-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33620|linux|2.6.22-1-k7|200804010443
1245671|1245671-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804011411
1246102|1246102-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.11.0 patch 33609|linux|2.6.18-5-alpha-generic|200804011728
1246605|1246605-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33623|linux|2.6.16.38|200804011834
1247239|1247239-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Compare|1.18|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804020018
1249436|1249436-b19f-3f77-b713-d32bba55d77f|fail|200804|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804020616
1250046|1250046-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804021400
1250303|1250303-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804021720
1250327|1250327-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804021640
1250845|1250845-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200804021958
1250931|1250931-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.5.5|freebsd|6.1-release|200804022228
1251046|1251046-b19f-3f77-b713-d32bba55d77f|pass|200804|g.grigelionis@computer.org|Devel-CheckOS|1.43|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200804022200
1251060|1251060-b19f-3f77-b713-d32bba55d77f|na|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.5.5|freebsd|6.1-release|200804022228
1251663|1251663-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200804030054
1252351|1252351-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804030743
1252495|1252495-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.6.2|freebsd|6.1-release|200804030804
1252565|1252565-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.10.0|freebsd|6.1-release|200804030807
1252690|1252690-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804030846
1252944|1252944-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031013
1253193|1253193-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031110
1253816|1253816-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804031219
1254074|1254074-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031419
1254640|1254640-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031557
1254832|1254832-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200804031639
1256353|1256353-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33632|openbsd|4.1|200804032241
1256641|1256641-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804040035
1256699|1256699-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804040046
1258103|1258103-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804040823
1258262|1258262-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804040844
1258588|1258588-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804040903
1258998|1258998-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804041115
1259325|1259325-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804041211
1259700|1259700-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.8 patch 33638|linux|2.6.22-1-k7|200804041104
1260650|1260650-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33643|cygwin|1.5.24(0.15642)|200804041859
1261597|1261597-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.10.0|freebsd|6.1-release|200804050039
1261932|1261932-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050156
1262025|1262025-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050243
1262253|1262253-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050337
1262830|1262830-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050707
1262965|1262965-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050734
1263296|1263296-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33646|linux|2.6.22-1-k7|200804050833
1264058|1264058-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804051046
1264059|1264059-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804051047
1264192|1264192-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804051048
1264387|1264387-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.6.2|freebsd|6.1-release|200804051254
1264466|1264466-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804051243
1264548|1264548-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804051244
1264550|1264550-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804051245
1264740|1264740-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200804051349
1265774|1265774-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.10.0|freebsd|6.1-release|200804051816
1265782|1265782-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd|5.10.0|freebsd|6.1-release|200804051819
1265898|1265898-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.10.0|freebsd|6.1-release|200804051818
1266599|1266599-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804052116
1267915|1267915-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060102
1267993|1267993-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060048
1268179|1268179-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060113
1268941|1268941-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060231
1269251|1269251-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.11.0 patch 33648|linux|2.6.22-1-k7|200804060207
1270069|1270069-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804061049
1270100|1270100-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804061054
1270807|1270807-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804061538
1271214|1271214-b19f-3f77-b713-d32bba55d77f|pass|200804|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.15.7|200804062023
1272262|1272262-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|XML-Tiny|1.11|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804062307
1272703|1272703-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200804070033
1273196|1273196-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070512
1273374|1273374-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070526
1273441|1273441-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070552
1273961|1273961-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804070811
1274437|1274437-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804070943
1274783|1274783-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804071031
1275261|1275261-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33655|linux|2.6.21.5-smp|200804071002
1275273|1275273-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33642|linux|2.6.22-1-k7|200804071154
1275419|1275419-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33655|linux|2.6.18-5-alpha-generic|200804071127
1275742|1275742-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33655|netbsd|3.1|200804071205
1275956|1275956-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33655|darwin|8.10.0|200804071235
1276355|1276355-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804071621
1276975|1276975-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804071919
1280289|1280289-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.6.2|freebsd|6.1-release|200804080705
1282762|1282762-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|2.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804081911
1285009|1285009-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090442
1285671|1285671-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090643
1285857|1285857-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090734
1286432|1286432-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090756
1286479|1286479-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090922
1286504|1286504-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33659|linux|2.6.22-1-k7|200804090219
1286579|1286579-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804090930
1287189|1287189-b19f-3f77-b713-d32bba55d77f|pass|200804|rafl@debian.org|Data-Compare|1.18|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200804091259
1287547|1287547-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804091419
1288483|1288483-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804091852
1289736|1289736-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.10.0|freebsd|6.1-release|200804100214
1291176|1291176-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200804101229
1292857|1292857-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33659|darwin|8.10.0|200804102014
1292969|1292969-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Compare|1.18|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804102153
1294270|1294270-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.6.2|freebsd|6.1-release|200804110417
1295251|1295251-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.11.0 patch 33659|solaris|2.11|200804111006
1296395|1296395-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804111548
1296444|1296444-b19f-3f77-b713-d32bba55d77f|fail|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|3.0|sun4-solaris-thread-multi-64int|5.10.0|solaris|2.9|200804111559
1298893|1298893-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33669|cygwin|1.5.24(0.15642)|200804112348
1299784|1299784-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804120744
1299806|1299806-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804120736
1300813|1300813-b19f-3f77-b713-d32bba55d77f|fail|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.10.0|freebsd|6.1-release|200804121203
1302083|1302083-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121611
1302530|1302530-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121655
1302619|1302619-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121648
1302734|1302734-b19f-3f77-b713-d32bba55d77f|pass|200804|andy@hexten.net|Devel-CheckLib|0.5|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200804121616
1302878|1302878-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33669|linux|2.6.22-1-k7|200804121725
1303747|1303747-b19f-3f77-b713-d32bba55d77f|pass|200804|bobtfish@bobtfish.net|Data-Compare|1.18|darwin-thread-multi-2level|5.8.6|darwin|8.0|200804121656
1304958|1304958-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33670|openbsd|4.2|200804122311
1306578|1306578-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.6.2|freebsd|6.1-release|200804131000
1307348|1307348-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200804131229
1308479|1308479-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804131759
1308506|1308506-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.10.0|freebsd|6.1-release|200804131809
1309852|1309852-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200804132352
1309901|1309901-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804140004
1309990|1309990-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200804140024
1310065|1310065-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200804140032
1310264|1310264-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804140112
1312796|1312796-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33673|linux|2.6.18-5-alpha-generic|200804141247
1314443|1314443-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33673|netbsd|3.1|200804142104
1314651|1314651-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200804142240
1316284|1316284-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804150951
1318154|1318154-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33684|darwin|8.10.0|200804151533
1318181|1318181-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Compare|1.18|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804151633
1319178|1319178-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804152010
1319424|1319424-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804152133
1319427|1319427-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200804152135
1320037|1320037-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160006
1320202|1320202-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160045
1320688|1320688-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160154
1320854|1320854-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160153
1321240|1321240-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804160306
1321718|1321718-b19f-3f77-b713-d32bba55d77f|pass|200804|bobtfish@bobtfish.net|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.22-3-amd64|200804160036
1321958|1321958-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160426
1322246|1322246-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160545
1322346|1322346-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160609
1322726|1322726-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160707
1322791|1322791-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160722
1323725|1323725-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160935
1323925|1323925-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804160955
1324139|1324139-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804160937
1324238|1324238-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33695|linux|2.6.22-1-k7|200804161023
1324470|1324470-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200804161007
1324479|1324479-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200804161008
1324893|1324893-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804161208
1325309|1325309-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Devel-CheckOS|1.43|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804161332
1329851|1329851-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170219
1330384|1330384-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200804170602
1330587|1330587-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Bryar|3.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200804170816
1330869|1330869-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Hexdumper|1.3|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170940
1330877|1330877-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804170941
1331563|1331563-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171159
1331870|1331870-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171256
1333040|1333040-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.5.5|freebsd|6.1-release|200804171656
1333594|1333594-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171929
1333630|1333630-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804171941
1334678|1334678-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804172336
1334892|1334892-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.11.0 patch 33684|darwin|8.10.0|200804172324
1334893|1334893-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200804172324
1336996|1336996-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.4.27-2-386|200804181300
1337168|1337168-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804181149
1338088|1338088-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200804181535
1338833|1338833-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804181627
1340146|1340146-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804182058
1341403|1341403-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804190052
1342227|1342227-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804190341
1343054|1343054-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33713|netbsd|3.1|200804191000
1343247|1343247-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 33713|netbsd|3.1|200804191113
1343738|1343738-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33713|cygwin|1.5.24(0.15642)|200804191330
1344079|1344079-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|cygwin-thread-multi-64int|5.11.0 patch 33713|cygwin|1.5.24(0.15642)|200804191507
1344109|1344109-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|XML-Tiny|1.11|i686-linux|5.8.8|linux|2.4.27-2-386|200804191416
1344425|1344425-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|sun4-solaris|5.10.0|solaris|2.9|200804191717
1344978|1344978-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.4.27-2-386|200804191700
1345067|1345067-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Devel-CheckOS|1.43|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200804192108
1346102|1346102-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804192337
1346403|1346403-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33713|darwin|8.10.0|200804192340
1346430|1346430-b19f-3f77-b713-d32bba55d77f|unknown|200804|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804200042
1346569|1346569-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.4.27-2-386|200804200011
1346627|1346627-b19f-3f77-b713-d32bba55d77f|unknown|200804|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804200043
1347609|1347609-b19f-3f77-b713-d32bba55d77f|pass|200804|cpansmoker@renormalist.net ("Steffen Schwigon")|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.18-5-k7|200804200050
1348140|1348140-b19f-3f77-b713-d32bba55d77f|pass|200804|cpansmoker@renormalist.net ("Steffen Schwigon")|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.18-5-k7|200804200841
1348289|1348289-b19f-3f77-b713-d32bba55d77f|pass|200804|cpansmoker@renormalist.net ("Steffen Schwigon")|Data-Compare|1.18|i686-linux|5.10.0|linux|2.6.18-5-k7|200804200911
1348942|1348942-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804201142
1349045|1349045-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804201117
1349578|1349578-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201309
1349660|1349660-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201322
1349824|1349824-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201341
1349960|1349960-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201306
1350142|1350142-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201239
1350369|1350369-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804201434
1350385|1350385-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|darwin-2level|5.10.0|darwin|8.11.1|200804201202
1351314|1351314-b19f-3f77-b713-d32bba55d77f|pass|200804|artur+cpan@niif.spb.su|XML-Tiny|1.11|i386-linux|5.8.8|linux|2.6.18-53.1.4.el5.bz358661.1|200804201138
1352831|1352831-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|darwin-2level|5.10.0|darwin|8.11.1|200804201815
1352844|1352844-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.11.0 patch 33714|linux|2.6.16.38|200804202018
1352857|1352857-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33714|linux|2.6.22-1-k7|200804201809
1353180|1353180-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.11.0 patch 33714|linux|2.6.16.38|200804202058
1354151|1354151-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|XML-Tiny|1.11|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804210414
1355985|1355985-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33714|openbsd|4.1|200804211355
1356080|1356080-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|alpha-linux-thread-multi|5.11.0 patch 33716|linux|2.6.18-5-alpha-generic|200804211407
1357339|1357339-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.18|sun4-solaris|5.10.0|solaris|2.9|200804211952
1357838|1357838-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804212200
1359285|1359285-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Licence|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200804220029
1360100|1360100-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|i686-linux|5.8.8|linux|2.4.27-2-386|200804220442
1360220|1360220-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200804220549
1360275|1360275-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33714|openbsd|4.1|200804220557
1360430|1360430-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33714|openbsd|4.1|200804220712
1360762|1360762-b19f-3f77-b713-d32bba55d77f|pass|200804|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|sun4-solaris|5.10.0|solaris|2.9|200804221035
1361828|1361828-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Licence|1.0|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804221657
1361841|1361841-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.4.27-2-386|200804221541
1362745|1362745-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804221953
1362863|1362863-b19f-3f77-b713-d32bba55d77f|pass|200804|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200804221951
1362883|1362883-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.4.27-2-386|200804222000
1362913|1362913-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Licence|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804222148
1365292|1365292-b19f-3f77-b713-d32bba55d77f|pass|200804|mgardner@usatech.com|Data-Compare|1.18|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200804221340
1365401|1365401-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.4.27-2-386|200804231029
1365419|1365419-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804231207
1365571|1365571-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200804231245
1365589|1365589-b19f-3f77-b713-d32bba55d77f|pass|200804|rafl@debian.org|XML-Tiny|1.11|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200804230011
1365735|1365735-b19f-3f77-b713-d32bba55d77f|pass|200804|mgardner@usatech.com|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200804221350
1366323|1366323-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200804231630
1366439|1366439-b19f-3f77-b713-d32bba55d77f|unknown|200804|stro@cpan.org|Acme-Pony|1.1.2|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804231843
1366955|1366955-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200804231902
1367132|1367132-b19f-3f77-b713-d32bba55d77f|pass|200804|stro@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|armv5tejl-linux|5.8.8|linux|2.6.17.14|200804232203
1368275|1368275-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240105
1368277|1368277-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240106
1368280|1368280-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240107
1368324|1368324-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240122
1368325|1368325-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240123
1368334|1368334-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|CPU-Emulator-Z80|0.9|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240126
1368335|1368335-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Class-CanBeA|1.2|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240126
1368340|1368340-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240127
1368341|1368341-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240128
1368343|1368343-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Transactional|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240129
1368347|1368347-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240130
1368352|1368352-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240131
1368354|1368354-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240132
1368358|1368358-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|File-Overwrite|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240132
1368360|1368360-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240133
1368362|1368362-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|NestedMap|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240133
1368371|1368371-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Net-Random|2.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240138
1368372|1368372-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240139
1368373|1368373-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240141
1368375|1368375-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Statistics-ChiSquare|0.5|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240142
1368376|1368376-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Statistics-SerialCorrelation|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240142
1368377|1368377-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Sub-WrapPackages|1.2|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240143
1368378|1368378-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Tie-Hash-Longest|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240143
1368379|1368379-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Tie-Hash-Rank|1.0.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240143
1368380|1368380-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Tie-STDOUT|1.03|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240144
1368381|1368381-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Tie-Scalar-Decay|1.1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240144
1368383|1368383-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240145
1368386|1368386-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.11.0 patch 33724|darwin|8.10.0|200804240145
1371563|1371563-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804250734
1372822|1372822-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804251054
1373335|1373335-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804250926
1373398|1373398-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.11.0 patch 33741|freebsd|7.0-release|200804251510
1373795|1373795-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200804251645
1375050|1375050-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 33741|freebsd|7.0-release|200804260104
1375153|1375153-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.11.0 patch 33741|freebsd|7.0-release|200804260154
1375157|1375157-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804260235
1375177|1375177-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804260242
1375466|1375466-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33735|linux|2.6.22-1-k7|200804260413
1377678|1377678-b19f-3f77-b713-d32bba55d77f|pass|200804|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33741|darwin|8.10.0|200804262114
1380106|1380106-b19f-3f77-b713-d32bba55d77f|pass|200804|alexchorny@gmail.com|Data-Compare|1.18|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200804271820
1380947|1380947-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804281120
1382101|1382101-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804281840
1382290|1382290-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804281946
1384214|1384214-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|CPU-Emulator-Z80|0.9|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290214
1384220|1384220-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Devel-CheckLib|0.5|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290215
1384268|1384268-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804290043
1385201|1385201-b19f-3f77-b713-d32bba55d77f|pass|200804|daxim@cpan.org|Bryar|3.0|x86_64-linux|5.8.8|linux|2.6.20-gentoo-r8|200804290723
1385859|1385859-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804290843
1386203|1386203-b19f-3f77-b713-d32bba55d77f|pass|200804|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33760|linux|2.6.22-1-k7|200804291034
1386295|1386295-b19f-3f77-b713-d32bba55d77f|pass|200804|tester@tcool.org ("ishigaki")|Data-Compare|1.18|i386-freebsd-64int|5.8.8|freebsd|5.4-release-p16|200804291212
1391895|1391895-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33741|darwin|8.10.0|200805011812
1392094|1392094-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805011924
1392295|1392295-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012217
1392648|1392648-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012357
1392682|1392682-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012352
1392765|1392765-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805012331
1393191|1393191-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33755|linux|2.6.22-1-k7|200805020601
1394719|1394719-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.5.5|freebsd|6.1-release|200805021325
1396129|1396129-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Number-Phone|1.581|i386-freebsd|5.5.5|freebsd|6.1-release|200805021916
1396253|1396253-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805021945
1396966|1396966-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.5.5|freebsd|6.1-release|200805022257
1397502|1397502-b19f-3f77-b713-d32bba55d77f|pass|200805|gam3-cpanp@gam3.net|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.22.10|200805020917
1397513|1397513-b19f-3f77-b713-d32bba55d77f|pass|200805|ewhipple@kubuntu-1.americanstaffing.org ((ewhipple))|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200805021038
1397923|1397923-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200805030108
1398049|1398049-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805030108
1398157|1398157-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.3|i386-freebsd|5.5.5|freebsd|6.1-release|200805030059
1398349|1398349-b19f-3f77-b713-d32bba55d77f|pass|200805|jrockway@cpan.org|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200805021352
1398975|1398975-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805030441
1401073|1401073-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805031752
1401597|1401597-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805031236
1402427|1402427-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Devel-CheckLib|0.5|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805032247
1402547|1402547-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|Palm-SMS|0.02|darwin-thread-multi-64int-2level|5.11.0 patch 33782|darwin|8.10.0|200805032158
1402664|1402664-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805032304
1403160|1403160-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|XML-Tiny|1.11|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040108
1403333|1403333-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.43|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040137
1403502|1403502-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Compare|1.18|x86_64-linux-gnu|5.10.0|linux|2.6.24-1-amd64|200805040200
1404074|1404074-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805040138
1404127|1404127-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805040133
1404862|1404862-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33782|openbsd|4.2|200805041041
1406078|1406078-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805041339
1406538|1406538-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33736|linux|2.6.22-1-k7|200805041535
1407046|1407046-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805041750
1407061|1407061-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200805041858
1407291|1407291-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33776|linux|2.6.22-1-k7|200805041929
1408339|1408339-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33782|openbsd|4.2|200805050643
1409006|1409006-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805051201
1410617|1410617-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i386-netbsd-thread-multi-64int|5.11.0 patch 33788|netbsd|4.0|200805052144
1410773|1410773-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33788|linux|2.6.24-17-generic|200805052323
1413440|1413440-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33788|netbsd|4.0|200805061317
1414429|1414429-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805061700
1414480|1414480-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|Bryar|3.0|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805061751
1416098|1416098-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805070052
1417178|1417178-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805070124
1417798|1417798-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805070924
1418235|1418235-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805071058
1418752|1418752-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33788|linux|2.6.22-1-k7|200805071326
1419366|1419366-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805071751
1420893|1420893-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.10.0|freebsd|6.1-release|200805080836
1422492|1422492-b19f-3f77-b713-d32bba55d77f|pass|200805|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.18|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805081517
1423103|1423103-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl|Data-Compare|1.18|i486-linux-gnu|5.8.8|linux|2.6.22.10|200805081919
1423254|1423254-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i86pc-solaris-thread-multi-64int|5.11.0 patch 33789|solaris|2.10|200805082054
1424466|1424466-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33783|darwin|8.10.0|200805090547
1425874|1425874-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805090915
1426736|1426736-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.18|darwin-2level|5.8.1|darwin|7.9.0|200805091542
1427856|1427856-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805092020
1428749|1428749-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805092230
1428861|1428861-b19f-3f77-b713-d32bba55d77f|pass|200805|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.43|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200805092240
1428880|1428880-b19f-3f77-b713-d32bba55d77f|pass|200805|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.43|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200805092244
1429209|1429209-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|darwin-thread-multi-64int-2level|5.11.0 patch 33797|darwin|8.10.0|200805092351
1430158|1430158-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.3|darwin-thread-multi-64int-2level|5.11.0 patch 33797|darwin|8.10.0|200805100357
1431052|1431052-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 33797|linux|2.6.24-17-generic|200805100805
1431653|1431653-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101021
1432538|1432538-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101402
1432694|1432694-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101402
1433056|1433056-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckOS|1.43|darwin-2level|5.8.1|darwin|7.9.0|200805101404
1433313|1433313-b19f-3f77-b713-d32bba55d77f|pass|200805|icerider70@gmail.com ("ICERIDER")|XML-Tiny|1.11|i386-linux|5.8.8|linux|2.6.18-53.el5|200805100903
1433348|1433348-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|cygwin-thread-multi-64int|5.11.0 patch 33796|cygwin|1.5.24(0.15642)|200805101508
1433636|1433636-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805101544
1434358|1434358-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805101412
1434661|1434661-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805101847
1435099|1435099-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Data-Compare|1.18|i686-linux|5.11.0 patch 33797|linux|2.6.24-17-generic|200805102320
1436231|1436231-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|XML-Tiny|1.11|darwin-2level|5.8.1|darwin|7.9.0|200805110257
1436370|1436370-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805110336
1437768|1437768-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805110214
1438065|1438065-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805110149
1438346|1438346-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805111359
1438484|1438484-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805111438
1438874|1438874-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i686-linux-thread-multi-64int|5.11.0 patch 33816|linux|2.6.21.5-smp|200805111621
1438928|1438928-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33811|linux|2.6.22-1-k7|200805111638
1439819|1439819-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200805112200
1439820|1439820-b19f-3f77-b713-d32bba55d77f|na|200805|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.6.2|freebsd|6.1-release|200805112201
1441505|1441505-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805120600
1441873|1441873-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.11.0 patch 33798|linux|2.6.22-1-k7|200805120751
1443828|1443828-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805121541
1444415|1444415-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux|5.10.0 patch 33787|linux|2.6.22-1-k7|200805121738
1444798|1444798-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200805122042
1445168|1445168-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.3|i386-freebsd|5.6.2|freebsd|6.1-release|200805122155
1445749|1445749-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.18|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805122232
1445774|1445774-b19f-3f77-b713-d32bba55d77f|pass|200805|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200805130718
1446070|1446070-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805130005
1446250|1446250-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200805130109
1446252|1446252-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200805130110
1446254|1446254-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200805130111
1446260|1446260-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8|linux|2.6.14|200805130112
1446262|1446262-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200805130113
1446263|1446263-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200805130113
1446267|1446267-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200805130114
1446271|1446271-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200805130115
1446273|1446273-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200805130116
1446274|1446274-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200805130216
1446276|1446276-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805130218
1446279|1446279-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805130220
1446294|1446294-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200805130127
1446649|1446649-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200805130443
1446652|1446652-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200805130443
1446655|1446655-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200805130444
1446656|1446656-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200805130444
1446659|1446659-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200805130445
1446665|1446665-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200805130445
1446669|1446669-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200805130446
1446671|1446671-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200805130447
1446674|1446674-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200805130447
1446676|1446676-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200805130448
1447210|1447210-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Compare|1.19|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200805130904
1447307|1447307-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805130810
1447348|1447348-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200805130716
1447365|1447365-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200805130219
1447405|1447405-b19f-3f77-b713-d32bba55d77f|pass|200805|rafl@debian.org|Data-Compare|1.19|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200805130713
1447428|1447428-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i686-linux|5.8.8|linux|2.4.27-3-686|200805130827
1447433|1447433-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200805130829
1447622|1447622-b19f-3f77-b713-d32bba55d77f|pass|200805|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.19|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805130901
1447705|1447705-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.19|darwin-2level|5.8.1|darwin|7.9.0|200805130933
1447804|1447804-b19f-3f77-b713-d32bba55d77f|pass|200805|imacat@mail.imacat.idv.tw|Data-Compare|1.19|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200805131651
1447805|1447805-b19f-3f77-b713-d32bba55d77f|pass|200805|imacat@mail.imacat.idv.tw|Data-Compare|1.19|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200805131651
1447883|1447883-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200805131008
1447892|1447892-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200805130735
1448176|1448176-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805131111
1448508|1448508-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.18|i386-freebsd-64int|5.11.0 patch 33822|freebsd|7.0-release|200805131027
1448683|1448683-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200805131253
1448737|1448737-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|i686-linux|5.6.2|linux|2.4.27-3-686|200805131306
1448903|1448903-b19f-3f77-b713-d32bba55d77f|pass|200805|hohokus@gmail.com|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805130857
1449105|1449105-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.11.0 patch 33822|linux|2.6.18-5-alpha-generic|200805131449
1449658|1449658-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805131025
1449817|1449817-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.11.0 patch 33822|darwin|8.10.0|200805131730
1449960|1449960-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|CPU-Emulator-Memory|1.1001|darwin-2level|5.8.1|darwin|7.9.0|200805131811
1449999|1449999-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckLib|0.5|darwin-2level|5.8.1|darwin|7.9.0|200805131821
1450090|1450090-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200805131934
1450191|1450191-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl (DEVOGON)|Data-Compare|1.19|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200805131835
1450235|1450235-b19f-3f77-b713-d32bba55d77f|pass|200805|g.grigelionis@computer.org|Data-Compare|1.19|i586-linux-thread-multi|5.8.8|linux|2.6.16|200805131958
1450615|1450615-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd|5.10.0|freebsd|6.1-release|200805132205
1451204|1451204-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd|5.6.2|freebsd|6.1-release|200805140013
1451206|1451206-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805140015
1451390|1451390-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33822|openbsd|4.2|200805132353
1451490|1451490-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200805140016
1451562|1451562-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805140029
1451906|1451906-b19f-3f77-b713-d32bba55d77f|pass|200805|rlane10@wi.rr.com|Data-Compare|1.19|darwin-2level-ld|5.10.0|darwin|8.11.0|200805131335
1452642|1452642-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805140623
1453081|1453081-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200805140836
1453184|1453184-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805140900
1453262|1453262-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Number-Phone|1.581|darwin-2level|5.8.1|darwin|7.9.0|200805140826
1453544|1453544-b19f-3f77-b713-d32bba55d77f|pass|200805|claco@chrislaco.com ("Christopher H. Laco")|Data-Compare|1.19|darwin-thread-multi-2level|5.8.6|darwin|8.0|200805140110
1453574|1453574-b19f-3f77-b713-d32bba55d77f|pass|200805|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.43|i386-linux|5.10.0|linux|2.6.18-53.1.6.el5xen|200805141023
1454231|1454231-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33822|darwin|8.10.0|200805141259
1454795|1454795-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200805141727
1455003|1455003-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Data-Compare|1.19|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200805141817
1455200|1455200-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.1|darwin|7.9.0|200805141701
1455314|1455314-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805141105
1455526|1455526-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805141019
1456155|1456155-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Compare|1.19|i686-linux|5.10.0|linux|2.6.22-3-486|200805142209
1456214|1456214-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805142209
1456357|1456357-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Compare|1.19|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805142248
1456779|1456779-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200805142347
1456839|1456839-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805141907
1457182|1457182-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805150105
1458610|1458610-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33824|linux|2.6.22-1-k7|200805150835
1459230|1459230-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200805151214
1460527|1460527-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Devel-CheckOS|1.43|armv5tejl-linux|5.8.8|linux|2.6.17.14|200805151846
1460623|1460623-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805151656
1460959|1460959-b19f-3f77-b713-d32bba55d77f|pass|200805|dillman@ria.buffalo.edu|Data-Compare|1.19|sun4-solaris|5.10.0|solaris|2.9|200805150915
1461199|1461199-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33823|linux|2.6.22-1-k7|200805151803
1461793|1461793-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805151626
1461874|1461874-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805151640
1462583|1462583-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805160026
1462813|1462813-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805160218
1463177|1463177-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805160229
1463182|1463182-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805160229
1463203|1463203-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805160233
1463474|1463474-b19f-3f77-b713-d32bba55d77f|fail|200805|chris@bingosnet.co.uk|Bryar|3.0|darwin-thread-multi-64int-2level|5.11.0 patch 33824|darwin|8.10.0|200805160418
1463606|1463606-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.11.0 patch 33824|darwin|8.10.0|200805160448
1464426|1464426-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805160243
1464429|1464429-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200805160143
1465183|1465183-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805161049
1465966|1465966-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161339
1466142|1466142-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161335
1466168|1466168-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.11.0 patch 33831|netbsd|4.0|200805160737
1466808|1466808-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161613
1466853|1466853-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805161715
1467732|1467732-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|CPAN-FindDependencies|2.0|IP35-irix|5.8.8|irix|6.5|200805162203
1467738|1467738-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|IP35-irix|5.8.8|irix|6.5|200805162204
1467769|1467769-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Class-CanBeA|1.2|IP35-irix|5.8.8|irix|6.5|200805162209
1467784|1467784-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Compare|1.19|IP35-irix|5.8.8|irix|6.5|200805162211
1467790|1467790-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.3|IP35-irix|5.8.8|irix|6.5|200805162212
1467792|1467792-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Transactional|1.0|IP35-irix|5.8.8|irix|6.5|200805162213
1467796|1467796-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Devel-CheckLib|0.5|IP35-irix|5.8.8|irix|6.5|200805162213
1467804|1467804-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Devel-CheckOS|1.43|IP35-irix|5.8.8|irix|6.5|200805162214
1467811|1467811-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|File-Find-Rule-Permissions|1.3|IP35-irix|5.8.8|irix|6.5|200805162215
1467815|1467815-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|File-Overwrite|1.0|IP35-irix|5.8.8|irix|6.5|200805162215
1467819|1467819-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Games-Dice-Advanced|1.1|IP35-irix|5.8.8|irix|6.5|200805162216
1467823|1467823-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|NestedMap|1.0|IP35-irix|5.8.8|irix|6.5|200805162216
1467841|1467841-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Net-Random|2.0|IP35-irix|5.8.8|irix|6.5|200805162219
1467846|1467846-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.581|IP35-irix|5.8.8|irix|6.5|200805162220
1467856|1467856-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone-UK-DetailedLocations|1.3|IP35-irix|5.8.8|irix|6.5|200805162221
1467869|1467869-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.11.0 patch 33824|darwin|8.10.0|200805162123
1467879|1467879-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|IP35-irix|5.8.8|irix|6.5|200805162225
1467884|1467884-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Statistics-ChiSquare|0.5|IP35-irix|5.8.8|irix|6.5|200805162225
1467885|1467885-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Statistics-SerialCorrelation|1.1|IP35-irix|5.8.8|irix|6.5|200805162226
1467893|1467893-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Sub-WrapPackages|1.2|IP35-irix|5.8.8|irix|6.5|200805162227
1467896|1467896-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Tie-Hash-Longest|1.1|IP35-irix|5.8.8|irix|6.5|200805162227
1467900|1467900-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Tie-Hash-Rank|1.0.1|IP35-irix|5.8.8|irix|6.5|200805162228
1467903|1467903-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Tie-STDOUT|1.03|IP35-irix|5.8.8|irix|6.5|200805162228
1467906|1467906-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Tie-Scalar-Decay|1.1.1|IP35-irix|5.8.8|irix|6.5|200805162229
1467908|1467908-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|IP35-irix|5.8.8|irix|6.5|200805162229
1467909|1467909-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|XML-Tiny|1.11|IP35-irix|5.8.8|irix|6.5|200805162230
1468355|1468355-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805170020
1468495|1468495-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|cygwin-thread-multi-64int|5.11.0 patch 33836|cygwin|1.5.25(0.15642)|200805162356
1468894|1468894-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805170117
1469173|1469173-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.581|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805170251
1469324|1469324-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33832|linux|2.6.22-1-k7|200805170336
1469658|1469658-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Bryar|3.0|darwin-2level|5.8.1|darwin|7.9.0|200805170606
1470250|1470250-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805170326
1470540|1470540-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200805170334
1471030|1471030-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 33831|netbsd|4.0|200805170512
1473276|1473276-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.11.0 patch 33836|cygwin|1.5.25(0.15642)|200805171845
1474419|1474419-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.3|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805172158
1474499|1474499-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805172209
1474669|1474669-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171833
1474670|1474670-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171833
1474676|1474676-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805171834
1475128|1475128-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33819|linux|2.6.22-1-k7|200805172348
1475216|1475216-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.581|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805180005
1475628|1475628-b19f-3f77-b713-d32bba55d77f|pass|200805|g.grigelionis@computer.org|Data-Compare|1.19|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200805172247
1475926|1475926-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805180241
1476902|1476902-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200805180007
1477233|1477233-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|File-Find-Rule-Permissions|1.3|darwin-2level|5.8.1|darwin|7.9.0|200805180904
1479601|1479601-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805181231
1480382|1480382-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200805182014
1480561|1480561-b19f-3f77-b713-d32bba55d77f|pass|200805|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200805190443
1480879|1480879-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805181630
1480882|1480882-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805180852
1481334|1481334-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805181746
1481748|1481748-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805182258
1482086|1482086-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33845|linux|2.6.22-1-k7|200805190039
1482184|1482184-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200805190202
1482186|1482186-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200805190202
1482187|1482187-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200805190202
1482189|1482189-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200805190202
1482190|1482190-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200805190203
1482191|1482191-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200805190203
1482193|1482193-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200805190203
1482194|1482194-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200805190204
1482196|1482196-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200805190204
1482197|1482197-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200805190204
1482284|1482284-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200805190430
1482543|1482543-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200805190422
1482545|1482545-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805190423
1482546|1482546-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805190425
1482735|1482735-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805190027
1482909|1482909-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Transactional|1.0|darwin-2level|5.8.1|darwin|7.9.0|200805190618
1482957|1482957-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Tie-STDOUT|1.03|darwin-2level|5.8.1|darwin|7.9.0|200805190640
1483249|1483249-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805190900
1483386|1483386-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200805191049
1483387|1483387-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.10.0 patch 33412|linux|2.6.22-1-k7|200805191050
1483454|1483454-b19f-3f77-b713-d32bba55d77f|pass|200805|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.4|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200805191703
1483455|1483455-b19f-3f77-b713-d32bba55d77f|pass|200805|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.4|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200805191703
1483524|1483524-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200805191018
1483536|1483536-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Hexdumper|1.4|darwin-2level|5.8.1|darwin|7.9.0|200805191021
1483579|1483579-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.4.27-3-686|200805191026
1483593|1483593-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200805191028
1483622|1483622-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200805190431
1483630|1483630-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200805190718
1483690|1483690-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200805190944
1483703|1483703-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|IP35-irix|5.8.8|irix|6.5|200805191145
1484127|1484127-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Data-Hexdumper|1.4|i686-linux|5.6.2|linux|2.4.27-3-686|200805191221
1484190|1484190-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805191236
1484331|1484331-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200805191506
1484424|1484424-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805191331
1485485|1485485-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191154
1486143|1486143-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805191312
1486218|1486218-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805191411
1486232|1486232-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805191914
1486326|1486326-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Palm-TreoPhoneCallDB|1.1|darwin-2level|5.8.1|darwin|7.9.0|200805191942
1486432|1486432-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191502
1486442|1486442-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191503
1486855|1486855-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805191602
1487259|1487259-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 33858|linux|2.6.16.38|200805192153
1487680|1487680-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.6.2|freebsd|6.1-release|200805200038
1488161|1488161-b19f-3f77-b713-d32bba55d77f|pass|200805|feldt@nhn.ou.edu|Data-Compare|1.19|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200805191428
1489311|1489311-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805200546
1489810|1489810-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.10.0|freebsd|6.1-release|200805200901
1489931|1489931-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805200241
1490380|1490380-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200805201058
1490505|1490505-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805200147
1490736|1490736-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Data-Hexdumper|1.4|x86_64-linux-gnu|5.10.0|linux|2.6.18-6-xen-amd64|200805201311
1491016|1491016-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805201248
1491047|1491047-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200752
1491605|1491605-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805200852
1492814|1492814-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805201725
1493168|1493168-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200805201705
1493397|1493397-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805201231
1493723|1493723-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33858|linux|2.6.22-1-k7|200805201734
1493871|1493871-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|alpha-linux-thread-multi|5.11.0 patch 33858|linux|2.6.18-5-alpha-generic|200805201917
1494038|1494038-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805202004
1494083|1494083-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805202115
1494478|1494478-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805201620
1494758|1494758-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200805202316
1494873|1494873-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805202306
1495109|1495109-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805202251
1495311|1495311-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805210027
1495328|1495328-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805210132
1495828|1495828-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Net-Random|2.0|darwin-2level|5.8.1|darwin|7.9.0|200805210434
1496297|1496297-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 33871|openbsd|4.1|200805210724
1497266|1497266-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200805211319
1497286|1497286-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200805211325
1497634|1497634-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Number-Phone-UK-DetailedLocations|1.3|darwin-2level|5.8.1|darwin|7.9.0|200805211454
1497883|1497883-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805210933
1497924|1497924-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805210936
1498842|1498842-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200805212052
1499156|1499156-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33887|linux|2.6.22-1-k7|200805212132
1499608|1499608-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl (DEVOGON)|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch 33261|linux|2.6.22-3-486|200805220051
1500298|1500298-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805220037
1500367|1500367-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200805220152
1500524|1500524-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805220119
1501526|1501526-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805220657
1501834|1501834-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200805220845
1502059|1502059-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200805220843
1502062|1502062-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200805220844
1502068|1502068-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200805220845
1502069|1502069-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8|linux|2.6.14|200805220845
1502073|1502073-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200805220847
1502087|1502087-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200805220851
1502088|1502088-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200805220852
1504694|1504694-b19f-3f77-b713-d32bba55d77f|pass|200805|d@0x64.nl ("DEVOGON")|Devel-CheckOS|1.43|i486-linux-gnu|5.10.0|linux|2.6.24.4|200805222319
1504918|1504918-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805222259
1505260|1505260-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.11.0 patch 33852|darwin|8.10.0|200805230048
1505550|1505550-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805230140
1505637|1505637-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805230230
1506120|1506120-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805230724
1506208|1506208-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805230759
1506315|1506315-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Games-Dice-Advanced|1.1|darwin-2level|5.8.1|darwin|7.9.0|200805230737
1506856|1506856-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231023
1506900|1506900-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200805230934
1507112|1507112-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805230941
1507301|1507301-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231205
1507645|1507645-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231316
1508364|1508364-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231302
1508500|1508500-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200805231410
1509961|1509961-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33911|linux|2.6.22-1-k7|200805231127
1510117|1510117-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200805231809
1510229|1510229-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200805231850
1510416|1510416-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805231459
1510860|1510860-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Sub-WrapPackages|1.2|darwin-2level|5.8.1|darwin|7.9.0|200805232145
1511003|1511003-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200805232101
1512245|1512245-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805240206
1512408|1512408-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.24(0.15642)|200805240348
1513036|1513036-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805240848
1513111|1513111-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.10.0|freebsd|6.1-release|200805240835
1513937|1513937-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241100
1515510|1515510-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805241515
1515514|1515514-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241615
1515633|1515633-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241635
1515743|1515743-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241652
1516065|1516065-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805241728
1516784|1516784-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805241904
1516931|1516931-b19f-3f77-b713-d32bba55d77f|fail|200805|srezic@cpan.org|Bryar|3.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200805241940
1517129|1517129-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200805241305
1517199|1517199-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.581|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805241040
1517200|1517200-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33916|linux|2.6.22-1-k7|200805241039
1517791|1517791-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805241538
1517792|1517792-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805241538
1518444|1518444-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200805250045
1519128|1519128-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|0.9|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805250431
1519161|1519161-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805250425
1519188|1519188-b19f-3f77-b713-d32bba55d77f|fail|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805250422
1520092|1520092-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200805251403
1520295|1520295-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805251044
1520358|1520358-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200805251605
1520824|1520824-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Transactional|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200805251949
1520825|1520825-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.10.0|freebsd|6.1-release|200805251949
1521312|1521312-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805252129
1521493|1521493-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805252213
1521967|1521967-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805252315
1522401|1522401-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805260053
1522787|1522787-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200805260024
1523008|1523008-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805260301
1523621|1523621-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch 33919|linux|2.6.22-1-k7|200805260529
1523732|1523732-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0 patch 33921|linux|2.4.26|200805260503
1525227|1525227-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 33921|darwin|8.10.0|200805261723
1525775|1525775-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33921|linux|2.4.26|200805262215
1526175|1526175-b19f-3f77-b713-d32bba55d77f|unknown|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805262000
1526260|1526260-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Data-Compare|1.19|i686-linux|5.8.8|linux|2.4.27-2-386|200805270227
1527261|1527261-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805270739
1527373|1527373-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805270839
1528611|1528611-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805271252
1528936|1528936-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805271348
1529854|1529854-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805271519
1529942|1529942-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckOS|1.43|darwin-2level|5.8.2|darwin|7.9.0|200805271516
1531701|1531701-b19f-3f77-b713-d32bba55d77f|unknown|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805271600
1531753|1531753-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805271604
1531855|1531855-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805271618
1532012|1532012-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33935|linux|2.6.22-1-k7|200805272231
1533859|1533859-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Hexdumper|1.4|darwin-2level|5.8.2|darwin|7.9.0|200805280504
1534264|1534264-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200805280623
1534518|1534518-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.19|darwin-2level|5.8.2|darwin|7.9.0|200805280702
1534830|1534830-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200805280835
1534833|1534833-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200805280836
1534837|1534837-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200805280837
1534968|1534968-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.10.0 patch 33443|linux|2.6.22-1-k7|200805281011
1534970|1534970-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.10.0 patch 33628|linux|2.6.22-1-k7|200805281011
1534971|1534971-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.581|darwin-thread-multi-64int-2level|5.10.0 patch 33921|darwin|8.10.0|200805280911
1534974|1534974-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200805281011
1534976|1534976-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi|5.8.8 patch 33430|linux|2.6.22-1-k7|200805281012
1534978|1534978-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.8.8 patch 33243|linux|2.6.22-1-k7|200805281012
1534979|1534979-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200805281013
1534981|1534981-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-64int|5.8.8|linux|2.6.14|200805281013
1534982|1534982-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200805281013
1534986|1534986-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200805281014
1534989|1534989-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200805281015
1535216|1535216-b19f-3f77-b713-d32bba55d77f|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone|1.6|sun4-solaris|5.10.0|solaris|2.9|200805281141
1535363|1535363-b19f-3f77-b713-d32bba55d77f|pass|200805|imacat@mail.imacat.idv.tw|Number-Phone|1.6|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200805281807
1535406|1535406-b19f-3f77-b713-d32bba55d77f|pass|200805|imacat@mail.imacat.idv.tw|Number-Phone|1.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200805281814
1535658|1535658-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200805281052
1535682|1535682-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200805281157
1535806|1535806-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805280721
1536198|1536198-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Number-Phone|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200805281549
1536545|1536545-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i686-linux|5.6.2|linux|2.4.27-3-686|200805281657
1537012|1537012-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.10.0|freebsd|6.1-release|200805281511
1537078|1537078-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 33942|linux|2.4.26|200805281715
1537130|1537130-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|IP35-irix|5.8.8|irix|6.5|200805281838
1537263|1537263-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200805280739
1537595|1537595-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281352
1537697|1537697-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805281949
1537706|1537706-b19f-3f77-b713-d32bba55d77f|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.4|sun4-solaris|5.10.0|solaris|2.9|200805282003
1537736|1537736-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Number-Phone|1.6|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200805281901
1537752|1537752-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i686-linux|5.8.8|linux|2.4.27-3-686|200805282041
1537844|1537844-b19f-3f77-b713-d32bba55d77f|pass|200805|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.5.5|freebsd|6.1-release|200805281852
1537953|1537953-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200805281321
1538003|1538003-b19f-3f77-b713-d32bba55d77f|pass|200805|david@cantrell.org.uk|Number-Phone|1.6|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200805282101
1538119|1538119-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281438
1538401|1538401-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805282009
1539141|1539141-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281600
1539258|1539258-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281618
1539381|1539381-b19f-3f77-b713-d32bba55d77f|pass|200805|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.19|sun4-solaris|5.10.0|solaris|2.9|200805282235
1540914|1540914-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805281955
1541207|1541207-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290225
1541712|1541712-b19f-3f77-b713-d32bba55d77f|pass|200805|stro@cpan.org|Number-Phone|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200805290428
1541900|1541900-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290306
1542288|1542288-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290451
1542404|1542404-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33942|linux|2.4.26|200805290404
1542411|1542411-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805290305
1542913|1542913-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33939|linux|2.6.22-1-k7|200805290508
1543246|1543246-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Devel-CheckOS|1.43|darwin-2level|5.8.3|darwin|7.9.0|200805290544
1543714|1543714-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290151
1543716|1543716-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290151
1543723|1543723-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290152
1544485|1544485-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805290403
1545530|1545530-b19f-3f77-b713-d32bba55d77f|pass|200805|frank.wiegand@gmail.com ("Frank Wiegand")|Number-Phone|1.581|i686-linux|5.11.0 patch 33939|linux|2.6.24-17-generic|200805291306
1546019|1546019-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Number-Phone|1.6|darwin-2level|5.8.3|darwin|7.9.0|200805291421
1546378|1546378-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291059
1546701|1546701-b19f-3f77-b713-d32bba55d77f|pass|200805|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200805300056
1546823|1546823-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291223
1547548|1547548-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291502
1547613|1547613-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Number-Phone|1.6|darwin-2level|5.8.2|darwin|7.9.0|200805292012
1547844|1547844-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.6|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200805292232
1547908|1547908-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291631
1547923|1547923-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291632
1548260|1548260-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805291807
1549334|1549334-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300138
1549677|1549677-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300301
1550907|1550907-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300326
1551105|1551105-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805301000
1551379|1551379-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300436
1551554|1551554-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805301024
1552861|1552861-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805300915
1553080|1553080-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805301002
1553233|1553233-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Hexdumper|1.4|darwin-2level|5.8.3|darwin|7.9.0|200805301529
1553452|1553452-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805301607
1553827|1553827-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 33947|linux|2.4.26|200805301707
1554311|1554311-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|Data-Compare|1.19|darwin-2level|5.8.3|darwin|7.9.0|200805301832
1555790|1555790-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200805302248
1556369|1556369-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310153
1556382|1556382-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310149
1557706|1557706-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310526
1558052|1558052-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 33947|linux|2.4.26|200805310524
1558204|1558204-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33949|linux|2.6.22-1-k7|200805310629
1558565|1558565-b19f-3f77-b713-d32bba55d77f|pass|200805|jj@jonallen.info ("JJ")|XML-Tiny|1.11|darwin-2level|5.8.2|darwin|7.9.0|200805310703
1559072|1559072-b19f-3f77-b713-d32bba55d77f|na|200805|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200805310424
1559315|1559315-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311047
1559566|1559566-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311146
1559768|1559768-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311229
1560142|1560142-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311240
1560523|1560523-b19f-3f77-b713-d32bba55d77f|fail|200805|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805310810
1560668|1560668-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805310821
1561580|1561580-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 33947|darwin|8.10.0|200805311505
1561739|1561739-b19f-3f77-b713-d32bba55d77f|pass|200805|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200805311427
1563597|1563597-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311346
1563631|1563631-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805311949
1563925|1563925-b19f-3f77-b713-d32bba55d77f|pass|200805|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200805312016
1564012|1564012-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311430
1564013|1564013-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311431
1565202|1565202-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311633
1565287|1565287-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200805311647
1566031|1566031-b19f-3f77-b713-d32bba55d77f|pass|200805|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200805311827
1566359|1566359-b19f-3f77-b713-d32bba55d77f|unknown|200805|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200805311901
1567194|1567194-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Data-Compare|1.19|i386-linux|5.8.8|linux|2.6.18-53.el5|200806010053
1567352|1567352-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010110
1567593|1567593-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010135
1567652|1567652-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200806010141
1567710|1567710-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200806010147
1567753|1567753-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 33823|linux|2.6.24-16-generic|200806010153
1569849|1569849-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.10.0 patch 33947|cygwin|1.5.25(0.15642)|200806011153
1570315|1570315-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806010845
1570728|1570728-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806010925
1570773|1570773-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806010933
1571548|1571548-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011106
1571625|1571625-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200806011615
1571654|1571654-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011119
1572524|1572524-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806011401
1572574|1572574-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806011421
1574018|1574018-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806011810
1574265|1574265-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011854
1574269|1574269-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011854
1574295|1574295-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806011857
1574313|1574313-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806020000
1575798|1575798-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806020329
1575812|1575812-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020331
1575813|1575813-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020331
1575819|1575819-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020332
1576599|1576599-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020112
1578359|1578359-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806021115
1578579|1578579-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806021128
1578637|1578637-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020544
1578699|1578699-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200806021049
1578853|1578853-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806020604
1578906|1578906-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806021204
1579398|1579398-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806020705
1579434|1579434-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806020709
1580012|1580012-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806021223
1581408|1581408-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021328
1581689|1581689-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200806021910
1581836|1581836-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|XML-Tiny|1.11|darwin-2level|5.8.3|darwin|7.9.0|200806021935
1581849|1581849-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021441
1581858|1581858-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021442
1582149|1582149-b19f-3f77-b713-d32bba55d77f|pass|200806|flemming@ipk-gatersleben.de|Data-Compare|1.19|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200806021423
1582419|1582419-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806022203
1582436|1582436-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021604
1582778|1582778-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021631
1583949|1583949-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021819
1583985|1583985-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021821
1584228|1584228-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806030046
1584692|1584692-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200806030026
1584702|1584702-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806021928
1584989|1584989-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806021949
1585271|1585271-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 33986|linux|2.6.22-1-k7|200806030216
1585349|1585349-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030023
1587211|1587211-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030010
1587592|1587592-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030118
1589241|1589241-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030433
1589570|1589570-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806030510
1590004|1590004-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030604
1590985|1590985-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806030830
1591364|1591364-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Data-Hexdumper|1.4|i386-linux|5.8.8|linux|2.6.18-53.el5|200806030838
1591564|1591564-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200806031308
1592681|1592681-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200806031827
1594222|1594222-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031907
1594268|1594268-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806031916
1596106|1596106-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806040506
1596136|1596136-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040103
1596418|1596418-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040139
1596420|1596420-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040140
1597040|1597040-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040324
1598207|1598207-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040538
1599062|1599062-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806040715
1599765|1599765-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040824
1599815|1599815-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040829
1599859|1599859-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.10.0|linux|2.6.24-16-generic|200806040835
1600101|1600101-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806040852
1602119|1602119-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806041622
1602224|1602224-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806041822
1602252|1602252-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806041824
1602709|1602709-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041318
1602894|1602894-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806041850
1603182|1603182-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041406
1604234|1604234-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806041543
1604457|1604457-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041611
1604702|1604702-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806041631
1604828|1604828-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806041642
1605376|1605376-b19f-3f77-b713-d32bba55d77f|fail|200806|jj@jonallen.info ("JJ")|CPAN-FindDependencies|2.0|darwin-2level|5.8.1|darwin|7.9.0|200806042232
1606004|1606004-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806050018
1606511|1606511-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806050051
1606666|1606666-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Number-Phone|1.6|i386-linux|5.8.8|linux|2.6.18-53.el5|200806041827
1607012|1607012-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806050157
1607495|1607495-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050045
1609203|1609203-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|sun4-solaris|5.10.0|solaris|2.9|200806050719
1609209|1609209-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|0.9|sun4-solaris|5.10.0|solaris|2.9|200806050720
1609274|1609274-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckLib|0.5|sun4-solaris|5.10.0|solaris|2.9|200806050731
1609546|1609546-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050239
1609548|1609548-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050239
1609553|1609553-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050240
1610500|1610500-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806050511
1610872|1610872-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051117
1612263|1612263-b19f-3f77-b713-d32bba55d77f|pass|200806|rurban@x-ray.at (Reini Urban)|Data-Compare|1.19|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.25(0.15642)|200806051131
1612459|1612459-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806051454
1613348|1613348-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051119
1613350|1613350-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051119
1613481|1613481-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051131
1614296|1614296-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051253
1615657|1615657-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051522
1616492|1616492-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051650
1616507|1616507-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051652
1616957|1616957-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051741
1617027|1617027-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806051749
1617452|1617452-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|XML-Tiny|1.11|IP35-irix-64int|5.8.8|irix|6.5|200806060027
1617506|1617506-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051831
1617508|1617508-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806051832
1617612|1617612-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|IP35-irix-64int|5.8.8|irix|6.5|200806060044
1617620|1617620-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|0.9|IP35-irix-64int|5.8.8|irix|6.5|200806060044
1618807|1618807-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060122
1619151|1619151-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806060405
1619228|1619228-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806060216
1619306|1619306-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060225
1620600|1620600-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806060107
1622038|1622038-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.4.27-2-386|200806060117
1622052|1622052-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|CPU-Emulator-Z80|0.9|i686-linux|5.8.8|linux|2.4.27-2-386|200806060118
1622201|1622201-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061127
1623332|1623332-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806060916
1623843|1623843-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806061504
1624056|1624056-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806061023
1624257|1624257-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806061039
1624325|1624325-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806061044
1624400|1624400-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.8 patch 33935|linux|2.6.24-16-generic|200806061052
1625162|1625162-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806061703
1626149|1626149-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806061413
1626487|1626487-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806061453
1627601|1627601-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806062213
1628001|1628001-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806061748
1629230|1629230-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|sun4-solaris|5.10.0|solaris|2.9|200806070226
1629294|1629294-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070036
1629367|1629367-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070044
1629841|1629841-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070146
1630504|1630504-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070320
1631286|1631286-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070101
1631562|1631562-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070138
1631563|1631563-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070138
1632128|1632128-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070307
1632247|1632247-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070335
1632360|1632360-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806070354
1633163|1633163-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070545
1634343|1634343-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070823
1634390|1634390-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070827
1634430|1634430-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200806070833
1635103|1635103-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Compare|1.19|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071437
1635106|1635106-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071437
1635216|1635216-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071445
1635218|1635218-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071445
1635354|1635354-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200806071455
1635515|1635515-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Number-Phone|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806071505
1635990|1635990-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Number-Phone|1.6|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806071524
1636361|1636361-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806071453
1636805|1636805-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.4.27-2-386|200806071730
1637399|1637399-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071448
1637953|1637953-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071623
1638005|1638005-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Transactional|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200806072033
1638178|1638178-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806071700
1639376|1639376-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080352
1639451|1639451-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080007
1640367|1640367-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Devel-CheckLib|0.5|darwin-2level|5.8.2|darwin|7.9.0|200806080749
1641848|1641848-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080705
1641850|1641850-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080705
1641862|1641862-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806080707
1642539|1642539-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080853
1642540|1642540-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080854
1642550|1642550-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806080855
1643221|1643221-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Memory|1.1001|darwin-2level|5.8.3|darwin|7.9.0|200806081536
1643232|1643232-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Z80|0.9|darwin-2level|5.8.3|darwin|7.9.0|200806081537
1643318|1643318-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Devel-CheckLib|0.5|darwin-2level|5.8.3|darwin|7.9.0|200806081554
1643424|1643424-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806081116
1644483|1644483-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806081431
1645296|1645296-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806081757
1646787|1646787-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806090359
1646850|1646850-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0 patch 33976|darwin|8.10.0|200806090948
1647408|1647408-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Memory|1.1001|darwin-2level|5.8.2|darwin|7.9.0|200806091145
1647420|1647420-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806091147
1647683|1647683-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806090759
1648404|1648404-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806090946
1648608|1648608-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200806091520
1649407|1649407-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091208
1649840|1649840-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806091325
1650133|1650133-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806091233
1650326|1650326-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091553
1650336|1650336-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091554
1651712|1651712-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806091940
1652060|1652060-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100044
1653013|1653013-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806100317
1653402|1653402-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100019
1653717|1653717-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100117
1654962|1654962-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100426
1655173|1655173-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806100502
1655194|1655194-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806100505
1655216|1655216-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806100508
1655523|1655523-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|File-Overwrite|1.0|darwin-2level|5.8.1|darwin|7.9.0|200806101102
1655746|1655746-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.2|darwin|7.9.0|200806101129
1657381|1657381-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101014
1657448|1657448-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101021
1658997|1658997-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806100709
1659175|1659175-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101422
1659193|1659193-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPAN-FindDependencies|2.0|sun4-solaris|5.10.0|solaris|2.9|200806102025
1659368|1659368-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|alpha-linux-thread-multi|5.11.0 patch 34031|linux|2.6.18-5-alpha-generic|200806101942
1659428|1659428-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101451
1659430|1659430-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101451
1660151|1660151-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101620
1660908|1660908-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806101750
1661054|1661054-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806101804
1661124|1661124-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-64int|5.11.0 patch 34005|freebsd|7.0-release|200806102322
1662159|1662159-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|XML-DoubleEncodedEntities|1.0|darwin-2level|5.8.3|darwin|7.9.0|200806110209
1662363|1662363-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110130
1662410|1662410-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110134
1662449|1662449-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110138
1664439|1664439-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806110439
1664738|1664738-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110545
1665737|1665737-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110746
1665964|1665964-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110814
1666351|1666351-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110922
1666368|1666368-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806111417
1666437|1666437-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806110933
1667846|1667846-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806111412
1668478|1668478-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806111638
1669283|1669283-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.18-8.el5|200806120142
1669424|1669424-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806120259
1669539|1669539-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120117
1669540|1669540-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|0.9|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120117
1669547|1669547-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120118
1669897|1669897-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806120423
1670596|1670596-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120003
1671876|1671876-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806120241
1672276|1672276-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806120933
1672311|1672311-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120336
1672452|1672452-b19f-3f77-b713-d32bba55d77f|fail|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Bryar|3.0|sun4-solaris|5.10.0|solaris|2.9|200806120955
1672725|1672725-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120443
1673498|1673498-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120646
1673962|1673962-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806120744
1674081|1674081-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120801
1674093|1674093-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120802
1674468|1674468-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806120851
1675737|1675737-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121133
1676188|1676188-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121226
1676852|1676852-b19f-3f77-b713-d32bba55d77f|pass|200806|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.19|sun4-solaris|5.10.0|solaris|2.8|200806121006
1677239|1677239-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806121957
1677784|1677784-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806122038
1678451|1678451-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121559
1679107|1679107-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806121659
1680250|1680250-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806121900
1680311|1680311-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806121912
1680879|1680879-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130037
1681135|1681135-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130111
1682379|1682379-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34037|linux|2.6.22-1-k7|200806130553
1684521|1684521-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130829
1684598|1684598-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806130837
1685330|1685330-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806130950
1686169|1686169-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131105
1686172|1686172-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131105
1686674|1686674-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131150
1686957|1686957-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131217
1686959|1686959-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131218
1687989|1687989-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131500
1688343|1688343-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131528
1688392|1688392-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132133
1688860|1688860-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132202
1689558|1689558-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806132254
1689563|1689563-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806132255
1689568|1689568-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806132255
1689573|1689573-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Memory|1.1001|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806132256
1689579|1689579-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806132257
1689623|1689623-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806132300
1689644|1689644-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806132302
1689666|1689666-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806132304
1689729|1689729-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806132257
1689733|1689733-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200806132259
1689826|1689826-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131713
1690007|1690007-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806131927
1690730|1690730-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132226
1690743|1690743-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806132221
1690801|1690801-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806131827
1691351|1691351-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131909
1691414|1691414-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131913
1691484|1691484-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-16-generic|200806131917
1691805|1691805-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806140110
1693311|1693311-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|CPU-Emulator-Z80|1.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200806140324
1693934|1693934-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806140325
1693991|1693991-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806140331
1694046|1694046-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 33819|linux|2.6.24-16-generic|200806140339
1694082|1694082-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806140343
1694324|1694324-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140001
1694392|1694392-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34034|linux|2.6.22-1-k7|200806140606
1694436|1694436-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806140510
1694616|1694616-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140025
1696842|1696842-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200806141100
1696860|1696860-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806141107
1696874|1696874-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806141101
1696950|1696950-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806141132
1696955|1696955-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806140533
1696965|1696965-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806141035
1697410|1697410-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140818
1697529|1697529-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140837
1697947|1697947-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140939
1698033|1698033-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806140950
1698059|1698059-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|CPU-Emulator-Z80|1.0|darwin-2level|5.8.3|darwin|7.9.0|200806141453
1698529|1698529-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806142300
1698538|1698538-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806142301
1699335|1699335-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806141722
1699342|1699342-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806141723
1699778|1699778-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|XML-Tiny|1.11|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806142055
1700297|1700297-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806141629
1700782|1700782-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806141752
1701090|1701090-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806150036
1702144|1702144-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806150218
1702831|1702831-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151122
1702859|1702859-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151142
1702893|1702893-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151145
1703095|1703095-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200806151047
1703430|1703430-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806151344
1703470|1703470-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806151250
1703635|1703635-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|sun4-solaris|5.10.0|solaris|2.9|200806151434
1704329|1704329-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151039
1704932|1704932-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806151653
1704995|1704995-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806151702
1705126|1705126-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806151716
1705195|1705195-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806151722
1705271|1705271-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806151727
1705279|1705279-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806151230
1705323|1705323-b19f-3f77-b713-d32bba55d77f|fail|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806151733
1706395|1706395-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806152106
1706425|1706425-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34053|linux|2.6.22-1-k7|200806152058
1706452|1706452-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.11.0 patch 34053|linux|2.6.21.5-smp|200806151921
1707633|1707633-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806160103
1707653|1707653-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.0|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160101
1707663|1707663-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160102
1707973|1707973-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.11.0 patch 34053|linux|2.6.24-16-generic|200806160144
1708315|1708315-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|sun4-solaris|5.10.0|solaris|2.9|200806160502
1708637|1708637-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0 patch 34034|darwin|8.10.0|200806160805
1708672|1708672-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806160903
1708673|1708673-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200806160905
1709088|1709088-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|CPU-Emulator-Z80|1.0|i386-linux|5.8.8|linux|2.6.18-53.el5|200806160648
1709801|1709801-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161222
1709934|1709934-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200806161651
1710635|1710635-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161430
1710712|1710712-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161446
1711100|1711100-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806162138
1711102|1711102-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806162139
1711104|1711104-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806162139
1711107|1711107-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.8.8|linux|2.6.14|200806162139
1711109|1711109-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806162139
1711111|1711111-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806162140
1711114|1711114-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806162140
1711130|1711130-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161542
1711213|1711213-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806161554
1711344|1711344-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Transactional|1.02|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806162139
1711788|1711788-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Number-Phone|1.6|darwin-2level|5.8.1|darwin|7.9.0|200806162225
1712009|1712009-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806162253
1712014|1712014-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200806162255
1712052|1712052-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806162257
1712140|1712140-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200806162312
1712173|1712173-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200806162314
1712180|1712180-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200806162316
1713291|1713291-b19f-3f77-b713-d32bba55d77f|pass|200806|icerider70@gmail.com ("ICERIDER")|Data-Transactional|1.02|i386-linux|5.8.8|linux|2.6.18-53.el5|200806170216
1713400|1713400-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170325
1713550|1713550-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170343
1713618|1713618-b19f-3f77-b713-d32bba55d77f|pass|200806|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200806171259
1713683|1713683-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170407
1713736|1713736-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170019
1713937|1713937-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806170606
1713951|1713951-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806170608
1714719|1714719-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170416
1714825|1714825-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200806170905
1714858|1714858-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200806171643
1714961|1714961-b19f-3f77-b713-d32bba55d77f|pass|200806|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200806171700
1714995|1714995-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Transactional|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806171208
1714999|1714999-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200806171208
1715113|1715113-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170534
1715183|1715183-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i686-linux|5.8.8|linux|2.4.27-3-686|200806171047
1715190|1715190-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i686-linux|5.6.2|linux|2.4.27-3-686|200806171048
1715208|1715208-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i686-linux|5.8.8|linux|2.4.27-3-686|200806171047
1715210|1715210-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i686-linux|5.6.2|linux|2.4.27-3-686|200806171048
1715252|1715252-b19f-3f77-b713-d32bba55d77f|pass|200806|jj@jonallen.info ("JJ")|Data-Transactional|1.02|darwin-2level|5.8.2|darwin|7.9.0|200806171056
1715318|1715318-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806171105
1715320|1715320-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806171105
1715342|1715342-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806170509
1715353|1715353-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806170510
1715365|1715365-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806171106
1715367|1715367-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806171107
1715383|1715383-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Transactional|1.02|sun4-solaris|5.10.0|solaris|2.9|200806171214
1715448|1715448-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806171059
1715465|1715465-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806171101
1715871|1715871-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170756
1716180|1716180-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Compare|1.19|IP35-irix-64int|5.8.8|irix|6.5|200806171455
1716184|1716184-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|IP35-irix-64int|5.8.8|irix|6.5|200806171455
1716186|1716186-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|IP35-irix-64int|5.8.8|irix|6.5|200806171455
1716276|1716276-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806170912
1716633|1716633-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806171400
1716636|1716636-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Data-Transactional|1.02|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806171400
1716688|1716688-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171006
1716761|1716761-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806170909
1716770|1716770-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806170910
1716945|1716945-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806171504
1717130|1717130-b19f-3f77-b713-d32bba55d77f|pass|200806|robertl@apnic.net ("Robert Loomans")|CPAN-FindDependencies|2.0|darwin-2level|5.8.8|darwin|9.2.2|200806171530
1717223|1717223-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-STDOUT|1.03|sun4-solaris|5.10.0|solaris|2.9|200806171701
1717464|1717464-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806171732
1718386|1718386-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171319
1718665|1718665-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806171931
1719000|1719000-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806171958
1719112|1719112-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171420
1719207|1719207-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806172032
1719292|1719292-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806171946
1719316|1719316-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806171948
1719348|1719348-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806171950
1719382|1719382-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806171952
1719408|1719408-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806171954
1719445|1719445-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806171956
1719472|1719472-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806171958
1719487|1719487-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806172000
1719502|1719502-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806172001
1719510|1719510-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.6.2|freebsd|6.1-release|200806172058
1719534|1719534-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806172004
1719991|1719991-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200806172058
1720006|1720006-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200806172059
1720028|1720028-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200806172101
1720046|1720046-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806172202
1720049|1720049-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200806172103
1720057|1720057-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200806172104
1720065|1720065-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200806172105
1720087|1720087-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200806172107
1720104|1720104-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200806172108
1720126|1720126-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200806172110
1720153|1720153-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200806172111
1720412|1720412-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806172156
1720585|1720585-b19f-3f77-b713-d32bba55d77f|na|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.5.5|freebsd|6.1-release|200806172255
1720855|1720855-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|Devel-CheckOS|1.43|IP35-irix-64int|5.8.8|irix|6.5|200806172325
1721186|1721186-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806180001
1721360|1721360-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171817
1721943|1721943-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806172057
1722051|1722051-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806180106
1722175|1722175-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806171926
1722205|1722205-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.10.0|freebsd|6.1-release|200806180128
1722423|1722423-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200806180029
1722727|1722727-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806180144
1722737|1722737-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200806180244
1723607|1723607-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180258
1723848|1723848-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806180539
1723888|1723888-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180348
1725628|1725628-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806180837
1726053|1726053-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806180944
1726116|1726116-b19f-3f77-b713-d32bba55d77f|na|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.5.5|freebsd|6.1-release|200806180953
1726167|1726167-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806180942
1726246|1726246-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34066|linux|2.6.22-1-k7|200806180959
1726885|1726885-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180509
1727011|1727011-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180517
1727998|1727998-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200806181118
1728032|1728032-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200806180257
1728632|1728632-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.4.26|200806181255
1729448|1729448-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180919
1729848|1729848-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180951
1729855|1729855-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806180950
1730104|1730104-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.6.2|freebsd|6.1-release|200806181532
1730602|1730602-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.4.27-2-386|200806181452
1730977|1730977-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181129
1731015|1731015-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|File-Overwrite|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200806181535
1732000|1732000-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|sun4-solaris|5.10.0|solaris|2.9|200806181923
1732178|1732178-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181340
1733402|1733402-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181558
1733445|1733445-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181602
1733518|1733518-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806181606
1735264|1735264-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200806190000
1735338|1735338-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806181844
1735339|1735339-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806181844
1736559|1736559-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200806190450
1736819|1736819-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190232
1737043|1737043-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190418
1737055|1737055-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190419
1737077|1737077-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190421
1737080|1737080-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190421
1737088|1737088-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806190422
1737193|1737193-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190352
1737404|1737404-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190037
1737459|1737459-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190048
1737510|1737510-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190053
1737535|1737535-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190058
1738004|1738004-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190237
1738286|1738286-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806190841
1739632|1739632-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806190843
1739702|1739702-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Number-Phone|1.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806191453
1740244|1740244-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191013
1740729|1740729-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806191653
1741329|1741329-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 34073|netbsd|4.0|200806191749
1741735|1741735-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191338
1741954|1741954-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806192004
1742423|1742423-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192013
1742430|1742430-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192014
1742448|1742448-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192017
1742449|1742449-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192017
1742455|1742455-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806192019
1742894|1742894-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191719
1743652|1743652-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806191852
1744687|1744687-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.6.2|freebsd|6.1-release|200806200318
1744728|1744728-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200133
1745499|1745499-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200427
1745508|1745508-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200428
1745580|1745580-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200338
1745643|1745643-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200444
1745655|1745655-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806200446
1745714|1745714-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200355
1746263|1746263-b19f-3f77-b713-d32bba55d77f|na|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200113
1746585|1746585-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200154
1747063|1747063-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200806200848
1747364|1747364-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806200933
1747482|1747482-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.10.0|freebsd|6.1-release|200806200954
1748185|1748185-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806201012
1748835|1748835-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Net-Random|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200806201319
1749601|1749601-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806200926
1749788|1749788-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201454
1749808|1749808-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201455
1749834|1749834-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201500
1749849|1749849-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200806201502
1749881|1749881-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201013
1750206|1750206-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201137
1750249|1750249-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200806201605
1750719|1750719-b19f-3f77-b713-d32bba55d77f|na|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806201458
1751000|1751000-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0 patch 34065|linux|2.4.26|200806202127
1752441|1752441-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200806210053
1752510|1752510-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210004
1752784|1752784-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210050
1753897|1753897-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210326
1753972|1753972-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210338
1754219|1754219-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210029
1755355|1755355-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210532
1755663|1755663-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806210653
1757045|1757045-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211146
1757339|1757339-b19f-3f77-b713-d32bba55d77f|na|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211228
1757376|1757376-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211233
1757418|1757418-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806211240
1758182|1758182-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806211908
1758185|1758185-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806211908
1758189|1758189-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806211910
1759401|1759401-b19f-3f77-b713-d32bba55d77f|na|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220030
1759456|1759456-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220039
1759671|1759671-b19f-3f77-b713-d32bba55d77f|pass|200806|rjbs@cpan.org|Data-Compare|1.19|darwin-2level|5.10.0|darwin|9.1.0|200806220149
1759781|1759781-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806220346
1759782|1759782-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806220347
1759787|1759787-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806220348
1760117|1760117-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806220459
1760119|1760119-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806220459
1760130|1760130-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806220500
1761272|1761272-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220437
1761507|1761507-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220540
1761508|1761508-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220540
1762012|1762012-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806220748
1762046|1762046-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34075|openbsd|4.3|200806221116
1762754|1762754-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221051
1763690|1763690-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.18-5-686|200806221802
1764682|1764682-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221424
1765012|1765012-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221441
1765096|1765096-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221446
1765124|1765124-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221448
1765127|1765127-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221448
1765208|1765208-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221453
1765564|1765564-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806222048
1765798|1765798-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.22-14-generic|200806222033
1766324|1766324-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221605
1766480|1766480-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Transactional|1.02|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200806222113
1767765|1767765-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221755
1767873|1767873-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.4.27-2-386|200806230109
1768010|1768010-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Compare|1.19|i686-linux|5.10.0|linux|2.4.27-2-386|200806230128
1768606|1768606-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221943
1768644|1768644-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221946
1768673|1768673-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200806221950
1769631|1769631-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34076|solaris|2.10|200806230341
1770114|1770114-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806230642
1770299|1770299-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806230724
1770586|1770586-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230204
1770609|1770609-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230207
1770610|1770610-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230207
1770857|1770857-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230233
1770858|1770858-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230233
1770886|1770886-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34074|linux|2.6.22-1-k7|200806230728
1770959|1770959-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230246
1771753|1771753-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230450
1772060|1772060-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806230550
1772065|1772065-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200806231141
1772583|1772583-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Devel-CheckLib|0.5|i486-linux-gnu|5.8.8|linux|2.6.22.10|200806231259
1774401|1774401-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231217
1775143|1775143-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231356
1775988|1775988-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806232121
1775991|1775991-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806232121
1776015|1776015-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200806232123
1776860|1776860-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806231816
1777468|1777468-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200806240003
1777470|1777470-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200806240005
1777653|1777653-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806240214
1777657|1777657-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806240214
1777673|1777673-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806240116
1777675|1777675-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.01|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806240116
1777677|1777677-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200806240217
1777685|1777685-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Transactional|1.02|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806240118
1777743|1777743-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240127
1778008|1778008-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200806240417
1778545|1778545-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240331
1779184|1779184-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240047
1779573|1779573-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240137
1780615|1780615-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240409
1780753|1780753-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240429
1781189|1781189-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240524
1782392|1782392-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240811
1782638|1782638-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806240847
1782872|1782872-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806240926
1783244|1783244-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806241025
1783498|1783498-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806241059
1785150|1785150-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806241944
1785597|1785597-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250244
1786349|1786349-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806250134
1786732|1786732-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806250710
1786739|1786739-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Net-Random|2.0|sun4-solaris|5.10.0|solaris|2.9|200806250908
1786870|1786870-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34080|linux|2.6.16.38|200806250724
1787188|1787188-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806250740
1787558|1787558-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806250647
1787890|1787890-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806250520
1788301|1788301-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250554
1788304|1788304-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250554
1789082|1789082-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 34065|darwin|8.10.0|200806251123
1789201|1789201-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250741
1790185|1790185-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806250949
1790585|1790585-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806251642
1790586|1790586-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806251642
1790589|1790589-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806251642
1790595|1790595-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.8.8|linux|2.6.14|200806251642
1790599|1790599-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806251643
1790852|1790852-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806251642
1790854|1790854-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806251643
1790858|1790858-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806251643
1791331|1791331-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806251204
1791378|1791378-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806251207
1791409|1791409-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0 patch 34034|linux|2.6.24-16-generic|200806251211
1793688|1793688-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806252241
1793705|1793705-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34085|linux|2.6.22-1-k7|200806252246
1793794|1793794-b19f-3f77-b713-d32bba55d77f|fail|200806|srezic@cpan.org|DBIx-Class-SingletonRows|0.1|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806252323
1795338|1795338-b19f-3f77-b713-d32bba55d77f|pass|200806|danl@metrex.net|Data-Compare|1.19|i586-linux-thread-multi|5.10.0|linux|2.6.25|200806260023
1795508|1795508-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806260948
1795580|1795580-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806260400
1795706|1795706-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261019
1796391|1796391-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Data-Compare|1.19|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200806260455
1796581|1796581-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd|5.11.0 patch 34085|openbsd|4.1|200806260621
1796835|1796835-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806260800
1797399|1797399-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261514
1797468|1797468-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261456
1797741|1797741-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261530
1798310|1798310-b19f-3f77-b713-d32bba55d77f|fail|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200806261650
1798878|1798878-b19f-3f77-b713-d32bba55d77f|fail|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200806261706
1799261|1799261-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200806261934
1799264|1799264-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200806261934
1799266|1799266-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200806261934
1799293|1799293-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34088|linux|2.6.22-1-k7|200806261937
1799302|1799302-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200806261938
1799396|1799396-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|i686-linux|5.8.8|linux|2.4.27-3-686|200806261703
1799427|1799427-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200806261935
1799462|1799462-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200806261936
1799463|1799463-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200806261937
1799469|1799469-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|DBIx-Class-SingletonRows|0.11|i686-linux-64int|5.8.8|linux|2.6.14|200806261936
1800691|1800691-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806261801
1801186|1801186-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200806261850
1801665|1801665-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270028
1802752|1802752-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|DBIx-Class-SingletonRows|0.1|sun4-solaris|5.10.0|solaris|2.9|200806270638
1802983|1802983-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270136
1802984|1802984-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270136
1803070|1803070-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|darwin-2level|5.8.8|darwin|8.10.1|200806270744
1803075|1803075-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|darwin-2level|5.8.8|darwin|8.10.1|200806270744
1803651|1803651-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270316
1803652|1803652-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270316
1803824|1803824-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200806270355
1804043|1804043-b19f-3f77-b713-d32bba55d77f|pass|200806|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200806270937
1804246|1804246-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270522
1804400|1804400-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|DBIx-Class-SingletonRows|0.11|sun4-solaris|5.10.0|solaris|2.9|200806271202
1804487|1804487-b19f-3f77-b713-d32bba55d77f|fail|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200806271132
1804540|1804540-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200806270546
1804665|1804665-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|sun4-solaris|5.10.0|solaris|2.9|200806271315
1804813|1804813-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806270753
1805948|1805948-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806271358
1806046|1806046-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271150
1806122|1806122-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|i686-linux|5.8.8|linux|2.4.27-3-686|200806271432
1806936|1806936-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.1|IP35-irix-64int|5.8.8|irix|6.5|200806272105
1806945|1806945-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.24-16-generic|200806271506
1807304|1807304-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806271548
1807966|1807966-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806271729
1808105|1808105-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Devel-CheckOS|1.43|armv5tejl-linux|5.10.0|linux|2.6.17.14|200806280102
1809253|1809253-b19f-3f77-b713-d32bba55d77f|fail|200806|icerider70@gmail.com ("ICERIDER")|DBIx-Class-SingletonRows|0.11|i386-linux|5.8.8|linux|2.6.18-53.el5|200806280206
1810869|1810869-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280426
1810950|1810950-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806280434
1813714|1813714-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281155
1813849|1813849-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200806281343
1814361|1814361-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281300
1814366|1814366-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281300
1814639|1814639-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806281931
1815011|1815011-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806282015
1815274|1815274-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806282048
1815862|1815862-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281540
1815886|1815886-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806282010
1815954|1815954-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200806281547
1815995|1815995-b19f-3f77-b713-d32bba55d77f|pass|200806|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|IP35-irix-64int|5.8.8|irix|6.5|200806282149
1817322|1817322-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|Palm-SMS|0.02|i686-linux|5.8.8|linux|2.4.27-2-386|200806290122
1817742|1817742-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806281911
1817860|1817860-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806290032
1818177|1818177-b19f-3f77-b713-d32bba55d77f|pass|200806|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34090|linux|2.6.22-1-k7|200806290200
1818908|1818908-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290106
1820182|1820182-b19f-3f77-b713-d32bba55d77f|unknown|200806|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806290329
1820329|1820329-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806290007
1820383|1820383-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806290014
1820882|1820882-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Games-Dice-Advanced|1.1|sun4-solaris|5.10.0|solaris|2.9|200806290715
1821606|1821606-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-ld|5.11.0 patch 34090|linux|2.6.21.5-smp|200806290644
1822116|1822116-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806290951
1822309|1822309-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290530
1822949|1822949-b19f-3f77-b713-d32bba55d77f|fail|200806|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806290755
1823789|1823789-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200806291145
1824422|1824422-b19f-3f77-b713-d32bba55d77f|pass|200806|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sub-WrapPackages|1.2|sun4-solaris|5.10.0|solaris|2.9|200806291954
1824425|1824425-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200806291355
1824977|1824977-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200806291536
1826691|1826691-b19f-3f77-b713-d32bba55d77f|pass|200806|andy@hexten.net|Devel-CheckLib|0.5|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200806300051
1826968|1826968-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300042
1827379|1827379-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200806300225
1828898|1828898-b19f-3f77-b713-d32bba55d77f|pass|200806|stro@cpan.org|XML-Tiny|1.11|armv5tejl-linux|5.10.0|linux|2.6.17.14|200806301547
1829462|1829462-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301028
1830918|1830918-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301443
1830919|1830919-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200806301443
1831419|1831419-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301631
1831425|1831425-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200806301631
1831539|1831539-b19f-3f77-b713-d32bba55d77f|pass|200806|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200806301648
1832513|1832513-b19f-3f77-b713-d32bba55d77f|pass|200806|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-64int|5.11.0 patch 34093|openbsd|4.2|200806302346
1833685|1833685-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807010141
1833952|1833952-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010218
1834202|1834202-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Class-CanBeA|1.2|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807011305
1834458|1834458-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010357
1836068|1836068-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807010526
1837205|1837205-b19f-3f77-b713-d32bba55d77f|fail|200807|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010935
1837251|1837251-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807010950
1839694|1839694-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807011613
1839907|1839907-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807011646
1840333|1840333-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807011737
1840334|1840334-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200807011737
1840914|1840914-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Devel-CheckLib|0.5|os2|5.10.0|os2|2.45|200807020331
1842188|1842188-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd|5.11.0 patch 34094|netbsd|4.0|200807021131
1842724|1842724-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|XML-DoubleEncodedEntities|1.0|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807021706
1842760|1842760-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|XML-DoubleEncodedEntities|1.0|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807021715
1842991|1842991-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Devel-CheckOS|1.43|os2|5.10.0|os2|2.45|200807021803
1843586|1843586-b19f-3f77-b713-d32bba55d77f|pass|200807|andy@hexten.net|Data-Compare|1.19|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200807022017
1844679|1844679-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807030836
1845117|1845117-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031253
1845123|1845123-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|CPU-Emulator-Z80|0.9|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807031258
1845746|1845746-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200807030249
1847050|1847050-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807030911
1847135|1847135-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200807030919
1847182|1847182-b19f-3f77-b713-d32bba55d77f|unknown|200807|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200807031854
1847204|1847204-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|File-Overwrite|1.0|sun4-solaris|5.10.0|solaris|2.9|200807032050
1849403|1849403-b19f-3f77-b713-d32bba55d77f|unknown|200807|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200807032210
1849983|1849983-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807031927
1850429|1850429-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040048
1851555|1851555-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Class-CanBeA|1.2|sun4-solaris|5.10.0|solaris|2.9|200807040710
1852008|1852008-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|darwin-2level|5.10.0|darwin|8.11.1|200807040854
1852380|1852380-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040421
1852837|1852837-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.8 patch 34066|linux|2.6.24-16-generic|200807040634
1857100|1857100-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050239
1857594|1857594-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050403
1857595|1857595-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050403
1857796|1857796-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050437
1858026|1858026-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.6.2|freebsd|6.1-release|200807051120
1858459|1858459-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050641
1858671|1858671-b19f-3f77-b713-d32bba55d77f|pass|200807|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200807050727
1860147|1860147-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Transactional|1.0|i386-freebsd-64int|5.8.8|freebsd|7.0-release|200807051639
1864049|1864049-b19f-3f77-b713-d32bba55d77f|pass|200807|sanko@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.11.0 patch 34101|MSWin32|5.1|200807051408
1865845|1865845-b19f-3f77-b713-d32bba55d77f|pass|200807|postmaster@TOMXP.spectra-direct.com|Data-Compare|1.19|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200807071710
1870236|1870236-b19f-3f77-b713-d32bba55d77f|pass|200807|mgardner@usatech.com|Data-Compare|1.19|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200807081438
1870237|1870237-b19f-3f77-b713-d32bba55d77f|pass|200807|sanko@cpan.org|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.11.0 patch 34107|MSWin32|5.1|200807080816
1870763|1870763-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090026
1871046|1871046-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090005
1871077|1871077-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090000
1871298|1871298-b19f-3f77-b713-d32bba55d77f|pass|200807|bob@randomness.org.uk ("bob walker")|Data-Compare|1.19|OpenBSD.i386-openbsd|5.8.8|openbsd|4.2|200807090112
1871307|1871307-b19f-3f77-b713-d32bba55d77f|pass|200807|bob@randomness.org.uk ("bob walker")|Data-Compare|1.19|OpenBSD.i386-openbsd|5.10.0|openbsd|4.2|200807090114
1871711|1871711-b19f-3f77-b713-d32bba55d77f|fail|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-SMS|0.02|sun4-solaris|5.10.0|solaris|2.9|200807090504
1871761|1871761-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807090518
1871953|1871953-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|sun4-solaris|5.10.0|solaris|2.9|200807090630
1874988|1874988-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807100101
1875310|1875310-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34112|linux|2.6.22-1-k7|200807100240
1877308|1877308-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-64int|5.11.0 patch 34114|openbsd|4.1|200807101527
1879484|1879484-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200807110816
1879866|1879866-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|sun4-solaris|5.10.0|solaris|2.9|200807111104
1880013|1880013-b19f-3f77-b713-d32bba55d77f|pass|200807|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200807111811
1880015|1880015-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200807111209
1880023|1880023-b19f-3f77-b713-d32bba55d77f|pass|200807|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200807111815
1880186|1880186-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200807111238
1880257|1880257-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200807111333
1880431|1880431-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200807111434
1880469|1880469-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34117|openbsd|4.3|200807111214
1880550|1880550-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200807111538
1880567|1880567-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200807110851
1880653|1880653-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Data-Hexdumper|1.4|IP35-irix-64int|5.8.8|irix|6.5|200807111613
1880661|1880661-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|IP35-irix-64int|5.8.8|irix|6.5|200807111614
1880688|1880688-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200807110844
1880690|1880690-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200807110844
1880696|1880696-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200807111521
1880888|1880888-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200807110924
1880913|1880913-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200807111604
1881263|1881263-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807111611
1881373|1881373-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807111700
1881381|1881381-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807111706
1881526|1881526-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200807111839
1881589|1881589-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|sun4-solaris|5.10.0|solaris|2.9|200807112102
1881597|1881597-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807112010
1881631|1881631-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807112030
1881979|1881979-b19f-3f77-b713-d32bba55d77f|pass|200807|pjacklam@online.no|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.10.0|cygwin|1.5.25(0.15642)|200807120016
1882976|1882976-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd|5.11.0 patch 34120|freebsd|6.2-release|200807120643
1883227|1883227-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807121146
1883249|1883249-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807121153
1883279|1883279-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807121206
1883513|1883513-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807121315
1883722|1883722-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807121410
1883742|1883742-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807121416
1884017|1884017-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807121625
1884092|1884092-b19f-3f77-b713-d32bba55d77f|pass|200807|sanko@cpan.org|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.11.0 patch 34116|MSWin32|5.1|200807120352
1884116|1884116-b19f-3f77-b713-d32bba55d77f|fail|200807|sanko@cpan.org|Palm-Treo680MessagesDB|1.0|MSWin32-x86-multi-thread|5.11.0 patch 34116|MSWin32|5.1|200807120358
1884331|1884331-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807121639
1884411|1884411-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807121621
1884991|1884991-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807121957
1885642|1885642-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807122151
1886018|1886018-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris|5.11.0 patch 34131|solaris|2.10|200807122246
1886250|1886250-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807130030
1886715|1886715-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34134|linux|2.6.22-1-k7|200807130209
1887496|1887496-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807130705
1887713|1887713-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807131014
1887720|1887720-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807131017
1888851|1888851-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807131751
1888875|1888875-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807131803
1889291|1889291-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807132039
1889768|1889768-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807140010
1889801|1889801-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807140028
1889814|1889814-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807140047
1889836|1889836-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807140059
1889837|1889837-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807140101
1889858|1889858-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807140115
1890161|1890161-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807140411
1891058|1891058-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i686-linux-thread-multi-ld|5.11.0 patch 34136|linux|2.6.21.5-smp|200807141140
1891574|1891574-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807141638
1891600|1891600-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807141652
1891730|1891730-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Longest|1.1|sun4-solaris|5.10.0|solaris|2.9|200807141846
1891733|1891733-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Statistics-ChiSquare|0.5|sun4-solaris|5.10.0|solaris|2.9|200807141847
1891774|1891774-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807141758
1891813|1891813-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807141811
1893246|1893246-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807150513
1893480|1893480-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34134|openbsd|4.2|200807150707
1893723|1893723-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807150928
1893919|1893919-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807151108
1894000|1894000-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-64int|5.11.0 patch 34134|netbsd|4.0|200807151145
1894908|1894908-b19f-3f77-b713-d32bba55d77f|pass|200807|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.10.0|freebsd|6.1-release|200807151806
1897024|1897024-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|NestedMap|1.0|sun4-solaris|5.10.0|solaris|2.9|200807160638
1897245|1897245-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160506
1897251|1897251-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160507
1897276|1897276-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160516
1897283|1897283-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160517
1897439|1897439-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807160837
1897771|1897771-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807160715
1897774|1897774-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807160715
1897831|1897831-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807160906
1898169|1898169-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161054
1899447|1899447-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34134|openbsd|4.2|200807161430
1899642|1899642-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161619
1900007|1900007-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161741
1900014|1900014-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807161731
1901024|1901024-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-64int|5.11.0 patch 34144|freebsd|7.0-release|200807161945
1901200|1901200-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807162036
1901212|1901212-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807162227
1901431|1901431-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807162323
1901474|1901474-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200807162328
1901477|1901477-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34144|linux|2.6.22-1-k7|200807170035
1901489|1901489-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807162333
1901499|1901499-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807162334
1901510|1901510-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807162339
1901513|1901513-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807162341
1901520|1901520-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807162342
1901535|1901535-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807162347
1901566|1901566-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807162352
1901576|1901576-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200807162358
1902813|1902813-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807170739
1902859|1902859-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807170747
1903090|1903090-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200807170853
1904723|1904723-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i686-linux-thread-multi-ld|5.11.0 patch 34150|linux|2.6.24.5-smp|200807171449
1904735|1904735-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-ld|5.11.0 patch 34150|linux|2.6.24.5-smp|200807171453
1904820|1904820-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-64int|5.11.0 patch 34150|netbsd|4.0|200807171506
1904869|1904869-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|i386-netbsd-64int|5.11.0 patch 34150|netbsd|4.0|200807171523
1904936|1904936-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34150|linux|2.6.24.5-smp|200807171529
1905990|1905990-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807180620
1907801|1907801-b19f-3f77-b713-d32bba55d77f|unknown|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Licence|1.0|sun4-solaris|5.10.0|solaris|2.9|200807181658
1909274|1909274-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807182328
1909836|1909836-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34151|freebsd|7.0-release|200807190141
1909974|1909974-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807190317
1910043|1910043-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34151|openbsd|4.3|200807190545
1911641|1911641-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807191421
1912343|1912343-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807191741
1914094|1914094-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807192239
1915717|1915717-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807200325
1916521|1916521-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807200940
1916732|1916732-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34151|linux|2.6.22-1-k7|200807201023
1916950|1916950-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807201014
1917372|1917372-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807201134
1917468|1917468-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807201154
1918191|1918191-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807201617
1918224|1918224-b19f-3f77-b713-d32bba55d77f|unknown|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Acme-Pony|1.1.2|sun4-solaris|5.10.0|solaris|2.9|200807201729
1918463|1918463-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|sun4-solaris|5.10.0|solaris|2.9|200807201834
1918665|1918665-b19f-3f77-b713-d32bba55d77f|pass|200807|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|sun4-solaris|5.10.0|solaris|2.9|200807201949
1918745|1918745-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200807201910
1918958|1918958-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807202018
1918963|1918963-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807202019
1918968|1918968-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807202020
1919527|1919527-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210026
1919530|1919530-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210028
1919544|1919544-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210034
1919550|1919550-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Class-CanBeA|1.2|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210037
1919562|1919562-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Compare|1.19|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210043
1919563|1919563-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210044
1919567|1919567-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210047
1919574|1919574-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210049
1919576|1919576-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210051
1919615|1919615-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210107
1919619|1919619-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|File-Overwrite|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210109
1919621|1919621-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210110
1919622|1919622-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|NestedMap|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210111
1919632|1919632-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Net-Random|2.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210118
1919642|1919642-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210120
1919662|1919662-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210132
1919679|1919679-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210141
1919693|1919693-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210154
1919695|1919695-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Statistics-ChiSquare|0.5|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210155
1919696|1919696-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Statistics-SerialCorrelation|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210155
1919699|1919699-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sub-WrapPackages|1.2|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210156
1919701|1919701-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Tie-Hash-Longest|1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210157
1919703|1919703-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Tie-Hash-Rank|1.0.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210158
1919707|1919707-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Tie-STDOUT|1.03|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210159
1919712|1919712-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Tie-Scalar-Decay|1.1.1|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210200
1919717|1919717-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210202
1919719|1919719-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 34095|darwin|8.10.0|200807210201
1920793|1920793-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200807210841
1920887|1920887-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34151|solaris|2.10|200807210931
1921536|1921536-b19f-3f77-b713-d32bba55d77f|pass|200807|andy@hexten.net|Data-Compare|1.19|i86pc-solaris-thread-multi|5.10.0|solaris|2.11|200807211405
1922183|1922183-b19f-3f77-b713-d32bba55d77f|fail|200807|stro@cpan.org|Bryar|3.0|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807211946
1924105|1924105-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34151|linux|2.6.16.38|200807220155
1924198|1924198-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200807220244
1924342|1924342-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200807220346
1926834|1926834-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Hexdumper|1.4|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807221251
1926928|1926928-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Compare|1.19|armv5tejl-linux|5.10.0|linux|2.6.17.14|200807221609
1927030|1927030-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Hexdumper|1.4|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807221523
1927087|1927087-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Data-Compare|1.19|armv5tejl-linux|5.8.8|linux|2.6.17.14|200807221639
1927327|1927327-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807222103
1927555|1927555-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807222147
1929231|1929231-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807230207
1929554|1929554-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807230416
1929713|1929713-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807230450
1930126|1930126-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34153|netbsd|4.0|200807230525
1930619|1930619-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200807230704
1930745|1930745-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-64int|5.11.0 patch 34153|openbsd|4.1|200807230724
1930792|1930792-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200807230733
1931384|1931384-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Tie-Hash-Longest|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200807230824
1932393|1932393-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807231418
1932727|1932727-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34153|linux|2.6.22-1-k7|200807231536
1938533|1938533-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200807242216
1938537|1938537-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200807242218
1938542|1938542-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200807242218
1938547|1938547-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200807242219
1939381|1939381-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi|5.11.0 patch 34156|freebsd|6.2-release|200807242148
1939657|1939657-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807250026
1939754|1939754-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807250038
1939827|1939827-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807250047
1939856|1939856-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807250056
1939913|1939913-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807250107
1939928|1939928-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807250109
1939959|1939959-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807250115
1939961|1939961-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807250116
1940011|1940011-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807250126
1940530|1940530-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200807250139
1940570|1940570-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200807250150
1940772|1940772-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807250514
1940799|1940799-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.11.0 patch 34156|freebsd|7.0-release|200807250125
1941869|1941869-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807251244
1941928|1941928-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807251315
1942156|1942156-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807251421
1943494|1943494-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200807252350
1943498|1943498-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200807260004
1943503|1943503-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200807260004
1943506|1943506-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.8.8|linux|2.6.14|200807260005
1943508|1943508-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200807260005
1943509|1943509-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200807260006
1943511|1943511-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200807260006
1943532|1943532-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200807260004
1943533|1943533-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|0.001_01|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200807260003
1943639|1943639-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807260040
1944678|1944678-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807260447
1944791|1944791-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807260424
1945089|1945089-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807260451
1945112|1945112-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807260601
1945113|1945113-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807260602
1945116|1945116-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807260603
1945635|1945635-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.11.0 patch 34156|linux|2.6.21.5-smp|200807260730
1945982|1945982-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807260851
1946153|1946153-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807260936
1946430|1946430-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|IP35-irix-64int|5.8.8|irix|6.5|200807261226
1946495|1946495-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200807261047
1946586|1946586-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200807261115
1946745|1946745-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807261603
1946879|1946879-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807261633
1947584|1947584-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i686-linux|5.6.2|linux|2.4.27-3-686|200807261910
1947597|1947597-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i686-linux|5.8.8|linux|2.4.27-3-686|200807261915
1947656|1947656-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200807261930
1947672|1947672-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200807261935
1947857|1947857-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200807261455
1947861|1947861-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200807261956
1948026|1948026-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|IP35-irix-64int|5.8.8|irix|6.5|200807262244
1948071|1948071-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34156|linux|2.6.22-1-k7|200807262300
1948183|1948183-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|0.001_01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200807262320
1949069|1949069-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Net-Random|2.0|i686-linux|5.10.0|linux|2.4.27-2-386|200807270954
1950303|1950303-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807271731
1950420|1950420-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200807271749
1950511|1950511-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807271712
1950562|1950562-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807271826
1950606|1950606-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34160|openbsd|4.2|200807271738
1950656|1950656-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200807271846
1950912|1950912-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807271901
1950950|1950950-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807271910
1950981|1950981-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34160|openbsd|4.2|200807271922
1951060|1951060-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807271959
1952306|1952306-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200807280602
1952445|1952445-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200807280711
1952552|1952552-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807280659
1952593|1952593-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807280707
1952613|1952613-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807280712
1952631|1952631-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807280716
1952647|1952647-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807280721
1952670|1952670-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807280726
1952689|1952689-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807280730
1953802|1953802-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi|5.11.0 patch 34160|openbsd|4.2|200807281343
1953922|1953922-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200807281437
1953930|1953930-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807281439
1954513|1954513-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200807281812
1954596|1954596-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200807281904
1954667|1954667-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807282035
1955416|1955416-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807282252
1955426|1955426-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807282255
1955429|1955429-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200807282358
1955430|1955430-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200807282359
1955431|1955431-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200807282359
1955432|1955432-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200807282359
1955435|1955435-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200807282359
1955436|1955436-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807282257
1955437|1955437-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200807290000
1955439|1955439-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200807290000
1955441|1955441-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200807290000
1955445|1955445-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807282259
1955448|1955448-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807282301
1955452|1955452-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807282303
1955457|1955457-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807282305
1955474|1955474-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807282307
1955483|1955483-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sort-MultipleFields|1.0|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200807290007
1955880|1955880-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.11.0 patch 34156|dragonfly|2.0.0-release|200807290246
1955968|1955968-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200807290338
1955990|1955990-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807290252
1955999|1955999-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807290256
1956268|1956268-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200807290547
1956270|1956270-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200807290547
1956271|1956271-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200807290548
1956531|1956531-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200807290813
1956557|1956557-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807290823
1956909|1956909-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807290951
1956961|1956961-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200807290901
1957223|1957223-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807291103
1957283|1957283-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807291013
1957288|1957288-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807291014
1957376|1957376-b19f-3f77-b713-d32bba55d77f|pass|200807|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200807291735
1957406|1957406-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200807291045
1957407|1957407-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i686-linux|5.6.2|linux|2.4.27-3-686|200807291045
1957413|1957413-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200807291009
1957470|1957470-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200807290505
1957471|1957471-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200807291005
1957476|1957476-b19f-3f77-b713-d32bba55d77f|pass|200807|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200807291808
1957513|1957513-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807291115
1957650|1957650-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|IP35-irix-64int|5.8.8|irix|6.5|200807291312
1957671|1957671-b19f-3f77-b713-d32bba55d77f|pass|200807|david@cantrell.org.uk|Sort-MultipleFields|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200807291216
1958030|1958030-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807291444
1958035|1958035-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807291445
1958203|1958203-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807291541
1958905|1958905-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807291925
1958907|1958907-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807291926
1958966|1958966-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807291953
1959723|1959723-b19f-3f77-b713-d32bba55d77f|pass|200807|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200807300117
1959756|1959756-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807300048
1959797|1959797-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807300109
1959916|1959916-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200807300151
1959917|1959917-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200807300151
1959918|1959918-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200807300152
1959919|1959919-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200807300152
1959921|1959921-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200807300153
1959922|1959922-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200807300153
1959923|1959923-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200807300153
1959924|1959924-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200807300154
1959925|1959925-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200807300154
1959926|1959926-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200807300154
1960114|1960114-b19f-3f77-b713-d32bba55d77f|pass|200807|jeff@zeroclue.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-2level|5.10.0|darwin|9.2.0|200807300151
1960233|1960233-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807300451
1960358|1960358-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807300435
1960665|1960665-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200807300600
1960702|1960702-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200807300611
1960894|1960894-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.11.0 patch 34160|netbsd|4.0|200807300708
1961785|1961785-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807301059
1961787|1961787-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807301059
1962019|1962019-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807301409
1962097|1962097-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807301357
1962234|1962234-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807301233
1962240|1962240-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807301234
1962428|1962428-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807301314
1962664|1962664-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200807301544
1962973|1962973-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807301640
1963162|1963162-b19f-3f77-b713-d32bba55d77f|pass|200807|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34160|linux|2.6.22-1-k7|200807301740
1963239|1963239-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807301538
1963241|1963241-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807301539
1963368|1963368-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200807301800
1963405|1963405-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807301617
1964343|1964343-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807302232
1964347|1964347-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807302232
1964707|1964707-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807310048
1964708|1964708-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807310049
1964821|1964821-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807310133
1965204|1965204-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Sort-MultipleFields|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200807310506
1965814|1965814-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-64int|5.11.0 patch 34162|freebsd|7.0-release|200807310624
1966158|1966158-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807310826
1966586|1966586-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200807311051
1966756|1966756-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-freebsd-64int|5.10.0 patch 34161|freebsd|7.0-release|200807311155
1966845|1966845-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Number-Phone|1.6|i686-linux|5.10.0|linux|2.4.27-2-386|200807311319
1966860|1966860-b19f-3f77-b713-d32bba55d77f|pass|200807|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.4.27-2-386|200807311323
1967293|1967293-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807311603
1967574|1967574-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34164|openbsd|4.3|200807311835
1967656|1967656-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-Tiny|1.11|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807311918
1967811|1967811-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200807312059
1967829|1967829-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200807312046
1968131|1968131-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200807312348
1968132|1968132-b19f-3f77-b713-d32bba55d77f|pass|200807|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200807312348
1968342|1968342-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808010101
1968348|1968348-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808010102
1968695|1968695-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010330
1968845|1968845-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808010255
1968847|1968847-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808010255
1968849|1968849-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808010256
1968851|1968851-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808010256
1968853|1968853-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808010256
1968854|1968854-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808010257
1968856|1968856-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808010257
1968858|1968858-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808010257
1968859|1968859-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808010258
1968861|1968861-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808010258
1969122|1969122-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010531
1969492|1969492-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010701
1969982|1969982-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808010854
1971018|1971018-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808011258
1971041|1971041-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200808011303
1971045|1971045-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200808011305
1971441|1971441-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808011451
1971445|1971445-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808011452
1971643|1971643-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200808011530
1972120|1972120-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|0.001_01|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808011756
1972121|1972121-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808011757
1972217|1972217-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.11.0 patch 34166|solaris|2.10|200808011840
1972481|1972481-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808011953
1972895|1972895-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808012154
1973809|1973809-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808020555
1974358|1974358-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34161|linux|2.6.22-1-k7|200808020821
1975026|1975026-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808021053
1975119|1975119-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808021219
1975137|1975137-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i86pc-solaris-thread-multi-64int|5.11.0 patch 34169|solaris|2.10|200808021124
1975297|1975297-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34169|linux|2.6.16.38|200808021204
1976192|1976192-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808021702
1976242|1976242-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.11.0 patch 34169|linux|2.6.16.38|200808021716
1976243|1976243-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808021717
1976693|1976693-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808022003
1976706|1976706-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808022006
1976985|1976985-b19f-3f77-b713-d32bba55d77f|pass|200808|conrad@fringehead.org|XML-Tiny|1.11|darwin-2level|5.10.0|darwin|9.3.0|200808021334
1976994|1976994-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808022237
1977069|1977069-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.4.27-2-386|200808022054
1977074|1977074-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.4.27-2-386|200808022055
1977127|1977127-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808022314
1977128|1977128-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808022212
1977200|1977200-b19f-3f77-b713-d32bba55d77f|pass|200808|conrad@fringehead.org|XML-Tiny|1.11|i686-linux-thread-multi|5.8.8|linux|2.6.15.1|200808021437
1977216|1977216-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808022336
1978598|1978598-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808030831
1978664|1978664-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808030849
1978893|1978893-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-Tiny|1.11|i686-linux-thread-multi-ld|5.11.0 patch 34169|linux|2.6.16.38|200808031003
1978994|1978994-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808031131
1979426|1979426-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808031308
1979701|1979701-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808031444
1980396|1980396-b19f-3f77-b713-d32bba55d77f|pass|200808|dpavlin@rot13.org ((Dobrica Pavlinusic))|Data-Compare|1.19|i486-linux-gnu|5.10.0|linux|2.6.25.10|200808032133
1980946|1980946-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34169|freebsd|7.0-release|200808032245
1981115|1981115-b19f-3f77-b713-d32bba55d77f|na|200808|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200808040140
1981178|1981178-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200808040110
1981369|1981369-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200808040136
1981852|1981852-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34169|openbsd|4.1|200808040345
1981982|1981982-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34169|openbsd|4.1|200808040454
1981986|1981986-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|i386-freebsd-thread-multi-64int|5.11.0 patch 34169|freebsd|7.0-release|200808040324
1982322|1982322-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808040829
1985957|1985957-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200808050827
1985958|1985958-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200808050827
1986173|1986173-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34170|freebsd|6.2-release|200808050950
1986927|1986927-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200808051559
1987031|1987031-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34170|linux|2.6.24-19-generic|200808051640
1988273|1988273-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34161|linux|2.6.24-19-generic|200808052200
1990402|1990402-b19f-3f77-b713-d32bba55d77f|pass|200808|yanick@cpan.org ("Yanick Champoux")|Data-Compare|1.19|i686-linux|5.10.0|linux|2.6.22-gentoo-r2enkidu|200808060050
1993045|1993045-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808061711
1993209|1993209-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808061710
1994194|1994194-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808062152
1994372|1994372-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808062154
1994469|1994469-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.5.5|freebsd|6.1-release|200808062231
1994636|1994636-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34174|linux|2.6.21.5-smp|200808062134
1996505|1996505-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808070918
1996526|1996526-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808070921
1996771|1996771-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808071017
1997654|1997654-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.6.2|freebsd|6.1-release|200808071253
1999527|1999527-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200808071845
2000199|2000199-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.11.0 patch 34175|dragonfly|2.0.0-release|200808072155
2000255|2000255-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808072227
2001810|2001810-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.5.5|freebsd|6.1-release|200808080804
2001827|2001827-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808080830
2002243|2002243-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808080953
2002433|2002433-b19f-3f77-b713-d32bba55d77f|pass|200808|vpit@cpan.org|Devel-CheckLib|0.5|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200808080127
2002615|2002615-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.5.5|freebsd|6.1-release|200808081055
2002850|2002850-b19f-3f77-b713-d32bba55d77f|pass|200808|vpit@cpan.org|Devel-CheckOS|1.43|sun4-solaris-thread-multi-64|5.10.0|solaris|2.7|200808080125
2003523|2003523-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808081350
2003686|2003686-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.6.2|freebsd|6.1-release|200808081425
2004412|2004412-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808081652
2004545|2004545-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808081722
2004701|2004701-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808081737
2005947|2005947-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808082105
2006352|2006352-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.5.5|freebsd|6.1-release|200808082202
2007141|2007141-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808090233
2008766|2008766-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.6.2|freebsd|6.1-release|200808091214
2009821|2009821-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808091353
2010349|2010349-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Sort-MultipleFields|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200808091937
2011846|2011846-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|i86pc-solaris|5.10.0|solaris|2.11|200808100230
2012066|2012066-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris|5.10.0|solaris|2.11|200808100338
2012237|2012237-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris|5.10.0|solaris|2.11|200808100415
2012452|2012452-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris|5.10.0|solaris|2.11|200808100701
2014850|2014850-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34192|netbsd|4.0|200808110207
2016490|2016490-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808111356
2016902|2016902-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808111555
2017203|2017203-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808111703
2017416|2017416-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris|5.10.0|solaris|2.11|200808111825
2017451|2017451-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Compare|1.19|i86pc-solaris|5.10.0|solaris|2.11|200808111834
2018259|2018259-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|DBIx-Class-SingletonRows|0.11|i86pc-solaris|5.10.0|solaris|2.11|200808120046
2018882|2018882-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris|5.10.0|solaris|2.11|200808120433
2019240|2019240-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34201|freebsd|7.0-release|200808120403
2019367|2019367-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34197|linux|2.6.24.5-smp|200808120651
2020015|2020015-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808120710
2021100|2021100-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24.3|200808120312
2021633|2021633-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808121726
2021647|2021647-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808121727
2023871|2023871-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34197|linux|2.6.22-1-k7|200808131503
2027286|2027286-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34203|solaris|2.10|200808141452
2028942|2028942-b19f-3f77-b713-d32bba55d77f|pass|200808|brooks-cpan-tester@deseret.com|Devel-CheckOS|1.43|x86_64-linux|5.8.8|linux|2.6.9-023stab044.4-smp|200808141358
2029012|2029012-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.6.24.3|200808150140
2029368|2029368-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Devel-CheckOS|1.43|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151003
2029752|2029752-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.4.27-2-386|200808151016
2029819|2029819-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151231
2029928|2029928-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.4.27-2-386|200808151101
2029960|2029960-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151305
2030081|2030081-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.4.27-2-386|200808151133
2030248|2030248-b19f-3f77-b713-d32bba55d77f|pass|200808|Jost.Krieger+smokeback@ruhr-uni-bochum.de ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200808151443
2032178|2032178-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.6.24.3|200808150705
2032940|2032940-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200808160849
2035176|2035176-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808161754
2035227|2035227-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.8|linux|2.6.24.3|200808161251
2035519|2035519-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris-64int|5.10.0|solaris|2.11|200808161324
2035534|2035534-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.19|i86pc-solaris-64int|5.10.0|solaris|2.11|200808161341
2037202|2037202-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.10.0|freebsd|6.1-release|200808170827
2037266|2037266-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808170900
2037620|2037620-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808171001
2038600|2038600-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808171540
2038755|2038755-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808171541
2038973|2038973-b19f-3f77-b713-d32bba55d77f|pass|200808|rafl@debian.org|Devel-CheckLib|0.5|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200808171641
2039107|2039107-b19f-3f77-b713-d32bba55d77f|pass|200808|rafl@debian.org|Devel-CheckOS|1.43|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200808171644
2040114|2040114-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808172114
2040460|2040460-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808172321
2041167|2041167-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34204|linux|2.6.16.38|200808180203
2041799|2041799-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808180838
2042345|2042345-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181112
2042373|2042373-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181115
2042962|2042962-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.8|linux|2.6.24.3|200808180651
2043275|2043275-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.19|i686-linux|5.8.8|linux|2.6.24.3|200808180740
2043444|2043444-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181402
2044098|2044098-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181544
2044616|2044616-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181713
2045471|2045471-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Number-Phone|1.6|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808181711
2045989|2045989-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34204|linux|2.6.22-1-k7|200808181920
2046283|2046283-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808181934
2046651|2046651-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.10.0|freebsd|6.1-release|200808181958
2047415|2047415-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808182212
2048317|2048317-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808190533
2048368|2048368-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808190548
2048381|2048381-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808190550
2048399|2048399-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808190553
2048411|2048411-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808190557
2048450|2048450-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808190614
2048486|2048486-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808190632
2048568|2048568-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808190645
2048588|2048588-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808190658
2048980|2048980-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200808182153
2049353|2049353-b19f-3f77-b713-d32bba55d77f|pass|200808|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.6|i86pc-solaris-64int|5.10.0|solaris|2.11|200808190300
2049726|2049726-b19f-3f77-b713-d32bba55d77f|pass|200808|rafl@debian.org|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200808182146
2051551|2051551-b19f-3f77-b713-d32bba55d77f|pass|200808|rafl@debian.org|Devel-CheckOS|1.43|x86_64-linux|5.10.0|linux|2.6.18-6-xen-amd64|200808191418
2051862|2051862-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.6.2|linux|2.6.24.3|200808190925
2052618|2052618-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808191826
2053168|2053168-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808191826
2053301|2053301-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808191826
2053463|2053463-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808191826
2054987|2054987-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200808192316
2055631|2055631-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808200539
2055923|2055923-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808200749
2055983|2055983-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808200749
2057195|2057195-b19f-3f77-b713-d32bba55d77f|pass|200808|shlomif@cpan.org|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200808192108
2057250|2057250-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.8|linux|2.6.24.3|200808200655
2057810|2057810-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200808201411
2059653|2059653-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808202236
2060673|2060673-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808210423
2060880|2060880-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.19|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808210513
2061033|2061033-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200808210107
2061156|2061156-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200808210137
2061484|2061484-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808210739
2061621|2061621-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808210810
2063986|2063986-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808211357
2064102|2064102-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808211516
2064510|2064510-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200808211743
2064513|2064513-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200808211743
2064515|2064515-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200808211743
2064516|2064516-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200808211744
2064523|2064523-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.8.8|linux|2.6.14|200808211744
2064530|2064530-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200808211746
2064533|2064533-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200808211746
2064554|2064554-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0 patch 34161|netbsd|4.0|200808211645
2064567|2064567-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200808211745
2064936|2064936-b19f-3f77-b713-d32bba55d77f|pass|200808|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200808220323
2064961|2064961-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808212029
2065204|2065204-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808212130
2065411|2065411-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8 patch 34096|netbsd|4.0|200808212048
2066247|2066247-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200808220134
2066292|2066292-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808220251
2066294|2066294-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808220252
2066295|2066295-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808220253
2066296|2066296-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808220253
2066298|2066298-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808220254
2066300|2066300-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808220255
2066302|2066302-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808220255
2066304|2066304-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808220256
2066306|2066306-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808220257
2066308|2066308-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808220257
2066367|2066367-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34212|linux|2.6.21.5-smp|200808220245
2067198|2067198-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34208|linux|2.6.22-1-k7|200808220857
2067222|2067222-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.19|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808220819
2067427|2067427-b19f-3f77-b713-d32bba55d77f|pass|200808|imacat@mail.imacat.idv.tw|Data-Compare|1.20|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200808221703
2067458|2067458-b19f-3f77-b713-d32bba55d77f|pass|200808|imacat@mail.imacat.idv.tw|Data-Compare|1.20|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200808221717
2068324|2068324-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0 patch 34161|netbsd|4.0|200808221626
2068382|2068382-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Compare|1.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200808221842
2068467|2068467-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200808221701
2068507|2068507-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808221719
2068520|2068520-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-64int|5.11.0 patch 34169|netbsd|4.0|200808221726
2068840|2068840-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200808221733
2068887|2068887-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200808221740
2068905|2068905-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.8 patch 34096|netbsd|4.0|200808221834
2068971|2068971-b19f-3f77-b713-d32bba55d77f|pass|200808|g.grigelionis@computer.org|Data-Compare|1.20|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200808222001
2068972|2068972-b19f-3f77-b713-d32bba55d77f|pass|200808|g.grigelionis@computer.org|Data-Compare|1.20|i586-linux-thread-multi|5.8.8|linux|2.6.16|200808222002
2069329|2069329-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd|5.10.0|freebsd|6.1-release|200808222136
2069741|2069741-b19f-3f77-b713-d32bba55d77f|pass|200808|shlomif@cpan.org|Data-Compare|1.20|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200808221504
2069771|2069771-b19f-3f77-b713-d32bba55d77f|pass|200808|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.20|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5|200808222145
2070163|2070163-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i686-linux|5.6.2|linux|2.4.27-3-686|200808230033
2070440|2070440-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.11.0 patch 34212|linux|2.6.21.5-smp|200808230235
2070919|2070919-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.24.3|200808230317
2071133|2071133-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.24.3|200808230555
2071338|2071338-b19f-3f77-b713-d32bba55d77f|pass|200808|claco@chrislaco.com|Data-Compare|1.20|darwin-thread-multi-2level|5.8.8|darwin|9.0|200808230018
2071425|2071425-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24.3|200808230709
2071692|2071692-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200808231339
2072061|2072061-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200808231723
2072209|2072209-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808231936
2072470|2072470-b19f-3f77-b713-d32bba55d77f|pass|200808|rafl@debian.org|Data-Compare|1.20|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200808232020
2072533|2072533-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808231829
2073155|2073155-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808232148
2073186|2073186-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808232151
2073566|2073566-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808232225
2073732|2073732-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808232123
2074123|2074123-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808232123
2074801|2074801-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-thread-multi-64int|5.11.0 patch 34218|freebsd|7.0-release|200808232205
2074805|2074805-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.11.0 patch 34218|freebsd|7.0-release|200808232206
2075907|2075907-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.6.2|linux|2.6.24.3|200808240047
2075993|2075993-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240708
2076432|2076432-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240834
2076708|2076708-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240918
2076997|2076997-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34218|linux|2.6.22-1-k7|200808240951
2077246|2077246-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd|5.6.2|freebsd|6.1-release|200808241010
2078672|2078672-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-64int|5.11.0 patch 34218|openbsd|4.2|200808241519
2078905|2078905-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808241606
2079549|2079549-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200808242014
2080095|2080095-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-ld|5.11.0 patch 34225|linux|2.6.24-19-generic|200808242229
2081096|2081096-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.20|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808250450
2081180|2081180-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24.3|200808250311
2082190|2082190-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-64int-ld|5.10.0 patch 34161|linux|2.6.24-19-generic|200808251225
2082734|2082734-b19f-3f77-b713-d32bba55d77f|pass|200808|hohokus@gmail.com|Data-Compare|1.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200808250932
2082785|2082785-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200808251445
2082915|2082915-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200808251519
2083908|2083908-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-netbsd-thread-multi-64int|5.11.0 patch 34225|netbsd|4.0|200808251845
2084703|2084703-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-64int-ld|5.8.8 patch 34096|linux|2.6.24-19-generic|200808260127
2085617|2085617-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200808260842
2085777|2085777-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.10.0|freebsd|6.1-release|200808260842
2086330|2086330-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Compare|1.20|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200808261335
2086870|2086870-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-Tiny|1.11|i686-linux|5.8.8|linux|2.6.24.3|200808260813
2086986|2086986-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-Tiny|1.11|i686-linux|5.6.2|linux|2.6.24.3|200808260836
2087422|2087422-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808261521
2087755|2087755-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808261456
2087975|2087975-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808261643
2089096|2089096-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.10.0|linux|2.6.24.3|200808261322
2089169|2089169-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.8|linux|2.6.24.3|200808261335
2089572|2089572-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808262033
2089756|2089756-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200808262039
2089787|2089787-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200808262045
2089835|2089835-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808262040
2090135|2090135-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34226|linux|2.6.22-1-k7|200808262145
2090474|2090474-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200808262312
2090475|2090475-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200808262313
2090477|2090477-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200808262313
2090479|2090479-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200808262314
2090489|2090489-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-64int|5.8.8|linux|2.6.14|200808262315
2090503|2090503-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200808262318
2090706|2090706-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200808262316
2090707|2090707-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.200_500|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200808262317
2090725|2090725-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i686-linux|5.8.8|linux|2.4.27-3-686|200808262257
2090771|2090771-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd|5.10.0|freebsd|6.1-release|200808270000
2092079|2092079-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200808270619
2092080|2092080-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200808270619
2092082|2092082-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200808270620
2092083|2092083-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200808270621
2092085|2092085-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200808270621
2092086|2092086-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200808270622
2092089|2092089-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200808270623
2092092|2092092-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200808270624
2092094|2092094-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200808270625
2092097|2092097-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808270625
2092290|2092290-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.11.0 patch 34225|netbsd|4.0|200808270722
2093120|2093120-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200808271221
2093398|2093398-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200808270738
2093507|2093507-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|IP35-irix-64int|5.8.8|irix|6.5|200808271500
2093624|2093624-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200808271232
2094114|2094114-b19f-3f77-b713-d32bba55d77f|pass|200808|cpan@herlpacker.co.uk|Data-Compare|1.200_500|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808271419
2094165|2094165-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808271658
2094167|2094167-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808271700
2094507|2094507-b19f-3f77-b713-d32bba55d77f|fail|200808|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.24.3|200808270846
2094847|2094847-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Devel-CheckLib|0.5|armv5tejl-linux|5.10.0|linux|2.6.17.14|200808272011
2094886|2094886-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Devel-CheckLib|0.5|armv5tejl-linux|5.8.8|linux|2.6.17.14|200808272014
2094976|2094976-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808271919
2094995|2094995-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808271901
2095008|2095008-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808271902
2095144|2095144-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-FindDependencies|2.0|i686-linux|5.8.8|linux|2.6.24.3|200808271337
2095165|2095165-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.24.3|200808271338
2095284|2095284-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.6.2|linux|2.6.24.3|200808271348
2095553|2095553-b19f-3f77-b713-d32bba55d77f|fail|200808|rick@jrmyers.net ("Rick Myers")|CPAN-FindDependencies|2.0|i686-linux|5.6.2|linux|2.6.24.3|200808271432
2095708|2095708-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.6.24.3|200808271510
2095711|2095711-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.8|linux|2.6.24.3|200808271512
2095822|2095822-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24.3|200808271549
2095833|2095833-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24.3|200808271550
2096531|2096531-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808280030
2096537|2096537-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808280032
2096958|2096958-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808280031
2096961|2096961-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808280033
2097113|2097113-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808280141
2097115|2097115-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808280143
2097915|2097915-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34161|dragonfly|2.0.0-release|200808280949
2098421|2098421-b19f-3f77-b713-d32bba55d77f|pass|200808|cpan@herlpacker.co.uk|Data-Compare|1.20|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808280347
2098456|2098456-b19f-3f77-b713-d32bba55d77f|pass|200808|cpan@herlpacker.co.uk|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.15.7|200808281035
2098735|2098735-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-64int|5.11.0 patch 34233|dragonfly|2.0.0-release|200808281333
2098779|2098779-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.4.27-2-386|200808281020
2099111|2099111-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200808281117
2099969|2099969-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Compare|1.20|i686-linux|5.10.0|linux|2.4.27-2-386|200808281411
2100251|2100251-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.200_500|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200808281754
2100283|2100283-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Data-Compare|1.20|i686-linux|5.8.8|linux|2.4.27-2-386|200808281956
2100457|2100457-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.200_500|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200808281721
2101020|2101020-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.10.0|freebsd|6.1-release|200808282129
2101100|2101100-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Pony|1.1.2|i386-freebsd|5.10.0|freebsd|6.1-release|200808282130
2101199|2101199-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd|5.6.2|freebsd|6.1-release|200808282135
2101531|2101531-b19f-3f77-b713-d32bba55d77f|unknown|200808|srezic@cpan.org|Acme-Licence|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808282130
2102011|2102011-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8 patch 34096|dragonfly|2.0.0-release|200808282328
2102284|2102284-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200808290030
2102290|2102290-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200808290031
2102308|2102308-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200808290034
2102312|2102312-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200808290034
2102320|2102320-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200808290031
2102324|2102324-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200808290032
2102325|2102325-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-64int|5.8.8|linux|2.6.14|200808290033
2102326|2102326-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200808290033
2102373|2102373-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi|5.11.0 patch 34233|freebsd|7.0-release|200808282034
2102398|2102398-b19f-3f77-b713-d32bba55d77f|pass|200808|stro@cpan.org|Number-Phone|1.6|i686-linux|5.8.8|linux|2.4.27-2-386|200808290126
2102647|2102647-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34161|freebsd|7.0-release|200808290017
2102935|2102935-b19f-3f77-b713-d32bba55d77f|pass|200808|david@cantrell.org.uk|Data-Compare|1.20|i686-linux-thread-multi|5.10.0|linux|2.4.27-3-686|200808290055
2103035|2103035-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290211
2103229|2103229-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290227
2103434|2103434-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290312
2103568|2103568-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290348
2104091|2104091-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808290554
2105206|2105206-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808290814
2105209|2105209-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200808290815
2105219|2105219-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808290816
2105234|2105234-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808290816
2105247|2105247-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808290817
2105252|2105252-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200808290818
2105258|2105258-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808290819
2105265|2105265-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808290820
2105938|2105938-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200808290951
2106681|2106681-b19f-3f77-b713-d32bba55d77f|pass|200808|srezic@cpan.org|Data-Compare|1.200_500|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808291334
2106692|2106692-b19f-3f77-b713-d32bba55d77f|fail|200808|chris@bingosnet.co.uk|Class-DBI-ClassGenerator|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200808291239
2107403|2107403-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34234|linux|2.6.22-1-k7|200808291506
2108246|2108246-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808291712
2108287|2108287-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808291727
2108604|2108604-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd|5.6.2|freebsd|6.1-release|200808292011
2108719|2108719-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd|5.10.0|freebsd|6.1-release|200808292040
2108765|2108765-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808291956
2108996|2108996-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200808292103
2109051|2109051-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808292112
2109463|2109463-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808292339
2110749|2110749-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200808300810
2110879|2110879-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200808300841
2110994|2110994-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.6.2|linux|2.6.24.3|200808300306
2111004|2111004-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200808300904
2111005|2111005-b19f-3f77-b713-d32bba55d77f|fail|200808|srezic@cpan.org|Class-DBI-ClassGenerator|1.0|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200808300904
2112339|2112339-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808301515
2112373|2112373-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200808301528
2112873|2112873-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808301829
2113254|2113254-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808302103
2113274|2113274-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.11.0 patch 34234|solaris|2.10|200808302114
2113325|2113325-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200808302139
2113593|2113593-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0 patch 34161|openbsd|4.3|200808310000
2113928|2113928-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808310238
2114152|2114152-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34234|openbsd|4.3|200808310515
2114170|2114170-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200808310534
2114229|2114229-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200808310606
2115011|2115011-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311239
2115094|2115094-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808311155
2115120|2115120-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200808311202
2116106|2116106-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808311420
2116113|2116113-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808311422
2116364|2116364-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808311502
2116382|2116382-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200808311504
2116417|2116417-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.20|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311548
2116847|2116847-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311627
2117292|2117292-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.24.3|200808311248
2117351|2117351-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808311854
2118245|2118245-b19f-3f77-b713-d32bba55d77f|pass|200808|rick@jrmyers.net ("Rick Myers")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24.3|200808311437
2118585|2118585-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808312124
2118957|2118957-b19f-3f77-b713-d32bba55d77f|pass|200808|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34237|linux|2.6.22-1-k7|200808312218
2119384|2119384-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.200_500|i686-linux-thread-multi-64int-ld|5.11.0 patch 34237|linux|2.6.16.38|200808312231
2119435|2119435-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|Data-Compare|1.20|i686-linux-thread-multi-64int-ld|5.11.0 patch 34237|linux|2.6.16.38|200808312239
2119735|2119735-b19f-3f77-b713-d32bba55d77f|pass|200808|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200808312337
2119793|2119793-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34237|linux|2.6.16.38|200809010033
2120156|2120156-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.0|i686-linux|5.10.0|linux|2.4.27-2-386|200809010537
2120442|2120442-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Data-Compare|1.200_500|i686-linux|5.10.0|linux|2.4.27-2-386|200809010647
2120514|2120514-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.4.27-2-386|200809010655
2120517|2120517-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809010029
2120778|2120778-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Data-Compare|1.200_500|i686-linux|5.8.8|linux|2.4.27-2-386|200809010855
2121277|2121277-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809011108
2121300|2121300-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809011114
2121647|2121647-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809011256
2121692|2121692-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809011302
2122006|2122006-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809011452
2122014|2122014-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809011454
2122158|2122158-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809011552
2122165|2122165-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809011555
2122170|2122170-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809011558
2122414|2122414-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200809011833
2122416|2122416-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200809011833
2122420|2122420-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200809011833
2122421|2122421-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200809011834
2122424|2122424-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8|linux|2.6.14|200809011834
2122425|2122425-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200809011834
2122429|2122429-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-thread-multi-64int|5.8.6|linux|2.6.18-4-k7|200809011835
2122432|2122432-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-thread-multi-64int|5.8.5|linux|2.6.18-4-k7|200809011835
2122703|2122703-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809011911
2122729|2122729-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.20|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809011920
2122923|2122923-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.10.0|freebsd|6.1-release|200809012154
2123235|2123235-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809012347
2123274|2123274-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.6.2|freebsd|6.1-release|200809012355
2123275|2123275-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809012355
2123451|2123451-b19f-3f77-b713-d32bba55d77f|pass|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Compare|1.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809020814
2123737|2123737-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200809020145
2123739|2123739-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200809020146
2123741|2123741-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200809020147
2123742|2123742-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200809020147
2123744|2123744-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200809020148
2123745|2123745-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200809020149
2123747|2123747-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200809020149
2123748|2123748-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200809020150
2123749|2123749-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200809020151
2123752|2123752-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809020151
2124180|2124180-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.1|200809020557
2124282|2124282-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200809020753
2124283|2124283-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809020751
2124285|2124285-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809020656
2124458|2124458-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809020816
2124573|2124573-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809020845
2124579|2124579-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809020846
2124587|2124587-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809020846
2124592|2124592-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809020847
2124706|2124706-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809020822
2124735|2124735-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809020928
2124737|2124737-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809020828
2124773|2124773-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.8.8|linux|2.6.22.10|200809021637
2124774|2124774-b19f-3f77-b713-d32bba55d77f|pass|200809|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200809021637
2125023|2125023-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi|5.8.8|openbsd|4.1|200809021104
2125137|2125137-b19f-3f77-b713-d32bba55d77f|pass|200809|rafl@debian.org|Data-Compare|1.21|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200809021255
2125465|2125465-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.200_500|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34238|openbsd|4.1|200809021411
2125471|2125471-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34238|openbsd|4.1|200809021412
2125812|2125812-b19f-3f77-b713-d32bba55d77f|pass|200809|hohokus@gmail.com|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809020949
2126196|2126196-b19f-3f77-b713-d32bba55d77f|pass|200809|artur+cpan@niif.spb.su (ARTO)|Data-Compare|1.21|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5|200809012146
2126563|2126563-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809021204
2126630|2126630-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809021214
2126647|2126647-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809021715
2126719|2126719-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|i686-linux|5.6.2|linux|2.4.27-3-686|200809021742
2126957|2126957-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Data-Compare|1.21|i686-linux|5.10.0|linux|2.4.27-2-386|200809022101
2127042|2127042-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809021603
2127349|2127349-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809021425
2127399|2127399-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Data-Compare|1.21|i586-linux-thread-multi|5.8.8|linux|2.6.16|200809022139
2127698|2127698-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809022243
2127723|2127723-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809022254
2127739|2127739-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200809022153
2128059|2128059-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809030011
2128162|2128162-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200809022328
2128314|2128314-b19f-3f77-b713-d32bba55d77f|pass|200809|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.21|sun4-solaris|5.10.0|solaris|2.8|200809021035
2128711|2128711-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34238|openbsd|4.1|200809030050
2128775|2128775-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|i686-linux|5.8.8|linux|2.4.27-3-686|200809030101
2129258|2129258-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200809030255
2129836|2129836-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809030817
2130314|2130314-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809030928
2130745|2130745-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34243|linux|2.6.22-1-k7|200809031006
2131867|2131867-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.10.0|solaris|2.11|200809031242
2132073|2132073-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809031339
2132570|2132570-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Data-Compare|1.200_500|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031533
2132572|2132572-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031534
2132621|2132621-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Devel-CheckOS|1.43|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809031543
2132704|2132704-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809031335
2132760|2132760-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809031347
2132788|2132788-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|i686-linux|5.8.8|linux|2.4.27-3-686|200809031526
2132967|2132967-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809031015
2133120|2133120-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|IP35-irix-64int|5.8.8|irix|6.5|200809031755
2133127|2133127-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|IP35-irix-64int|5.8.8|irix|6.5|200809031756
2134058|2134058-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809032134
2134276|2134276-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.4.27-3-686|200809032122
2134304|2134304-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809032125
2134327|2134327-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.10.0|freebsd|6.1-release|200809032232
2134426|2134426-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200809032244
2134428|2134428-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200809032244
2134429|2134429-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200809032245
2134431|2134431-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.8.8|linux|2.6.14|200809032245
2134432|2134432-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200809032245
2134542|2134542-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.01|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200809032244
2134677|2134677-b19f-3f77-b713-d32bba55d77f|fail|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200809032345
2135029|2135029-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.24.2-fuuka.profvince.com|200809040049
2135133|2135133-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|i686-linux|5.6.2|linux|2.4.27-3-686|200809040028
2136726|2136726-b19f-3f77-b713-d32bba55d77f|fail|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809040443
2136741|2136741-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.200_500|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809040445
2136884|2136884-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200809040528
2136914|2136914-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Class-DBI-ClassGenerator|1.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200809040912
2136974|2136974-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.6.2|freebsd|6.1-release|200809041033
2137123|2137123-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200809041109
2137189|2137189-b19f-3f77-b713-d32bba55d77f|pass|200809|claco@chrislaco.com|Data-Compare|1.21|darwin-thread-multi-2level|5.8.8|darwin|9.0|200809031956
2137306|2137306-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809041141
2137485|2137485-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200809040720
2137803|2137803-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809041316
2138046|2138046-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0 patch 34161|solaris|2.10|200809041517
2138691|2138691-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24.3|200809041233
2138785|2138785-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200809041704
2139060|2139060-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.10.0|solaris|2.11|200809042023
2140153|2140153-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809042353
2140156|2140156-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809042354
2140181|2140181-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050030
2140954|2140954-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200809050032
2140978|2140978-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050207
2141182|2141182-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809050112
2142272|2142272-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050642
2142646|2142646-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809050740
2143390|2143390-b19f-3f77-b713-d32bba55d77f|fail|200809|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809050959
2143413|2143413-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Data-Compare|1.21|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200809051001
2143584|2143584-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34266|linux|2.6.22-1-k7|200809050954
2144940|2144940-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|i86pc-solaris-64int|5.10.0|solaris|2.11|200809051418
2145002|2145002-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809051336
2145208|2145208-b19f-3f77-b713-d32bba55d77f|pass|200809|jrockway@cpan.org|Data-Compare|1.21|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200809050656
2145547|2145547-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809051514
2145666|2145666-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.6.24.3|200809051039
2146109|2146109-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.8|linux|2.6.24.3|200809051232
2146110|2146110-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.8|linux|2.6.24.3|200809051232
2146406|2146406-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809051828
2146859|2146859-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200809052042
2146903|2146903-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200809052044
2146936|2146936-b19f-3f77-b713-d32bba55d77f|pass|200809|shlomif@cpan.org|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.26.2-desktop-2mnb|200809052248
2146953|2146953-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Data-Compare|1.21|IP35-irix-64int|5.8.8|irix|6.5|200809052153
2147039|2147039-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200809052103
2147815|2147815-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060038
2148192|2148192-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809060001
2148403|2148403-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060245
2148500|2148500-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060246
2148806|2148806-b19f-3f77-b713-d32bba55d77f|pass|200809|rjbs@cpan.org|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.1.0|200809060200
2148848|2148848-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060205
2148887|2148887-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200809060310
2149478|2149478-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060620
2150047|2150047-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34279|linux|2.6.22-1-k7|200809060919
2150562|2150562-b19f-3f77-b713-d32bba55d77f|pass|200809|dillman@ria.buffalo.edu|Data-Compare|1.21|sun4-solaris|5.10.0|solaris|2.9|200809051516
2151414|2151414-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-ld|5.11.0 patch 34282|linux|2.6.21.5-smp|200809061758
2151492|2151492-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809061318
2152473|2152473-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24.3|200809061749
2152821|2152821-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809062350
2152856|2152856-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070133
2153132|2153132-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070233
2154234|2154234-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070700
2154322|2154322-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070719
2154565|2154565-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34301|linux|2.6.22-1-k7|200809070831
2155585|2155585-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.8|linux|2.6.24.3|200809070542
2155658|2155658-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24.3|200809070555
2156076|2156076-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-ld|5.11.0 patch 34282|linux|2.6.21.5-smp|200809071257
2156378|2156378-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.24.3|200809070934
2157510|2157510-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809071950
2158290|2158290-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809072204
2158758|2158758-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|IP35-irix-64int|5.8.8|irix|6.5|200809072310
2158801|2158801-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.8|linux|2.4.27-3-686|200809072214
2159044|2159044-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200809072251
2159070|2159070-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200809072254
2159366|2159366-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.24.3|200809071842
2159738|2159738-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809080100
2159772|2159772-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809080116
2160285|2160285-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809080652
2160582|2160582-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809080745
2161534|2161534-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809081021
2161756|2161756-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.10.0|solaris|2.11|200809081110
2162236|2162236-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809081327
2162663|2162663-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809080915
2164470|2164470-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0 patch 34305|netbsd|4.0|200809081903
2164719|2164719-b19f-3f77-b713-d32bba55d77f|pass|200809|dwheeler@cpan.org|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.4.0|200809081854
2164829|2164829-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Net-Random|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809082106
2165191|2165191-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809081551
2165321|2165321-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809082130
2166664|2166664-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34304|linux|2.6.22-1-k7|200809090041
2166850|2166850-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200809090011
2166888|2166888-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200809090017
2166963|2166963-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.10.0|solaris|2.11|200809090135
2168102|2168102-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809090453
2168515|2168515-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8 patch 34313|netbsd|4.0|200809090446
2168549|2168549-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809090530
2168917|2168917-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.8.8|linux|2.6.24.3|200809090101
2169493|2169493-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809090845
2169887|2169887-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809091001
2170196|2170196-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.24.3|200809090442
2170228|2170228-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24.3|200809090445
2170535|2170535-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809091035
2170688|2170688-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809091146
2171000|2171000-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34322|linux|2.6.22-1-k7|200809091224
2171365|2171365-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809090717
2172415|2172415-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24.3|200809090948
2173132|2173132-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Class-DBI-ClassGenerator|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809091118
2173799|2173799-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809091905
2173893|2173893-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809091923
2174004|2174004-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809091941
2174587|2174587-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809092124
2174928|2174928-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809092215
2175725|2175725-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200809100019
2176322|2176322-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809100330
2177303|2177303-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.10.0 patch 34305|netbsd|4.0|200809100536
2177586|2177586-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-Treo680MessagesDB|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809100233
2178345|2178345-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34305|linux|2.6.22-1-k7|200809100908
2179057|2179057-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100846
2179468|2179468-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Devel-CheckOS|1.43|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100846
2179568|2179568-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179569|2179569-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179797|2179797-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-64int|5.10.0|freebsd|7.0-release|200809100822
2179849|2179849-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100847
2179889|2179889-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2179938|2179938-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2180325|2180325-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100848
2180393|2180393-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809100845
2180813|2180813-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809101259
2180933|2180933-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0 patch 34325|freebsd|7.0-release|200809101058
2182471|2182471-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809101709
2182493|2182493-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-netbsd-thread-multi-64int|5.8.8 patch 34313|netbsd|4.0|200809101525
2182526|2182526-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8 patch 34327|freebsd|7.0-release|200809101506
2183605|2183605-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200809102018
2183883|2183883-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809101945
2184050|2184050-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.24.3|200809101520
2184500|2184500-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102241
2184805|2184805-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809102322
2185551|2185551-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-64int-ld|5.10.0|linux|2.6.24.5-smp|200809110110
2186886|2186886-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809110758
2186951|2186951-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809110813
2187759|2187759-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809110955
2188217|2188217-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111052
2188457|2188457-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111110
2188515|2188515-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111117
2189291|2189291-b19f-3f77-b713-d32bba55d77f|fail|200809|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200809111240
2189385|2189385-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809111252
2189538|2189538-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809111311
2189654|2189654-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809111325
2190278|2190278-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809111426
2191574|2191574-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34327|linux|2.6.22-1-k7|200809111659
2192929|2192929-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.8|linux|2.6.24.3|200809111332
2193628|2193628-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Data-Compare|1.21|i86pc-solaris-thread-multi|5.10.0|solaris|2.11|200809120152
2194022|2194022-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34325|freebsd|7.0-release|200809111951
2194874|2194874-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8 patch 34327|freebsd|7.0-release|200809112155
2195859|2195859-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809120405
2195893|2195893-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809120514
2196189|2196189-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809120114
2196789|2196789-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200809120852
2197199|2197199-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Longest|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809121015
2197203|2197203-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Statistics-ChiSquare|0.5|i86pc-solaris-64int|5.10.0|solaris|2.11|200809121015
2197209|2197209-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.24.3|200809120417
2197970|2197970-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809121217
2200967|2200967-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809121821
2201560|2201560-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|NestedMap|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809122005
2202046|2202046-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809122121
2202341|2202341-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.6.24.3|200809121558
2202370|2202370-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809121602
2203007|2203007-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809122334
2203270|2203270-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809122156
2203548|2203548-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809121901
2204171|2204171-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.8|linux|2.6.24.3|200809130040
2206477|2206477-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200809130456
2206563|2206563-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809130623
2206854|2206854-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|darwin-2level|5.8.8|darwin|8.10.1|200809130639
2207038|2207038-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809130738
2207162|2207162-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34354|linux|2.6.22-1-k7|200809130749
2207391|2207391-b19f-3f77-b713-d32bba55d77f|unknown|200809|JOST@cpan.org ("Josts Smokehouse")|Acme-Licence|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200809130817
2209250|2209250-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809131320
2209305|2209305-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34342|linux|2.6.24.5-smp|200809131218
2209944|2209944-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 34347|linux|2.6.24.5-smp|200809131408
2210024|2210024-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24.3|200809130931
2210032|2210032-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.8|linux|2.6.24.3|200809130932
2211035|2211035-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809131806
2211723|2211723-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24.3|200809131419
2213262|2213262-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.8|linux|2.6.24.3|200809131828
2214291|2214291-b19f-3f77-b713-d32bba55d77f|unknown|200809|JOST@cpan.org ("Josts Smokehouse")|Acme-Pony|1.1.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200809140253
2214362|2214362-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809140301
2214565|2214565-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200809140355
2216453|2216453-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34342|linux|2.6.22-1-k7|200809140830
2216455|2216455-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.8 patch 34347|solaris|2.10|200809140729
2216472|2216472-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34342|linux|2.6.22-1-k7|200809140834
2216530|2216530-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.8|linux|2.6.24.3|200809140241
2216571|2216571-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200809140745
2217634|2217634-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.8|linux|2.6.24.3|200809140716
2217915|2217915-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.24.3|200809140815
2218095|2218095-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.24.3|200809140844
2218653|2218653-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.24.3|200809141107
2220303|2220303-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809142146
2220467|2220467-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809142250
2220769|2220769-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809142343
2221043|2221043-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150019
2221441|2221441-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150114
2221518|2221518-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150145
2222888|2222888-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200809150543
2222968|2222968-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.10.0 patch 34342|freebsd|7.0-release|200809150451
2223014|2223014-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150650
2223018|2223018-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.10.0|linux|2.6.24.3|200809150058
2223485|2223485-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809150710
2223644|2223644-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34360|linux|2.6.22-1-k7|200809150759
2226111|2226111-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.8|linux|2.6.24.3|200809151119
2226205|2226205-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.8|linux|2.6.24.3|200809151148
2226565|2226565-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.6.24.3|200809151239
2228780|2228780-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8 patch 34360|freebsd|7.0-release|200809160415
2229376|2229376-b19f-3f77-b713-d32bba55d77f|pass|200809|feldt@nhn.ou.edu|Data-Compare|1.21|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200809151343
2232416|2232416-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.10.0 patch 34372|linux|2.6.24-19-generic|200809170320
2233753|2233753-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809171121
2234064|2234064-b19f-3f77-b713-d32bba55d77f|pass|200809|dmdk1@comcast.net|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809170640
2235521|2235521-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809171951
2235523|2235523-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809171952
2236401|2236401-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809172122
2236480|2236480-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8 patch 34376|linux|2.6.24-19-generic|200809172047
2236751|2236751-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Data-Compare|1.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200809172332
2236778|2236778-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809172334
2237726|2237726-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34378|linux|2.6.24-19-generic|200809172353
2237796|2237796-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.8.8|linux|2.6.24.3|200809171902
2238524|2238524-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-freebsd-thread-multi-64int|5.8.8 patch 34376|freebsd|6.2-release|200809180053
2238607|2238607-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.8|linux|2.6.24.3|200809180105
2238659|2238659-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180212
2238665|2238665-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180212
2238669|2238669-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180213
2238701|2238701-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Bryar|3.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180218
2238722|2238722-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPAN-FindDependencies|2.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180221
2238727|2238727-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPU-Emulator-Memory|1.1001|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180222
2238745|2238745-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180325
2238766|2238766-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|CPU-Emulator-Z80|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180228
2238776|2238776-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Class-CanBeA|1.2|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180229
2238813|2238813-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Class-DBI-ClassGenerator|1.01|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180234
2238901|2238901-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|DBIx-Class-SingletonRows|0.11|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180245
2238908|2238908-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180245
2238916|2238916-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Transactional|1.02|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180246
2238924|2238924-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180247
2238937|2238937-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|File-Find-Rule-Permissions|1.3|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180248
2238941|2238941-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|File-Overwrite|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180249
2238945|2238945-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Games-Dice-Advanced|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180249
2238948|2238948-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|NestedMap|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180250
2238956|2238956-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Net-Random|2.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180252
2238963|2238963-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Number-Phone|1.6|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180253
2238976|2238976-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Number-Phone-UK-DetailedLocations|1.3|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180255
2238977|2238977-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180355
2239002|2239002-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Palm-Treo680MessagesDB|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180258
2239018|2239018-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Palm-TreoPhoneCallDB|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180300
2239023|2239023-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Sort-MultipleFields|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180301
2239033|2239033-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Statistics-ChiSquare|0.5|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180302
2239042|2239042-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Statistics-SerialCorrelation|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180303
2239047|2239047-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Sub-WrapPackages|1.2|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180304
2239048|2239048-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Tie-Hash-Longest|1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180304
2239051|2239051-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Tie-Hash-Rank|1.0.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180305
2239057|2239057-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Tie-STDOUT|1.03|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180306
2239060|2239060-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Tie-Scalar-Decay|1.1.1|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180307
2239066|2239066-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180308
2239072|2239072-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809180309
2239564|2239564-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180543
2240143|2240143-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34378|linux|2.6.22-1-k7|200809180743
2240621|2240621-b19f-3f77-b713-d32bba55d77f|pass|200809|rlane10@wi.rr.com|Data-Compare|1.21|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5xen|200809171734
2242839|2242839-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200809182205
2244075|2244075-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200809190651
2245958|2245958-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191226
2246060|2246060-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191305
2246291|2246291-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191259
2246429|2246429-b19f-3f77-b713-d32bba55d77f|pass|200809|rlane10@wi.rr.com|Data-Compare|1.21|darwin-2level-ld|5.10.0|darwin|8.11.0|200809190145
2246637|2246637-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Data-Compare|1.21|i686-linux|5.8.8|linux|2.4.27-2-386|200809191143
2246666|2246666-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191147
2246685|2246685-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809191137
2247058|2247058-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34379|linux|2.6.24.3|200809190942
2247620|2247620-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i686-linux-thread-multi-64int-ld|5.11.0 patch 34379|linux|2.6.21.5-smp|200809191726
2247631|2247631-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.8.8 patch 34376|dragonfly|2.0.0-release|200809191814
2248904|2248904-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192112
2248907|2248907-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192112
2250153|2250153-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192113
2250570|2250570-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192112
2250695|2250695-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 34313|freebsd|6.1-release-p23|200809192113
2250965|2250965-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Devel-CheckOS|1.43|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809192322
2252554|2252554-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.43|i386-dragonfly-thread-multi-64int|5.10.0 patch 34372|dragonfly|2.0.0-release|200809200237
2253129|2253129-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34376|linux|2.6.22-1-k7|200809200458
2254479|2254479-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.8|linux|2.6.24.3|200809200851
2257805|2257805-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809210901
2258126|2258126-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809210954
2258972|2258972-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.26.5|200809210654
2259096|2259096-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809210730
2259896|2259896-b19f-3f77-b713-d32bba55d77f|pass|200809|shlomif@cpan.org|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.27-desktop-0.rc6.3.2mnb|200809211534
2259900|2259900-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.8.8|linux|2.6.26.5|200809210835
2259935|2259935-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809211442
2261013|2261013-b19f-3f77-b713-d32bba55d77f|fail|200809|vpit@cpan.org|Bryar|3.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809211725
2261749|2261749-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809211920
2262089|2262089-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809211948
2263304|2263304-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809212219
2264023|2264023-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34384|linux|2.6.22-1-k7|200809220007
2267038|2267038-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.01|i686-linux|5.10.0|linux|2.4.27-2-386|200809220120
2270334|2270334-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Data-Hexdumper|1.4|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809230309
2272202|2272202-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230108
2272391|2272391-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230118
2273987|2273987-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230243
2274657|2274657-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230315
2275372|2275372-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230356
2276210|2276210-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230438
2276822|2276822-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230510
2277905|2277905-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809230605
2278342|2278342-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200809230630
2278630|2278630-b19f-3f77-b713-d32bba55d77f|pass|200809|andy@hexten.net|Devel-CheckLib|0.5|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809231241
2278891|2278891-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809230655
2279583|2279583-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.26.5|200809230813
2279896|2279896-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.26.5|200809230902
2282157|2282157-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.43|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231319
2282765|2282765-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231409
2282820|2282820-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.8|linux|2.6.26.5|200809231412
2282898|2282898-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231419
2283100|2283100-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809231436
2283878|2283878-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809231648
2284464|2284464-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231822
2284488|2284488-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809231825
2284690|2284690-b19f-3f77-b713-d32bba55d77f|pass|200809|stro@cpan.org|Class-DBI-ClassGenerator|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200809240157
2285740|2285740-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.8|linux|2.6.26.5|200809240143
2286365|2286365-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809240446
2286699|2286699-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809240451
2288619|2288619-b19f-3f77-b713-d32bba55d77f|pass|200809|jeff@zeroclue.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.2.0|200809240350
2291076|2291076-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.8|linux|2.6.26.5|200809241242
2291763|2291763-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.26.5|200809241416
2292092|2292092-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809241509
2294629|2294629-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250030
2296227|2296227-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250025
2296959|2296959-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250204
2297496|2297496-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250318
2297597|2297597-b19f-3f77-b713-d32bba55d77f|pass|200809|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200809250331
2302018|2302018-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.8.8|linux|2.6.26.5|200809251429
2302099|2302099-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.10.0|linux|2.6.26.5|200809251442
2309012|2309012-b19f-3f77-b713-d32bba55d77f|pass|200809|mgardner@usatech.com|Data-Compare|1.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200809261128
2309548|2309548-b19f-3f77-b713-d32bba55d77f|pass|200809|gabor@pti.co.il ("Gabor Szabo")|Devel-CheckOS|1.43|i486-linux-gnu|5.8.8|linux|2.6.15.7|200809261932
2312149|2312149-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270000
2312313|2312313-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270037
2312446|2312446-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270100
2312499|2312499-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270110
2312505|2312505-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270111
2312544|2312544-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270119
2312597|2312597-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270128
2312628|2312628-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270134
2312795|2312795-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270201
2312978|2312978-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270224
2313151|2313151-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809270448
2313310|2313310-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270310
2313316|2313316-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270310
2313639|2313639-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270349
2313864|2313864-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270025
2313873|2313873-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270027
2313923|2313923-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270027
2314486|2314486-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270235
2314715|2314715-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270323
2314721|2314721-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270324
2314737|2314737-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270327
2314821|2314821-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.8|linux|2.6.26.5|200809270350
2314935|2314935-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270418
2315002|2315002-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270429
2315044|2315044-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.8|linux|2.6.26.5|200809270437
2315047|2315047-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270438
2315100|2315100-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.8|linux|2.6.26.5|200809270445
2315158|2315158-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270455
2315184|2315184-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.8|linux|2.6.26.5|200809270459
2315312|2315312-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.8|linux|2.6.26.5|200809270525
2315331|2315331-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270527
2315436|2315436-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270540
2315811|2315811-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.8|linux|2.6.26.5|200809270632
2315816|2315816-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.8|linux|2.6.26.5|200809270633
2315825|2315825-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270633
2315835|2315835-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.11.0 patch 34383|linux|2.6.26.5|200809270635
2316116|2316116-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.8.8|linux|2.6.26.5|200809270712
2316271|2316271-b19f-3f77-b713-d32bba55d77f|pass|200809|eshank@drwholdings.com|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809261140
2316346|2316346-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809271246
2316400|2316400-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.8|linux|2.6.26.5|200809270757
2316405|2316405-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270758
2316406|2316406-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.8|linux|2.6.26.5|200809270758
2316478|2316478-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.8|linux|2.6.26.5|200809270808
2316644|2316644-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809270838
2316652|2316652-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.8|linux|2.6.26.5|200809270840
2316677|2316677-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.8|linux|2.6.26.5|200809270844
2316816|2316816-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.8|linux|2.6.26.5|200809270913
2317346|2317346-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.26.5|200809271226
2317418|2317418-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.8|linux|2.6.26.5|200809271241
2317421|2317421-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.8|linux|2.6.26.5|200809271242
2317491|2317491-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271256
2317583|2317583-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271305
2317661|2317661-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.26.5|200809271316
2317671|2317671-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271317
2317715|2317715-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.26.5|200809271322
2317727|2317727-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809271923
2317778|2317778-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271330
2317821|2317821-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.26.5|200809271335
2317935|2317935-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.26.5|200809271348
2318062|2318062-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271359
2318391|2318391-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.26.5|200809271435
2318395|2318395-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.26.5|200809271436
2318736|2318736-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.10.0|linux|2.6.26.5|200809271505
2318831|2318831-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809272029
2318871|2318871-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.26.5|200809271519
2318877|2318877-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271520
2318880|2318880-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.26.5|200809271520
2318903|2318903-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.26.5|200809271524
2319004|2319004-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271550
2319010|2319010-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.26.5|200809271551
2319035|2319035-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.26.5|200809271557
2319157|2319157-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.26.5|200809271616
2319483|2319483-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.10.0|linux|2.6.26.5|200809271708
2319498|2319498-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.26.5|200809271713
2322337|2322337-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34412|linux|2.6.22-1-k7|200809280900
2323841|2323841-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281313
2324323|2324323-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281350
2325540|2325540-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281607
2325883|2325883-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281411
2326598|2326598-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809281754
2327831|2327831-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34435|linux|2.6.22-1-k7|200809282012
2335378|2335378-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0 patch 33955|linux|2.6.22-1-k7|200809291729
2335380|2335380-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200809291729
2335382|2335382-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8 patch 33994|linux|2.6.22-1-k7|200809291729
2335386|2335386-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200809291730
2335389|2335389-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8|linux|2.6.14|200809291730
2335392|2335392-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200809291730
2336854|2336854-b19f-3f77-b713-d32bba55d77f|fail|200809|chris@bingosnet.co.uk|Palm-SMS|0.02|darwin-thread-multi-64int-2level|5.8.8 patch 34327|darwin|8.10.0|200809291916
2337033|2337033-b19f-3f77-b713-d32bba55d77f|fail|200809|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200809300340
2337154|2337154-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200809292051
2337323|2337323-b19f-3f77-b713-d32bba55d77f|fail|200809|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291512
2337451|2337451-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.43|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809292130
2337521|2337521-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809292123
2337627|2337627-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291552
2337779|2337779-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809292158
2339049|2339049-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.43|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809291830
2339181|2339181-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200809292343
2339185|2339185-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int|5.6.2|darwin|8.10.0|200809292344
2339198|2339198-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809292346
2339210|2339210-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809292348
2339578|2339578-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809300028
2339645|2339645-b19f-3f77-b713-d32bba55d77f|pass|200809|flemming@ipk-gatersleben.de|Data-Compare|1.21|x86_64-linux|5.8.5|linux|2.6.9-55.0.9.elsmp|200809291527
2339791|2339791-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809300132
2339931|2339931-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300003
2340018|2340018-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809300215
2342112|2342112-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.10.0|freebsd|6.1-release|200809300836
2342658|2342658-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300359
2342758|2342758-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200809300923
2342820|2342820-b19f-3f77-b713-d32bba55d77f|pass|200809|chris@bingosnet.co.uk|XML-Tiny|1.11|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200809300936
2342845|2342845-b19f-3f77-b713-d32bba55d77f|pass|200809|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.44|i86pc-solaris-64int|5.10.0|solaris|2.11|200809301041
2343727|2343727-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200809301219
2343785|2343785-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200809300738
2343916|2343916-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|IP35-irix-64int|5.8.8|irix|6.5|200809301357
2343943|2343943-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200809301300
2343970|2343970-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.4.27-3-686|200809301306
2344168|2344168-b19f-3f77-b713-d32bba55d77f|fail|200809|hohokus@gmail.com|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200809300838
2344321|2344321-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|i686-linux|5.6.2|linux|2.4.27-3-686|200809301358
2344441|2344441-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|XML-Tiny|1.11|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809301419
2344936|2344936-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200809300930
2345254|2345254-b19f-3f77-b713-d32bba55d77f|pass|200809|david@cantrell.org.uk|Devel-CheckOS|1.44|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200809301522
2345303|2345303-b19f-3f77-b713-d32bba55d77f|pass|200809|martin.evans@easysoft.com|Devel-CheckOS|1.44|i686-linux-ld|5.10.0|linux|2.6.24-19-generic|200809301631
2345328|2345328-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8 patch 34439|netbsd|4.0|200809301628
2345369|2345369-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.6.2|freebsd|6.1-release|200809301737
2345442|2345442-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200809301745
2345463|2345463-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200809301747
2345489|2345489-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200809301750
2345644|2345644-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200809301820
2345731|2345731-b19f-3f77-b713-d32bba55d77f|pass|200809|g.grigelionis@computer.org|Devel-CheckOS|1.44|i586-linux-thread-multi|5.8.8|linux|2.6.16|200809301848
2345835|2345835-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0 patch 34437|netbsd|4.0|200809301800
2345902|2345902-b19f-3f77-b713-d32bba55d77f|pass|200809|vpit@cpan.org|Devel-CheckOS|1.44|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200809301921
2346083|2346083-b19f-3f77-b713-d32bba55d77f|pass|200809|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.10.0|linux|2.6.26.5|200809301352
2346495|2346495-b19f-3f77-b713-d32bba55d77f|pass|200809|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200809302053
2346541|2346541-b19f-3f77-b713-d32bba55d77f|pass|200809|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200809302059
2346554|2346554-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.11.0 patch 34444|netbsd|4.0|200809301957
2347621|2347621-b19f-3f77-b713-d32bba55d77f|pass|200809|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.11.0 patch 34448|freebsd|6.2-release|200809301612
2348573|2348573-b19f-3f77-b713-d32bba55d77f|pass|200809|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.44|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5xen|200809300833
2350694|2350694-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.6.26.5|200810010205
2351580|2351580-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010457
2351637|2351637-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010509
2351789|2351789-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010542
2351821|2351821-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010547
2351822|2351822-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010547
2351852|2351852-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010553
2351853|2351853-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010553
2351900|2351900-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010600
2351912|2351912-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010603
2351970|2351970-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010615
2352031|2352031-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010625
2352092|2352092-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010644
2352098|2352098-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010644
2352196|2352196-b19f-3f77-b713-d32bba55d77f|fail|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.20|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010701
2352283|2352283-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010718
2352285|2352285-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010718
2352286|2352286-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010718
2352415|2352415-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010758
2352501|2352501-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010816
2352502|2352502-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010817
2352512|2352512-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010820
2352544|2352544-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010829
2352706|2352706-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200810011515
2352827|2352827-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010943
2352829|2352829-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.11.0 patch 34435|linux|2.6.26.5|200810010943
2354265|2354265-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810011736
2355010|2355010-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200810012054
2355042|2355042-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200810012104
2355309|2355309-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.11.0 patch 34451|freebsd|7.0-release|200810012041
2357351|2357351-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810020504
2357354|2357354-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200810020505
2357359|2357359-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.2|netbsd|3.1|200810020506
2357363|2357363-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.3|netbsd|3.1|200810020507
2357367|2357367-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.4|netbsd|3.1|200810020507
2357371|2357371-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.5|netbsd|3.1|200810020508
2357380|2357380-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.6|netbsd|3.1|200810020509
2357386|2357386-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810020510
2357391|2357391-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810020510
2358373|2358373-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810020824
2358649|2358649-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810020842
2358794|2358794-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810020757
2359161|2359161-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200810020905
2359337|2359337-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810021013
2361236|2361236-b19f-3f77-b713-d32bba55d77f|pass|200810|rlane10@wi.rr.com|Devel-CheckOS|1.44|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.6.el5xen|200810020617
2363266|2363266-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810022037
2363552|2363552-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810021809
2363838|2363838-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810021830
2364436|2364436-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34450|linux|2.6.22-1-k7|200810022223
2365777|2365777-b19f-3f77-b713-d32bba55d77f|pass|200810|rlane10@wi.rr.com|Devel-CheckOS|1.44|darwin-2level-ld|5.10.0|darwin|8.11.0|200810021301
2366104|2366104-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810030138
2366361|2366361-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810030315
2366661|2366661-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810030522
2366665|2366665-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810030523
2366669|2366669-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810030525
2372448|2372448-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.7|linux|2.6.26.5|200810031624
2373001|2373001-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.7|linux|2.6.26.5|200810031758
2373652|2373652-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.7|linux|2.6.26.5|200810040007
2373731|2373731-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0 patch 34445|freebsd|7.0-release|200810040024
2373780|2373780-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8 patch 34450|freebsd|7.0-release|200810040031
2374313|2374313-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.7|linux|2.6.26.5|200810040228
2374876|2374876-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|OpenBSD.i386-openbsd-thread-multi-64int|5.11.0 patch 34456|openbsd|4.2|200810040217
2378123|2378123-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.8.6|linux|2.6.26.5|200810040907
2379530|2379530-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Bryar|3.0|i686-linux|5.8.6|linux|2.6.26.5|200810041330
2380687|2380687-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Hexdumper|1.4|i686-linux|5.8.6|linux|2.6.26.5|200810041718
2381463|2381463-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Compare|1.21|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810041930
2382914|2382914-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.8.6|linux|2.6.26.5|200810060430
2384752|2384752-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Palm-SMS|0.02|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810061018
2386783|2386783-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810062050
2386863|2386863-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810062112
2387692|2387692-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810062332
2387762|2387762-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810062317
2388111|2388111-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810070108
2389245|2389245-b19f-3f77-b713-d32bba55d77f|pass|200810|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.44|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810071033
2389583|2389583-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810070515
2390588|2390588-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810070830
2392379|2392379-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810071232
2392460|2392460-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.7|linux|2.6.26.5|200810070640
2392462|2392462-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.7|linux|2.6.26.5|200810070641
2392480|2392480-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.7|linux|2.6.26.5|200810070643
2392485|2392485-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.7|linux|2.6.26.5|200810070643
2392700|2392700-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.7|linux|2.6.26.5|200810070706
2393059|2393059-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.7|linux|2.6.26.5|200810070757
2393415|2393415-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.7|linux|2.6.26.5|200810070845
2394310|2394310-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.7|linux|2.6.26.5|200810071113
2394327|2394327-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071115
2394350|2394350-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.7|linux|2.6.26.5|200810071118
2394559|2394559-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.7|linux|2.6.26.5|200810071146
2394604|2394604-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.7|linux|2.6.26.5|200810071150
2394616|2394616-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071151
2395006|2395006-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.7|linux|2.6.26.5|200810071238
2395145|2395145-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.7|linux|2.6.26.5|200810071250
2395438|2395438-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071326
2395613|2395613-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810071843
2395781|2395781-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.7|linux|2.6.26.5|200810071408
2396275|2396275-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.7|linux|2.6.26.5|200810071516
2397251|2397251-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.7|linux|2.6.26.5|200810071712
2397252|2397252-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071712
2397253|2397253-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071712
2397323|2397323-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.7|linux|2.6.26.5|200810071721
2397374|2397374-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071726
2397382|2397382-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071728
2397824|2397824-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.7|linux|2.6.26.5|200810071837
2397861|2397861-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810071841
2398034|2398034-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080002
2398537|2398537-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080002
2398624|2398624-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080112
2398627|2398627-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080112
2399199|2399199-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080220
2399200|2399200-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080220
2399215|2399215-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080123
2399310|2399310-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080240
2399311|2399311-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810080240
2399487|2399487-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone|1.6|i686-linux|5.8.6|linux|2.6.26.5|200810080203
2399488|2399488-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.6|linux|2.6.26.5|200810080204
2399545|2399545-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-SerialCorrelation|1.1|i686-linux|5.8.6|linux|2.6.26.5|200810080216
2399550|2399550-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-CanBeA|1.2|i686-linux|5.8.6|linux|2.6.26.5|200810080217
2399570|2399570-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810080323
2400188|2400188-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080354
2400201|2400201-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080355
2400205|2400205-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080357
2400344|2400344-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080020
2400375|2400375-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080024
2400381|2400381-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080025
2400672|2400672-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Rank|1.0.1|i686-linux|5.8.6|linux|2.6.26.5|200810080103
2400758|2400758-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080117
2400962|2400962-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080145
2401241|2401241-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080229
2401256|2401256-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sub-WrapPackages|1.2|i686-linux|5.8.6|linux|2.6.26.5|200810080232
2401425|2401425-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810080304
2401687|2401687-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Hash-Longest|1.1|i686-linux|5.8.6|linux|2.6.26.5|200810080346
2403309|2403309-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081519
2403986|2403986-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.6|linux|2.6.26.5|200810081127
2404020|2404020-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Sort-MultipleFields|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081130
2404034|2404034-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Net-Random|2.0|i686-linux|5.8.6|linux|2.6.26.5|200810081132
2404177|2404177-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081739
2404347|2404347-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Tie-STDOUT|1.03|i686-linux|5.8.6|linux|2.6.26.5|200810081205
2404417|2404417-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Memory|1.1001|i686-linux|5.8.6|linux|2.6.26.5|200810081212
2404428|2404428-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|CPU-Emulator-Z80|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081213
2404578|2404578-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810081730
2404816|2404816-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081854
2404994|2404994-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081912
2405186|2405186-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810081836
2405256|2405256-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Statistics-ChiSquare|0.5|i686-linux|5.8.6|linux|2.6.26.5|200810081345
2405326|2405326-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810081953
2405457|2405457-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810081909
2405496|2405496-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Games-Dice-Advanced|1.1|i686-linux|5.8.6|linux|2.6.26.5|200810081413
2405826|2405826-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|NestedMap|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081450
2406205|2406205-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Data-Transactional|1.02|i686-linux|5.8.6|linux|2.6.26.5|200810081530
2406514|2406514-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.8.6|linux|2.6.26.5|200810081629
2406680|2406680-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810082151
2406981|2406981-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810082229
2407181|2407181-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Class-DBI-ClassGenerator|1.01|i686-linux|5.8.6|linux|2.6.26.5|200810081801
2407241|2407241-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Overwrite|1.0|i686-linux|5.8.6|linux|2.6.26.5|200810081808
2407740|2407740-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckLib|0.5|i686-linux|5.8.6|linux|2.6.26.5|200810081940
2408656|2408656-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34465|linux|2.6.22-1-k7|200810090900
2408741|2408741-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|File-Find-Rule-Permissions|1.3|i686-linux|5.11.0 patch 34456|linux|2.6.26.5|200810090314
2410831|2410831-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.10.0|linux|2.6.26.6|200810091027
2411206|2411206-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.6.26.6|200810091126
2411451|2411451-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.7|linux|2.6.26.6|200810091200
2411847|2411847-b19f-3f77-b713-d32bba55d77f|pass|200810|rick@jrmyers.net ("Rick Myers")|Devel-CheckOS|1.44|i686-linux|5.8.6|linux|2.6.26.6|200810091249
2412109|2412109-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810091157
2415526|2415526-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810100234
2415612|2415612-b19f-3f77-b713-d32bba55d77f|pass|200810|rafl@debian.org|Devel-CheckOS|1.44|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200810100449
2416834|2416834-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810101125
2418723|2418723-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810102248
2418784|2418784-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810102304
2419263|2419263-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810110123
2421100|2421100-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810111405
2422180|2422180-b19f-3f77-b713-d32bba55d77f|pass|200810|bobtfish@bobtfish.net|XML-Tiny|1.11|darwin-thread-multi-2level|5.8.6|darwin|8.0|200810112343
2423591|2423591-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200810121816
2423624|2423624-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200810121825
2426648|2426648-b19f-3f77-b713-d32bba55d77f|pass|200810|andy@hexten.net|Devel-CheckOS|1.44|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200810131955
2428930|2428930-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140103
2429590|2429590-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810140051
2430265|2430265-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140047
2430274|2430274-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140048
2430283|2430283-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140049
2430375|2430375-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140054
2430749|2430749-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140113
2431812|2431812-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140236
2432263|2432263-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140315
2433004|2433004-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140422
2433208|2433208-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140451
2433436|2433436-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140518
2433775|2433775-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140552
2433845|2433845-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140601
2434066|2434066-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140623
2434099|2434099-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140626
2434685|2434685-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140745
2434782|2434782-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140000
2435083|2435083-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140831
2435324|2435324-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810140906
2435512|2435512-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810140948
2435778|2435778-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810141032
2435795|2435795-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810141034
2437103|2437103-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200810141734
2437120|2437120-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200810141738
2438337|2438337-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810150855
2438472|2438472-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810150851
2438808|2438808-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810150854
2439360|2439360-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810151026
2439526|2439526-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810150851
2439551|2439551-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810151054
2439931|2439931-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810151111
2440340|2440340-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810151129
2441130|2441130-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151701
2441253|2441253-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151730
2441288|2441288-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151737
2441374|2441374-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151755
2441749|2441749-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34482|linux|2.6.22-1-k7|200810151724
2442108|2442108-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810151925
2442170|2442170-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810151943
2442624|2442624-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810152056
2442929|2442929-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810152045
2443542|2443542-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810152301
2443632|2443632-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810152300
2445048|2445048-b19f-3f77-b713-d32bba55d77f|fail|200810|mthurn@cpan.org|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200810160055
2446197|2446197-b19f-3f77-b713-d32bba55d77f|fail|200810|alexchorny@gmail.com|Devel-CheckOS|1.44|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200810160657
2448136|2448136-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810162113
2449165|2449165-b19f-3f77-b713-d32bba55d77f|pass|200810|andy@hexten.net|Data-Hexdumper|1.4|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200810170121
2451647|2451647-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810172339
2451763|2451763-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810172340
2453135|2453135-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810180826
2453261|2453261-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810180826
2454735|2454735-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810181713
2454809|2454809-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.44|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810181733
2457101|2457101-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Devel-CheckOS|1.44|i686-linux|5.8.8|linux|2.4.27-2-386|200810190906
2457513|2457513-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810191252
2457553|2457553-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810191252
2458962|2458962-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810191305
2459015|2459015-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810191305
2463982|2463982-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810210000
2464503|2464503-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810210004
2464860|2464860-b19f-3f77-b713-d32bba55d77f|fail|200810|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810210001
2468226|2468226-b19f-3f77-b713-d32bba55d77f|pass|200810|davidp@preshweb.co.uk ("David Precious")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i486-linux-gnu|5.10.0|linux|2.6.26.1|200810211951
2469182|2469182-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.44|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810220802
2469824|2469824-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810220953
2470404|2470404-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810221158
2470612|2470612-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810221236
2470971|2470971-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810221344
2473021|2473021-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200810222203
2473031|2473031-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200810222204
2473033|2473033-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200810222205
2473060|2473060-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200810222159
2473064|2473064-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200810222203
2473065|2473065-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810222204
2473143|2473143-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34555|linux|2.6.22-1-k7|200810222219
2473302|2473302-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200810222304
2473339|2473339-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200810222312
2473532|2473532-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200810222320
2474135|2474135-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810222317
2474805|2474805-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810222317
2475248|2475248-b19f-3f77-b713-d32bba55d77f|fail|200810|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.45|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200810230753
2475451|2475451-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230042
2475879|2475879-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200810230118
2476257|2476257-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810230102
2476350|2476350-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810230106
2476362|2476362-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810230007
2476412|2476412-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810230109
2476585|2476585-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230042
2476637|2476637-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230040
2476647|2476647-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810230042
2476744|2476744-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 34467|freebsd|6.1-release-p23|200810230030
2476833|2476833-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810230207
2476865|2476865-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810230218
2476895|2476895-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810230222
2477132|2477132-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810230449
2477135|2477135-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810230450
2477139|2477139-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810230451
2477330|2477330-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810230626
2477361|2477361-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810230635
2477363|2477363-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810230636
2477713|2477713-b19f-3f77-b713-d32bba55d77f|pass|200810|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.45|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810231631
2477945|2477945-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810231041
2478227|2478227-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810231107
2478379|2478379-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.45|i86pc-solaris-64int|5.10.0|solaris|2.11|200810231248
2478472|2478472-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810231132
2478478|2478478-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|i686-linux|5.6.2|linux|2.4.27-3-686|200810231222
2478516|2478516-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.8.8 patch 33662|freebsd|6.1-release-p23|200810231244
2478663|2478663-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.10.0|freebsd|6.1-release|200810231414
2478685|2478685-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810231416
2478847|2478847-b19f-3f77-b713-d32bba55d77f|fail|200810|hohokus@gmail.com|Devel-CheckOS|1.45|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200810230941
2479494|2479494-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810231726
2479548|2479548-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810231842
2480107|2480107-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2480933|2480933-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232151
2480989|2480989-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.44|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232057
2481074|2481074-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|i686-linux|5.8.8|linux|2.4.27-3-686|200810232130
2481082|2481082-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.6.2|freebsd|6.1-release|200810232229
2481358|2481358-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810232100
2481577|2481577-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810232239
2481785|2481785-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240003
2482494|2482494-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240123
2482565|2482565-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200810240001
2483115|2483115-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200810240215
2483233|2483233-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810240655
2484095|2484095-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240824
2484114|2484114-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484151|2484151-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484233|2484233-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484461|2484461-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240822
2484591|2484591-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810240947
2485089|2485089-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810240958
2485503|2485503-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|IP35-irix-64int|5.8.8|irix|6.5|200810241215
2486019|2486019-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|i586-linux-thread-multi|5.8.8|linux|2.6.16|200810241428
2486095|2486095-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810241442
2486113|2486113-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34560|linux|2.6.22-1-k7|200810241439
2487352|2487352-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.45|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810241400
2488319|2488319-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.45|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810250250
2488744|2488744-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810250758
2490042|2490042-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200810251236
2490325|2490325-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251455
2490399|2490399-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251455
2490625|2490625-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251454
2491173|2491173-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810251546
2492058|2492058-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810251638
2492134|2492134-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Devel-CheckOS|1.45|i686-linux|5.8.8|linux|2.4.27-2-386|200810251741
2492206|2492206-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810251540
2492486|2492486-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810251609
2492844|2492844-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810251819
2492857|2492857-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810251722
2494614|2494614-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252226
2494749|2494749-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252223
2495081|2495081-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252225
2495509|2495509-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200810252129
2495552|2495552-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252226
2496066|2496066-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252228
2496163|2496163-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810252229
2496323|2496323-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810260009
2496562|2496562-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810260009
2496914|2496914-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34563|linux|2.6.22-1-k7|200810260107
2497613|2497613-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200810260509
2497640|2497640-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200810260550
2498986|2498986-b19f-3f77-b713-d32bba55d77f|pass|200810|rafl@debian.org|Devel-CheckOS|1.45|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200810261508
2499251|2499251-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810261651
2499275|2499275-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810261639
2499297|2499297-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810261714
2499318|2499318-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.45|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200810261821
2499468|2499468-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.45|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200810261939
2500305|2500305-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262156
2500744|2500744-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262157
2501284|2501284-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262302
2501355|2501355-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262157
2501608|2501608-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262151
2501723|2501723-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810262157
2502687|2502687-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810270422
2502805|2502805-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200810270652
2502865|2502865-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200810270725
2503585|2503585-b19f-3f77-b713-d32bba55d77f|pass|200810|autarch@urth.org|Devel-CheckOS|1.45|x86_64-linux-gnu|5.10.0|linux|2.6.24-15-server|200810270459
2504009|2504009-b19f-3f77-b713-d32bba55d77f|pass|200810|stro@cpan.org|Devel-CheckOS|1.45|i686-linux|5.10.0|linux|2.4.27-2-386|200810270430
2504185|2504185-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200810271210
2504471|2504471-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271551
2504937|2504937-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.45|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810271734
2505236|2505236-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810271551
2505240|2505240-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810271740
2505308|2505308-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810271749
2505629|2505629-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200810271709
2505988|2505988-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200810272139
2506062|2506062-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200810272155
2506063|2506063-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200810272156
2506064|2506064-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810272157
2506067|2506067-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200810272158
2506068|2506068-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200810272158
2506737|2506737-b19f-3f77-b713-d32bba55d77f|pass|200810|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.46|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200810280933
2507019|2507019-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810280325
2507269|2507269-b19f-3f77-b713-d32bba55d77f|pass|200810|gabor@pti.co.il ("Gabor Szabo")|Devel-CheckOS|1.45|i486-linux-gnu|5.8.8|linux|2.6.15.7|200810280542
2507534|2507534-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810280300
2507692|2507692-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810280606
2507696|2507696-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810280608
2507698|2507698-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810280609
2508250|2508250-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810280801
2508475|2508475-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200810280801
2508788|2508788-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810280809
2508796|2508796-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810280818
2508800|2508800-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810280819
2508952|2508952-b19f-3f77-b713-d32bba55d77f|pass|200810|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.46|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200810281653
2509020|2509020-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.46|i86pc-solaris-64int|5.10.0|solaris|2.11|200810281028
2509286|2509286-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200810281129
2509343|2509343-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.46|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281250
2509570|2509570-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200810281247
2509878|2509878-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.01|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281524
2509990|2509990-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810281554
2510613|2510613-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200810281821
2510615|2510615-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200810281822
2510625|2510625-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200810281825
2510628|2510628-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200810281827
2510832|2510832-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|i586-linux-thread-multi|5.8.8|linux|2.6.16|200810282005
2510919|2510919-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200810282017
2510931|2510931-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200810282020
2511490|2511490-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810282313
2511798|2511798-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810282356
2512110|2512110-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290105
2512344|2512344-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290145
2512788|2512788-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810290214
2512798|2512798-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810290216
2513012|2513012-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290401
2513016|2513016-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290401
2513133|2513133-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290409
2513793|2513793-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200810290519
2514498|2514498-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200810290725
2514504|2514504-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290834
2514752|2514752-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290912
2514753|2514753-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810290912
2514837|2514837-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810290901
2515288|2515288-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34613|linux|2.6.22-1-k7|200810291044
2516057|2516057-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291518
2516371|2516371-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291556
2516446|2516446-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200810291504
2516478|2516478-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.6|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810291616
2516753|2516753-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291637
2516933|2516933-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200810291659
2516935|2516935-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200810291700
2517027|2517027-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810291722
2517459|2517459-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200810291723
2517605|2517605-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|i686-linux|5.8.8|linux|2.4.27-3-686|200810291747
2517662|2517662-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200810291800
2517664|2517664-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|IP35-irix-64int|5.8.8|irix|6.5|200810291900
2517712|2517712-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200810291315
2517761|2517761-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200810291837
2517906|2517906-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200810292043
2518027|2518027-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200810292138
2518031|2518031-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200810292138
2518078|2518078-b19f-3f77-b713-d32bba55d77f|pass|200810|david@cantrell.org.uk|Devel-CheckOS|1.46|i686-linux|5.6.2|linux|2.4.27-3-686|200810292107
2518110|2518110-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.45|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200810292217
2518115|2518115-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200810292218
2518295|2518295-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200810292333
2518304|2518304-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200810292335
2518625|2518625-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.10.0|freebsd|6.1-release|200810300137
2519361|2519361-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200810300654
2519368|2519368-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200810300657
2519379|2519379-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200810300700
2519407|2519407-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810300804
2519534|2519534-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200810300822
2520307|2520307-b19f-3f77-b713-d32bba55d77f|pass|200810|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200810301052
2520628|2520628-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200810301125
2521123|2521123-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200810301043
2521267|2521267-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34633|linux|2.6.22-1-k7|200810301300
2521584|2521584-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200810301248
2521744|2521744-b19f-3f77-b713-d32bba55d77f|pass|200810|rafl@debian.org|Devel-CheckOS|1.46|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200810301406
2521755|2521755-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.7|netbsd|3.1|200810301308
2521791|2521791-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200810301311
2522809|2522809-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810301439
2522998|2522998-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810301500
2524061|2524061-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810302041
2524206|2524206-b19f-3f77-b713-d32bba55d77f|pass|200810|alexchorny@gmail.com|Devel-CheckOS|1.46|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200810301605
2524431|2524431-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810302038
2524729|2524729-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810302110
2524941|2524941-b19f-3f77-b713-d32bba55d77f|pass|200810|alexchorny@gmail.com|Devel-CheckOS|1.46|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200810301734
2525121|2525121-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810302318
2525689|2525689-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310106
2526519|2526519-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310305
2528098|2528098-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310740
2528209|2528209-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810310756
2528306|2528306-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810310543
2528355|2528355-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810310720
2528663|2528663-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810310637
2529022|2529022-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200810310743
2529027|2529027-b19f-3f77-b713-d32bba55d77f|pass|200810|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34662|linux|2.6.22-1-k7|200810311016
2529118|2529118-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200810310945
2529333|2529333-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200810310847
2529508|2529508-b19f-3f77-b713-d32bba55d77f|pass|200810|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200810311157
2529526|2529526-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200810311155
2529589|2529589-b19f-3f77-b713-d32bba55d77f|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|Number-Phone|1.6|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810311207
2529657|2529657-b19f-3f77-b713-d32bba55d77f|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.45|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810311221
2529744|2529744-b19f-3f77-b713-d32bba55d77f|pass|200810|frank.wiegand@gmail.com ("Frank Wiegand")|XML-Tiny|1.11|i686-linux|5.11.0 patch 34669|linux|2.6.24-21-generic|200810311244
2529946|2529946-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810311309
2529997|2529997-b19f-3f77-b713-d32bba55d77f|pass|200810|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.46|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200810311256
2530130|2530130-b19f-3f77-b713-d32bba55d77f|pass|200810|g.grigelionis@computer.org|Devel-CheckOS|1.46|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200810311510
2530145|2530145-b19f-3f77-b713-d32bba55d77f|pass|200810|artur+cpan@niif.spb.su (ARTO)|Devel-CheckOS|1.45|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200810311042
2530332|2530332-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200810311512
2530558|2530558-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200810311714
2530598|2530598-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200810311724
2531155|2531155-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200810312117
2531165|2531165-b19f-3f77-b713-d32bba55d77f|pass|200810|bingos@cpan.org|Devel-CheckOS|1.46|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200810312125
2532014|2532014-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811010701
2532160|2532160-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811010744
2532466|2532466-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.1|netbsd|3.1|200811010839
2532502|2532502-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811010844
2532782|2532782-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811010932
2532885|2532885-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811011018
2534035|2534035-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200811011812
2534107|2534107-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811011558
2534123|2534123-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200811011854
2534583|2534583-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811012020
2535111|2535111-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.6.2|freebsd|6.1-release|200811012242
2535874|2535874-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811020919
2536236|2536236-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811021008
2536237|2536237-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811021009
2537140|2537140-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811021430
2537248|2537248-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811021456
2538157|2538157-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811021941
2538385|2538385-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811021942
2539180|2539180-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200811030147
2539183|2539183-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811030150
2539727|2539727-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|i386-freebsd|5.8.8 patch 34559|freebsd|6.1-release-p23|200811030815
2541079|2541079-b19f-3f77-b713-d32bba55d77f|pass|200811|schwern@pobox.com|Devel-CheckOS|1.46|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200811030129
2541577|2541577-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811031621
2542036|2542036-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|Devel-CheckOS|1.46|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811031927
2542522|2542522-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811032027
2542678|2542678-b19f-3f77-b713-d32bba55d77f|pass|200811|rlane10@wi.rr.com|Devel-CheckOS|1.46|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200811031045
2542819|2542819-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811032155
2542832|2542832-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811032156
2543230|2543230-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34693|linux|2.6.22-1-k7|200811032210
2543298|2543298-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i486-linux-gnu|5.8.8|linux|2.6.22.10|200811032250
2543970|2543970-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811040106
2544048|2544048-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811040119
2544168|2544168-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811040106
2544179|2544179-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811040109
2544575|2544575-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811040415
2544934|2544934-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040531
2544949|2544949-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200811040433
2544952|2544952-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200811040434
2545268|2545268-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040626
2545541|2545541-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040747
2545569|2545569-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811040753
2546290|2546290-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|sun4-solaris-64int|5.8.4|solaris|2.10|200811041057
2546913|2546913-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811041319
2546981|2546981-b19f-3f77-b713-d32bba55d77f|pass|200811|altblue@gmail.com ("Marius Feraru")|File-Find-Rule-Permissions|1.3|x86_64-linux|5.11.0 patch 34595|linux|2.6.18-8.1.14.el5|200811040044
2547071|2547071-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811041235
2547087|2547087-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34707|linux|2.6.22-1-k7|200811041339
2548496|2548496-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811041751
2548813|2548813-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811042025
2550270|2550270-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200811050048
2550539|2550539-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811050439
2551320|2551320-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811050829
2552614|2552614-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051252
2552717|2552717-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051322
2552720|2552720-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051322
2552776|2552776-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34732|linux|2.6.22-1-k7|200811051334
2553083|2553083-b19f-3f77-b713-d32bba55d77f|fail|200811|cbrown@mail ((root))|Devel-CheckOS|1.46|i386-linux|5.8.8|linux|2.6.18-53.1.14.el5xen|200811041414
2553764|2553764-b19f-3f77-b713-d32bba55d77f|pass|200811|rlane10@wi.rr.com|Devel-CheckOS|1.46|darwin-2level-ld|5.10.0|darwin|8.11.0|200811041145
2554662|2554662-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811051937
2555016|2555016-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200811051933
2555052|2555052-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200811051938
2555055|2555055-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811052048
2555227|2555227-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811052117
2555567|2555567-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811052217
2555720|2555720-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811052249
2556200|2556200-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200811052353
2556214|2556214-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200811052355
2556218|2556218-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200811052355
2556227|2556227-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200811052357
2556243|2556243-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.49_01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200811052354
2556397|2556397-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811060121
2556513|2556513-b19f-3f77-b713-d32bba55d77f|pass|200811|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.49_01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200811061104
2556889|2556889-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811060446
2557660|2557660-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811060652
2557834|2557834-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811060723
2557935|2557935-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200811060740
2557975|2557975-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200811060755
2558649|2558649-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.8 patch 34736|linux|2.6.22-1-k7|200811061111
2558755|2558755-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.49_01|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811061133
2558802|2558802-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.49_01|i86pc-solaris-64int|5.10.0|solaris|2.11|200811061140
2560242|2560242-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811061914
2560840|2560840-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811062110
2560842|2560842-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811062111
2561302|2561302-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200811062317
2561375|2561375-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200811062340
2561391|2561391-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200811062353
2561849|2561849-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200811070206
2562116|2562116-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811070355
2562127|2562127-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811070401
2562184|2562184-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811070616
2562584|2562584-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811070944
2563372|2563372-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071258
2563389|2563389-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071301
2563414|2563414-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200811071300
2563590|2563590-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200811071224
2563595|2563595-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200811071225
2564255|2564255-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071441
2564363|2564363-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200811071500
2564732|2564732-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071535
2565220|2565220-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|Devel-CheckOS|1.49_01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811071653
2565716|2565716-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811071809
2567524|2567524-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34757|linux|2.6.22-1-k7|200811072307
2567855|2567855-b19f-3f77-b713-d32bba55d77f|fail|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.02|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811080017
2567904|2567904-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811080031
2569847|2569847-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200811081210
2570655|2570655-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811081538
2570711|2570711-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811081443
2570723|2570723-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811081452
2571920|2571920-b19f-3f77-b713-d32bba55d77f|pass|200811|alexchorny@gmail.com|Sub-WrapPackages|1.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.1|200811081546
2571947|2571947-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811082138
2572453|2572453-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811082341
2573394|2573394-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090239
2573577|2573577-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090313
2574056|2574056-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090553
2574416|2574416-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34778|linux|2.6.22-1-k7|200811090653
2575216|2575216-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811091043
2575228|2575228-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811091048
2575313|2575313-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200811081751
2575535|2575535-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811082110
2575964|2575964-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811090137
2576097|2576097-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811090239
2576216|2576216-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811090327
2576354|2576354-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811090437
2576423|2576423-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811090541
2577302|2577302-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811082145
2577534|2577534-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811090310
2577669|2577669-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811090432
2577802|2577802-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811091331
2578105|2578105-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811091341
2578208|2578208-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811090209
2578531|2578531-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811090232
2579270|2579270-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811090245
2579695|2579695-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200811091603
2579703|2579703-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200811091604
2579710|2579710-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200811091605
2579751|2579751-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811091712
2580238|2580238-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811092001
2580961|2580961-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200811092241
2580967|2580967-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200811092243
2582050|2582050-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811100723
2582078|2582078-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811100726
2582326|2582326-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811100809
2582385|2582385-b19f-3f77-b713-d32bba55d77f|pass|200811|gabor@pti.co.il ("Gabor Szabo")|Data-Compare|1.21|i486-linux-gnu|5.10.0|linux|2.6.24-15-server|200811100919
2583005|2583005-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811100952
2583698|2583698-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811101153
2583840|2583840-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811101204
2584335|2584335-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811101218
2585044|2585044-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811101523
2585532|2585532-b19f-3f77-b713-d32bba55d77f|pass|200811|mw487.yahoo.com@gmail.com|Data-Compare|1.21|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811101037
2585862|2585862-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Longest|1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811101759
2585863|2585863-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Statistics-ChiSquare|0.5|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811101759
2586407|2586407-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811102044
2587312|2587312-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811110028
2587440|2587440-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811110042
2587527|2587527-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34785|linux|2.6.22-1-k7|200811110103
2587638|2587638-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|i686-linux|5.8.8|linux|2.4.27-3-686|200811110029
2587640|2587640-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200811110031
2587641|2587641-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|IP35-irix-64int|5.8.8|irix|6.5|200811110131
2587663|2587663-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200811110042
2587691|2587691-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|NestedMap|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811110154
2587697|2587697-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|i686-linux|5.6.2|linux|2.4.27-3-686|200811110046
2587984|2587984-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.46|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110308
2589161|2589161-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110650
2589185|2589185-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110713
2589391|2589391-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811110737
2590240|2590240-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811110919
2590531|2590531-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200811110903
2591312|2591312-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811111117
2591868|2591868-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811111124
2591883|2591883-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811111127
2593003|2593003-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.49_01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200811110859
2593091|2593091-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34813|linux|2.6.22-1-k7|200811111247
2593304|2593304-b19f-3f77-b713-d32bba55d77f|unknown|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Licence|1.0|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811111642
2593570|2593570-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200811111625
2593601|2593601-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200811111628
2593627|2593627-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200811111630
2593732|2593732-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200811111649
2594983|2594983-b19f-3f77-b713-d32bba55d77f|pass|200811|gabor@pti.co.il ("Gabor Szabo")|Devel-CheckOS|1.46|i486-linux-gnu|5.10.0|linux|2.6.24-15-server|200811112313
2595600|2595600-b19f-3f77-b713-d32bba55d77f|pass|200811|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.46|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811111753
2595945|2595945-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200811120055
2595946|2595946-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34437|linux|2.6.22-1-k7|200811120056
2595947|2595947-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200811120056
2595949|2595949-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.8 patch 34468|linux|2.6.22-1-k7|200811120056
2595950|2595950-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200811120056
2595952|2595952-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200811120057
2596294|2596294-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200811120059
2596797|2596797-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.46|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200811120242
2597159|2597159-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811120500
2597576|2597576-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811120650
2597637|2597637-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811120708
2597801|2597801-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200811120642
2597814|2597814-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200811120644
2597818|2597818-b19f-3f77-b713-d32bba55d77f|pass|200811|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200811121544
2597982|2597982-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Compare|1.21|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120755
2597996|2597996-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120755
2598013|2598013-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.46|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811120757
2598086|2598086-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200811120801
2598113|2598113-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200811120803
2598372|2598372-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811120809
2598466|2598466-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811120819
2598531|2598531-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811120822
2598573|2598573-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.18-92.el5|200811120825
2599401|2599401-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811121000
2599568|2599568-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.46|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811120954
2600248|2600248-b19f-3f77-b713-d32bba55d77f|unknown|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Pony|1.1.2|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121057
2600283|2600283-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121101
2600480|2600480-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121135
2600709|2600709-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|XML-Tiny|1.11|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121131
2601466|2601466-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.10.0|solaris|2.11|200811121400
2601594|2601594-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.8.8 patch 34559|solaris|2.11|200811121411
2601746|2601746-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Sort-MultipleFields|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121403
2601943|2601943-b19f-3f77-b713-d32bba55d77f|pass|200811|hohokus@gmail.com|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200811120834
2602130|2602130-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121457
2602468|2602468-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Hexdumper|1.4|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811121457
2603473|2603473-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200811121908
2603481|2603481-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.49_01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811121719
2603489|2603489-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200811121720
2603493|2603493-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200811121914
2603691|2603691-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.10.0|darwin|8.10.0|200811121920
2603694|2603694-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.6|darwin|8.10.0|200811121922
2603695|2603695-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.8|darwin|8.10.0|200811121923
2604162|2604162-b19f-3f77-b713-d32bba55d77f|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|i586-linux-thread-multi|5.8.8|linux|2.6.16|200811122335
2604312|2604312-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPU-Emulator-Memory|1.1001|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130001
2604455|2604455-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Transactional|1.02|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130001
2604575|2604575-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPU-Emulator-Z80|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130001
2604699|2604699-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Number-Phone|1.6|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811130026
2606310|2606310-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811130757
2606331|2606331-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.49_01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811130802
2606456|2606456-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811130758
2606908|2606908-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811130906
2606926|2606926-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811130910
2607802|2607802-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckLib|0.5|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131049
2608821|2608821-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPAN-FindDependencies|2.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131306
2609436|2609436-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Bryar|3.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131443
2609496|2609496-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|File-Find-Rule-Permissions|1.3|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131443
2609715|2609715-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Tie-STDOUT|1.03|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131532
2609908|2609908-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811131500
2610048|2610048-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811131522
2610198|2610198-b19f-3f77-b713-d32bba55d77f|pass|200811|robbiebow@gmail.com|CPAN-FindDependencies|2.0|i486-linux-gnu|5.10.0|linux|2.6.26.1|200811122351
2610256|2610256-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131615
2610415|2610415-b19f-3f77-b713-d32bba55d77f|pass|200811|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.22.10|200811140034
2610452|2610452-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2610645|2610645-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Net-Random|2.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811131727
2611193|2611193-b19f-3f77-b713-d32bba55d77f|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200811131835
2611223|2611223-b19f-3f77-b713-d32bba55d77f|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200811131840
2611233|2611233-b19f-3f77-b713-d32bba55d77f|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200811131921
2611260|2611260-b19f-3f77-b713-d32bba55d77f|pass|200811|vpit@cpan.org|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200811131847
2611359|2611359-b19f-3f77-b713-d32bba55d77f|pass|200811|g.grigelionis@computer.org|Devel-CheckOS|1.50|i386-linux|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200811131852
2611588|2611588-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811131811
2611689|2611689-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811131825
2612452|2612452-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Games-Dice-Advanced|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132052
2612701|2612701-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Sub-WrapPackages|1.2|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132107
2613115|2613115-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200811132141
2614137|2614137-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811132239
2615275|2615275-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Class-CanBeA|1.2|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132348
2615288|2615288-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|File-Overwrite|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811132348
2616015|2616015-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811140029
2616757|2616757-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140150
2617296|2617296-b19f-3f77-b713-d32bba55d77f|pass|200811|mthurn@cpan.org|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200811140257
2617329|2617329-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140403
2617636|2617636-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140518
2618156|2618156-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200811140733
2618435|2618435-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811140748
2618695|2618695-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811140750
2619006|2619006-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811140834
2620460|2620460-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Statistics-SerialCorrelation|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141004
2620572|2620572-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Palm-SMS|0.02|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811140748
2620625|2620625-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34793|linux|2.6.22-1-k7|200811141025
2621323|2621323-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Tie-Hash-Longest|1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141123
2621490|2621490-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Statistics-ChiSquare|0.5|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141123
2621677|2621677-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200811140501
2621832|2621832-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|NestedMap|1.0|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811141209
2621900|2621900-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Compare|1.21|i686-linux|5.8.9|linux|2.6.18-4-486|200811141203
2622725|2622725-b19f-3f77-b713-d32bba55d77f|pass|200811|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.50|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200811140858
2623012|2623012-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|i686-linux|5.6.2|linux|2.4.27-3-686|200811141453
2623102|2623102-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200811141519
2623103|2623103-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200811141519
2623107|2623107-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|i686-linux|5.8.8|linux|2.4.27-3-686|200811141519
2624397|2624397-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|IP35-irix-64int|5.8.8|irix|6.5|200811141813
2624447|2624447-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811141816
2625842|2625842-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811142302
2626311|2626311-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811150006
2626493|2626493-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811142318
2626630|2626630-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811150007
2626667|2626667-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811150007
2626762|2626762-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150024
2626763|2626763-b19f-3f77-b713-d32bba55d77f|pass|200811|david@cantrell.org.uk|Devel-CheckOS|1.50|alpha-netbsd|5.10.0|netbsd|2.1.0_stable|200811142331
2627138|2627138-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Tie-Hash-Rank|1.0.1|i386-freebsd|5.8.8|freebsd|6.1-release-p23|200811150006
2627681|2627681-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811150124
2628382|2628382-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811150359
2628475|2628475-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150517
2628657|2628657-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200811150456
2628664|2628664-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200811150458
2628823|2628823-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150634
2629266|2629266-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34836|linux|2.6.22-1-k7|200811150819
2632873|2632873-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200811161135
2632879|2632879-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200811161137
2633154|2633154-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-19-generic|200811161249
2633214|2633214-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24-19-generic|200811161305
2633552|2633552-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811161440
2634255|2634255-b19f-3f77-b713-d32bba55d77f|pass|200811|rlane10@wi.rr.com|Devel-CheckOS|1.50|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.10.el5|200811151624
2634399|2634399-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811161651
2634650|2634650-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811161637
2634691|2634691-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811161641
2635457|2635457-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811161927
2636444|2636444-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811162117
2637023|2637023-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811162226
2638283|2638283-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34839|linux|2.6.22-1-k7|200811170451
2639731|2639731-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200811171306
2640048|2640048-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811171609
2641399|2641399-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811172327
2641438|2641438-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811172217
2641746|2641746-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd-64int|5.8.8|freebsd|6.1-release|200811180027
2641757|2641757-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd|5.10.0|freebsd|6.1-release|200811180029
2642172|2642172-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi|5.10.0|freebsd|6.1-release|200811180125
2642177|2642177-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180126
2642350|2642350-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi|5.8.8|freebsd|6.1-release|200811180144
2642369|2642369-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd|5.6.2|freebsd|6.1-release|200811180117
2642985|2642985-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200811180237
2643177|2643177-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180351
2643414|2643414-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180445
2643566|2643566-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180515
2643594|2643594-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34869|linux|2.6.22-1-k7|200811180512
2643742|2643742-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200811180453
2644577|2644577-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811180914
2644766|2644766-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200811180946
2645722|2645722-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200811181254
2645781|2645781-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811181218
2645990|2645990-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181441
2646137|2646137-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181505
2646760|2646760-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.8.9|solaris|2.11|200811181722
2647154|2647154-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811181754
2647682|2647682-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811182002
2649448|2649448-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.11|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190447
2650706|2650706-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200811190859
2651864|2651864-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811191400
2652026|2652026-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811191553
2652487|2652487-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|1.4|i86pc-solaris-64int|5.8.9|solaris|2.11|200811191829
2652489|2652489-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811191830
2652993|2652993-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200811191942
2653123|2653123-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192129
2653317|2653317-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192205
2653319|2653319-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192205
2653778|2653778-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811192255
2654011|2654011-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200811192320
2654013|2654013-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.6|i86pc-solaris-64int|5.8.9|solaris|2.11|200811192332
2654271|2654271-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200003
2654660|2654660-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200044
2655089|2655089-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200228
2655915|2655915-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200811200359
2656392|2656392-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200620
2657124|2657124-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.8.9|solaris|2.11|200811200832
2657474|2657474-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34883|linux|2.6.22-1-k7|200811200932
2658270|2658270-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811201152
2658653|2658653-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200811201322
2658696|2658696-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|Data-Compare|1.21|armv5tejl-linux|5.8.8|linux|2.6.17.14|200811201730
2658954|2658954-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200811201415
2659533|2659533-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811201758
2659844|2659844-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811201838
2659938|2659938-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811201900
2660119|2660119-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200811201917
2660519|2660519-b19f-3f77-b713-d32bba55d77f|fail|200811|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811202023
2660902|2660902-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811202057
2660920|2660920-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811202100
2661386|2661386-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200811202109
2662093|2662093-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|1.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200811210002
2662766|2662766-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200811210158
2663127|2663127-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811210309
2664231|2664231-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811210935
2664535|2664535-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811211039
2664721|2664721-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200811211129
2664815|2664815-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34893|linux|2.6.22-1-k7|200811211137
2666546|2666546-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200811212250
2666633|2666633-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|i386-freebsd|5.8.9|freebsd|6.1-release-p23|200811212337
2667070|2667070-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220320
2667220|2667220-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220401
2667663|2667663-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|Data-Compare|1.21|armv5tejl-linux|5.10.0|linux|2.6.17.14|200811220848
2667763|2667763-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220614
2668317|2668317-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811220920
2669079|2669079-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200811221129
2669945|2669945-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811221537
2669975|2669975-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34899|linux|2.6.22-1-k7|200811221546
2672840|2672840-b19f-3f77-b713-d32bba55d77f|pass|200811|jeff@zeroclue.com|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.18.8|200811230307
2672888|2672888-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Devel-CheckOS|1.50|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811230413
2673381|2673381-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|XML-DoubleEncodedEntities|1.0|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811230651
2673626|2673626-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811230505
2674615|2674615-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811230922
2675217|2675217-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200811231348
2676161|2676161-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Data-Compare|1.21|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811232125
2678038|2678038-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Class-DBI-ClassGenerator|1.01|x86_64-linux-multi|5.11.0|linux|2.6.26-1-xen-amd64|200811240747
2678887|2678887-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200811240554
2679219|2679219-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200811240814
2680013|2680013-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811241933
2680361|2680361-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200811242131
2682122|2682122-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200811250602
2682515|2682515-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811250743
2682752|2682752-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200811250844
2683184|2683184-b19f-3f77-b713-d32bba55d77f|pass|200811|stro@cpan.org|Devel-CheckOS|1.50|armv5tejl-linux|5.10.0|linux|2.6.17.14|200811251247
2684229|2684229-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200811251034
2684539|2684539-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.18-4-686|200811250930
2685559|2685559-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200811250431
2686529|2686529-b19f-3f77-b713-d32bba55d77f|fail|200811|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200811252007
2686586|2686586-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811252018
2687313|2687313-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200811252254
2687773|2687773-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811260025
2690322|2690322-b19f-3f77-b713-d32bba55d77f|pass|200811|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200811260930
2690890|2690890-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261142
2691240|2691240-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261244
2691249|2691249-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200811261146
2691266|2691266-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200811261148
2691526|2691526-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261302
2691558|2691558-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200811261249
2691588|2691588-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200811261259
2692351|2692351-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34904|linux|2.6.22-1-k7|200811261736
2694091|2694091-b19f-3f77-b713-d32bba55d77f|pass|200811|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.18-4-686|200811270500
2694990|2694990-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271010
2695035|2695035-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271013
2695139|2695139-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271036
2696271|2696271-b19f-3f77-b713-d32bba55d77f|pass|200811|rafl@debian.org|Devel-CheckOS|1.50|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200811271420
2696614|2696614-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271526
2696650|2696650-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271534
2697611|2697611-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34943|linux|2.6.22-1-k7|200811271846
2698909|2698909-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811272231
2699083|2699083-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.8.9|freebsd|7.0-release|200811272254
2699400|2699400-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200811272249
2700276|2700276-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811280245
2701374|2701374-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811280622
2702042|2702042-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.8.9|freebsd|7.0-release|200811280745
2703484|2703484-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281247
2703503|2703503-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281252
2704176|2704176-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281304
2704505|2704505-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34948|linux|2.6.22-1-k7|200811281414
2704593|2704593-b19f-3f77-b713-d32bba55d77f|fail|200811|ackack1024@gmail.com|Bryar|3.0|x86_64-linux-gnu|5.10.0|linux|2.6.22-3-vserver-amd64|200811280034
2705095|2705095-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Sort-MultipleFields|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281600
2705307|2705307-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281656
2705560|2705560-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281702
2706019|2706019-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281903
2706021|2706021-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPU-Emulator-Z80|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281903
2706119|2706119-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Data-Transactional|1.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200811281903
2706439|2706439-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Number-Phone|1.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200811282003
2707483|2707483-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290019
2707819|2707819-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290036
2707901|2707901-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290043
2708650|2708650-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290213
2708838|2708838-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290207
2709107|2709107-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Games-Dice-Advanced|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290314
2709271|2709271-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Sub-WrapPackages|1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200811290315
2709871|2709871-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.10.0|linux|2.6.18-92.el5|200811290459
2710189|2710189-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290641
2710754|2710754-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290915
2710866|2710866-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811290937
2712234|2712234-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 34916|linux|2.6.22-1-k7|200811291301
2712827|2712827-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Class-CanBeA|1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291334
2713044|2713044-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|File-Overwrite|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291335
2714072|2714072-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Palm-SMS|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291337
2714520|2714520-b19f-3f77-b713-d32bba55d77f|pass|200811|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200811291334
2716111|2716111-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200811300040
2716120|2716120-b19f-3f77-b713-d32bba55d77f|pass|200811|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200811300042
2717845|2717845-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200811300924
2718220|2718220-b19f-3f77-b713-d32bba55d77f|pass|200811|"Rick Myers <rick@jrmyers.net>"|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24.3|200811300444
2719984|2719984-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200811301552
2720540|2720540-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200811301659
2720556|2720556-b19f-3f77-b713-d32bba55d77f|pass|200811|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200811301658
2722147|2722147-b19f-3f77-b713-d32bba55d77f|pass|200811|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200811302019
2723860|2723860-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200812010046
2724097|2724097-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812010137
2724251|2724251-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200812010203
2724627|2724627-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34928|linux|2.6.22-1-k7|200812010311
2726411|2726411-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|XML-DoubleEncodedEntities|1.0|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812011403
2726822|2726822-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812011210
2729332|2729332-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812020300
2730254|2730254-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200812020607
2730352|2730352-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200812020629
2730753|2730753-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812020858
2731076|2731076-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812020307
2731451|2731451-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021111
2731466|2731466-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021113
2732934|2732934-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021428
2732946|2732946-b19f-3f77-b713-d32bba55d77f|fail|200812|rivy@cpan.org ("Roy Ivy III")|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812020341
2732948|2732948-b19f-3f77-b713-d32bba55d77f|fail|200812|rivy@cpan.org ("Roy Ivy III")|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812020454
2733597|2733597-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021605
2734063|2734063-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 34974|linux|2.6.22-1-k7|200812021726
2735721|2735721-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812022258
2736160|2736160-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200812030416
2736235|2736235-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.11|i686-linux|5.10.0|linux|2.6.18-4-686|200812030547
2736945|2736945-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812030843
2736963|2736963-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812030850
2736968|2736968-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812030852
2737577|2737577-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812031025
2739030|2739030-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200812031531
2739588|2739588-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812031553
2739594|2739594-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 34986|linux|2.6.22-1-k7|200812031554
2741814|2741814-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812032155
2743024|2743024-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812040607
2743095|2743095-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812040643
2743368|2743368-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812040926
2743415|2743415-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812040920
2744247|2744247-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812041138
2745522|2745522-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812041617
2746236|2746236-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200812041816
2746682|2746682-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812041910
2747434|2747434-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35005|linux|2.6.22-1-k7|200812042145
2747547|2747547-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.el5|200812042206
2748728|2748728-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200812050103
2748988|2748988-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812050338
2749116|2749116-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812050401
2749471|2749471-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812050437
2749841|2749841-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812050514
2751713|2751713-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Devel-CheckOS|1.50|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812051112
2752288|2752288-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200812051129
2753021|2753021-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812051438
2753040|2753040-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812051434
2753936|2753936-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 35013|linux|2.6.22-1-k7|200812051658
2754877|2754877-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812052029
2755272|2755272-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812052216
2756192|2756192-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200812060213
2757104|2757104-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812060801
2757570|2757570-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200812060938
2757875|2757875-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200812061144
2760109|2760109-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200812061806
2760549|2760549-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812062053
2760698|2760698-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812062121
2761654|2761654-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812062319
2762696|2762696-b19f-3f77-b713-d32bba55d77f|pass|200812|salvacpan@gmail.com ("Salvador Fandino")|Data-Compare|1.21|sparc64-netbsd|5.10.0|netbsd|4.0_rc5|200812070205
2763041|2763041-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812070419
2763250|2763250-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812070354
2764240|2764240-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812070834
2765084|2765084-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071006
2766527|2766527-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35041|linux|2.6.22-1-k7|200812071127
2767043|2767043-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071009
2767155|2767155-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.8.9|freebsd|7.0-release|200812071006
2768263|2768263-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.18-92.1.17.el5|200812071746
2768458|2768458-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812071756
2770111|2770111-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812072059
2770543|2770543-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200812072153
2772224|2772224-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080152
2772792|2772792-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080334
2773286|2773286-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080534
2773440|2773440-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200812080645
2774364|2774364-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.8.8|linux|2.6.18-92.el5|200812080935
2775728|2775728-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Sort-MultipleFields|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081416
2776027|2776027-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081449
2776080|2776080-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081449
2776152|2776152-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081527
2776594|2776594-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Transactional|1.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081622
2776837|2776837-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPU-Emulator-Z80|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081622
2776950|2776950-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081622
2777481|2777481-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Number-Phone|1.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200812081700
2779448|2779448-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.9|freebsd|7.0-release|200812082312
2782107|2782107-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812090949
2782725|2782725-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812091105
2782913|2782913-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091107
2782968|2782968-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091102
2782974|2782974-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPAN-FindDependencies|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091123
2782996|2782996-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPU-Emulator-Z80|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091124
2783051|2783051-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091126
2783242|2783242-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091127
2784434|2784434-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091209
2784544|2784544-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|CPU-Emulator-Memory|1.1001|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091124
2785638|2785638-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Sort-MultipleFields|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091256
2785705|2785705-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Palm-Treo680MessagesDB|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091234
2786578|2786578-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|XML-DoubleEncodedEntities|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091332
2787491|2787491-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091414
2787559|2787559-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091415
2788027|2788027-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200812091415
2788306|2788306-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091137
2789178|2789178-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Number-Phone|1.6|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091232
2789378|2789378-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091137
2789569|2789569-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|File-Find-Rule-Permissions|1.3|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091145
2790751|2790751-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-STDOUT|1.03|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091637
2791311|2791311-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Transactional|1.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091130
2791699|2791699-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Palm-TreoPhoneCallDB|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091636
2791702|2791702-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|DBIx-Class-SingletonRows|0.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200812091135
2793718|2793718-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812092201
2794124|2794124-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812092252
2794647|2794647-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.8.9|freebsd|7.0-release|200812092124
2795233|2795233-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Number-Phone-UK-DetailedLocations|1.3|amd64-freebsd|5.8.8|freebsd|7.0-release|200812100006
2795306|2795306-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812100101
2795329|2795329-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Net-Random|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100013
2796282|2796282-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812100345
2796290|2796290-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|XML-Tiny|1.11|amd64-freebsd|5.8.8|freebsd|7.0-release|200812100246
2796907|2796907-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812100621
2798039|2798039-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Games-Dice-Advanced|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812100855
2798287|2798287-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 35055|linux|2.6.22-1-k7|200812101018
2798388|2798388-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Games-Dice-Advanced|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812101005
2800622|2800622-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|File-Overwrite|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812101524
2800852|2800852-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200812101452
2800876|2800876-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|File-Overwrite|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812101524
2801403|2801403-b19f-3f77-b713-d32bba55d77f|pass|200812|fayland@gmail.com ("Fayland Lam")|Data-Compare|1.21|i386-linux|5.8.6|linux|2.6.9-34.elsmp|200812100817
2801494|2801494-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Class-CanBeA|1.2|amd64-freebsd|5.8.8|freebsd|7.0-release|200812101628
2801623|2801623-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200812101728
2802464|2802464-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Class-CanBeA|1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200812101824
2804353|2804353-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Palm-SMS|0.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200812102246
2804681|2804681-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812102312
2804813|2804813-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812102313
2805174|2805174-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Palm-SMS|0.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200812102313
2805789|2805789-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812110053
2806541|2806541-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.10.0|freebsd|7.0-release|200812110753
2808229|2808229-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Statistics-SerialCorrelation|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812111228
2808263|2808263-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Statistics-SerialCorrelation|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812111228
2809562|2809562-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812111431
2809848|2809848-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-Hash-Longest|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812111619
2809851|2809851-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Statistics-ChiSquare|0.5|amd64-freebsd|5.8.8|freebsd|7.0-release|200812111619
2809905|2809905-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Statistics-ChiSquare|0.5|amd64-freebsd|5.8.9|freebsd|7.0-release|200812111619
2810112|2810112-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-Hash-Longest|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812111619
2811405|2811405-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Devel-CheckOS|1.50|amd64-freebsd|5.6.2|freebsd|7.0-release|200812112151
2811883|2811883-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|NestedMap|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812112229
2811921|2811921-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|NestedMap|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812112230
2812369|2812369-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.0-release|200812112308
2812566|2812566-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.0-release|200812112335
2813036|2813036-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200812120105
2813038|2813038-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200812120105
2814278|2814278-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812120728
2814386|2814386-b19f-3f77-b713-d32bba55d77f|unknown|200812|srezic@cpan.org|Acme-Licence|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200812120840
2814813|2814813-b19f-3f77-b713-d32bba55d77f|unknown|200812|srezic@cpan.org|Acme-Licence|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200812120848
2817042|2817042-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.18-4-686|200812121620
2817047|2817047-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200812121621
2817048|2817048-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121621
2817254|2817254-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121634
2817255|2817255-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121637
2818742|2818742-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812121927
2819533|2819533-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.0-release|200812122018
2820611|2820611-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200812130038
2820804|2820804-b19f-3f77-b713-d32bba55d77f|pass|200812|andy@hexten.net|Devel-CheckOS|1.50|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200812130117
2821002|2821002-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-Hash-Rank|1.0.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812130246
2821016|2821016-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-Hash-Rank|1.0.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812130246
2821110|2821110-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200812130257
2821122|2821122-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Tie-Scalar-Decay|1.1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200812130257
2821229|2821229-b19f-3f77-b713-d32bba55d77f|unknown|200812|srezic@cpan.org|Acme-Pony|1.1.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200812130246
2821240|2821240-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812130223
2821344|2821344-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200812130233
2821357|2821357-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812130239
2821406|2821406-b19f-3f77-b713-d32bba55d77f|unknown|200812|srezic@cpan.org|Acme-Pony|1.1.2|amd64-freebsd|5.8.8|freebsd|7.0-release|200812130246
2821425|2821425-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812130252
2822282|2822282-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.17.el5|200812130920
2823527|2823527-b19f-3f77-b713-d32bba55d77f|fail|200812|srezic@cpan.org|Class-DBI-ClassGenerator|1.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200812131152
2823660|2823660-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812131155
2824656|2824656-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35072|linux|2.6.22-1-k7|200812131413
2828016|2828016-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200812140459
2828047|2828047-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200812140608
2829387|2829387-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.8|dragonfly|2.0.1-release|200812141129
2829396|2829396-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.10.0|dragonfly|2.0.1-release|200812141130
2830115|2830115-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141423
2830148|2830148-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141427
2830281|2830281-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|darwin-2level|5.10.0|darwin|8.11.1|200812141408
2830300|2830300-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|darwin-2level|5.10.0|darwin|8.11.1|200812141411
2831034|2831034-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141557
2831500|2831500-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141707
2832569|2832569-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812141947
2832650|2832650-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812141901
2832930|2832930-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.18-4-686|200812142100
2833867|2833867-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.11.0 patch 35088|linux|2.6.22-1-k7|200812142334
2835370|2835370-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200812150522
2836735|2836735-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.18-4-686|200812151501
2836740|2836740-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200812151502
2839840|2839840-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200812160329
2843801|2843801-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812161611
2844746|2844746-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812161906
2845107|2845107-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812161942
2845633|2845633-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812162048
2845878|2845878-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812162120
2845909|2845909-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812162124
2846388|2846388-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812162214
2846671|2846671-b19f-3f77-b713-d32bba55d77f|pass|200812|stro@cpan.org|DBIx-Class-SingletonRows|0.11|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200812162354
2847277|2847277-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812162242
2847950|2847950-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812170001
2849222|2849222-b19f-3f77-b713-d32bba55d77f|pass|200812|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200812161530
2849275|2849275-b19f-3f77-b713-d32bba55d77f|pass|200812|wolfman.ncsu2000@gmail.com|Devel-CheckOS|1.50|darwin-2level|5.10.0|darwin|9.5.0|200812161800
2849289|2849289-b19f-3f77-b713-d32bba55d77f|pass|200812|wolfman.ncsu2000@gmail.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.5.0|200812161813
2849440|2849440-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170143
2851400|2851400-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170447
2853227|2853227-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812170252
2853285|2853285-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200812170858
2854457|2854457-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812171144
2854842|2854842-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.11|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171258
2854913|2854913-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171312
2855399|2855399-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812171405
2856215|2856215-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171459
2856409|2856409-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200812171511
2856657|2856657-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.6|i686-linux|5.10.0|linux|2.6.18-4-686|200812171543
2857148|2857148-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812171628
2857770|2857770-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Devel-CheckOS|1.50|i386-netbsd|5.10.0|netbsd|5.0_beta|200812171618
2857853|2857853-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812171615
2858912|2858912-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171346
2859596|2859596-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812171524
2861126|2861126-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180001
2861439|2861439-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812180152
2861591|2861591-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180115
2861592|2861592-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180115
2861966|2861966-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200812180150
2862222|2862222-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180223
2862505|2862505-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180258
2862575|2862575-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180311
2862576|2862576-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180311
2862849|2862849-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812180450
2862970|2862970-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180409
2863975|2863975-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812180758
2864299|2864299-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200812180750
2864423|2864423-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200812180724
2864465|2864465-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200812180809
2864474|2864474-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200812180809
2864717|2864717-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200812180844
2864805|2864805-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180358
2865836|2865836-b19f-3f77-b713-d32bba55d77f|pass|200812|vutral@gmail.com|Data-Compare|1.21|x86_64-linux-gnu|5.8.8|linux|2.6.26-1-vserver-amd64|200812180200
2866826|2866826-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812181205
2867138|2867138-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180825
2867688|2867688-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812180954
2867800|2867800-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812181506
2868546|2868546-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812181749
2868648|2868648-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812181801
2868649|2868649-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181203
2868906|2868906-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200812181830
2869146|2869146-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181305
2869551|2869551-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181348
2870198|2870198-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812190343
2870238|2870238-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812182045
2870415|2870415-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812182102
2870523|2870523-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812182112
2870612|2870612-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812182118
2870726|2870726-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812182127
2870795|2870795-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200812182132
2870944|2870944-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200812182149
2871153|2871153-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200812182009
2871313|2871313-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181620
2871351|2871351-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200812182222
2871924|2871924-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812181711
1883728|1883728-b19f-3f77-b713-d32bba55d77f|pass|200807|mw487.yahoo.com@gmail.com|Data-Hexdumper|1.4|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200807120916
1896279|1896279-b19f-3f77-b713-d32bba55d77f|pass|200807|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.43|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200807151949
1973625|1973625-b19f-3f77-b713-d32bba55d77f|pass|200808|mw487.yahoo.com@gmail.com|XML-Tiny|1.11|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200808020125
2498600|2498600-b19f-3f77-b713-d32bba55d77f|pass|200810|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.44|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200810260600
2315664|2315664-b19f-3f77-b713-d32bba55d77f|pass|200809|jeff@zeroclue.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.2.0|200809261459
2315682|2315682-b19f-3f77-b713-d32bba55d77f|pass|200809|jeff@zeroclue.com|XML-DoubleEncodedEntities|1.0|darwin-2level|5.10.0|darwin|9.2.0|200809261539
2316178|2316178-b19f-3f77-b713-d32bba55d77f|pass|200809|jeff@zeroclue.com|Devel-CheckOS|1.43|darwin-2level|5.10.0|darwin|9.2.0|200809261645
2348696|2348696-b19f-3f77-b713-d32bba55d77f|fail|200809|jeff@zeroclue.com|Class-DBI-ClassGenerator|1.0|darwin-2level|5.10.0|darwin|9.2.0|200809300310
2637111|2637111-b19f-3f77-b713-d32bba55d77f|pass|200811|jeff@zeroclue.com|Data-Compare|1.21|darwin-2level|5.10.0|darwin|9.2.0|200811161337
2637310|2637310-b19f-3f77-b713-d32bba55d77f|pass|200811|jeff@zeroclue.com|Devel-CheckOS|1.50|darwin-2level|5.10.0|darwin|9.2.0|200811161412
2637720|2637720-b19f-3f77-b713-d32bba55d77f|pass|200811|jeff@zeroclue.com|Devel-CheckOS|1.49_01|darwin-2level|5.10.0|darwin|9.2.0|200811161554
2873201|2873201-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200812190000
2873297|2873297-b19f-3f77-b713-d32bba55d77f|pass|200812|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.6.2|freebsd|7.0-release|200812190105
2873610|2873610-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812190833
2874399|2874399-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190150
2874665|2874665-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190220
2874953|2874953-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190259
2876360|2876360-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190134
2876685|2876685-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190216
2877419|2877419-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200812190843
2879660|2879660-b19f-3f77-b713-d32bba55d77f|fail|200812|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190819
2879718|2879718-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812190830
2880250|2880250-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200812191538
2881650|2881650-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812191723
2881720|2881720-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191233
2882111|2882111-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191310
2882117|2882117-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191310
2882982|2882982-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812191448
2883908|2883908-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200812192235
2883928|2883928-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200812192238
2884187|2884187-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200812192209
2885389|2885389-b19f-3f77-b713-d32bba55d77f|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200009
2885630|2885630-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|XML-DoubleEncodedEntities|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812200028
2886280|2886280-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200812200127
2886887|2886887-b19f-3f77-b713-d32bba55d77f|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200250
2886959|2886959-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200256
2887031|2887031-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200305
2887113|2887113-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Number-Phone|1.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812201113
2887212|2887212-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812200322
2891001|2891001-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200928
2891047|2891047-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812200931
2892048|2892048-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812201605
2892266|2892266-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812201627
2892522|2892522-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200812201714
2893169|2893169-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812201808
2893502|2893502-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200812201849
2894325|2894325-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812201534
2895545|2895545-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200812202304
2895875|2895875-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200812202348
2896124|2896124-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200812210021
2897833|2897833-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.11|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210048
2898774|2898774-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210302
2900393|2900393-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812211106
2900660|2900660-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210640
2900706|2900706-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812211142
2901362|2901362-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210758
2901366|2901366-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812210758
2902320|2902320-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200812211533
2902335|2902335-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211037
2902449|2902449-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211052
2902457|2902457-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211052
2902634|2902634-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200812211616
2903009|2903009-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211211
2904781|2904781-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812211756
2905324|2905324-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812220006
2906678|2906678-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220428
2906994|2906994-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200812220523
2907217|2907217-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220121
2908320|2908320-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812220925
2908326|2908326-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812220926
2908670|2908670-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220416
2909264|2909264-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220542
2909708|2909708-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812220645
2910034|2910034-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200812221231
2910076|2910076-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200812221239
2911775|2911775-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200812221903
2911789|2911789-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200812221905
2912851|2912851-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812222326
2913208|2913208-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812221817
2913520|2913520-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812230056
2913521|2913521-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812230057
2913601|2913601-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230007
2913921|2913921-b19f-3f77-b713-d32bba55d77f|pass|200812|rhaen@cpan.org (Ulrich Habel)|Data-Compare|1.21|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200812230056
2914905|2914905-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230350
2915226|2915226-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230458
2915479|2915479-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200812230552
2915507|2915507-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200812230557
2916888|2916888-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230351
2917138|2917138-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812230432
2918558|2918558-b19f-3f77-b713-d32bba55d77f|unknown|200812|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232145
2918561|2918561-b19f-3f77-b713-d32bba55d77f|unknown|200812|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232145
2918563|2918563-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232146
2918583|2918583-b19f-3f77-b713-d32bba55d77f|fail|200812|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232149
2918586|2918586-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232150
2918589|2918589-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232150
2918601|2918601-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232151
2918602|2918602-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232152
2918628|2918628-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Hexdumper|1.4|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232157
2918631|2918631-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232158
2918634|2918634-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232158
2918638|2918638-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232159
2918643|2918643-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232159
2918646|2918646-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232159
2918650|2918650-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232200
2918661|2918661-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232201
2918668|2918668-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232202
2918680|2918680-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232204
2918697|2918697-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232206
2918699|2918699-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232206
2918700|2918700-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232206
2918704|2918704-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232207
2918710|2918710-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232207
2918712|2918712-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232207
2918716|2918716-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232208
2918718|2918718-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232208
2918720|2918720-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232209
2918721|2918721-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232209
2918722|2918722-b19f-3f77-b713-d32bba55d77f|pass|200812|imacat@mail.imacat.idv.tw|XML-Tiny|1.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200812232209
2919291|2919291-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812231502
2919546|2919546-b19f-3f77-b713-d32bba55d77f|fail|200812|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231042
2919615|2919615-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231050
2921115|2921115-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200812231853
2921664|2921664-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231501
2921955|2921955-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231537
2921957|2921957-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231537
2922125|2922125-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812232106
2922744|2922744-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812231759
2923002|2923002-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200812232325
2923611|2923611-b19f-3f77-b713-d32bba55d77f|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240212
2924466|2924466-b19f-3f77-b713-d32bba55d77f|unknown|200812|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240452
2924504|2924504-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240457
2924535|2924535-b19f-3f77-b713-d32bba55d77f|pass|200812|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200812240004
2926641|2926641-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200812240957
2926853|2926853-b19f-3f77-b713-d32bba55d77f|pass|200812|chris@bingosnet.co.uk|Data-Compare|1.21|i686-linux-thread-multi-64int|5.6.2|linux|2.4.26|200812241109
2928116|2928116-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812241554
2929091|2929091-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200812241937
2929486|2929486-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200812242118
2929897|2929897-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812250031
2929898|2929898-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812250031
2930317|2930317-b19f-3f77-b713-d32bba55d77f|pass|200812|yanick@cpan.org ("Yanick Champoux")|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.22-gentoo-r2enkidu|200812241237
2933025|2933025-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200812251348
2933026|2933026-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200812251348
2933659|2933659-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200812252043
2938494|2938494-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200812262114
2939739|2939739-b19f-3f77-b713-d32bba55d77f|pass|200812|davidrw@cpan.org|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200812270346
2939983|2939983-b19f-3f77-b713-d32bba55d77f|pass|200812|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.18-4-686|200812270958
2940826|2940826-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812271408
2943274|2943274-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812272317
2943341|2943341-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812272329
2947073|2947073-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812280846
2947328|2947328-b19f-3f77-b713-d32bba55d77f|pass|200812|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|1.4|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200812280915
2948935|2948935-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812281405
2949187|2949187-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200812281409
2949939|2949939-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200812281750
2950457|2950457-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812282054
2951440|2951440-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812290139
2953740|2953740-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812291511
2953742|2953742-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812291512
2953993|2953993-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812291627
2953998|2953998-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812291628
2955398|2955398-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200812292207
2956271|2956271-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812300130
2956422|2956422-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300215
2956428|2956428-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300215
2956429|2956429-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300216
2956431|2956431-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Class-DBI-ClassGenerator|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300218
2956432|2956432-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300217
2956452|2956452-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956453|2956453-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956454|2956454-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300224
2956456|2956456-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956457|2956457-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300221
2956461|2956461-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300221
2956463|2956463-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300222
2956465|2956465-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300218
2956474|2956474-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300222
2956487|2956487-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300221
2956494|2956494-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300223
2956495|2956495-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300219
2956497|2956497-b19f-3f77-b713-d32bba55d77f|pass|200812|bingos@cpan.org|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200812300219
2957197|2957197-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812300611
2962681|2962681-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812311512
2963147|2963147-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812311739
2963177|2963177-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200812311740
2963351|2963351-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812311746
2963683|2963683-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200812311840
2964004|2964004-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812312003
2964005|2964005-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200812312004
2964154|2964154-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200812312109
2964386|2964386-b19f-3f77-b713-d32bba55d77f|pass|200812|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200812312216
2965522|2965522-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901010245
2966094|2966094-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901010440
2970431|2970431-b19f-3f77-b713-d32bba55d77f|pass|200812|schwern@pobox.com|Data-Compare|1.21|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200812311350
2972816|2972816-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901020241
2975571|2975571-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901020803
2975607|2975607-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901020814
2977034|2977034-b19f-3f77-b713-d32bba55d77f|pass|200901|pjacklam@online.no|Statistics-ChiSquare|0.5|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200901021648
2977742|2977742-b19f-3f77-b713-d32bba55d77f|pass|200901|pjacklam@online.no|Statistics-SerialCorrelation|1.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200901021812
2980384|2980384-b19f-3f77-b713-d32bba55d77f|pass|200901|vutral@gmail.com|Devel-CheckOS|1.50|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.26-1-vserver-amd64|200901021136
2983106|2983106-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901031244
2984385|2984385-b19f-3f77-b713-d32bba55d77f|fail|200901|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901031821
2988399|2988399-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-thread-multi-64int|5.8.9|dragonfly|2.0.1-release|200901041000
2989226|2989226-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901040921
2989280|2989280-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901040940
2989302|2989302-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901040946
2989367|2989367-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901040956
2989567|2989567-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041021
2989644|2989644-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901041630
2990077|2990077-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041115
2990207|2990207-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041121
2990404|2990404-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041140
2990588|2990588-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041158
2990736|2990736-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041218
2992341|2992341-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041437
2992353|2992353-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041438
2992362|2992362-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041439
2992423|2992423-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041444
2992512|2992512-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901041452
2993181|2993181-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200901042205
2993215|2993215-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041606
2993227|2993227-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200901042207
2993275|2993275-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901041611
2993573|2993573-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901041638
2994599|2994599-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901050025
2995379|2995379-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901041443
2995415|2995415-b19f-3f77-b713-d32bba55d77f|pass|200901|bobtfish@bobtfish.net|Devel-CheckOS|1.50|darwin-thread-multi-2level|5.8.6|darwin|8.0|200901042109
2995926|2995926-b19f-3f77-b713-d32bba55d77f|pass|200901|fayland@gmail.com ("Fayland Lam")|Devel-CheckOS|1.50|i386-linux-thread-multi|5.8.6|linux|2.6.9-34.elsmp|200901050300
2997005|2997005-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901051045
2998795|2998795-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901051656
2998800|2998800-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901051657
2998880|2998880-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901051709
2998888|2998888-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901051710
3002020|3002020-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901052322
3002205|3002205-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901052336
3002265|3002265-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901051840
3002332|3002332-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901051843
3002521|3002521-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901051851
3002553|3002553-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901051852
3002714|3002714-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901060007
3002946|3002946-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901060033
3003702|3003702-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901060245
3006895|3006895-b19f-3f77-b713-d32bba55d77f|pass|200901|alceu.freitas.jr@gmail.com|Devel-CheckOS|1.50|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-14-server|200901060041
3007544|3007544-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901060632
3007551|3007551-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901060633
3008585|3008585-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901061355
3009674|3009674-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901061558
3009704|3009704-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901061600
3010481|3010481-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|File-Find-Rule-Permissions|1.3|i686-linux|5.10.0|linux|2.6.18-4-686|200901061820
3011821|3011821-b19f-3f77-b713-d32bba55d77f|fail|200901|imacat@mail.imacat.idv.tw|Palm-SMS|0.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901070326
3012451|3012451-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|XML-Tiny|1.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901061526
3012845|3012845-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901062203
3012853|3012853-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901062203
3013870|3013870-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s3@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061635
3013872|3013872-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s3@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061637
3013892|3013892-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s3@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061659
3014349|3014349-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.s3@gmail.com|Tie-STDOUT|1.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901061658
3014615|3014615-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Class-DBI-ClassGenerator|1.01|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901070159
3016330|3016330-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070353
3016455|3016455-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070404
3016625|3016625-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070424
3016659|3016659-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070428
3016712|3016712-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070434
3016961|3016961-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200901071102
3016985|3016985-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200901071103
3017173|3017173-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070523
3017384|3017384-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200901071212
3017425|3017425-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200901071218
3017659|3017659-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070642
3017842|3017842-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070657
3017848|3017848-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070657
3017959|3017959-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070708
3017965|3017965-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070709
3018043|3018043-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Tie-STDOUT|1.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070717
3018049|3018049-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901070717
3018162|3018162-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Tie-STDOUT|1.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070729
3018177|3018177-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901070730
3020466|3020466-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Sort-MultipleFields|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901071550
3020801|3020801-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901071613
3021091|3021091-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.26.3-29.fc9.i686|200901072153
3021121|3021121-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.26.3-29.fc9.i686|200901072157
3022738|3022738-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901080309
3022740|3022740-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901080310
3023078|3023078-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-Hexdumper|1.4|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080347
3023203|3023203-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Palm-Treo680MessagesDB|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080417
3025042|3025042-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|DBIx-Class-SingletonRows|0.11|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901080854
3025313|3025313-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Data-Transactional|1.02|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081022
3025402|3025402-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPU-Emulator-Memory|1.1001|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081046
3025405|3025405-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPU-Emulator-Z80|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081046
3026194|3026194-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Number-Phone|1.6|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901081254
3026216|3026216-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.18-4-686|200901081931
3028031|3028031-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901082204
3028034|3028034-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901082205
3030345|3030345-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901090719
3030353|3030353-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901090720
3030465|3030465-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901090743
3031056|3031056-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901090940
3032394|3032394-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Devel-CheckLib|0.5|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901090906
3034476|3034476-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901092038
3034562|3034562-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901092059
3034980|3034980-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901092019
3035363|3035363-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901092309
3035629|3035629-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901092346
3035762|3035762-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|CPAN-FindDependencies|2.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901091803
3036705|3036705-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Bryar|3.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901100141
3037456|3037456-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901100503
3038236|3038236-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|File-Find-Rule-Permissions|1.3|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901100102
3041175|3041175-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200901101721
3041177|3041177-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200901101722
3041179|3041179-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200901101722
3041195|3041195-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-SMS|0.03|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200901101721
3041654|3041654-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Tie-STDOUT|1.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901101247
3041909|3041909-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.blead@gmail.com|Devel-CheckLib|0.5|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901101400
3042141|3042141-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901101443
3042195|3042195-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901101450
3042321|3042321-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901102116
3042349|3042349-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.8.9|freebsd|7.0-release|200901102120
3042384|3042384-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.8.8|freebsd|7.0-release|200901102120
3042646|3042646-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.10.0|freebsd|7.0-release|200901102230
3042724|3042724-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Palm-TreoPhoneCallDB|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901101653
3042788|3042788-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901102307
3043291|3043291-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901110038
3043567|3043567-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200901110034
3043569|3043569-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200901110035
3043571|3043571-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200901110036
3043574|3043574-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200901110037
3044048|3044048-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901110423
3045008|3045008-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Net-Random|2.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901110346
3045176|3045176-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200901111157
3045241|3045241-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901111027
3045453|3045453-b19f-3f77-b713-d32bba55d77f|na|200901|srezic@cpan.org|Palm-SMS|0.03|amd64-freebsd|5.6.2|freebsd|7.0-release|200901111226
3045905|3045905-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901110805
3045969|3045969-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|Palm-SMS|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901112222
3046396|3046396-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901111740
3046521|3046521-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901111201
3046732|3046732-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|i686-linux|5.8.8|linux|2.4.27-3-686|200901111739
3046733|3046733-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901111741
3046741|3046741-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|IP35-irix-64int|5.8.8|irix|6.5|200901111842
3046858|3046858-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901111813
3047439|3047439-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.03|i86pc-solaris-64int|5.10.0|solaris|2.11|200901112123
3047586|3047586-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901111422
3047835|3047835-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Number-Phone|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901111319
3048049|3048049-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901112144
3049043|3049043-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901120101
3049355|3049355-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901120147
3049614|3049614-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Games-Dice-Advanced|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901120250
3050815|3050815-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Sub-WrapPackages|1.2|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901120204
3051732|3051732-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Number-Phone|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901120939
3051755|3051755-b19f-3f77-b713-d32bba55d77f|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901121042
3051816|3051816-b19f-3f77-b713-d32bba55d77f|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901121104
3051972|3051972-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901121204
3051993|3051993-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200901121217
3052076|3052076-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200901121238
3052262|3052262-b19f-3f77-b713-d32bba55d77f|pass|200901|mohsen_basirat@yahoo.com ("Mohsen Basirat")|Devel-CheckOS|1.50|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.15.7|200901121712
3052901|3052901-b19f-3f77-b713-d32bba55d77f|unknown|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901121535
3052903|3052903-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901121535
3055025|3055025-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901122043
3055128|3055128-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901121940
3055305|3055305-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|File-Overwrite|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901121509
3055374|3055374-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200901122015
3055379|3055379-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901122016
3055877|3055877-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200901122120
3055888|3055888-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901122223
3056023|3056023-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Class-CanBeA|1.2|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901121639
3056648|3056648-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.18-4-686|200901130030
3057594|3057594-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901130224
3057888|3057888-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901130306
3058988|3058988-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901130645
3059229|3059229-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901130719
3060174|3060174-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Palm-SMS|0.03|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901131039
3060676|3060676-b19f-3f77-b713-d32bba55d77f|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901131256
3060926|3060926-b19f-3f77-b713-d32bba55d77f|na|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901131342
3061039|3061039-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901131400
3061210|3061210-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901131417
3061988|3061988-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901131530
3062551|3062551-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901131827
3062786|3062786-b19f-3f77-b713-d32bba55d77f|fail|200901|davidrw@cpan.org|Palm-SMS|0.02|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901131320
3062866|3062866-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901131833
3062876|3062876-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901131934
3062904|3062904-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200901131439
3062953|3062953-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901131345
3063656|3063656-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200901131705
3064812|3064812-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901140209
3064835|3064835-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901140213
3066864|3066864-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901141226
3068176|3068176-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Statistics-SerialCorrelation|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901141202
3068842|3068842-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Tie-Hash-Longest|1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901141522
3068845|3068845-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Statistics-ChiSquare|0.5|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901141522
3069414|3069414-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200901142328
3069447|3069447-b19f-3f77-b713-d32bba55d77f|pass|200901|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200901142332
3069556|3069556-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901142247
3070623|3070623-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|NestedMap|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901150300
3071702|3071702-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901150848
3071881|3071881-b19f-3f77-b713-d32bba55d77f|pass|200901|billf@FreeBSD.org ("Bill Fumerola")|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200901150502
3071928|3071928-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901150934
3072868|3072868-b19f-3f77-b713-d32bba55d77f|pass|200901|frank.wiegand@gmail.com ("Frank Wiegand")|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.8.9|linux|2.6.26-1-amd64|200901151555
3073733|3073733-b19f-3f77-b713-d32bba55d77f|unknown|200901|davidrw@cpan.org|Acme-Licence|1.0|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901151351
3075263|3075263-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901160127
3075384|3075384-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200901160205
3075501|3075501-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200901160244
3076468|3076468-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901160745
3076974|3076974-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901161005
3077674|3077674-b19f-3f77-b713-d32bba55d77f|unknown|200901|davidrw@cpan.org|Acme-Pony|1.1.2|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901160944
3077761|3077761-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Tie-Hash-Rank|1.0.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901161000
3077829|3077829-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Tie-Scalar-Decay|1.1.1|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901161016
3078106|3078106-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901161557
3078430|3078430-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200901161710
3078438|3078438-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200901161710
3078481|3078481-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|alpha-netbsd|5.10.0|netbsd|4.0.1|200901161717
3078818|3078818-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901162017
3078878|3078878-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901161836
3079684|3079684-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901162124
3080154|3080154-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901162347
3080479|3080479-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200901170133
3080489|3080489-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200901170134
3080494|3080494-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200901170135
3080878|3080878-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901170309
3080893|3080893-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200901170310
3081216|3081216-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901170539
3082000|3082000-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901171011
3082067|3082067-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901171023
3082188|3082188-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|MirBSD.i386-mirbsd-thread-multi-64int|5.8.8|mirbsd|10|200901171047
3082367|3082367-b19f-3f77-b713-d32bba55d77f|fail|200901|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200901171254
3083075|3083075-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901171606
3083181|3083181-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901171631
3083183|3083183-b19f-3f77-b713-d32bba55d77f|fail|200901|srezic@cpan.org|Bryar|3.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901171727
3083730|3083730-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901171928
3083833|3083833-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901171941
3083867|3083867-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901171848
3084047|3084047-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901172007
3084160|3084160-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901172023
3084385|3084385-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901172058
3084426|3084426-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901172105
3084438|3084438-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901172106
3084638|3084638-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901172128
3084851|3084851-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Palm-SMS|0.03|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200901172048
3084921|3084921-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|Bryar|3.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901172056
3084958|3084958-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200901172201
3085078|3085078-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200901172216
3085202|3085202-b19f-3f77-b713-d32bba55d77f|fail|200901|david@cantrell.org.uk|Bryar|3.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200901172135
3085316|3085316-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901172246
3085423|3085423-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901172306
3085556|3085556-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901172221
3086173|3086173-b19f-3f77-b713-d32bba55d77f|fail|200901|rhaen@cpan.org (Ulrich Habel)|Bryar|3.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901180013
3087406|3087406-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|MirBSD.i386-mirbsd-thread-multi-64int|5.10.0|mirbsd|10|200901180805
3087642|3087642-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901181036
3087651|3087651-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.18-4-686|200901181040
3088536|3088536-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901181254
3088616|3088616-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901181318
3088650|3088650-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901181322
3090667|3090667-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|Bryar|3.0|amd64-freebsd|5.6.2|freebsd|7.0-release|200901181839
3091576|3091576-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200901182023
3091579|3091579-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200901182024
3092109|3092109-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|Palm-SMS|0.03|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901181726
3093276|3093276-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200901190415
3093840|3093840-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|XML-Tiny|1.11|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901190727
3093903|3093903-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901190842
3094021|3094021-b19f-3f77-b713-d32bba55d77f|pass|200901|mw487.yahoo.com@gmail.com|Palm-SMS|0.03|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200901190317
3094816|3094816-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200901191104
3094992|3094992-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200901191135
3096218|3096218-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200901191507
3098209|3098209-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901192012
3099593|3099593-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901192222
3100693|3100693-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901200111
3100701|3100701-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200901200112
3101214|3101214-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901200327
3101252|3101252-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901200336
3101452|3101452-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200901200437
3101854|3101854-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200901200624
3102253|3102253-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200902
3102255|3102255-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200902
3102288|3102288-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200910
3102298|3102298-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200911
3102315|3102315-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200914
3102316|3102316-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200914
3102331|3102331-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200917
3102333|3102333-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200917
3102335|3102335-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200918
3102336|3102336-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200918
3102343|3102343-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200919
3102344|3102344-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901200919
3102349|3102349-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200919
3102350|3102350-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901200919
3103416|3103416-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.18-4-686|200901201357
3103802|3103802-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901201514
3103902|3103902-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201433
3104594|3104594-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201511
3104600|3104600-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901201745
3104736|3104736-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200901201620
3105743|3105743-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200901202105
3106475|3106475-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901210141
3106869|3106869-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901210230
3107068|3107068-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901210203
3107565|3107565-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901210553
3108972|3108972-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901211210
3110542|3110542-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901211610
3110600|3110600-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|Data-Compare|1.21|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901211747
3113403|3113403-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901220631
3113641|3113641-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901220740
3113680|3113680-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200901220746
3114002|3114002-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200901220912
3114664|3114664-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|Palm-SMS|0.03|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901221238
3115222|3115222-b19f-3f77-b713-d32bba55d77f|pass|200901|jeff@zeroclue.com|Devel-CheckOS|1.50|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200901221507
3115892|3115892-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200901221741
3116396|3116396-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200901221937
3117051|3117051-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.11|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901230015
3117085|3117085-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.8.9|freebsd|7.0-release|200901222352
3117087|3117087-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.8.8|freebsd|7.0-release|200901222352
3117361|3117361-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200901230056
3117362|3117362-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200901230056
3117364|3117364-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200901230057
3117366|3117366-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200901230057
3117367|3117367-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200901230058
3117644|3117644-b19f-3f77-b713-d32bba55d77f|pass|200901|davidrw@cpan.org|XML-Tiny|1.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200901230321
3118206|3118206-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200901230711
3118207|3118207-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200901230711
3118208|3118208-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200901230712
3118210|3118210-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200901230712
3118228|3118228-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Sort-MultipleFields|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901230618
3118327|3118327-b19f-3f77-b713-d32bba55d77f|pass|200901|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200901231542
3118848|3118848-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200901230907
3118883|3118883-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200901230915
3118982|3118982-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200901230931
3119057|3119057-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200901230944
3119145|3119145-b19f-3f77-b713-d32bba55d77f|pass|200901|imacat@mail.imacat.idv.tw|XML-Tiny|1.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200901231703
3119175|3119175-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200901231013
3119384|3119384-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200901231045
3119456|3119456-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901230847
3119457|3119457-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200901230847
3119467|3119467-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.10.0|linux|2.6.18-92.el5|200901231101
3119468|3119468-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200901231102
3119496|3119496-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200901231107
3119536|3119536-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Data-Hexdumper|1.4|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901231015
3119538|3119538-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Palm-Treo680MessagesDB|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901231015
3119547|3119547-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200901231117
3119557|3119557-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200901231119
3119755|3119755-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.18-4-686|200901231144
3119819|3119819-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200901231154
3119868|3119868-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200901231104
3120019|3120019-b19f-3f77-b713-d32bba55d77f|pass|200901|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.12|i86pc-solaris-64int|5.10.0|solaris|2.11|200901231250
3120191|3120191-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200901231349
3120883|3120883-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200901231435
3121016|3121016-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200901231510
3121194|3121194-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|IP35-irix-64int|5.8.8|irix|6.5|200901231653
3121313|3121313-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200901231606
3121412|3121412-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200901231613
3121414|3121414-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200901231614
3121468|3121468-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200901231624
3121519|3121519-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901231637
3121780|3121780-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200901231729
3121783|3121783-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200901231729
3121805|3121805-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|alpha-netbsd|5.10.0|netbsd|4.0.1|200901231732
3121822|3121822-b19f-3f77-b713-d32bba55d77f|pass|200901|david@cantrell.org.uk|XML-Tiny|1.12|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200901231134
3121964|3121964-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200901231757
3122534|3122534-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200901232155
3122728|3122728-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200901232029
3123194|3123194-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200901232207
3123823|3123823-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200901240027
3124660|3124660-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Bryar|3.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200901240355
3124819|3124819-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Data-Transactional|1.02|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240442
3124845|3124845-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200901240449
3124901|3124901-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901240508
3124996|3124996-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPU-Emulator-Memory|1.1001|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240538
3124997|3124997-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPU-Emulator-Z80|1.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901240538
3125657|3125657-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Number-Phone|1.6|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901241015
3125747|3125747-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int|5.8.8|linux|2.4.26|200901241042
3125882|3125882-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.10.0|freebsd|7.0-release|200901241208
3126151|3126151-b19f-3f77-b713-d32bba55d77f|fail|200901|bingos@cpan.org|Bryar|3.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200901241232
3126500|3126500-b19f-3f77-b713-d32bba55d77f|pass|200901|vpit@cpan.org|XML-Tiny|1.12|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200901241509
3126707|3126707-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200901241438
3126734|3126734-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200901241543
3126741|3126741-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200901241546
3127495|3127495-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200901241718
3128380|3128380-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200901242139
3128767|3128767-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200901242313
3129686|3129686-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200901250159
3129721|3129721-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200901250314
3130481|3130481-b19f-3f77-b713-d32bba55d77f|pass|200901|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200901251022
3130866|3130866-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200901251109
3132000|3132000-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.18-4-686|200901251705
3133636|3133636-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200901260223
3133678|3133678-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200901260246
3133836|3133836-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200901260340
3133852|3133852-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200901260346
3135680|3135680-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200901261141
3135783|3135783-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200901261204
3135813|3135813-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200901261309
3136871|3136871-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.18-4-686|200901261733
3137864|3137864-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901262051
3138299|3138299-b19f-3f77-b713-d32bba55d77f|pass|200901|srezic@cpan.org|XML-Tiny|1.12|amd64-freebsd|5.6.2|freebsd|7.0-release|200901262311
3139120|3139120-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200901270014
3139208|3139208-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200901270020
3141201|3141201-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|Devel-CheckLib|0.5|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901270439
3142492|3142492-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901271224
3142519|3142519-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200901271139
3143418|3143418-b19f-3f77-b713-d32bba55d77f|pass|200901|rlane10@wi.rr.com|Devel-CheckOS|1.50|darwin-2level-ld|5.10.0|darwin|8.11.0|200901270153
3144749|3144749-b19f-3f77-b713-d32bba55d77f|pass|200901|cjfields@bioperl.org|XML-Tiny|1.12|darwin-2level|5.10.0|darwin|9.2.0|200901271052
3146371|3146371-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200901280126
3146470|3146470-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200901280201
3147913|3147913-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|CPAN-FindDependencies|2.0|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901281125
3148184|3148184-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200901280748
3148256|3148256-b19f-3f77-b713-d32bba55d77f|pass|200901|rlane10@wi.rr.com|XML-Tiny|1.12|darwin-2level-ld|5.10.0|darwin|8.11.0|200901271703
3148341|3148341-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.8|dragonfly|2.0.1-release|200901280757
3149104|3149104-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200901281115
3150091|3150091-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200901281345
3150295|3150295-b19f-3f77-b713-d32bba55d77f|pass|200901|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|x86_64-linux-ld|5.10.0|linux|2.6.27-9-generic|200901281506
3150835|3150835-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200901281559
3151148|3151148-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200901281647
3152204|3152204-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200901290241
3152777|3152777-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.blead@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200901290338
3152825|3152825-b19f-3f77-b713-d32bba55d77f|fail|200901|cpan.dcollins.5100@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901290342
3152896|3152896-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|XML-Tiny|1.12|i686-linux-thread-multi|0|linux|2.6.24-19-generic|200901290345
3153489|3153489-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200901290133
3153540|3153540-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200901290155
3153617|3153617-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200901290218
3153623|3153623-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200901290218
3155515|3155515-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200901291200
3155540|3155540-b19f-3f77-b713-d32bba55d77f|pass|200901|rhaen@cpan.org (Ulrich Habel)|File-Find-Rule-Permissions|1.3|i386-netbsd-thread-multi|5.10.0|netbsd|5.0_beta|200901291236
3156187|3156187-b19f-3f77-b713-d32bba55d77f|pass|200901|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200901291442
3157695|3157695-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200901291950
3160093|3160093-b19f-3f77-b713-d32bba55d77f|pass|200901|bingos@cpan.org|XML-Tiny|1.12|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200901300249
3160855|3160855-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300559
3161599|3161599-b19f-3f77-b713-d32bba55d77f|pass|200901|vovkasm@gmail.com|Devel-CheckOS|1.50|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200901291221
3162691|3162691-b19f-3f77-b713-d32bba55d77f|pass|200901|rafl@debian.org|XML-Tiny|1.12|i686-linux-multi|5.10.0|linux|2.6.24-rc5|200901301249
3164246|3164246-b19f-3f77-b713-d32bba55d77f|fail|200901|stro@cpan.org|Bryar|3.0|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300758
3164789|3164789-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Data-Compare|1.21|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901300941
3165345|3165345-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.18-4-686|200901302022
3166563|3166563-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901301436
3167132|3167132-b19f-3f77-b713-d32bba55d77f|pass|200901|stro@cpan.org|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200901310037
3169338|3169338-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310904
3170148|3170148-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901310956
3170593|3170593-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200901311032
3170596|3170596-b19f-3f77-b713-d32bba55d77f|pass|200901|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200901311033
3172441|3172441-b19f-3f77-b713-d32bba55d77f|pass|200901|stsc@refcnt.org ("Steven Schubiger")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.18-4-686|200901312121
3174834|3174834-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010413
3175183|3175183-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010025
3175187|3175187-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010025
3175190|3175190-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902010026
3175292|3175292-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902010655
3179540|3179540-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902010425
3179541|3179541-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902010426
3180592|3180592-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902020000
3181192|3181192-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902020221
3182198|3182198-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902020811
3183037|3183037-b19f-3f77-b713-d32bba55d77f|pass|200902|"Rick Myers <rick@jrmyers.net>"|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.24.3|200902020456
3183902|3183902-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|XML-Tiny|1.12|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902020835
3184408|3184408-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Devel-CheckOS|1.50|alpha-netbsd|5.10.0|netbsd|4.0.1|200902021525
3191738|3191738-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902031317
3192181|3192181-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902031533
3192224|3192224-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902031541
3197695|3197695-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902041136
3199931|3199931-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902041348
3200634|3200634-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902041611
3201003|3201003-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902041637
3201070|3201070-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902041642
3201739|3201739-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902042227
3202413|3202413-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902041845
3202691|3202691-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050005
3203291|3203291-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com|XML-Tiny|1.12|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902050051
3203507|3203507-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902050126
3203592|3203592-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050138
3203703|3203703-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050153
3204141|3204141-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902050245
3204156|3204156-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902050246
3205407|3205407-b19f-3f77-b713-d32bba55d77f|fail|200902|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902050311
3206339|3206339-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|XML-Tiny|1.12|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902050349
3208246|3208246-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902051031
3213350|3213350-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902061023
3213352|3213352-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902061023
3215542|3215542-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902061735
3216711|3216711-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902061552
3216816|3216816-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902061600
3217019|3217019-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902061619
3217037|3217037-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902061620
3218461|3218461-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902070106
3218624|3218624-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070118
3218884|3218884-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070140
3219189|3219189-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Acme-Licence|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902070159
3219367|3219367-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc1@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902070212
3219384|3219384-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902070214
3220795|3220795-b19f-3f77-b713-d32bba55d77f|pass|200902|conrad@fringehead.org|XML-Tiny|1.12|i686-linux-thread-multi|5.8.8|linux|2.6.15.1|200902070724
3221614|3221614-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200902071240
3224567|3224567-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.5100rc1@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071349
3224768|3224768-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.5100rc2@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071412
3225052|3225052-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Bryar|3.0|i686-linux-thread-multi|5.11.0|linux|2.6.24-19-generic|200902071438
3225185|3225185-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.5100@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902071454
3225616|3225616-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.589@gmail.com|Bryar|3.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902071557
3226001|3226001-b19f-3f77-b713-d32bba55d77f|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902072146
3228066|3228066-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Compare|1.21|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080045
3228078|3228078-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080046
3228080|3228080-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080047
3228096|3228096-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080048
3228468|3228468-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080154
3228535|3228535-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080204
3228645|3228645-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080221
3228672|3228672-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080223
3229258|3229258-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080325
3229365|3229365-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.blead@gmail.com (cpanblead)|Data-Transactional|1.02|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902080337
3229624|3229624-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080412
3229661|3229661-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902080429
3229992|3229992-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200902081022
3231564|3231564-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902081118
3234425|3234425-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080247
3234610|3234610-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080440
3234863|3234863-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902080058
3235226|3235226-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.s1@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902081804
3235347|3235347-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s1@gmail.com|File-Overwrite|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902081818
3236420|3236420-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.5100rc2@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902090231
3237946|3237946-b19f-3f77-b713-d32bba55d77f|fail|200902|cpan.dcollins.s3@gmail.com|File-Find-Rule-Permissions|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902081759
3238067|3238067-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan.dcollins.s3@gmail.com|File-Overwrite|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902081811
3241426|3241426-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902090952
3248516|3248516-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.11.0 patch GitLive-blead-571-gabd7186|freebsd|7.0-release|200902100616
3248801|3248801-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902100738
3250417|3250417-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902101618
3250471|3250471-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902101618
3250472|3250472-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902101619
3250474|3250474-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200902101619
3250744|3250744-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902101730
3251797|3251797-b19f-3f77-b713-d32bba55d77f|fail|200902|srezic@cpan.org|Class-DBI-ClassGenerator|1.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200902102136
3251800|3251800-b19f-3f77-b713-d32bba55d77f|fail|200902|srezic@cpan.org|Class-DBI-ClassGenerator|1.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200902102137
3253184|3253184-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902110020
3253190|3253190-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902110021
3253193|3253193-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902110021
3253196|3253196-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902110022
3254544|3254544-b19f-3f77-b713-d32bba55d77f|pass|200902|stro@cpan.org|Class-DBI-ClassGenerator|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200902111048
3254633|3254633-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200902111002
3255045|3255045-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902111054
3255279|3255279-b19f-3f77-b713-d32bba55d77f|pass|200902|stro@cpan.org|Class-DBI-ClassGenerator|1.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200902111226
3255635|3255635-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902111125
3255810|3255810-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902110651
3255941|3255941-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902110701
3256844|3256844-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111334
3257582|3257582-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111508
3257662|3257662-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111527
3257851|3257851-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902111702
3257963|3257963-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111626
3257998|3257998-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902111642
3258974|3258974-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902111436
3259008|3259008-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902112038
3259025|3259025-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902112039
3261709|3261709-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200902120108
3261898|3261898-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902120041
3261996|3261996-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120052
3262138|3262138-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902120103
3262234|3262234-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120113
3262294|3262294-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|1.4|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902120218
3262299|3262299-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902120219
3265350|3265350-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902120642
3265360|3265360-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902120643
3265374|3265374-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902120644
3265384|3265384-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int|5.8.7|linux|2.6.14|200902120644
3266094|3266094-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902120728
3266287|3266287-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902120641
3266296|3266296-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902120642
3266310|3266310-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902120643
3266324|3266324-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902120644
3266336|3266336-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902120644
3266568|3266568-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902120759
3266624|3266624-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902120803
3266713|3266713-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902120810
3266717|3266717-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902120811
3266782|3266782-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902120816
3266798|3266798-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902120817
3266826|3266826-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902120819
3266862|3266862-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902120822
3266923|3266923-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902120826
3266930|3266930-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902120826
3266942|3266942-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902120829
3266967|3266967-b19f-3f77-b713-d32bba55d77f|fail|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120156
3267164|3267164-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902120827
3267710|3267710-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902121636
3267890|3267890-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902120848
3267897|3267897-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200902120849
3268096|3268096-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902120906
3268661|3268661-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120317
3269601|3269601-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902121144
3269616|3269616-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902121046
3269792|3269792-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902121156
3270080|3270080-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902121212
3270337|3270337-b19f-3f77-b713-d32bba55d77f|fail|200902|DCOLLINS@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902120317
3270411|3270411-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902121133
3270416|3270416-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902121133
3270447|3270447-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902121135
3270521|3270521-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902121138
3270540|3270540-b19f-3f77-b713-d32bba55d77f|pass|200902|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200902121239
3270551|3270551-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902121139
3270557|3270557-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902121139
3271644|3271644-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902120647
3271687|3271687-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|IP35-irix-64int|5.8.8|irix|6.5|200902121350
3271833|3271833-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.11.0 patch GitLive-blead-586-gbf8d130|dragonfly|2.0.1-release|200902121301
3271836|3271836-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.11.0 patch GitLive-blead-586-gbf8d130|dragonfly|2.0.1-release|200902121302
3272255|3272255-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200902121410
3274307|3274307-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902121120
3274314|3274314-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|File-Find-Rule-Permissions|2.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200902121642
3274403|3274403-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121136
3274420|3274420-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121148
3274757|3274757-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902121026
3274801|3274801-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902121009
3277322|3277322-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902122314
3277323|3277323-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902122314
3277605|3277605-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200902122321
3277641|3277641-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200902122330
3278249|3278249-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902130222
3278252|3278252-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902130224
3278253|3278253-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902130224
3278261|3278261-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902130226
3278265|3278265-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902130228
3278510|3278510-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130403
3278514|3278514-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130404
3278624|3278624-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130426
3278647|3278647-b19f-3f77-b713-d32bba55d77f|fail|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130430
3278687|3278687-b19f-3f77-b713-d32bba55d77f|fail|200902|DCOLLINS@cpan.org|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130437
3278888|3278888-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902130506
3278906|3278906-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200902130508
3279442|3279442-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130117
3279575|3279575-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130135
3279584|3279584-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130140
3279762|3279762-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130205
3279767|3279767-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130206
3279782|3279782-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130209
3279783|3279783-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130209
3279795|3279795-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130211
3279831|3279831-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130143
3279851|3279851-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130218
3279881|3279881-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130222
3279884|3279884-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130222
3279887|3279887-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130223
3280014|3280014-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902130206
3280113|3280113-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130242
3280118|3280118-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130242
3280195|3280195-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130217
3280220|3280220-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.11.0 patch GitLive-blead-163-g28b1dae|linux|2.6.24-19-generic|200902130218
3280379|3280379-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130241
3280434|3280434-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902130208
3282049|3282049-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902131032
3283396|3283396-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902131210
3284607|3284607-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902131335
3284616|3284616-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902131335
3284640|3284640-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200902131336
3284645|3284645-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200902131337
3285123|3285123-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902131414
3285410|3285410-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200902131427
3285656|3285656-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131449
3285662|3285662-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131449
3286678|3286678-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.11.0 patch GitLive-blead-586-gbf8d130|dragonfly|2.0.1-release|200902131602
3286793|3286793-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Data-Hexdumper|1.4|alpha-netbsd|5.10.0|netbsd|4.0.1|200902131639
3287792|3287792-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131259
3287853|3287853-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131303
3288094|3288094-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902131824
3288267|3288267-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131331
3289850|3289850-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131553
3290684|3290684-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131711
3290989|3290989-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131707
3291093|3291093-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902131736
3291362|3291362-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.11.0 patch GitLive-blead-599-gd9acc78|linux|2.6.16.38|200902132304
3292665|3292665-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140153
3292741|3292741-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902140201
3292994|3292994-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140226
3293864|3293864-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200902140448
3294438|3294438-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140611
3295481|3295481-b19f-3f77-b713-d32bba55d77f|pass|200902|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.24-19-generic|200902140941
3296521|3296521-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141346
3296543|3296543-b19f-3f77-b713-d32bba55d77f|pass|200902|vpit@cpan.org|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200902141449
3296553|3296553-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141348
3297056|3297056-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200902141525
3297671|3297671-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141721
3297672|3297672-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902141721
3297826|3297826-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.2-release|200902141805
3297827|3297827-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.2-release|200902141805
3298349|3298349-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200902142025
3299270|3299270-b19f-3f77-b713-d32bba55d77f|na|200902|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902141839
3299284|3299284-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902142345
3299336|3299336-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902142358
3299776|3299776-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.2-release|200902150211
3300040|3300040-b19f-3f77-b713-d32bba55d77f|pass|200902|stro@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux|5.8.8|linux|2.4.27-2-386|200902150627
3300729|3300729-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200902151252
3300774|3300774-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902151202
3301130|3301130-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151348
3301165|3301165-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151403
3301170|3301170-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902151405
3301764|3301764-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200902151648
3302206|3302206-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902151819
3302467|3302467-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902151946
3302727|3302727-b19f-3f77-b713-d32bba55d77f|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.26-1-686|200902152131
3303098|3303098-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200902152207
3303160|3303160-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i386-dragonfly-64int|5.8.9|dragonfly|2.0.0-release|200902152222
3303730|3303730-b19f-3f77-b713-d32bba55d77f|na|200902|mw487.yahoo.com@gmail.com|File-Find-Rule-Permissions|2.0|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200902160237
3304723|3304723-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902160838
3305048|3305048-b19f-3f77-b713-d32bba55d77f|pass|200902|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.50|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200902160458
3305227|3305227-b19f-3f77-b713-d32bba55d77f|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|x86_64-linux-thread-multi|5.10.0|linux|2.6.26-1-amd64|200902161030
3305573|3305573-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161140
3305574|3305574-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161140
3305575|3305575-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161141
3305989|3305989-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902161345
3306057|3306057-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161418
3306061|3306061-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902161419
3306114|3306114-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161437
3306119|3306119-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161438
3306331|3306331-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902161540
3307158|3307158-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902161944
3308048|3308048-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|XML-Tiny|1.12|i686-linux-64int-ld|5.11.0 patch GitLive-blead-623-g4705144|linux|2.6.21.5-smp|200902162341
3308194|3308194-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902170123
3308261|3308261-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902170043
3308262|3308262-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902170043
3308787|3308787-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200902170331
3308827|3308827-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902170439
3308828|3308828-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902170439
3308834|3308834-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902170441
3310414|3310414-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902171055
3310417|3310417-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902171056
3310951|3310951-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200902171245
3310981|3310981-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171256
3310984|3310984-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171257
3310986|3310986-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171257
3311763|3311763-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902171613
3311770|3311770-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902171615
3311833|3311833-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200902171626
3311838|3311838-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.2|200902171628
3312523|3312523-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171851
3312527|3312527-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171852
3312528|3312528-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902171852
3312547|3312547-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200902171858
3313856|3313856-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200902180101
3314145|3314145-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180250
3314146|3314146-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180251
3314147|3314147-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180251
3314380|3314380-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.2|200902180628
3314697|3314697-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200902180908
3315628|3315628-b19f-3f77-b713-d32bba55d77f|fail|200902|david@cantrell.org.uk|Devel-CheckOS|1.50|alpha-netbsd|5.10.0|netbsd|4.0.1|200902181717
3315922|3315922-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.2|200902181923
3315923|3315923-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902181859
3315924|3315924-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902181859
3316609|3316609-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd|5.10.0|freebsd|7.0-release|200902182306
3316832|3316832-b19f-3f77-b713-d32bba55d77f|pass|200902|nothingmuch@woobling.org|Number-Phone|1.6|darwin-2level|5.10.0|darwin|9.5.0|200902180429
3317708|3317708-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200902190325
3317709|3317709-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200902190325
3319416|3319416-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200902192108
3319696|3319696-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200902192157
3319956|3319956-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200902192303
3320276|3320276-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Data-Hexdumper|1.4|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200902200023
3324808|3324808-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|Data-Hexdumper|1.4|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902211006
3327140|3327140-b19f-3f77-b713-d32bba55d77f|pass|200902|srezic@cpan.org|File-Find-Rule-Permissions|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200902212229
3328741|3328741-b19f-3f77-b713-d32bba55d77f|pass|200902|rafl@debian.org|Data-Compare|1.21|i686-linux|5.10.0 patch 35117|linux|2.6.26|200902220600
3333867|3333867-b19f-3f77-b713-d32bba55d77f|pass|200902|amoore@cpan.org|Devel-CheckOS|1.50|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-vserver-amd64|200902201428
3334176|3334176-b19f-3f77-b713-d32bba55d77f|pass|200902|robbiebow@gmail.com|XML-Tiny|1.12|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18-6-686|200902210007
3338316|3338316-b19f-3f77-b713-d32bba55d77f|pass|200902|andy@hexten.net|Data-Hexdumper|1.4|i686-linux-thread-multi|5.10.0|linux|2.6.26-1-686|200902240333
3340932|3340932-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241007
3341552|3341552-b19f-3f77-b713-d32bba55d77f|pass|200902|rlane10@wi.rr.com|XML-Tiny|1.12|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200902240849
3341581|3341581-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241802
3341582|3341582-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241803
3341737|3341737-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241227
3341904|3341904-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200902241255
3342039|3342039-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902241926
3346325|3346325-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.24-16-generic|200902250724
3346932|3346932-b19f-3f77-b713-d32bba55d77f|fail|200902|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902251044
3347107|3347107-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.10.0|linux|2.6.24-16-generic|200902251135
3349261|3349261-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902260148
3352078|3352078-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200902262119
3352080|3352080-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902262119
3352085|3352085-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902262120
3352093|3352093-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902262121
3352100|3352100-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200902262122
3353126|3353126-b19f-3f77-b713-d32bba55d77f|pass|200902|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.7|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200902271203
3353363|3353363-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902270501
3353364|3353364-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902270502
3353366|3353366-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902270502
3353368|3353368-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902270503
3353370|3353370-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902270504
3353687|3353687-b19f-3f77-b713-d32bba55d77f|fail|200902|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200902270834
3353773|3353773-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902270856
3353774|3353774-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902270856
3353789|3353789-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902270858
3353791|3353791-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902270858
3353827|3353827-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902270912
3353916|3353916-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902270333
3353946|3353946-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|IP35-irix-64int|5.8.8|irix|6.5|200902271043
3353951|3353951-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|Number-Phone|1.7|alpha-netbsd|5.10.0|netbsd|4.0.1|200902270944
3353992|3353992-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200902271007
3354110|3354110-b19f-3f77-b713-d32bba55d77f|pass|200902|stro@cpan.org|Number-Phone|1.7|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200902271249
3354296|3354296-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|i386-dragonfly-64int|5.8.8|dragonfly|2.0.0-release|200902271144
3354607|3354607-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902271440
3354908|3354908-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902271547
3354922|3354922-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902271551
3354973|3354973-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902271607
3354988|3354988-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902271610
3355007|3355007-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902271622
3355038|3355038-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902271628
3355060|3355060-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902271632
3355113|3355113-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902271647
3355219|3355219-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902271720
3355254|3355254-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902271734
3355279|3355279-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902271747
3355302|3355302-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902271753
3355851|3355851-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200902272217
3355852|3355852-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200902272217
3355853|3355853-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200902272217
3355855|3355855-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200902272218
3355857|3355857-b19f-3f77-b713-d32bba55d77f|pass|200902|andreas.koenig.gmwojprw@franz.ak.mind.de|WWW-Facebook-Go-SGF|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200902272218
3355866|3355866-b19f-3f77-b713-d32bba55d77f|pass|200902|jeff@zeroclue.com|Number-Phone|1.7|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200902271806
3356531|3356531-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|Number-Phone|1.7|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902281038
3356612|3356612-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200902280311
3356623|3356623-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200902280316
3356777|3356777-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280441
3356927|3356927-b19f-3f77-b713-d32bba55d77f|pass|200902|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7|i686-linux|5.10.0|linux|2.6.24-16-generic|200902280043
3356934|3356934-b19f-3f77-b713-d32bba55d77f|pass|200902|jeff@zeroclue.com|WWW-Facebook-Go-SGF|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200902280232
3357167|3357167-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200902280650
3357170|3357170-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200902280651
3357172|3357172-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200902280651
3357177|3357177-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200902280652
3357179|3357179-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200902280652
3357896|3357896-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200902281049
3357927|3357927-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200902281058
3357935|3357935-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200902281101
3357936|3357936-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200902281101
3358192|3358192-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200902281044
3358211|3358211-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200902281147
3358215|3358215-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200902281049
3358222|3358222-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200902281050
3358228|3358228-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200902281051
3358230|3358230-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200902281051
3358296|3358296-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200902281159
3358327|3358327-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200902281205
3358334|3358334-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200902281207
3358375|3358375-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200902281214
3358451|3358451-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200902281225
3358473|3358473-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200902281129
3358486|3358486-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200902281231
3358523|3358523-b19f-3f77-b713-d32bba55d77f|pass|200902|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200902281236
3358653|3358653-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281256
3358806|3358806-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281317
3359047|3359047-b19f-3f77-b713-d32bba55d77f|pass|200902|imacat@mail.imacat.idv.tw|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200902282106
3359183|3359183-b19f-3f77-b713-d32bba55d77f|pass|200902|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281433
3359184|3359184-b19f-3f77-b713-d32bba55d77f|fail|200902|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200902281433
3359404|3359404-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|IP35-irix-64int|5.8.8|irix|6.5|200902281458
3359423|3359423-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200902280802
3359435|3359435-b19f-3f77-b713-d32bba55d77f|pass|200902|david@cantrell.org.uk|WWW-Facebook-Go-SGF|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200902281406
3359467|3359467-b19f-3f77-b713-d32bba55d77f|pass|200902|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200902281413
3361773|3361773-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010203
3361986|3361986-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|1.4|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010417
3361987|3361987-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010417
3362264|3362264-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010236
3362437|3362437-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010430
3362476|3362476-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010501
3362477|3362477-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903010501
3362672|3362672-b19f-3f77-b713-d32bba55d77f|pass|200902|fraterm@gmail.com ("Michael Costello")|Games-Dice-Advanced|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200902251649
3363187|3363187-b19f-3f77-b713-d32bba55d77f|pass|200903|ddascaNOSPAMlescu+perl@gmail.com|Data-Hexdumper|1.4|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903010109
3363239|3363239-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903011245
3365498|3365498-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903012102
3365757|3365757-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200903011738
3365916|3365916-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903012256
3365934|3365934-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903012259
3365938|3365938-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903012259
3366828|3366828-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200903020206
3366830|3366830-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200903020207
3367215|3367215-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903020448
3367317|3367317-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903020511
3367403|3367403-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903020548
3368772|3368772-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903020338
3369508|3369508-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903021113
3369636|3369636-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7|i86pc-solaris-64int|5.10.0|solaris|2.11|200903021131
3370474|3370474-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|WWW-Facebook-Go-SGF|1.0|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903020825
3370622|3370622-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903021355
3370624|3370624-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903021356
3370646|3370646-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Number-Phone|1.7|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903021601
3370863|3370863-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903021540
3371042|3371042-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903021605
3371207|3371207-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903021526
3371208|3371208-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903021527
3371319|3371319-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903021641
3371534|3371534-b19f-3f77-b713-d32bba55d77f|pass|200903|celavie@reflec.net|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-stable|200903030026
3371966|3371966-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903021943
3371990|3371990-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Number-Phone|1.7|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903021851
3371992|3371992-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903021851
3372150|3372150-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200903021324
3372917|3372917-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|WWW-Facebook-Go-SGF|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903022059
3373060|3373060-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903021515
3373083|3373083-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903022124
3373129|3373129-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|WWW-Facebook-Go-SGF|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903021740
3373799|3373799-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903021749
3374116|3374116-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd|5.8.9|freebsd|7.0-release|200903022347
3374224|3374224-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903030048
3374226|3374226-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903030048
3374228|3374228-b19f-3f77-b713-d32bba55d77f|fail|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903030048
3374230|3374230-b19f-3f77-b713-d32bba55d77f|fail|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903030048
3374233|3374233-b19f-3f77-b713-d32bba55d77f|fail|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903030049
3374537|3374537-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903030102
3374541|3374541-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903030103
3374545|3374545-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903030104
3374547|3374547-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903030105
3374750|3374750-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030203
3375107|3375107-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030405
3375181|3375181-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030438
3375678|3375678-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Hexdumper|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903031600
3375854|3375854-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd|5.8.8|freebsd|7.0-release|200903030841
3375906|3375906-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903030846
3375935|3375935-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903030842
3376003|3376003-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Data-Hexdumper|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903031017
3376143|3376143-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903030846
3376204|3376204-b19f-3f77-b713-d32bba55d77f|fail|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903030901
3376205|3376205-b19f-3f77-b713-d32bba55d77f|fail|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903030901
3376245|3376245-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|2.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903031006
3376388|3376388-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903030923
3376391|3376391-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903030923
3376394|3376394-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903030923
3376396|3376396-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903030924
3376399|3376399-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903030924
3376402|3376402-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903030924
3376603|3376603-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903031107
3376628|3376628-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|WWW-Facebook-Go-SGF|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903031114
3376690|3376690-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903031126
3376977|3376977-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903031107
3376983|3376983-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903031106
3376995|3376995-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903031108
3376999|3376999-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903031108
3377004|3377004-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200903031109
3377008|3377008-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903031109
3377010|3377010-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200903031110
3377104|3377104-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd|5.10.0|freebsd|7.0-release|200903031227
3377162|3377162-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903030544
3377164|3377164-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903031144
3377188|3377188-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030649
3377445|3377445-b19f-3f77-b713-d32bba55d77f|fail|200903|david@cantrell.org.uk|Data-Hexdumper|2.0|IP35-irix-64int|5.8.8|irix|6.5|200903031410
3377483|3377483-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Data-Hexdumper|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903031520
3377737|3377737-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200903030918
3377808|3377808-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200903031436
3377817|3377817-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200903031440
3377827|3377827-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200903031443
3378296|3378296-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Data-Hexdumper|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903031724
3378717|3378717-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903031901
3378760|3378760-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903031914
3378766|3378766-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903031709
3378769|3378769-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903031710
3378774|3378774-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903031711
3378779|3378779-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903031920
3378905|3378905-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903031945
3379056|3379056-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903032006
3379235|3379235-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031831
3379239|3379239-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031832
3379242|3379242-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903031833
3379675|3379675-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903032132
3379920|3379920-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903031608
3380352|3380352-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903032321
3380383|3380383-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200903031730
3380787|3380787-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200903032349
3380790|3380790-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200903032349
3380793|3380793-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.6.2|solaris|2.10|200903032350
3381107|3381107-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903040954
3381153|3381153-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903040107
3381161|3381161-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903040109
3381165|3381165-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200903040109
3381314|3381314-b19f-3f77-b713-d32bba55d77f|pass|200903|rafl@debian.org|Devel-CheckOS|1.50|i686-linux|5.10.0 patch 35117|linux|2.6.26|200903040244
3381952|3381952-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux|5.10.0|linux|2.6.24-16-generic|200903040438
3381971|3381971-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200903040447
3382079|3382079-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903040529
3382082|3382082-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903040529
3382085|3382085-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903040529
3382088|3382088-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903040530
3382093|3382093-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903040530
3382348|3382348-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903040723
3382351|3382351-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903040724
3382352|3382352-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903040724
3382353|3382353-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903040724
3382356|3382356-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903040724
3382532|3382532-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903040755
3382536|3382536-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903040755
3382539|3382539-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903040755
3382543|3382543-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903040756
3382546|3382546-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7001|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903040757
3382726|3382726-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903040229
3382737|3382737-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903040830
3382782|3382782-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903041638
3382952|3382952-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903040901
3382968|3382968-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200903040850
3382976|3382976-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903040850
3383001|3383001-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903040905
3383013|3383013-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903040906
3383018|3383018-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903040908
3383058|3383058-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903040913
3383067|3383067-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903040914
3383081|3383081-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903040916
3383082|3383082-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903040916
3383133|3383133-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903040923
3383214|3383214-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903040939
3383265|3383265-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903040946
3383266|3383266-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7001|i86pc-solaris-64int|5.10.0|solaris|2.11|200903040947
3383285|3383285-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903040948
3383297|3383297-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903040951
3383298|3383298-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|2.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200903040951
3383333|3383333-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903040957
3383344|3383344-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903040958
3383352|3383352-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903040959
3383392|3383392-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041003
3383416|3383416-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903040907
3383419|3383419-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903040908
3383426|3383426-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903040909
3383427|3383427-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903040910
3383430|3383430-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903040911
3383436|3383436-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903041012
3383439|3383439-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903041013
3383503|3383503-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903041024
3383506|3383506-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903041024
3383516|3383516-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040929
3383518|3383518-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040929
3383522|3383522-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040930
3383528|3383528-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040930
3383529|3383529-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903041029
3383530|3383530-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200903040931
3383537|3383537-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903041031
3383578|3383578-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903041039
3383581|3383581-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903041040
3383645|3383645-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7001|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903041052
3383680|3383680-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903041055
3383696|3383696-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903041057
3383712|3383712-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041059
3383871|3383871-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Data-Hexdumper|2.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200903041124
3383873|3383873-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Number-Phone|1.7001|amd64-freebsd|5.8.8|freebsd|7.0-release|200903041124
3383884|3383884-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Data-Hexdumper|2.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200903041124
3383890|3383890-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Number-Phone|1.7001|amd64-freebsd|5.8.9|freebsd|7.0-release|200903041124
3383913|3383913-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903041127
3384092|3384092-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903041038
3384100|3384100-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903041037
3384102|3384102-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903041038
3384103|3384103-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903041038
3384107|3384107-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903041038
3384109|3384109-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903041039
3384135|3384135-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903041143
3384205|3384205-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903041158
3384281|3384281-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903041202
3384304|3384304-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903041109
3384306|3384306-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903041109
3384341|3384341-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903041116
3384344|3384344-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903041116
3384369|3384369-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903041119
3384394|3384394-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903041122
3384414|3384414-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903041225
3384430|3384430-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903041226
3384433|3384433-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903040627
3384755|3384755-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903041228
3384765|3384765-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903041328
3384898|3384898-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903041349
3385165|3385165-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200903041329
3385169|3385169-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903040729
3385170|3385170-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Hexdumper|2.01|IP35-irix-64int|5.8.8|irix|6.5|200903041429
3385180|3385180-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|alpha-netbsd|5.10.0|netbsd|4.0.1|200903041330
3385185|3385185-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|IP35-irix-64int|5.8.8|irix|6.5|200903041430
3385186|3385186-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Number-Phone|1.7001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903040730
3385358|3385358-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041508
3385592|3385592-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Data-Compare|1.21|alpha-netbsd|5.10.0|netbsd|4.0.1|200903041453
3385967|3385967-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903041643
3386102|3386102-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.24-16-generic|200903041112
3386212|3386212-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903041734
3386561|3386561-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|Number-Phone|1.7001|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903041403
3386772|3386772-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|Data-Hexdumper|2.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903041429
3386876|3386876-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903041348
3386892|3386892-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903041953
3386922|3386922-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041859
3386923|3386923-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041859
3386926|3386926-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041900
3386933|3386933-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041901
3386935|3386935-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903041902
3386953|3386953-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041906
3386956|3386956-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041907
3386960|3386960-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041908
3386963|3386963-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903041408
3386964|3386964-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041909
3386966|3386966-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903041909
3387615|3387615-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903042226
3387618|3387618-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Number-Phone|1.7001|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903042226
3388547|3388547-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|darwin-2level|5.8.8|darwin|8.10.1|200903050018
3388595|3388595-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|darwin-2level|5.8.8|darwin|8.10.1|200903050014
3388761|3388761-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903041839
3389169|3389169-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903050033
3389170|3389170-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.24-16-generic|200903050034
3389617|3389617-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Hexdumper|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200903050937
3389619|3389619-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Number-Phone|1.7001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.24-etchnhalf.1-amd64|200903050937
3390053|3390053-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050143
3390068|3390068-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050144
3390118|3390118-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050148
3390121|3390121-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903050207
3390143|3390143-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050151
3390155|3390155-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903050154
3390420|3390420-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903050332
3390534|3390534-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050302
3390548|3390548-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050305
3390571|3390571-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050309
3390594|3390594-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050313
3390605|3390605-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903050315
3390892|3390892-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903050437
3391727|3391727-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050909
3391729|3391729-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050909
3391733|3391733-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050909
3391738|3391738-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050910
3391742|3391742-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903050910
3392030|3392030-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903050542
3392087|3392087-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903051257
3392232|3392232-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903051216
3392252|3392252-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903051347
3392548|3392548-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903050934
3392941|3392941-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Number-Phone|1.7001|i686-linux|5.8.8|linux|2.4.27-2-386|200903051756
3392975|3392975-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|i686-linux|5.8.8|linux|2.4.27-2-386|200903051811
3393896|3393896-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Number-Phone|1.7|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903052053
3393977|3393977-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052019
3393978|3393978-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903052119
3393979|3393979-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052020
3393983|3393983-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052021
3393987|3393987-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052022
3393991|3393991-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903052022
3393992|3393992-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052023
3393993|3393993-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052024
3393994|3393994-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052024
3393998|3393998-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052025
3394001|3394001-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903052026
3394811|3394811-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903060006
3394812|3394812-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903060006
3395620|3395620-b19f-3f77-b713-d32bba55d77f|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060320
3396073|3396073-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903060413
3396937|3396937-b19f-3f77-b713-d32bba55d77f|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060140
3396972|3396972-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060145
3397007|3397007-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200903060153
3398350|3398350-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060920
3398353|3398353-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060920
3398356|3398356-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060921
3398359|3398359-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903060922
3398714|3398714-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061047
3398715|3398715-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061047
3398718|3398718-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061048
3398719|3398719-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903061048
3399200|3399200-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Data-Compare|1.21|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903060635
3399415|3399415-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.50|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903060359
3399606|3399606-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|Data-Hexdumper|2.0|amd64-freebsd|5.6.2|freebsd|7.0-release|200903061321
3400328|3400328-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|File-Find-Rule-Permissions|2.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903061106
3400566|3400566-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|Class-DBI-ClassGenerator|1.02|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903061141
3400760|3400760-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|i686-linux-64int|5.11.0|linux|2.6.22-1-k7|200903061726
3402040|3402040-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903062206
3402043|3402043-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903062207
3402047|3402047-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903062208
3402073|3402073-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903061715
3402101|3402101-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903062221
3402102|3402102-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903062222
3402123|3402123-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903062227
3402294|3402294-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Number-Phone|1.7001|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903061436
3402578|3402578-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903061847
3402619|3402619-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903061853
3403043|3403043-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Data-Hexdumper|2.01|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903070103
3403100|3403100-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070116
3403108|3403108-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903070117
3403117|3403117-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903070118
3403137|3403137-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070122
3403736|3403736-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070313
3405049|3405049-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070410
3405051|3405051-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070410
3405056|3405056-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070411
3405059|3405059-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903070411
3405351|3405351-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070215
3405396|3405396-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070223
3406350|3406350-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903071031
3406352|3406352-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903071031
3407116|3407116-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070810
3407411|3407411-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903070908
3407689|3407689-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071005
3408610|3408610-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903071849
3409215|3409215-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903071956
3409216|3409216-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903071956
3409217|3409217-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903071957
3409218|3409218-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903071957
3409221|3409221-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903071958
3409224|3409224-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903071958
3409433|3409433-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903071534
3410628|3410628-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200903080045
3410629|3410629-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200903080045
3410697|3410697-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200903080056
3410701|3410701-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200903080057
3410785|3410785-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|WWW-Facebook-Go-SGF|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903080117
3411223|3411223-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903080355
3413241|3413241-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903080806
3413246|3413246-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903080806
3413250|3413250-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903080807
3413609|3413609-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903080941
3413612|3413612-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903080942
3413618|3413618-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903080943
3414071|3414071-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081224
3414706|3414706-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080832
3414730|3414730-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200903081232
3414735|3414735-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200903081233
3414778|3414778-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081336
3415688|3415688-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903080949
3416662|3416662-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081106
3417264|3417264-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081156
3417554|3417554-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081217
3417556|3417556-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903081217
3418403|3418403-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.5|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903081817
3418859|3418859-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081707
3419060|3419060-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200903081816
3419484|3419484-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200903081843
3419998|3419998-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|Number-Phone|1.7001|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200903081913
3420027|3420027-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200903081844
3420231|3420231-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200903081934
3420457|3420457-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Data-Hexdumper|2.0|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903081447
3420461|3420461-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Data-Hexdumper|2.01|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903081447
3420511|3420511-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903081949
3421225|3421225-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903082133
3421549|3421549-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903082153
3422121|3422121-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200903082230
3422231|3422231-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903082142
3422238|3422238-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903082142
3423019|3423019-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903082250
3423020|3423020-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200903082250
3423089|3423089-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903082257
3423098|3423098-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200903082257
3424260|3424260-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090043
3424877|3424877-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.03|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903090300
3425196|3425196-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903090334
3426959|3426959-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090206
3427647|3427647-b19f-3f77-b713-d32bba55d77f|pass|200903|robbiebow@gmail.com|XML-Tiny|1.12|i686-linux|5.10.0|linux|2.6.27.12-bytemark-kvm-2009-01-19|200903081933
3427864|3427864-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|1.12|darwin-2level|5.10.0|darwin|8.11.1|200903090908
3428320|3428320-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Sub-WrapPackages|1.2|darwin-2level|5.10.0|darwin|8.11.1|200903090944
3429036|3429036-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903090621
3429122|3429122-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200903091028
3429125|3429125-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.6.2|netbsd|4.0|200903091028
3429200|3429200-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|XML-Tiny|1.12|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200903091037
3430089|3430089-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090817
3430157|3430157-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903091224
3430161|3430161-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903091224
3430774|3430774-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903090923
3430799|3430799-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091326
3431136|3431136-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.50|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091507
3431433|3431433-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.21|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091553
3432109|3432109-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7001|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091715
3432266|3432266-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Hexdumper|2.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091737
3432780|3432780-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091743
3432782|3432782-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903091743
3432791|3432791-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903091744
3432792|3432792-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091744
3432823|3432823-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903091752
3432825|3432825-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903091752
3433115|3433115-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|WWW-Facebook-Go-SGF|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903091937
3433223|3433223-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091448
3433735|3433735-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903091554
3433824|3433824-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|darwin-2level|5.10.0|darwin|8.11.1|200903092103
3435889|3435889-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100012
3436233|3436233-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200903100102
3436234|3436234-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200903100102
3436244|3436244-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|Data-Hexdumper|2.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200903100107
3436248|3436248-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200903100107
3436251|3436251-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200903100107
3436264|3436264-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200903100111
3436378|3436378-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100127
3436660|3436660-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Hexdumper|2.01|darwin-2level|5.10.0|darwin|8.11.1|200903100300
3438231|3438231-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|File-Find-Rule-Permissions|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903100553
3438300|3438300-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Class-DBI-ClassGenerator|1.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903100603
3438753|3438753-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100206
3439120|3439120-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-CanBeA|1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903100249
3440035|3440035-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903100910
3442981|3442981-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903101451
3443504|3443504-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200903101557
3443517|3443517-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Number-Phone|1.7001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200903101600
3443590|3443590-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|1.12|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101721
3444113|3444113-b19f-3f77-b713-d32bba55d77f|fail|200903|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903101914
3444566|3444566-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-SMS|0.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200903102015
3444689|3444689-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903101529
3445958|3445958-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903102314
3447750|3447750-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110110
3448115|3448115-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110152
3448116|3448116-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110152
3448665|3448665-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-DoubleEncodedEntities|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903110407
3449044|3449044-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110055
3449473|3449473-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903110155
3449905|3449905-b19f-3f77-b713-d32bba55d77f|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110303
3450966|3450966-b19f-3f77-b713-d32bba55d77f|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110521
3451017|3451017-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110525
3451064|3451064-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903110530
3454103|3454103-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903111728
3454359|3454359-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903111825
3454728|3454728-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|File-Find-Rule-Permissions|2.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903111057
3455393|3455393-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Class-DBI-ClassGenerator|1.02|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903111319
3456798|3456798-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Sort-MultipleFields|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120344
3457511|3457511-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903120621
3457645|3457645-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903121351
3457736|3457736-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903120723
3458680|3458680-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Data-Transactional|1.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121023
3459045|3459045-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Memory|1.1001|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121113
3459049|3459049-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPU-Emulator-Z80|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903121113
3460507|3460507-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121340
3460510|3460510-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121341
3461344|3461344-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903121559
3462720|3462720-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903122020
3463819|3463819-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903130108
3463931|3463931-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903130248
3465138|3465138-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903130506
3465343|3465343-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903130506
3465694|3465694-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Number-Phone|1.7001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903130752
3465821|3465821-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903130753
3466396|3466396-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.50|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903131717
3466703|3466703-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903130953
3466799|3466799-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200903131129
3466849|3466849-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200903131138
3468132|3468132-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903131416
3469791|3469791-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.03|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903131232
3469863|3469863-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Number-Phone|1.7001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903131838
3470390|3470390-b19f-3f77-b713-d32bba55d77f|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903131832
3471591|3471591-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24.5-smp|200903132118
3471674|3471674-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200903132130
3471716|3471716-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.24.5-smp|200903132137
3471747|3471747-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903132143
3471944|3471944-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903131707
3472752|3472752-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903140007
3472893|3472893-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903140030
3473021|3473021-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903132326
3473195|3473195-b19f-3f77-b713-d32bba55d77f|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.18-14-ovz-686|200903140004
3473280|3473280-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903140119
3473457|3473457-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903140126
3474262|3474262-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903140457
3475587|3475587-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-64int|5.8.9|dragonfly|2.0.1-release|200903141057
3475598|3475598-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-dragonfly-64int|5.10.0|dragonfly|2.0.1-release|200903141059
3478862|3478862-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|1.12|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903142218
3479437|3479437-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903150100
3479784|3479784-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.50|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903150152
3479831|3479831-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903150155
3480135|3480135-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903150231
3480589|3480589-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200903150254
3480603|3480603-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200903150257
3480725|3480725-b19f-3f77-b713-d32bba55d77f|pass|200903|altblue@gmail.com ("Marius Feraru")|File-Find-Rule-Permissions|2.0|x86_64-linux-ld|5.11.0 patch 34814|linux|2.6.18-8.1.14.el5|200903150508
3484221|3484221-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny|1.12|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903150641
3484466|3484466-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7001|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151603
3484593|3484593-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151623
3485297|3485297-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903151937
3486175|3486175-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903152227
3486458|3486458-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152329
3486512|3486512-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903152339
3487569|3487569-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Bryar|3.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903160205
3488580|3488580-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|1.12|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160713
3488911|3488911-b19f-3f77-b713-d32bba55d77f|fail|200903|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160816
3489194|3489194-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-SMS|0.03|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903160913
3490224|3490224-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200903161107
3490226|3490226-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903161107
3490918|3490918-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903161442
3491374|3491374-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903161647
3491538|3491538-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903161711
3492140|3492140-b19f-3f77-b713-d32bba55d77f|pass|200903|davidp@preshweb.co.uk ("David Precious")|Devel-CheckOS|1.50|x86_64-linux-thread-multi|5.10.0|linux|2.6.25-arch|200903161551
3493752|3493752-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200903162119
3494921|3494921-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.6.2|freebsd|7.0-release|200903170108
3495035|3495035-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200903170142
3496132|3496132-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903170623
3497708|3497708-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171141
3498489|3498489-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171356
3498810|3498810-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200903171325
3498811|3498811-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200903171326
3499162|3499162-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171005
3499565|3499565-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171548
3500158|3500158-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Data-Transactional|1.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171644
3500365|3500365-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171701
3500366|3500366-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903171702
3500825|3500825-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.50|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171239
3501411|3501411-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171321
3501453|3501453-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200903171324
3502969|3502969-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903172207
3503401|3503401-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.5|i86pc-solaris-64int|5.8.9|solaris|2.11|200903172316
3504009|3504009-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903180121
3505486|3505486-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903180644
3505747|3505747-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Palm-SMS|0.03|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903180634
3505952|3505952-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903180809
3506577|3506577-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200903180948
3508025|3508025-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903180845
3508796|3508796-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903181554
3509047|3509047-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.03|i86pc-solaris-64int|5.8.9|solaris|2.11|200903181634
3509470|3509470-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-TreoPhoneCallDB|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903181802
3509667|3509667-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903181331
3510210|3510210-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903182051
3510213|3510213-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903182052
3510216|3510216-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903182052
3510219|3510219-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903182052
3510221|3510221-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.04|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903182053
3510266|3510266-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903182103
3510267|3510267-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903182103
3510270|3510270-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903182104
3510271|3510271-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903182104
3510272|3510272-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00001|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903182104
3510507|3510507-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Tie-STDOUT|1.04|amd64-freebsd|5.8.8|freebsd|7.0-release|200903182159
3510539|3510539-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00001|amd64-freebsd|5.8.8|freebsd|7.0-release|200903182159
3510719|3510719-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903181731
3510799|3510799-b19f-3f77-b713-d32bba55d77f|pass|200903|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.15.7|200903182137
3511122|3511122-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Tie-STDOUT|1.04|amd64-freebsd|5.8.9|freebsd|7.0-release|200903182307
3511126|3511126-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00001|amd64-freebsd|5.8.9|freebsd|7.0-release|200903182307
3511659|3511659-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Net-Random|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903190022
3512182|3512182-b19f-3f77-b713-d32bba55d77f|fail|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Tie-STDOUT|1.04|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903191101
3512192|3512192-b19f-3f77-b713-d32bba55d77f|unknown|200903|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191006
3512193|3512193-b19f-3f77-b713-d32bba55d77f|unknown|200903|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191006
3512194|3512194-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191006
3512204|3512204-b19f-3f77-b713-d32bba55d77f|fail|200903|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191010
3512211|3512211-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191014
3512212|3512212-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191015
3512220|3512220-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191016
3512223|3512223-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191017
3512235|3512235-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Hexdumper|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191024
3512236|3512236-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191025
3512238|3512238-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191026
3512240|3512240-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191026
3512241|3512241-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|File-Overwrite|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191027
3512243|3512243-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191027
3512244|3512244-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191027
3512249|3512249-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191029
3512252|3512252-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191030
3512254|3512254-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Palm-SMS|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191030
3512260|3512260-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191033
3512267|3512267-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191035
3512269|3512269-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191036
3512270|3512270-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191036
3512272|3512272-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191036
3512274|3512274-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191037
3512276|3512276-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191037
3512277|3512277-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191037
3512278|3512278-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191038
3512279|3512279-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191038
3512280|3512280-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191039
3512281|3512281-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191039
3512282|3512282-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|1.12|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903191039
3512723|3512723-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903190435
3512726|3512726-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903190436
3512730|3512730-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903190436
3512732|3512732-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903190437
3512745|3512745-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200903190441
3512756|3512756-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903190442
3512761|3512761-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903190443
3512763|3512763-b19f-3f77-b713-d32bba55d77f|fail|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903190443
3512765|3512765-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903190444
3512768|3512768-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903190445
3512770|3512770-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903190445
3512870|3512870-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.04|i686-linux|5.10.0|linux|2.6.24-16-generic|200903190118
3513067|3513067-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.04|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200903190214
3513168|3513168-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903190736
3513171|3513171-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903190737
3513172|3513172-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903190738
3513190|3513190-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903190741
3513319|3513319-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.04|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190313
3513627|3513627-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903190858
3513667|3513667-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903190903
3513705|3513705-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903190911
3513752|3513752-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903190918
3514131|3514131-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190513
3514222|3514222-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903190527
3514265|3514265-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903191031
3514284|3514284-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903191032
3514450|3514450-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903191050
3514603|3514603-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903191106
3514626|3514626-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903191112
3514633|3514633-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903191114
3514636|3514636-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903191114
3514642|3514642-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903191115
3514644|3514644-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903191115
3514646|3514646-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-STDOUT|1.0401|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903191115
3514703|3514703-b19f-3f77-b713-d32bba55d77f|fail|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903191026
3514760|3514760-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903191037
3514762|3514762-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903191037
3514825|3514825-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903191145
3514837|3514837-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903191147
3514919|3514919-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903191058
3514920|3514920-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903191058
3514926|3514926-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903191058
3514927|3514927-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903191058
3514928|3514928-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903191058
3514929|3514929-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903191059
3514932|3514932-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|IP35-irix-64int|5.8.8|irix|6.5|200903191159
3514941|3514941-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|IP35-irix-64int|5.8.8|irix|6.5|200903191200
3515451|3515451-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.04|i86pc-solaris-64int|5.10.0|solaris|2.11|200903191309
3515460|3515460-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.04|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191309
3515841|3515841-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.03|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903191348
3516228|3516228-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903191430
3516815|3516815-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Tie-STDOUT|1.0401|amd64-freebsd|5.8.8|freebsd|7.0-release|200903191542
3516820|3516820-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Tie-STDOUT|1.0401|amd64-freebsd|5.8.9|freebsd|7.0-release|200903191542
3517280|3517280-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903191041
3517288|3517288-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903191042
3517406|3517406-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|App-Rsnapshot|1.999_00001|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903191657
3517408|3517408-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Tie-STDOUT|1.04|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903191657
3517530|3517530-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00001|alpha-netbsd|5.10.0|netbsd|4.0.1|200903191606
3517545|3517545-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Number-Phone-UK-DetailedLocations|1.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200903191708
3517591|3517591-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.04|alpha-netbsd|5.10.0|netbsd|4.0.1|200903191613
3517857|3517857-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Net-Random|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903191747
3518618|3518618-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903191904
3518622|3518622-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903191905
3518626|3518626-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903191905
3518630|3518630-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903191905
3518902|3518902-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Tie-STDOUT|1.0401|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903200505
3519294|3519294-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903192213
3519476|3519476-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.0401|i86pc-solaris-64int|5.8.9|solaris|2.11|200903192252
3519930|3519930-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.0401|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903200737
3520270|3520270-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903200039
3520688|3520688-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903200149
3520693|3520693-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903200149
3520943|3520943-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200903200234
3521634|3521634-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200903200450
3521637|3521637-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200903200451
3521945|3521945-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200649
3522453|3522453-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903200831
3523302|3523302-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903201002
3523443|3523443-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903201125
3523482|3523482-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903201032
3523542|3523542-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903201048
3523565|3523565-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-STDOUT|1.0401|i86pc-solaris-64int|5.10.0|solaris|2.11|200903201150
3523570|3523570-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903201050
3523774|3523774-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200709
3524017|3524017-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Data-Compare|1.21|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903200644
3524561|3524561-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|1.12|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200852
3525084|3525084-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Bryar|3.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903200957
3525224|3525224-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00001|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903201411
3525228|3525228-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.04|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903201411
3525231|3525231-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Tie-STDOUT|1.0401|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200903201411
3525361|3525361-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|IP35-irix-64int|5.8.8|irix|6.5|200903201527
3525455|3525455-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903200934
3525648|3525648-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201059
3526141|3526141-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903201711
3526262|3526262-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|App-Rsnapshot|1.999_00001|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903201123
3526283|3526283-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Tie-STDOUT|1.04|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903201125
3526658|3526658-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|Tie-STDOUT|1.0401|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903201232
3527602|3527602-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Class-CanBeA|1.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903201955
3528147|3528147-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903201608
3528227|3528227-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903202116
3528282|3528282-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903202120
3528444|3528444-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903202141
3528491|3528491-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Games-Dice-Advanced|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903202153
3530152|3530152-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|XML-Tiny|1.12|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903210049
3531127|3531127-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200903210333
3531128|3531128-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|1.12|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200903210333
3532274|3532274-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.04|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903210706
3532966|3532966-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903210906
3533115|3533115-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903210929
3533218|3533218-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903210942
3533310|3533310-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903210954
3533360|3533360-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903210959
3533420|3533420-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903211005
3533527|3533527-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903211019
3533709|3533709-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211154
3533794|3533794-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sort-MultipleFields|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210609
3534113|3534113-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903211313
3534161|3534161-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210730
3534550|3534550-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|DBIx-Class-SingletonRows|0.11|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210856
3534829|3534829-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Transactional|1.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903210950
3534902|3534902-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Memory|1.1001|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211012
3534903|3534903-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPU-Emulator-Z80|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211012
3536683|3536683-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903212122
3537407|3537407-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903212336
3537410|3537410-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903212337
3537440|3537440-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903212340
3537553|3537553-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.5|i686-linux|5.8.9|linux|2.6.24-16-generic|200903211915
3537731|3537731-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903220057
3537940|3537940-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903220152
3538595|3538595-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|NestedMap|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903220542
3539726|3539726-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903220404
3540905|3540905-b19f-3f77-b713-d32bba55d77f|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Licence|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903221312
3541592|3541592-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903221019
3542439|3542439-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-TreoPhoneCallDB|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903221302
3543019|3543019-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Tie-STDOUT|1.0401|alpha-netbsd|5.10.0|netbsd|4.0.1|200903221846
3543663|3543663-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903231839
3543712|3543712-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903231841
3543725|3543725-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903231841
3543743|3543743-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903231841
3543767|3543767-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903231841
3543775|3543775-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903231842
3543917|3543917-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903231920
3543931|3543931-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903231919
3543940|3543940-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903231920
3543947|3543947-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903231920
3543950|3543950-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.01|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903231919
3544025|3544025-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903231845
3544026|3544026-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903231846
3544041|3544041-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903231846
3544052|3544052-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903231846
3544061|3544061-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903231846
3544390|3544390-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903231722
3544510|3544510-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903231856
3544518|3544518-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903231856
3544523|3544523-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903231856
3544536|3544536-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903231856
3544542|3544542-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903231856
3544566|3544566-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903231857
3544576|3544576-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903231857
3544582|3544582-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903231857
3544589|3544589-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903231857
3544595|3544595-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|App-Rsnapshot|1.999_00002|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903231858
3544694|3544694-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903231220
3544698|3544698-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903231220
3544836|3544836-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Sub-WrapPackages|1.2|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231902
3544999|3544999-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903231804
3545036|3545036-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Tie-STDOUT|1.0401|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903232010
3545236|3545236-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Net-Random|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231914
3545305|3545305-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903230850
3545318|3545318-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|IP35-irix-64int|5.8.8|irix|6.5|200903231445
3545341|3545341-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903231219
3545344|3545344-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903231219
3545356|3545356-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903231220
3545359|3545359-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903231219
3545396|3545396-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903231146
3545524|3545524-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231921
3545942|3545942-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903231146
3546005|3546005-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903231219
3546015|3546015-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|IP35-irix-64int|5.8.8|irix|6.5|200903231446
3546021|3546021-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903230850
3546188|3546188-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903231721
3546325|3546325-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Games-Dice-Advanced|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231957
3546579|3546579-b19f-3f77-b713-d32bba55d77f|pass|200903|joerg.meltzer@tngtech.com|Statistics-ChiSquare|0.5|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200903202041
3546789|3546789-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|XML-Tiny|2.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903231721
3546847|3546847-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903231959
3547067|3547067-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903232002
3547241|3547241-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903232010
3547300|3547300-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903231825
3547429|3547429-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903232015
3547445|3547445-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903231219
3547513|3547513-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903231619
3547604|3547604-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903232122
3547639|3547639-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|App-Rsnapshot|1.999_00002|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903232124
3547641|3547641-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903232124
3547644|3547644-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|XML-Tiny|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903232125
3547942|3547942-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200903232132
3547988|3547988-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903232133
3547996|3547996-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd|5.8.8|freebsd|7.0-release|200903230959
3548000|3548000-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903230951
3548134|3548134-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232038
3548140|3548140-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903232138
3548272|3548272-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903232044
3548571|3548571-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903230950
3548634|3548634-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd|5.8.9|freebsd|7.0-release|200903230959
3548675|3548675-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd|5.10.0|freebsd|7.0-release|200903230950
3548700|3548700-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903231709
3548747|3548747-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903230936
3549305|3549305-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903231843
3549316|3549316-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903231904
3549574|3549574-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903232309
3549583|3549583-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903232310
3549697|3549697-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903232326
3549789|3549789-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903232333
3549959|3549959-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903232350
3550179|3550179-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200903240027
3550185|3550185-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200903240027
3550663|3550663-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|App-Rsnapshot|1.999_00002|alpha-netbsd|5.10.0|netbsd|4.0.1|200903240013
3550666|3550666-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903240013
3551079|3551079-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903240155
3551318|3551318-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903240220
3551770|3551770-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903240140
3552004|3552004-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Tie-STDOUT|1.04|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903240157
3552056|3552056-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200903240301
3552082|3552082-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200903240304
3552096|3552096-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903240305
3552169|3552169-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-SerialCorrelation|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240220
3552224|3552224-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903240226
3552227|3552227-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903240227
3552235|3552235-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903240227
3552241|3552241-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903240228
3552246|3552246-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903240228
3552290|3552290-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200903240333
3552560|3552560-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903240412
3552584|3552584-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Longest|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240317
3552585|3552585-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Statistics-ChiSquare|0.5|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240318
3552589|3552589-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903241218
3552779|3552779-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|XML-Tiny|2.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.00|200903240557
3552945|3552945-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240036
3553106|3553106-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny|2.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903240507
3553294|3553294-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|NestedMap|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903240140
3553704|3553704-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240746
3554087|3554087-b19f-3f77-b713-d32bba55d77f|unknown|200903|stsc@refcnt.org ("Steven Schubiger")|Acme-Pony|1.1.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240834
3554135|3554135-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240839
3554188|3554188-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903240844
3554305|3554305-b19f-3f77-b713-d32bba55d77f|pass|200903|d@0x64.nl|XML-Tiny|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-vserver-amd64|200903240903
3554433|3554433-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200903240929
3554502|3554502-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200903240941
3555426|3555426-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903241009
3555528|3555528-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903241028
3555538|3555538-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903241029
3555544|3555544-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903241029
3555546|3555546-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903241029
3555674|3555674-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903240557
3555877|3555877-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903241923
3556013|3556013-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Tie-STDOUT|1.0401|amd64-freebsd|5.10.0|freebsd|7.0-release|200903241134
3556057|3556057-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Sub-WrapPackages|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200903241247
3556133|3556133-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|IP35-irix-64int|5.8.8|irix|6.5|200903241304
3556768|3556768-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Tie-STDOUT|1.0401|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903240520
3556968|3556968-b19f-3f77-b713-d32bba55d77f|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Licence|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241025
3557357|3557357-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903241616
3557359|3557359-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903241616
3557362|3557362-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903241616
3557364|3557364-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903241617
3557365|3557365-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903241617
3558301|3558301-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|XML-Tiny|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903241824
3558484|3558484-b19f-3f77-b713-d32bba55d77f|unknown|200903|dagolden@cpan.org (DAGOLDEN)|Acme-Pony|1.1.2|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241341
3558529|3558529-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Hash-Rank|1.0.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241346
3558594|3558594-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241353
3558628|3558628-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.8.9|freebsd|7.0-release|200903241856
3558630|3558630-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.8.8|freebsd|7.0-release|200903241856
3558927|3558927-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903241925
3558930|3558930-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903241926
3559662|3559662-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200903241939
3559855|3559855-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux|5.8.9|linux|2.6.24-16-generic|200903241557
3559860|3559860-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903241559
3559875|3559875-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903242101
3559935|3559935-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903242113
3559959|3559959-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903242120
3560034|3560034-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903242129
3560064|3560064-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903242134
3560100|3560100-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903242141
3560239|3560239-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903242158
3560610|3560610-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903241757
3560630|3560630-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.02|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903242303
3560710|3560710-b19f-3f77-b713-d32bba55d77f|fail|200903|srezic@cpan.org|App-Rsnapshot|1.999_00002|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903242257
3560711|3560711-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.0|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903242257
3561062|3561062-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Class-CanBeA|1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200903250014
3561086|3561086-b19f-3f77-b713-d32bba55d77f|pass|200903|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|XML-Tiny|2.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200903250817
3561365|3561365-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903250020
3561367|3561367-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903250021
3561370|3561370-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903250021
3561371|3561371-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903250022
3561374|3561374-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903250022
3562303|3562303-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7001|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250325
3562318|3562318-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250329
3562737|3562737-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903250551
3563098|3563098-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200903250709
3563141|3563141-b19f-3f77-b713-d32bba55d77f|pass|200903|jeff@zeroclue.com|XML-Tiny|2.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200903250057
3563825|3563825-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny|2.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903251621
3564052|3564052-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903250958
3564100|3564100-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.02|i86pc-solaris-64int|5.8.9|solaris|2.11|200903251008
3564228|3564228-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903250928
3564250|3564250-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250530
3564369|3564369-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903250546
3564388|3564388-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny|2.02|i86pc-solaris-64int|5.10.0|solaris|2.11|200903251050
3564403|3564403-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903251051
3564847|3564847-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903251141
3564861|3564861-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903251142
3564868|3564868-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903251143
3564872|3564872-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903251143
3564984|3564984-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|IP35-irix-64int|5.8.8|irix|6.5|200903251300
3565581|3565581-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Acme-Scurvy-Whoreson-BilgeRat|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903251518
3565643|3565643-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903250926
3565703|3565703-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903251535
3565957|3565957-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200903251638
3566933|3566933-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200903251423
3567226|3567226-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903252029
3567665|3567665-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903252155
3567755|3567755-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200903252209
3567789|3567789-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903252221
3567935|3567935-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903252301
3568012|3568012-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903251813
3568671|3568671-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903260159
3568750|3568750-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200903260210
3568971|3568971-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|Tie-STDOUT|1.0401|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903260328
3569002|3569002-b19f-3f77-b713-d32bba55d77f|na|200903|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903260131
3569364|3569364-b19f-3f77-b713-d32bba55d77f|pass|200903|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200903260232
3569614|3569614-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Statistics-SerialCorrelation|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903260408
3569673|3569673-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|XML-Tiny|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903260543
3569676|3569676-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|XML-Tiny|2.02|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200903260543
3569685|3569685-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903260448
3569832|3569832-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903260602
3569889|3569889-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903260619
3570331|3570331-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903260921
3570936|3570936-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903261306
3571424|3571424-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903261519
3571513|3571513-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903261537
3571722|3571722-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903261630
3572107|3572107-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny|2.02|alpha-netbsd|5.10.0|netbsd|4.0.1|200903261745
3572189|3572189-b19f-3f77-b713-d32bba55d77f|fail|200903|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200903261438
3572382|3572382-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903262109
3572539|3572539-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903262207
3572541|3572541-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903262208
3572542|3572542-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903262208
3572544|3572544-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903262208
3572566|3572566-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903262207
3573086|3573086-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903270223
3573087|3573087-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200903270223
3573090|3573090-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903270224
3573091|3573091-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903270224
3573092|3573092-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903270225
3573233|3573233-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903270437
3573263|3573263-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|App-Rsnapshot|1.999_00002|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270349
3573267|3573267-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903270450
3573273|3573273-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Tie-STDOUT|1.0401|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270354
3573289|3573289-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny|2.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270359
3573302|3573302-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny|2.01|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270404
3573322|3573322-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny|2.02|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903270408
3573406|3573406-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903270429
3573410|3573410-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903270430
3573412|3573412-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903270431
3573416|3573416-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903270432
3573647|3573647-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903270713
3573648|3573648-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903270714
3573650|3573650-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903270714
3573653|3573653-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903270715
3573661|3573661-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-ProjectGutenberg|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903270714
3574074|3574074-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903271006
3574086|3574086-b19f-3f77-b713-d32bba55d77f|pass|200903|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200903271010
3574271|3574271-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Palm-ProjectGutenberg|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903271109
3574273|3574273-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny-DOM|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903271109
3574386|3574386-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Palm-ProjectGutenberg|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903271139
3574389|3574389-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny-DOM|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903271139
3574412|3574412-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Palm-ProjectGutenberg|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903271144
3574522|3574522-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903271207
3574597|3574597-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-ProjectGutenberg|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903271236
3574616|3574616-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903271242
3574721|3574721-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200903271155
3574752|3574752-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny-DOM|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200903271248
3574754|3574754-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.10.0|freebsd|7.0-release|200903271248
3574948|3574948-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Palm-ProjectGutenberg|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903271359
3574992|3574992-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200903271407
3575086|3575086-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903272207
3575087|3575087-b19f-3f77-b713-d32bba55d77f|pass|200903|imacat@mail.imacat.idv.tw|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200903272207
3575127|3575127-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903271442
3575128|3575128-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200903271442
3575131|3575131-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903271443
3575139|3575139-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200903271443
3575150|3575150-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903271446
3575152|3575152-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903271446
3575155|3575155-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200903271446
3575157|3575157-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200903271446
3575165|3575165-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|IP35-irix-64int|5.8.8|irix|6.5|200903271548
3575178|3575178-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|IP35-irix-64int|5.8.8|irix|6.5|200903271549
3575183|3575183-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903270950
3575190|3575190-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200903270951
3575386|3575386-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903271648
3575715|3575715-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903271834
3576094|3576094-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200903272138
3576535|3576535-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903272253
3576573|3576573-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903272304
3576611|3576611-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903272313
3576677|3576677-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272228
3576682|3576682-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272229
3576684|3576684-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272230
3576687|3576687-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272230
3576690|3576690-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272231
3576692|3576692-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272231
3576693|3576693-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272232
3576695|3576695-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272232
3576696|3576696-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200903272232
3576697|3576697-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272233
3576699|3576699-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272233
3576703|3576703-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200903272234
3577002|3577002-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280002
3577004|3577004-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280003
3577006|3577006-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280003
3577008|3577008-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280004
3577009|3577009-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280004
3577010|3577010-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200903280004
3577308|3577308-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903280207
3577393|3577393-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903280229
3577450|3577450-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903280242
3577573|3577573-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903280324
3577575|3577575-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903280324
3577583|3577583-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903280328
3577608|3577608-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903280342
3577869|3577869-b19f-3f77-b713-d32bba55d77f|pass|200903|stro@cpan.org|XML-Tiny|2.02|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200903280542
3579366|3579366-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280828
3579374|3579374-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280829
3579377|3579377-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280829
3579378|3579378-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280829
3579379|3579379-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280830
3579381|3579381-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200903280830
3579993|3579993-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200903281104
3580618|3580618-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903281310
3580816|3580816-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903281344
3581058|3581058-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903281428
3581125|3581125-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200903281437
3581301|3581301-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903281506
3581327|3581327-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200903281511
3581513|3581513-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200903281541
3581646|3581646-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281617
3581806|3581806-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903281709
3581807|3581807-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903281709
3581810|3581810-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903281709
3581811|3581811-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903281710
3581937|3581937-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281730
3581939|3581939-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281730
3581947|3581947-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903281733
3582122|3582122-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|Palm-ProjectGutenberg|1.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903281219
3582142|3582142-b19f-3f77-b713-d32bba55d77f|pass|200903|mw487.yahoo.com@gmail.com|XML-Tiny-DOM|1.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200903281228
3582218|3582218-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903281847
3582251|3582251-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200903281900
3582472|3582472-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200903281951
3583310|3583310-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200903282254
3584044|3584044-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290210
3584046|3584046-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290210
3584053|3584053-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290212
3584054|3584054-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290212
3584056|3584056-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290213
3584057|3584057-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290213
3584059|3584059-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290213
3584060|3584060-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290213
3584063|3584063-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290214
3584065|3584065-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290214
3584067|3584067-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200903290215
3584068|3584068-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200903290215
3584223|3584223-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200903290346
3584453|3584453-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|Palm-ProjectGutenberg|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290302
3584480|3584480-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903290511
3584613|3584613-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny|2.02|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290354
3584614|3584614-b19f-3f77-b713-d32bba55d77f|pass|200903|wiml@hhhh.org ("Wim Lewis")|XML-Tiny-DOM|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200903290354
3584921|3584921-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903290702
3584925|3584925-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200903290703
3585039|3585039-b19f-3f77-b713-d32bba55d77f|na|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903290725
3585613|3585613-b19f-3f77-b713-d32bba55d77f|pass|200903|jrockway@cpan.org|Devel-CheckOS|1.50|x86_64-linux|5.10.0|linux|2.6.22-3-amd64|200903290223
3586133|3586133-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|Palm-ProjectGutenberg|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903290841
3586140|3586140-b19f-3f77-b713-d32bba55d77f|pass|200903|david@cantrell.org.uk|XML-Tiny-DOM|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200903290842
3586405|3586405-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903291116
3586415|3586415-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200903291116
3586479|3586479-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903291131
3586482|3586482-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903291132
3586589|3586589-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903291141
3586590|3586590-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903291142
3586596|3586596-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903291145
3586763|3586763-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903291146
3586908|3586908-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903291305
3587082|3587082-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200903291255
3587086|3587086-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200903291256
3587090|3587090-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200903291257
3587096|3587096-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200903291258
3587117|3587117-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200903291405
3587202|3587202-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200903291437
3587445|3587445-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200903291553
3587657|3587657-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903291707
3587659|3587659-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200903291708
3588290|3588290-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903291943
3588299|3588299-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200903291947
3589424|3589424-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292305
3589430|3589430-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292306
3589434|3589434-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292306
3589438|3589438-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292307
3589441|3589441-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.21.5-smp|200903292307
3589667|3589667-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300020
3590005|3590005-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300137
3590013|3590013-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300138
3590016|3590016-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300138
3590019|3590019-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300139
3590022|3590022-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300139
3590024|3590024-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200903300139
3590214|3590214-b19f-3f77-b713-d32bba55d77f|pass|200903|dpavlin@mail.carnet.hr ((Dobrica Pavlinusic))|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200903291243
3590330|3590330-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|App-Rsnapshot|1.999_00002|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300240
3590346|3590346-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300243
3590358|3590358-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.0|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300243
3590362|3590362-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300244
3590364|3590364-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300244
3590365|3590365-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|darwin-thread-multi-64int-2level|5.10.0 patch 35117|darwin|8.11.0|200903300245
3591761|3591761-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200903301050
3592268|3592268-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903301410
3592316|3592316-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903301425
3592550|3592550-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903301631
3592645|3592645-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200903301725
3593115|3593115-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.10.0|freebsd|7.0-release|200903301938
3593460|3593460-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200903302108
3594715|3594715-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903302358
3594734|3594734-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200903310101
3594735|3594735-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200903310101
3594737|3594737-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200903310101
3594739|3594739-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200903310102
3594740|3594740-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903310102
3594930|3594930-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310034
3594932|3594932-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310035
3594935|3594935-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310035
3594939|3594939-b19f-3f77-b713-d32bba55d77f|pass|200903|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200903310035
3596610|3596610-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200903310949
3596674|3596674-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-ParseDistribution|1.0|amd64-freebsd|5.8.8|freebsd|7.0-release|200903311022
3596921|3596921-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|CPAN-ParseDistribution|1.0|amd64-freebsd|5.8.9|freebsd|7.0-release|200903311140
3597111|3597111-b19f-3f77-b713-d32bba55d77f|pass|200903|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.50|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200903311237
3597535|3597535-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Longest|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200903311348
3597540|3597540-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|Statistics-ChiSquare|0.5|i86pc-solaris-64int|5.8.9|solaris|2.11|200903311348
3598037|3598037-b19f-3f77-b713-d32bba55d77f|pass|200903|JOST@cpan.org ("Josts Smokehouse")|NestedMap|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200903311601
3598426|3598426-b19f-3f77-b713-d32bba55d77f|pass|200903|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200903311745
3598489|3598489-b19f-3f77-b713-d32bba55d77f|fail|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200903311758
3599000|3599000-b19f-3f77-b713-d32bba55d77f|pass|200903|vpit@cpan.org|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200903311950
3599005|3599005-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200903311949
3599123|3599123-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903312016
3599215|3599215-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903312027
3599216|3599216-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200903312027
3599296|3599296-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903312058
3599357|3599357-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903312122
3599358|3599358-b19f-3f77-b713-d32bba55d77f|pass|200903|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200903312122
3600007|3600007-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904010109
3600092|3600092-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904010131
3600096|3600096-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904010131
3600318|3600318-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904010256
3600378|3600378-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904010307
3600381|3600381-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904010308
3600446|3600446-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904010223
3600447|3600447-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904010223
3600452|3600452-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904010224
3600458|3600458-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904010224
3600460|3600460-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904010225
3600555|3600555-b19f-3f77-b713-d32bba55d77f|unknown|200904|JOST@cpan.org ("Josts Smokehouse")|Acme-Licence|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200904010340
3601251|3601251-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904010645
3601308|3601308-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904010700
3601310|3601310-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904010701
3601360|3601360-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904010719
3601436|3601436-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904010735
3601437|3601437-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904010735
3601744|3601744-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904010901
3602008|3602008-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904010949
3602019|3602019-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904010952
3602020|3602020-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904010952
3603155|3603155-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.0|amd64-freebsd|5.10.0|freebsd|7.0-release|200904011512
3603860|3603860-b19f-3f77-b713-d32bba55d77f|unknown|200904|JOST@cpan.org ("Josts Smokehouse")|Acme-Pony|1.1.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200904011903
3603920|3603920-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Tie-Hash-Rank|1.0.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904011913
3604078|3604078-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Tie-Scalar-Decay|1.1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904012003
3604311|3604311-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904012112
3604363|3604363-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904012126
3604365|3604365-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904012126
3605518|3605518-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020140
3605817|3605817-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904020337
3605909|3605909-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020310
3605911|3605911-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020310
3605912|3605912-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020311
3605913|3605913-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904020311
3605954|3605954-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020325
3605956|3605956-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020325
3605959|3605959-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020325
3605961|3605961-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200904020326
3606229|3606229-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904020534
3606611|3606611-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904020700
3606847|3606847-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904020743
3607633|3607633-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904021027
3607793|3607793-b19f-3f77-b713-d32bba55d77f|pass|200904|robertl@apnic.net ("Robert Loomans")|Devel-CheckOS|1.50|darwin-2level|5.8.9|darwin|9.6.0|200904021324
3608076|3608076-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904021138
3608085|3608085-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904021139
3608456|3608456-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021148
3608783|3608783-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021255
3608913|3608913-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021322
3608915|3608915-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021322
3608917|3608917-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021323
3608920|3608920-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021323
3609426|3609426-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021453
3609427|3609427-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021453
3609430|3609430-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021454
3609434|3609434-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904021455
3609715|3609715-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904021648
3609947|3609947-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904021720
3610573|3610573-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904021909
3610654|3610654-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904021824
3610818|3610818-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904021855
3611181|3611181-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904022028
3611182|3611182-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904022028
3611184|3611184-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904022028
3611311|3611311-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904022227
3611855|3611855-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904030024
3612013|3612013-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904030058
3612224|3612224-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904030145
3612304|3612304-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030106
3612451|3612451-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904030237
3612586|3612586-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030203
3612589|3612589-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030204
3612594|3612594-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030204
3612599|3612599-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904030204
3612661|3612661-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.1-release|200904030220
3612953|3612953-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.5|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904030345
3614296|3614296-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031032
3615014|3615014-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031219
3615015|3615015-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031218
3615017|3615017-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031219
3615019|3615019-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031219
3615594|3615594-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904031454
3615737|3615737-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031416
3615882|3615882-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904031539
3615941|3615941-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904031548
3615943|3615943-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904031548
3616110|3616110-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200904031517
3616162|3616162-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031523
3616164|3616164-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031523
3616166|3616166-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031524
3616172|3616172-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904031524
3617528|3617528-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904032207
3617530|3617530-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904032208
3618032|3618032-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904040010
3618034|3618034-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904040011
3618080|3618080-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904032301
3618277|3618277-b19f-3f77-b713-d32bba55d77f|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904040114
3618566|3618566-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040114
3618569|3618569-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.01|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040114
3618573|3618573-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040115
3618574|3618574-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny-DOM|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904040115
3619170|3619170-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904040529
3619818|3619818-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.0|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904041027
3620321|3620321-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904041102
3620694|3620694-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.0|i86pc-solaris-64int|5.10.0|solaris|2.11|200904041222
3620861|3620861-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904041247
3620865|3620865-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904041247
3620869|3620869-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904041248
3620872|3620872-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904041248
3620876|3620876-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-ParseDistribution|1.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904041249
3621107|3621107-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.0|i86pc-solaris-64int|5.8.9|solaris|2.11|200904041323
3621125|3621125-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904041324
3621175|3621175-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904041231
3621703|3621703-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904041354
3621706|3621706-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904041354
3621707|3621707-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904041355
3621740|3621740-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|IP35-irix-64int|5.8.8|irix|6.5|200904041500
3621743|3621743-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904041401
3622234|3622234-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904041256
3622465|3622465-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-ParseDistribution|1.0|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904041634
3622917|3622917-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200904041534
3622955|3622955-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.0|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904041037
3622967|3622967-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904041740
3623373|3623373-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904041825
3623390|3623390-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|CPAN-ParseDistribution|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904050025
3623642|3623642-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904041853
3624010|3624010-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904041918
3624201|3624201-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904041947
3624209|3624209-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904041948
3624211|3624211-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904041949
3624218|3624218-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904041950
3624520|3624520-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904042025
3624896|3624896-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904042142
3625954|3625954-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904050300
3626144|3626144-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-ParseDistribution|1.0|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904050203
3626151|3626151-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-ParseDistribution|1.1|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904050206
3626411|3626411-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904050529
3626460|3626460-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904050443
3626467|3626467-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904050545
3626468|3626468-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904050446
3626985|3626985-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904050812
3627105|3627105-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200904050646
3627107|3627107-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200904050646
3627237|3627237-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904050906
3627363|3627363-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200904050733
3627619|3627619-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904051702
3627914|3627914-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904051201
3628315|3628315-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904051221
3628483|3628483-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904050713
3628484|3628484-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051247
3628488|3628488-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904050715
3628489|3628489-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051248
3628529|3628529-b19f-3f77-b713-d32bba55d77f|pass|200904|gbnewby@pglaf.org|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200904041432
3629249|3629249-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904051436
3629350|3629350-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.11.0|darwin|8.11.0|200904051451
3629363|3629363-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904051554
3629655|3629655-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904051007
3629950|3629950-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904051636
3629968|3629968-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904051104
3630550|3630550-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904051940
3630585|3630585-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904051943
3630586|3630586-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904051943
3630802|3630802-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200904052110
3630881|3630881-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-ParseDistribution|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904052136
3630957|3630957-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904052157
3630962|3630962-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904052200
3630964|3630964-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904052201
3631667|3631667-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904060130
3631839|3631839-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060002
3631841|3631841-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060003
3631872|3631872-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904060012
3631909|3631909-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904060019
3632095|3632095-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200904060047
3632405|3632405-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060149
3632410|3632410-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060150
3632981|3632981-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060348
3633178|3633178-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904060532
3633188|3633188-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904060534
3633189|3633189-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904060535
3633340|3633340-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904060524
3633672|3633672-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200904060656
3633726|3633726-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904060815
3633731|3633731-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904060817
3633915|3633915-b19f-3f77-b713-d32bba55d77f|fail|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-ParseDistribution|1.1|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904060702
3634114|3634114-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904060955
3634376|3634376-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904060949
3634380|3634380-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904060948
3635106|3635106-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.0|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904061418
3635115|3635115-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904061419
3635202|3635202-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904061240
3635443|3635443-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200904061316
3635458|3635458-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200904061318
3635492|3635492-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904061420
3635562|3635562-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904061337
3636897|3636897-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200904061911
3637726|3637726-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904062127
3637732|3637732-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904062128
3638024|3638024-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904062301
3638137|3638137-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904062316
3638390|3638390-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904062331
3638592|3638592-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904062356
3639113|3639113-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904070103
3639258|3639258-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904070125
3639671|3639671-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904070144
3639750|3639750-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904070253
3639839|3639839-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904070307
3639841|3639841-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904070308
3639874|3639874-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904070314
3639943|3639943-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904070330
3640031|3640031-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904070350
3640428|3640428-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904070543
3640458|3640458-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904070559
3640599|3640599-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904070646
3640896|3640896-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904070835
3641616|3641616-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904070943
3641619|3641619-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904070943
3642009|3642009-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904071147
3642489|3642489-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904071249
3642682|3642682-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904071314
3642897|3642897-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904071341
3643160|3643160-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904071425
3643257|3643257-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904071440
3643326|3643326-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071350
3643334|3643334-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071351
3643337|3643337-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904071452
3643421|3643421-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904071505
3643446|3643446-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904071410
3644809|3644809-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904072002
3644998|3644998-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904071930
3645002|3645002-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904071931
3645140|3645140-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200904071949
3645311|3645311-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904072005
3645341|3645341-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200904072008
3645865|3645865-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|XML-Tiny|2.02|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904072111
3646314|3646314-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904072225
3647537|3647537-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.0|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080155
3647539|3647539-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080156
3649102|3649102-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200904080645
3649671|3649671-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904080929
3650941|3650941-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081220
3651243|3651243-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|IP35-irix-64int|5.8.8|irix|6.5|200904081359
3651762|3651762-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904081425
3652871|3652871-b19f-3f77-b713-d32bba55d77f|pass|200904|dwheeler@cpan.org|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.22-14-server|200904080954
3652872|3652872-b19f-3f77-b713-d32bba55d77f|pass|200904|dwheeler@cpan.org|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.22-14-server|200904080943
3653457|3653457-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200904081927
3654298|3654298-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.50|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904082250
3655288|3655288-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904082327
3656098|3656098-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904090224
3656214|3656214-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904090249
3656269|3656269-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904090258
3656711|3656711-b19f-3f77-b713-d32bba55d77f|pass|200904|dwheeler@cpan.org|Tie-STDOUT|1.0401|darwin-2level|5.10.0|darwin|9.4.0|200904090220
3657442|3657442-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904090703
3657444|3657444-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904090703
3657898|3657898-b19f-3f77-b713-d32bba55d77f|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904090900
3659046|3659046-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-ParseDistribution|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904090625
3659207|3659207-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-64int-ld|5.11.0|linux|2.6.16.38|200904091315
3659521|3659521-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@consol.de|CPAN-ParseDistribution|1.1|i86pc-solaris|5.8.9|solaris|2.11|200904091411
3660936|3660936-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904091856
3660950|3660950-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904091859
3660953|3660953-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904091859
3661190|3661190-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904091951
3661194|3661194-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904091953
3661200|3661200-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-DoubleEncodedEntities|1.0|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904091955
3661720|3661720-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|darwin-64int-2level|5.11.0|darwin|8.11.0|200904092115
3663059|3663059-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904100252
3663113|3663113-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904100254
3663130|3663130-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904100257
3663135|3663135-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904100259
3665282|3665282-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904101142
3665462|3665462-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904101316
3665463|3665463-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904101317
3666408|3666408-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904101647
3666412|3666412-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904101647
3666418|3666418-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904101648
3666419|3666419-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904101648
3666422|3666422-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Palm-Treo680MessagesDB|1.01|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904101649
3666526|3666526-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904101716
3666529|3666529-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904101716
3666530|3666530-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904101716
3666532|3666532-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904101716
3666533|3666533-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|File-Overwrite|1.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904101717
3666693|3666693-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904101757
3667070|3667070-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904101935
3667265|3667265-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904102034
3667809|3667809-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904102136
3667850|3667850-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904102241
3667997|3667997-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904102211
3668285|3668285-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904102302
3668290|3668290-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904102303
3668303|3668303-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904102305
3668307|3668307-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904102307
3668313|3668313-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904102309
3668332|3668332-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904102314
3668333|3668333-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904102314
3668336|3668336-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904102314
3668341|3668341-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904102315
3668344|3668344-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904102315
3668637|3668637-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904110025
3669587|3669587-b19f-3f77-b713-d32bba55d77f|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904110524
3669697|3669697-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904110546
3669701|3669701-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904110547
3669983|3669983-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|XML-DoubleEncodedEntities|1.0|i86pc-solaris|5.8.9|solaris|2.11|200904110110
3670253|3670253-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904110808
3670344|3670344-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904110838
3670581|3670581-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904110950
3670786|3670786-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|File-Overwrite|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904111703
3670787|3670787-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904111705
3670972|3670972-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904111148
3671812|3671812-b19f-3f77-b713-d32bba55d77f|na|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904111457
3671841|3671841-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|CPAN-ParseDistribution|1.1|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.00|200904110604
3671921|3671921-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904111418
3671933|3671933-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904111420
3671958|3671958-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904111422
3671966|3671966-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904111422
3671968|3671968-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904111423
3671986|3671986-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904111425
3671987|3671987-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904111425
3671989|3671989-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904111425
3672303|3672303-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904111514
3673158|3673158-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904111849
3673322|3673322-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904111940
3673327|3673327-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904111941
3673330|3673330-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904111943
3673341|3673341-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904111944
3673347|3673347-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904111945
3673462|3673462-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200904111759
3673524|3673524-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|alpha-netbsd|5.10.0|netbsd|4.0.1|200904111808
3673976|3673976-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904112031
3674255|3674255-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904112228
3674301|3674301-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904112136
3674302|3674302-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904112236
3674568|3674568-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904112239
3674592|3674592-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904112246
3674685|3674685-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904120011
3674725|3674725-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904120026
3675380|3675380-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904120326
3675877|3675877-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904120543
3675939|3675939-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904120451
3676520|3676520-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904120718
3676538|3676538-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904120721
3676555|3676555-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904120724
3676567|3676567-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904120727
3676770|3676770-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|File-Overwrite|1.1|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904121012
3676811|3676811-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Palm-Treo680MessagesDB|1.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904121020
3677176|3677176-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904120949
3677215|3677215-b19f-3f77-b713-d32bba55d77f|fail|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904121654
3677558|3677558-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904121214
3677582|3677582-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904121218
3677585|3677585-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.0|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904121218
3677677|3677677-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904120533
3677679|3677679-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|File-Overwrite|1.1|IP35-irix-64int|5.8.8|irix|6.5|200904121233
3677690|3677690-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904121136
3677694|3677694-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904121136
3677705|3677705-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904121138
3677715|3677715-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|IP35-irix-64int|5.8.8|irix|6.5|200904121239
3677718|3677718-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904121140
3677760|3677760-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Palm-Treo680MessagesDB|1.01|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904120544
3678067|3678067-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-ParseDistribution|1.1|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904121309
3678342|3678342-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Data-Hexdumper|2.01|i86pc-solaris|5.8.9|solaris|2.11|200904111029
3678549|3678549-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|File-Overwrite|1.1|i86pc-solaris|5.8.9|solaris|2.11|200904111029
3679336|3679336-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904121852
3679622|3679622-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200904121834
3679791|3679791-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904122029
3679848|3679848-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.1|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904122207
3679985|3679985-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904122256
3680058|3680058-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|IP35-irix-64int|5.8.8|irix|6.5|200904122346
3680213|3680213-b19f-3f77-b713-d32bba55d77f|fail|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-FindDependencies|2.1|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904121332
3680401|3680401-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904130004
3680421|3680421-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|File-Overwrite|1.1|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904130014
3680428|3680428-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|Palm-Treo680MessagesDB|1.01|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904130020
3680687|3680687-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|File-Overwrite|1.1|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904130235
3680698|3680698-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Data-Hexdumper|2.01|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904130243
3680714|3680714-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Palm-Treo680MessagesDB|1.01|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904130252
3681040|3681040-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|XML-DoubleEncodedEntities|1.0|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904130612
3681236|3681236-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904131004
3681861|3681861-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904131503
3682050|3682050-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|XML-Tiny|2.02|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904130132
3682126|3682126-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904131554
3682211|3682211-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.1|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904121400
3682515|3682515-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200904131742
3682604|3682604-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200904131757
3682605|3682605-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.01|i86pc-solaris-64int|5.10.0|solaris|2.11|200904131757
3682785|3682785-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904131854
3682970|3682970-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904131945
3683418|3683418-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132058
3683420|3683420-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132059
3683424|3683424-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132059
3683427|3683427-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904132100
3683680|3683680-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904132306
3683773|3683773-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|File-Overwrite|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200904132322
3683778|3683778-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Palm-Treo680MessagesDB|1.01|i86pc-solaris-64int|5.8.9|solaris|2.11|200904132322
3684604|3684604-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.1|cygwin-thread-multi-64int|0|cygwin|1.5.25(0.15642)|200904140025
3685097|3685097-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904140317
3685119|3685119-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140319
3685120|3685120-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140319
3685123|3685123-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140320
3685129|3685129-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904140321
3685611|3685611-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904140556
3685710|3685710-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904140738
3686714|3686714-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904141231
3687107|3687107-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904141257
3687255|3687255-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|File-Overwrite|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200904141439
3687289|3687289-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Palm-Treo680MessagesDB|1.01|amd64-freebsd|5.8.8|freebsd|7.0-release|200904141439
3687345|3687345-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|File-Overwrite|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200904141439
3687369|3687369-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Palm-Treo680MessagesDB|1.01|amd64-freebsd|5.8.9|freebsd|7.0-release|200904141439
3687408|3687408-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200904141441
3687414|3687414-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200904141441
3687598|3687598-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904141418
3688168|3688168-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904141611
3689000|3689000-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904142030
3689111|3689111-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904142102
3689380|3689380-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904142158
3689410|3689410-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904142215
3689414|3689414-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904142216
3689416|3689416-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904142216
3689418|3689418-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904142216
3689420|3689420-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.51|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904142217
3689445|3689445-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904142121
3689581|3689581-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|CPAN-FindDependencies|2.1|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904142204
3689645|3689645-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904142219
3690140|3690140-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904150111
3690145|3690145-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904150112
3690149|3690149-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904150113
3690156|3690156-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904150114
3690164|3690164-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904150115
3690177|3690177-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904150111
3690235|3690235-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.51|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904150832
3690479|3690479-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150130
3690480|3690480-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150131
3690482|3690482-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150131
3690486|3690486-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150132
3690766|3690766-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904150349
3690836|3690836-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.2|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200904150405
3690863|3690863-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-Scalar-Decay|1.1.1|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200904150412
3690870|3690870-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Tie-Scalar-Decay|1.1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904150413
3691104|3691104-b19f-3f77-b713-d32bba55d77f|fail|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.2|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904151219
3691281|3691281-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904150506
3691282|3691282-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904150506
3691289|3691289-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904150507
3691292|3691292-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904150508
3691297|3691297-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904150508
3691669|3691669-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904150658
3691680|3691680-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904150701
3691685|3691685-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904150704
3691690|3691690-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904150706
3691796|3691796-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.16.38|200904150736
3691976|3691976-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904150938
3692050|3692050-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904150954
3692064|3692064-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.51|amd64-freebsd|5.8.8|freebsd|7.0-release|200904150955
3692160|3692160-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904151026
3692177|3692177-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.51|amd64-freebsd|5.8.9|freebsd|7.0-release|200904150956
3692215|3692215-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904151038
3692304|3692304-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904151003
3692360|3692360-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904151117
3692395|3692395-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.2|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904151124
3692403|3692403-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904151125
3692406|3692406-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.51|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904151126
3692451|3692451-b19f-3f77-b713-d32bba55d77f|fail|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904151736
3692454|3692454-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.51|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904151736
3692469|3692469-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.2|amd64-freebsd|5.8.8|freebsd|7.0-release|200904151136
3692582|3692582-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904151159
3692610|3692610-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904151102
3692612|3692612-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904151102
3692624|3692624-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904151103
3692643|3692643-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.2|amd64-freebsd|5.8.9|freebsd|7.0-release|200904151200
3692688|3692688-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904151209
3692721|3692721-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904151214
3692765|3692765-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904151219
3692814|3692814-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904151230
3693164|3693164-b19f-3f77-b713-d32bba55d77f|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.51|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904151423
3693322|3693322-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904151252
3693326|3693326-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904151252
3693331|3693331-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904151252
3693332|3693332-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904151252
3693348|3693348-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151253
3693370|3693370-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904151355
3693374|3693374-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|IP35-irix-64int|5.8.8|irix|6.5|200904151357
3693389|3693389-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904151259
3693395|3693395-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|IP35-irix-64int|5.8.8|irix|6.5|200904151359
3693548|3693548-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904151416
3693685|3693685-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904151438
3693711|3693711-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckOS|1.51|i86pc-solaris|5.8.9|solaris|2.11|200904150933
3693736|3693736-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904151446
3693782|3693782-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904151359
3693785|3693785-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904151359
3693788|3693788-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904151400
3693827|3693827-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904151506
3693832|3693832-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904151507
3693866|3693866-b19f-3f77-b713-d32bba55d77f|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.51|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904150913
3693957|3693957-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.50|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200904151415
3694015|3694015-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|alpha-netbsd|5.10.0|netbsd|4.0.1|200904151340
3694242|3694242-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|alpha-netbsd|5.10.0|netbsd|4.0.1|200904151425
3694346|3694346-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200904151639
3694355|3694355-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.2|i86pc-solaris-64int|5.8.9|solaris|2.11|200904151640
3694378|3694378-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.51|i86pc-solaris-64int|5.10.0|solaris|2.11|200904151642
3694404|3694404-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.51|i86pc-solaris-64int|5.8.9|solaris|2.11|200904151644
3694762|3694762-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.2|i86pc-solaris-64int|5.10.0|solaris|2.11|200904151733
3694843|3694843-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904151746
3695011|3695011-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151716
3695012|3695012-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151717
3695015|3695015-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151718
3695019|3695019-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904151719
3695030|3695030-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904151821
3695208|3695208-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|i686-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200904151752
3695260|3695260-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.2|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904151157
3695317|3695317-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.51|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904151204
3695533|3695533-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904151943
3695611|3695611-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904152002
3695614|3695614-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904152003
3695769|3695769-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904152033
3695776|3695776-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904152033
3695784|3695784-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904152034
3695792|3695792-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904152036
3695802|3695802-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904152037
3695809|3695809-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904152038
3695814|3695814-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904152039
3695818|3695818-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904152039
3695822|3695822-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904152040
3695825|3695825-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904152040
3695871|3695871-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.52|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904152040
3695873|3695873-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.21|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904152033
3695962|3695962-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904151958
3695963|3695963-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904151958
3695966|3695966-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904151959
3695971|3695971-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904152000
3695991|3695991-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904152113
3696112|3696112-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904152134
3696172|3696172-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904152145
3696173|3696173-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904152145
3696185|3696185-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904152146
3696198|3696198-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904152147
3696204|3696204-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904152149
3696211|3696211-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.22|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904152150
3696445|3696445-b19f-3f77-b713-d32bba55d77f|fail|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.21|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160547
3696455|3696455-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.52|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160549
3696474|3696474-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904152156
3696534|3696534-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904152309
3696603|3696603-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.22|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904152321
3696610|3696610-b19f-3f77-b713-d32bba55d77f|fail|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.52|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904152322
3696638|3696638-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904152324
3696737|3696737-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.22|amd64-freebsd|5.8.8|freebsd|7.0-release|200904152339
3696740|3696740-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd|5.8.8|freebsd|7.0-release|200904152339
3696760|3696760-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904152341
3696881|3696881-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd|5.10.0|freebsd|7.0-release|200904152339
3696927|3696927-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904160009
3696929|3696929-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904160009
3696932|3696932-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904160009
3696933|3696933-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904160010
3696942|3696942-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904160010
3696985|3696985-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.53|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904160010
3697047|3697047-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd|5.8.9|freebsd|7.0-release|200904152339
3697051|3697051-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.22|amd64-freebsd|5.8.9|freebsd|7.0-release|200904152339
3697443|3697443-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|alpha-netbsd|5.10.0|netbsd|4.0.1|200904160029
3697658|3697658-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904160212
3697661|3697661-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904160212
3697664|3697664-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904160213
3697667|3697667-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904160213
3697672|3697672-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904160213
3697681|3697681-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904160216
3697686|3697686-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904160216
3697687|3697687-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904160217
3697689|3697689-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904160217
3697691|3697691-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904160217
3697695|3697695-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.54|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904160212
3697696|3697696-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.55|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904160216
3697839|3697839-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.22|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160953
3697852|3697852-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.53|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904160955
3698066|3698066-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.51|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904160241
3698154|3698154-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160302
3698167|3698167-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160305
3698170|3698170-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904160406
3698182|3698182-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160308
3698196|3698196-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160311
3698215|3698215-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160315
3698216|3698216-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160316
3698221|3698221-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160317
3698225|3698225-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160317
3698229|3698229-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160318
3698483|3698483-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904160416
3698515|3698515-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904160535
3698542|3698542-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904160440
3698588|3698588-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904161250
3698615|3698615-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160458
3698621|3698621-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160501
3698622|3698622-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160501
3698629|3698629-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160502
3698635|3698635-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160505
3698638|3698638-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160506
3698644|3698644-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160509
3698651|3698651-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160510
3698659|3698659-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904160612
3698660|3698660-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160513
3698868|3698868-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904160731
3698897|3698897-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904160744
3698917|3698917-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160653
3698918|3698918-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160653
3698921|3698921-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160654
3698928|3698928-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160655
3698931|3698931-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160656
3698936|3698936-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904160756
3698962|3698962-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904160810
3699083|3699083-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904160905
3699108|3699108-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904161014
3699130|3699130-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904160920
3699294|3699294-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904160853
3699296|3699296-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904160854
3699302|3699302-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904160855
3699305|3699305-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904160855
3699309|3699309-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904160856
3699334|3699334-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904160901
3699335|3699335-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160901
3699347|3699347-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160904
3699349|3699349-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160905
3699352|3699352-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160905
3699354|3699354-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160905
3699356|3699356-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160905
3699362|3699362-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.8.8|freebsd|7.0-release|200904161006
3699364|3699364-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.8.9|freebsd|7.0-release|200904161006
3699412|3699412-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904161016
3699434|3699434-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160921
3699435|3699435-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160921
3699436|3699436-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904160921
3699446|3699446-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160923
3699448|3699448-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160924
3699452|3699452-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904160924
3699634|3699634-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904161058
3699689|3699689-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904161108
3699793|3699793-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.55|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904161132
3699835|3699835-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904161141
3699865|3699865-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904161151
3699890|3699890-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.2|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904161154
3700013|3700013-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904161213
3700046|3700046-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904161220
3700137|3700137-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904161238
3700142|3700142-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904161239
3700159|3700159-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.55|i86pc-solaris-64int|5.10.0|solaris|2.11|200904161243
3700181|3700181-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.22|i86pc-solaris-64int|5.10.0|solaris|2.11|200904161247
3700255|3700255-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904161257
3700428|3700428-b19f-3f77-b713-d32bba55d77f|fail|200904|rbo@cpan.org|Devel-CheckOS|1.52|i86pc-solaris|5.8.9|solaris|2.11|200904161252
3700429|3700429-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckOS|1.54|i86pc-solaris|5.8.9|solaris|2.11|200904161253
3700580|3700580-b19f-3f77-b713-d32bba55d77f|pass|200904|vovkasm@gmail.com|Data-Compare|1.21|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904161244
3700604|3700604-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Data-Compare|1.21|i86pc-solaris|5.8.9|solaris|2.11|200904161251
3700606|3700606-b19f-3f77-b713-d32bba55d77f|fail|200904|rlane10@wi.rr.com|Devel-CheckOS|1.52|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904151613
3700607|3700607-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckOS|1.53|i86pc-solaris|5.8.9|solaris|2.11|200904161252
3700608|3700608-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.21|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904151607
3700675|3700675-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904161300
3700689|3700689-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.55|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904162002
3700699|3700699-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.22|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904162002
3700802|3700802-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.51|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904161420
3700855|3700855-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.55|i86pc-solaris-64int|5.8.9|solaris|2.11|200904161429
3700876|3700876-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|IP35-irix-64int|5.8.8|irix|6.5|200904161433
3700878|3700878-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161333
3700879|3700879-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161333
3700889|3700889-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161335
3700892|3700892-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.22|i86pc-solaris-64int|5.8.9|solaris|2.11|200904161435
3700893|3700893-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161335
3700897|3700897-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161335
3700898|3700898-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161336
3700906|3700906-b19f-3f77-b713-d32bba55d77f|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.55|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904161244
3700915|3700915-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161337
3700923|3700923-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161337
3700932|3700932-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904161338
3701100|3701100-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904161508
3701231|3701231-b19f-3f77-b713-d32bba55d77f|pass|200904|perl@galumph.com|Data-Compare|1.21|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904160835
3701233|3701233-b19f-3f77-b713-d32bba55d77f|pass|200904|perl@galumph.com|Devel-CheckOS|1.55|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904160836
3701244|3701244-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904161438
3701250|3701250-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161439
3701272|3701272-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161440
3701274|3701274-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|IP35-irix-64int|5.8.8|irix|6.5|200904161540
3701280|3701280-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904161441
3701283|3701283-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|IP35-irix-64int|5.8.8|irix|6.5|200904161542
3701292|3701292-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.21|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160844
3701302|3701302-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160847
3701313|3701313-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160850
3701328|3701328-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160852
3701336|3701336-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.52|IP35-irix-64int|5.8.8|irix|6.5|200904161553
3701360|3701360-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160856
3701364|3701364-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.53|IP35-irix-64int|5.8.8|irix|6.5|200904161556
3701375|3701375-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904160857
3701376|3701376-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.54|IP35-irix-64int|5.8.8|irix|6.5|200904161557
3701409|3701409-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckOS|1.55|i86pc-solaris|5.8.9|solaris|2.11|200904161251
3701563|3701563-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904161628
3701865|3701865-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904161629
3701866|3701866-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.21.5-smp|200904161629
3701926|3701926-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904161625
3701950|3701950-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.55|alpha-netbsd|5.10.0|netbsd|4.0.1|200904161544
3701958|3701958-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.22|alpha-netbsd|5.10.0|netbsd|4.0.1|200904161547
3702192|3702192-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904161825
3702825|3702825-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904162043
3702871|3702871-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.0|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904162057
3703003|3703003-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904162132
3703107|3703107-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904162151
3703291|3703291-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904162243
3704326|3704326-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.2|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170012
3704346|3704346-b19f-3f77-b713-d32bba55d77f|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.55|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170014
3704350|3704350-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.51|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170015
3704357|3704357-b19f-3f77-b713-d32bba55d77f|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.52|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170015
3704463|3704463-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904170236
3704959|3704959-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904170420
3705061|3705061-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170354
3705069|3705069-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170355
3705074|3705074-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170357
3705076|3705076-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170357
3705077|3705077-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170357
3705083|3705083-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170359
3705086|3705086-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170359
3705088|3705088-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170400
3705090|3705090-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170400
3705092|3705092-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170401
3705096|3705096-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170401
3705097|3705097-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170402
3705102|3705102-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904170403
3705110|3705110-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904170506
3705385|3705385-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|XML-DoubleEncodedEntities|1.0|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170421
3705570|3705570-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904170603
3705571|3705571-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200904170603
3705943|3705943-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|i586-linux-thread-multi|5.8.8|linux|2.6.16|200904170928
3705964|3705964-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904170932
3706504|3706504-b19f-3f77-b713-d32bba55d77f|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904161129
3706862|3706862-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170513
3706881|3706881-b19f-3f77-b713-d32bba55d77f|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.53|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170515
3706888|3706888-b19f-3f77-b713-d32bba55d77f|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.54|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904170516
3706926|3706926-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904171221
3707014|3707014-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904171230
3707079|3707079-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904171236
3707088|3707088-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904171238
3707109|3707109-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904171244
3707132|3707132-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904171249
3707175|3707175-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904171258
3707227|3707227-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904171312
3707238|3707238-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904171314
3707283|3707283-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904171322
3707312|3707312-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904171327
3707380|3707380-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904171338
3707387|3707387-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904171339
3707555|3707555-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904171325
3707562|3707562-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.53|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904171427
3707707|3707707-b19f-3f77-b713-d32bba55d77f|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.55|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904161129
3707731|3707731-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904171506
3707753|3707753-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904171514
3707782|3707782-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904171525
3707857|3707857-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904171555
3707898|3707898-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904171608
3708089|3708089-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904171656
3708330|3708330-b19f-3f77-b713-d32bba55d77f|pass|200904|pjacklam@online.no|Data-Compare|1.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904171748
3708863|3708863-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904171943
3708869|3708869-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171826
3708879|3708879-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171827
3708885|3708885-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171829
3708888|3708888-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171829
3708889|3708889-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171830
3708893|3708893-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171831
3708899|3708899-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171832
3708903|3708903-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171832
3708906|3708906-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171833
3708910|3708910-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171834
3708913|3708913-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171834
3708914|3708914-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171834
3708923|3708923-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904171835
3709033|3709033-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904172019
3709199|3709199-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904172101
3709250|3709250-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.21.5-smp|200904172013
3709262|3709262-b19f-3f77-b713-d32bba55d77f|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904171515
3709288|3709288-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Data-Compare|1.21|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904172118
3709289|3709289-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904172118
3709298|3709298-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Data-Compare|1.21|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904172119
3709300|3709300-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904172119
3709547|3709547-b19f-3f77-b713-d32bba55d77f|fail|200904|pjacklam@online.no|Devel-CheckOS|1.55|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904172205
3709845|3709845-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904172309
3709888|3709888-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904172317
3710027|3710027-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904172350
3710168|3710168-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904180024
3710224|3710224-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904180036
3710228|3710228-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904180037
3710275|3710275-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904180043
3710325|3710325-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904180052
3710339|3710339-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904180056
3710409|3710409-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904180107
3710481|3710481-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904180126
3710486|3710486-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904180127
3710507|3710507-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904180134
3710635|3710635-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904180042
3710656|3710656-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904180208
3710687|3710687-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.21|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904180217
3710690|3710690-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904180217
3710693|3710693-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904180217
3710910|3710910-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904180322
3711100|3711100-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904180431
3711124|3711124-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904180440
3711324|3711324-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904180605
3711836|3711836-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904180850
3712046|3712046-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904180957
3712074|3712074-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904181005
3712084|3712084-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904181009
3712117|3712117-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904181018
3712154|3712154-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904181031
3712201|3712201-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904181042
3712331|3712331-b19f-3f77-b713-d32bba55d77f|pass|200904|rafl@debian.org|Devel-CheckOS|1.55|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904181111
3713368|3713368-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181256
3713375|3713375-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181257
3713385|3713385-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181258
3713392|3713392-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181259
3713394|3713394-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181259
3713400|3713400-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181300
3713403|3713403-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181301
3713406|3713406-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181301
3713411|3713411-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181301
3713415|3713415-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181302
3713419|3713419-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181303
3713425|3713425-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181303
3713433|3713433-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904181304
3713482|3713482-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Palm-Treo680MessagesDB|1.01|amd64-freebsd|5.10.0|freebsd|7.0-release|200904181406
3713483|3713483-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Data-Hexdumper|2.01|amd64-freebsd|5.10.0|freebsd|7.0-release|200904181406
3713486|3713486-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|File-Overwrite|1.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200904181405
3713957|3713957-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904181510
3714500|3714500-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904181617
3714794|3714794-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904181659
3715020|3715020-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200904181616
3715154|3715154-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904181755
3715210|3715210-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.22|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904181757
3716195|3716195-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904181959
3716205|3716205-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182002
3716217|3716217-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904182105
3716223|3716223-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182007
3716248|3716248-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182011
3716250|3716250-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182011
3716256|3716256-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182013
3716268|3716268-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182016
3716273|3716273-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182018
3716288|3716288-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182023
3716312|3716312-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|File-Overwrite|1.1|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182026
3716319|3716319-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904182127
3716321|3716321-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Hexdumper|2.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182028
3716329|3716329-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904182029
3716711|3716711-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904182241
3716898|3716898-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904182313
3717157|3717157-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|Devel-CheckOS|1.52|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904182352
3717404|3717404-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904190035
3717449|3717449-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904190046
3717554|3717554-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904190101
3717897|3717897-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.8|linux|2.6.21.5-smp|200904190102
3717979|3717979-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904190219
3718102|3718102-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904190250
3718197|3718197-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904190312
3718257|3718257-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904190328
3718259|3718259-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904190328
3718332|3718332-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904190340
3718358|3718358-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904190347
3718408|3718408-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904190401
3718419|3718419-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904190405
3718448|3718448-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904190411
3718634|3718634-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904190449
3718803|3718803-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904190528
3723291|3723291-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.1|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200335
3723298|3723298-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200337
3723300|3723300-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200338
3723304|3723304-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200338
3723305|3723305-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200344
3723306|3723306-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200344
3723307|3723307-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200346
3723309|3723309-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200346
3723310|3723310-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200347
3723312|3723312-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200348
3723315|3723315-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200904200348
3724208|3724208-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904200841
3724364|3724364-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200809
3724375|3724375-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200812
3724381|3724381-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200813
3724385|3724385-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200813
3724396|3724396-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200815
3724398|3724398-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200816
3724403|3724403-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200817
3724406|3724406-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200818
3724411|3724411-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904200819
3724601|3724601-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904200947
3724609|3724609-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904200948
3724639|3724639-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904200955
3724668|3724668-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904201002
3724684|3724684-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904201005
3724709|3724709-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904201010
3724728|3724728-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904201016
3724755|3724755-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904201022
3724790|3724790-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904201029
3724819|3724819-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904201034
3724880|3724880-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904201045
3724938|3724938-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904201058
3725088|3725088-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904201132
3725160|3725160-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904201141
3725185|3725185-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904201146
3725199|3725199-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904201148
3725219|3725219-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904201151
3725238|3725238-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904201154
3725319|3725319-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904201204
3725491|3725491-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Data-Compare|1.21|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904201225
3725493|3725493-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.55|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904201225
3725988|3725988-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904201313
3726992|3726992-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904201702
3727080|3727080-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904201714
3727330|3727330-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904201755
3727412|3727412-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904201809
3727421|3727421-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904201810
3727434|3727434-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904201811
3727441|3727441-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904201813
3727449|3727449-b19f-3f77-b713-d32bba55d77f|fail|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.3|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904201814
3728598|3728598-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.3|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904202124
3728816|3728816-b19f-3f77-b713-d32bba55d77f|na|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202058
3728819|3728819-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202100
3728820|3728820-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202101
3728822|3728822-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202101
3728828|3728828-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202102
3728830|3728830-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202103
3728833|3728833-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202104
3728838|3728838-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202104
3728847|3728847-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200904202105
3728963|3728963-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Devel-CheckOS|1.55|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904202118
3728970|3728970-b19f-3f77-b713-d32bba55d77f|fail|200904|andy@hexten.net|CPAN-FindDependencies|2.3|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904202118
3729431|3729431-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.24-19-generic|200904202204
3729436|3729436-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200904202205
3729527|3729527-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.3|amd64-freebsd|5.8.9|freebsd|7.0-release|200904202316
3729538|3729538-b19f-3f77-b713-d32bba55d77f|fail|200904|srezic@cpan.org|CPAN-FindDependencies|2.3|amd64-freebsd|5.8.8|freebsd|7.0-release|200904202316
3730353|3730353-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904210221
3730560|3730560-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904210315
3731025|3731025-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200904210421
3731123|3731123-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904210449
3731153|3731153-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904210459
3731188|3731188-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904210506
3731214|3731214-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904210513
3732414|3732414-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904211037
3732484|3732484-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Hexdumper|2.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904211049
3732497|3732497-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904211050
3732504|3732504-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904211051
3732601|3732601-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904211107
3732673|3732673-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904211127
3733498|3733498-b19f-3f77-b713-d32bba55d77f|fail|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904211956
3733541|3733541-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904211405
3733622|3733622-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211319
3733628|3733628-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211321
3733633|3733633-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211321
3733635|3733635-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211321
3733638|3733638-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211323
3733639|3733639-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211323
3733643|3733643-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211324
3733649|3733649-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211325
3733654|3733654-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200904211325
3733901|3733901-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904211517
3734631|3734631-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904211738
3735091|3735091-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net ("GRAHAMC")|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904202224
3735253|3735253-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|Devel-CheckOS|1.55|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904210958
3735696|3735696-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904211933
3736091|3736091-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904212045
3736343|3736343-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904212140
3736348|3736348-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904212141
3736349|3736349-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904212141
3736351|3736351-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904212142
3736355|3736355-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904212142
3736358|3736358-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.6|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904212142
3736397|3736397-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.3|i386-linux-thread-multi|5.10.0|linux|2.6.18-92.1.18.el5|200904211000
3736538|3736538-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Data-Compare|1.21|amd64-freebsd|5.10.0|freebsd|7.0-release|200904211809
3736540|3736540-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.10.0|freebsd|7.0-release|200904211809
3736586|3736586-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net ("GRAHAMC")|Devel-CheckOS|1.55|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-generic|200904202225
3736692|3736692-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd|5.8.8|freebsd|7.0-release|200904212244
3736710|3736710-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200904212244
3737329|3737329-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904220116
3737335|3737335-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904220118
3737504|3737504-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904220216
3737791|3737791-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.55|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904220325
3737845|3737845-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904220338
3737921|3737921-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.22|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904220358
3738009|3738009-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904220332
3738026|3738026-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904220339
3738055|3738055-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904220347
3738078|3738078-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200904220355
3738085|3738085-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220359
3738089|3738089-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220401
3738092|3738092-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220401
3738093|3738093-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220402
3738095|3738095-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220403
3738099|3738099-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220404
3738101|3738101-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220404
3738103|3738103-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220405
3738105|3738105-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220405
3738107|3738107-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904220406
3738174|3738174-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904220526
3739036|3739036-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904221022
3739496|3739496-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.6|i86pc-solaris-64int|5.10.0|solaris|2.11|200904221055
3739537|3739537-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904221716
3739552|3739552-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904221121
3739700|3739700-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904221207
3739803|3739803-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904221131
3739804|3739804-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904221131
3739805|3739805-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904221131
3739916|3739916-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904221945
3739979|3739979-b19f-3f77-b713-d32bba55d77f|fail|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.3|i86pc-solaris-64int|5.10.0|solaris|2.11|200904221302
3740301|3740301-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.6|i86pc-solaris-64int|5.8.9|solaris|2.11|200904221431
3740358|3740358-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904221445
3740534|3740534-b19f-3f77-b713-d32bba55d77f|fail|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.3|i86pc-solaris-64int|5.8.9|solaris|2.11|200904221523
3740568|3740568-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904221433
3740676|3740676-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904221555
3740742|3740742-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904221608
3740942|3740942-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904221541
3740944|3740944-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904221541
3741133|3741133-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904221617
3741180|3741180-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904221622
3741191|3741191-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904221625
3741239|3741239-b19f-3f77-b713-d32bba55d77f|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904221134
3741646|3741646-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|alpha-netbsd|5.10.0|netbsd|4.0.1|200904221657
3741701|3741701-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Devel-CheckOS|1.6|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904221804
3741729|3741729-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221810
3741743|3741743-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221813
3741746|3741746-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221814
3741749|3741749-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221814
3741761|3741761-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221816
3741770|3741770-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200904221820
3741772|3741772-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221819
3741774|3741774-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221820
3741779|3741779-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221821
3741782|3741782-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221821
3741785|3741785-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221822
3741786|3741786-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200904221823
3741984|3741984-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|IP35-irix-64int|5.8.8|irix|6.5|200904222007
3742241|3742241-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904222050
3742242|3742242-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904222050
3742247|3742247-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904222051
3742248|3742248-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904222052
3742250|3742250-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904222053
3742281|3742281-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Number-Phone|1.7002|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904222051
3742293|3742293-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904222102
3742333|3742333-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904222111
3742412|3742412-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904222132
3742496|3742496-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.6|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904221500
3742690|3742690-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222235
3742837|3742837-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Number-Phone|1.7002|amd64-freebsd|5.8.8|freebsd|7.0-release|200904222223
3742974|3742974-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Number-Phone|1.7002|amd64-freebsd|5.8.9|freebsd|7.0-release|200904222317
3742978|3742978-b19f-3f77-b713-d32bba55d77f|fail|200904|vpit@cpan.org|Devel-CheckOS|1.52|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3742982|3742982-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Devel-CheckOS|1.53|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3742984|3742984-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Devel-CheckOS|1.54|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3742985|3742985-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Devel-CheckOS|1.55|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904222321
3743025|3743025-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904222324
3743175|3743175-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904222342
3743379|3743379-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int|5.6.2|darwin|8.11.0|200904222316
3743517|3743517-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.2|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222338
3743527|3743527-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222340
3743532|3743532-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222341
3743533|3743533-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222341
3743540|3743540-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222344
3743550|3743550-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222346
3743554|3743554-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.51|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222347
3743559|3743559-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222348
3743568|3743568-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222349
3743572|3743572-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222350
3743584|3743584-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222350
3743594|3743594-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200904222350
3743599|3743599-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|IP35-irix-64int|5.8.8|irix|6.5|200904230055
3743879|3743879-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904230202
3743931|3743931-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904230209
3744118|3744118-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Number-Phone|1.7002|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904230953
3744206|3744206-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904230222
3744768|3744768-b19f-3f77-b713-d32bba55d77f|fail|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.6|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904230430
3745119|3745119-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|i586-linux-thread-multi|5.8.8|linux|2.6.16|200904230834
3745223|3745223-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904230759
3745330|3745330-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904230929
3745585|3745585-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904230417
3745669|3745669-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904231048
3745673|3745673-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.6|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904231049
3745700|3745700-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|alpha-netbsd|5.10.0|netbsd|4.0.1|200904231000
3745928|3745928-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904231250
3746082|3746082-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7002|i86pc-solaris-64int|5.10.0|solaris|2.11|200904231336
3746441|3746441-b19f-3f77-b713-d32bba55d77f|pass|200904|perl@galumph.com|Devel-CheckOS|1.6|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904230730
3747207|3747207-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Devel-CheckOS|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904222039
3747587|3747587-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904231510
3747588|3747588-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904231511
3747656|3747656-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Data-Compare|1.21|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904222039
3747700|3747700-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904231629
3747701|3747701-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.3|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200904231630
3747736|3747736-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904231641
3747919|3747919-b19f-3f77-b713-d32bba55d77f|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904220947
3747965|3747965-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904231613
3748134|3748134-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|Number-Phone|1.7002|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904232345
3748320|3748320-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904231723
3748339|3748339-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904231728
3748368|3748368-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904231732
3748395|3748395-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904231135
3749018|3749018-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232018
3749019|3749019-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232019
3749020|3749020-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232019
3749037|3749037-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232020
3749039|3749039-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232022
3749040|3749040-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232022
3749042|3749042-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232023
3749043|3749043-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232023
3749044|3749044-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.16.38|200904232024
3749236|3749236-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904232247
3749317|3749317-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.21|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232216
3749327|3749327-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.22|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232218
3749331|3749331-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904232319
3749333|3749333-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232221
3749335|3749335-b19f-3f77-b713-d32bba55d77f|fail|200904|bingos@cpan.org|Devel-CheckOS|1.52|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232221
3749339|3749339-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.53|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232222
3749341|3749341-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.54|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232223
3749342|3749342-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.55|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904232224
3749967|3749967-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904240251
3750112|3750112-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|IP35-irix-64int|5.8.8|irix|6.5|200904240351
3750288|3750288-b19f-3f77-b713-d32bba55d77f|pass|200904|rafl@debian.org|Devel-CheckOS|1.6|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904240443
3750365|3750365-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904240507
3750428|3750428-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Number-Phone|1.7002|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904240323
3750794|3750794-b19f-3f77-b713-d32bba55d77f|pass|200904|conrad@fringehead.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.15.1|200904240509
3751177|3751177-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904240935
3751200|3751200-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904240943
3751273|3751273-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904240959
3751300|3751300-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Number-Phone|1.7002|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904241106
3751313|3751313-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904241010
3751335|3751335-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904241013
3751396|3751396-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904241024
3751451|3751451-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Number-Phone|1.7002|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904240931
3751552|3751552-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904241046
3751655|3751655-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904241102
3751673|3751673-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904241106
3751873|3751873-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|File-Overwrite|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904241143
3751933|3751933-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-Treo680MessagesDB|1.01|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904241156
3751957|3751957-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Data-Compare|1.21|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904241103
3751962|3751962-b19f-3f77-b713-d32bba55d77f|fail|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.6|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904241106
3751994|3751994-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Data-Compare|1.21|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904241112
3751996|3751996-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Devel-CheckOS|1.6|i686-linux-thread-multi|5.8.9|linux|2.6.27-11-server|200904241112
3751999|3751999-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904241212
3752017|3752017-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904241216
3752070|3752070-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241125
3752071|3752071-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241125
3752074|3752074-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241126
3752077|3752077-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241127
3752411|3752411-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux|5.10.0|linux|2.6.24-16-generic|200904240708
3752666|3752666-b19f-3f77-b713-d32bba55d77f|pass|200904|jozef@kutej.net|Data-Compare|1.21|x86_64-linux-gnu-thread-multi|5.8.8|linux|2.6.24-16-server|200904240956
3752767|3752767-b19f-3f77-b713-d32bba55d77f|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.6|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904232256
3753230|3753230-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux|5.10.0|linux|2.6.24-16-generic|200904240812
3753280|3753280-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904241419
3753952|3753952-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.3|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241000
3754394|3754394-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Number-Phone|1.7002|i86pc-solaris-64int|5.8.9|solaris|2.11|200904241651
3754413|3754413-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904241552
3754463|3754463-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.16.38|200904241558
3754611|3754611-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904241617
3754612|3754612-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904241617
3754753|3754753-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904241730
3754769|3754769-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904241730
3754773|3754773-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904241732
3754780|3754780-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904241733
3754794|3754794-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904241734
3754804|3754804-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.31|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904241736
3754822|3754822-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904241638
3754984|3754984-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904241804
3755155|3755155-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200904241736
3755239|3755239-b19f-3f77-b713-d32bba55d77f|fail|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|CPAN-FindDependencies|2.31|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904250145
3755251|3755251-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904241846
3755265|3755265-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904241848
3755343|3755343-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904241904
3755475|3755475-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241324
3755480|3755480-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241325
3755500|3755500-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904241230
3755524|3755524-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.31|amd64-freebsd|5.8.8|freebsd|7.0-release|200904241932
3755535|3755535-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.31|amd64-freebsd|5.8.9|freebsd|7.0-release|200904241932
3755595|3755595-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904241938
3755654|3755654-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.6|amd64-freebsd|5.10.0|freebsd|7.0-release|200904241945
3755655|3755655-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.31|amd64-freebsd|5.10.0|freebsd|7.0-release|200904241946
3755754|3755754-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904242010
3755808|3755808-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904242021
3755856|3755856-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904242034
3755926|3755926-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904242044
3755979|3755979-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904242055
3756028|3756028-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904242105
3756175|3756175-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.3|IP35-irix-64int|5.8.8|irix|6.5|200904242129
3756299|3756299-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241547
3756303|3756303-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904242147
3756367|3756367-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904242156
3756386|3756386-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904242158
3756410|3756410-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Devel-CheckLib|0.5|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904242101
3756411|3756411-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Number-Phone|1.7002|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904242202
3756554|3756554-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.6|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904242220
3756734|3756734-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.6|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904242249
3756742|3756742-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904242249
3756935|3756935-b19f-3f77-b713-d32bba55d77f|pass|200904|graham@crookham.uklinux.net (grahamc)|Number-Phone|1.7002|i686-linux-thread-multi|5.10.0|linux|2.6.27-11-server|200904242214
3757069|3757069-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241735
3757071|3757071-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241735
3757072|3757072-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241735
3757286|3757286-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904242314
3757288|3757288-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904242314
3757515|3757515-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|CPAN-FindDependencies|2.22|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250143
3757560|3757560-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241850
3757653|3757653-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250007
3757656|3757656-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250008
3757672|3757672-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904250110
3757769|3757769-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux|5.10.0|linux|2.6.24-16-generic|200904241928
3757811|3757811-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.51|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250235
3757816|3757816-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.55|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250235
3757821|3757821-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250236
3757882|3757882-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|File-Overwrite|1.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904250244
3758008|3758008-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904250210
3758015|3758015-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904250211
3758091|3758091-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904250223
3758131|3758131-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904250230
3758311|3758311-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250100
3758317|3758317-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250101
3758626|3758626-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904250349
3758652|3758652-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.6|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250154
3758867|3758867-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250240
3759204|3759204-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250451
3759215|3759215-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904250452
3759542|3759542-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904250703
3759665|3759665-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904250732
3759804|3759804-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904250800
3759940|3759940-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904250831
3759967|3759967-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904250835
3760167|3760167-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904250915
3760372|3760372-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904250955
3760593|3760593-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904251042
3760611|3760611-b19f-3f77-b713-d32bba55d77f|pass|200904|wiml@hhhh.org ("Wim Lewis")|Number-Phone|1.7002|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250845
3760645|3760645-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250449
3760648|3760648-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250450
3760696|3760696-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904251102
3760790|3760790-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904251116
3760964|3760964-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904251202
3761010|3761010-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904251119
3761056|3761056-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904251228
3761077|3761077-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.6|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904251232
3761269|3761269-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904251319
3761271|3761271-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904251319
3761274|3761274-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904251319
3761278|3761278-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904251320
3761281|3761281-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904251320
3761286|3761286-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904251319
3761319|3761319-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904251331
3761437|3761437-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904250755
3761486|3761486-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904251405
3761534|3761534-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904251313
3761596|3761596-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904251320
3761689|3761689-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904251339
3761690|3761690-b19f-3f77-b713-d32bba55d77f|fail|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904251340
3761967|3761967-b19f-3f77-b713-d32bba55d77f|pass|200904|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200904252232
3762012|3762012-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904251535
3762132|3762132-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904251555
3762182|3762182-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904251605
3762329|3762329-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251029
3762330|3762330-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251029
3762331|3762331-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251029
3762620|3762620-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904251727
3762639|3762639-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|alpha-netbsd|5.10.0|netbsd|4.0.1|200904251533
3762744|3762744-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251158
3762786|3762786-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904251809
3762920|3762920-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200904251241
3763213|3763213-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904251928
3763224|3763224-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251330
3763229|3763229-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251330
3763251|3763251-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904251933
3763491|3763491-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200904251902
3763586|3763586-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904251915
3763708|3763708-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904251934
3763711|3763711-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904251935
3763802|3763802-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904252047
3763826|3763826-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251452
3763884|3763884-b19f-3f77-b713-d32bba55d77f|fail|200904|wiml@hhhh.org ("Wim Lewis")|CPAN-FindDependencies|2.3|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200904250925
3763999|3763999-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200904252024
3764002|3764002-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200904252024
3764063|3764063-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904252033
3764122|3764122-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.61|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904252146
3764154|3764154-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200904252053
3764412|3764412-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904252235
3764683|3764683-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904251627
3764724|3764724-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7001|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904252333
3764898|3764898-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.8.8|freebsd|7.0-release|200904260010
3764940|3764940-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252324
3764942|3764942-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252325
3764975|3764975-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904252332
3765147|3765147-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904260003
3765169|3765169-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.31|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904260009
3765217|3765217-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.3|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904251817
3765224|3765224-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|CPAN-FindDependencies|2.31|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904251818
3765227|3765227-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904260118
3765262|3765262-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Devel-CheckLib|0.5|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904260027
3765268|3765268-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904260027
3765271|3765271-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904260028
3765398|3765398-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251955
3765401|3765401-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux|5.8.9|linux|2.6.24-16-generic|200904251956
3765490|3765490-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260119
3765615|3765615-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904260245
3766096|3766096-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260220
3766148|3766148-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904260432
3766572|3766572-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260011
3766574|3766574-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260011
3766834|3766834-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904260605
3766904|3766904-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.8.9|linux|2.6.24-16-generic|200904260119
3766926|3766926-b19f-3f77-b713-d32bba55d77f|pass|200904|rafl@debian.org|Devel-CheckOS|1.61|i686-linux|5.10.0 patch 35117|linux|2.6.26|200904260725
3767135|3767135-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260239
3767169|3767169-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260247
3767249|3767249-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200904261010
3767261|3767261-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904260912
3767274|3767274-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.31|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260315
3767283|3767283-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260817
3767321|3767321-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-netbsd-thread-multi-64int|5.8.9|netbsd|3.1|200904260824
3767505|3767505-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.8.9|freebsd|7.0-release|200904261005
3767632|3767632-b19f-3f77-b713-d32bba55d77f|pass|200904|dagolden@cpan.org (DAGOLDEN)|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200904260444
3767815|3767815-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|i586-linux-thread-multi|5.8.8|linux|2.6.16|200904261135
3767860|3767860-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200904261145
3767871|3767871-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200904261147
3767886|3767886-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200904261149
3767915|3767915-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904261157
3767931|3767931-b19f-3f77-b713-d32bba55d77f|pass|200904|g.grigelionis@computer.org|Devel-CheckOS|1.61|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200904261200
3768036|3768036-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.61|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904261826
3768106|3768106-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904261137
3768134|3768134-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.31|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904261842
3768174|3768174-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904261156
3768175|3768175-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904261157
3768183|3768183-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904261158
3768188|3768188-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|IP35-irix-64int|5.8.8|irix|6.5|200904261259
3768319|3768319-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904261224
3768507|3768507-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.21|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200904261411
3768528|3768528-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904261438
3768683|3768683-b19f-3f77-b713-d32bba55d77f|pass|200904|mahony357@gmail.com|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904261331
3768777|3768777-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200904261440
3768809|3768809-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904261605
3768833|3768833-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904261609
3769345|3769345-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904261816
3769368|3769368-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904261820
3769380|3769380-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904261822
3769387|3769387-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904261724
3769389|3769389-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904261724
3769824|3769824-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.9|solaris|2.11|200904262006
3769899|3769899-b19f-3f77-b713-d32bba55d77f|pass|200904|perl@galumph.com|Devel-CheckOS|1.61|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200904261324
3770031|3770031-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904262055
3770222|3770222-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckOS|1.6|i86pc-solaris|5.8.9|solaris|2.11|200904262149
3770224|3770224-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Number-Phone|1.7002|i86pc-solaris|5.8.9|solaris|2.11|200904262149
3770403|3770403-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262137
3770413|3770413-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262139
3770417|3770417-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262140
3770422|3770422-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904262141
3770507|3770507-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904262258
3770532|3770532-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904262302
3770689|3770689-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904262338
3770695|3770695-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904262341
3770842|3770842-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904270029
3771093|3771093-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904270141
3771121|3771121-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904270146
3771166|3771166-b19f-3f77-b713-d32bba55d77f|pass|200904|rbo@cpan.org|Devel-CheckLib|0.5|i86pc-solaris|5.8.9|solaris|2.11|200904270200
3771314|3771314-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904270241
3771492|3771492-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904270336
3771562|3771562-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904270355
3771570|3771570-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904270359
3771823|3771823-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904270545
3771931|3771931-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904270645
3771937|3771937-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904270649
3771942|3771942-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904270552
3772667|3772667-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.61|i86pc-solaris-64int|5.8.9|solaris|2.11|200904271104
3772733|3772733-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckOS|1.61|i86pc-solaris-64int|5.10.0|solaris|2.11|200904271124
3772807|3772807-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckOS|1.61|alpha-netbsd|5.10.0|netbsd|4.0.1|200904270948
3773291|3773291-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|CPAN-FindDependencies|2.31|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200904261329
3773445|3773445-b19f-3f77-b713-d32bba55d77f|pass|200904|rlane10@wi.rr.com|Devel-CheckOS|1.61|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200904261836
3773590|3773590-b19f-3f77-b713-d32bba55d77f|pass|200904|autarch@urth.org|Data-Compare|1.21|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200904260010
3773627|3773627-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.31|i86pc-solaris-64int|5.8.9|solaris|2.11|200904271350
3773760|3773760-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904271405
3773819|3773819-b19f-3f77-b713-d32bba55d77f|pass|200904|vovkasm@gmail.com|Devel-CheckOS|1.61|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200904271440
3773940|3773940-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|7.0-release|200904271338
3774046|3774046-b19f-3f77-b713-d32bba55d77f|pass|200904|hohokus@gmail.com|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200904270857
3774128|3774128-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271417
3774129|3774129-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271417
3774340|3774340-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.31|i86pc-solaris-64int|5.10.0|solaris|2.11|200904271553
3774385|3774385-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904271504
3774457|3774457-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904271625
3774858|3774858-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271652
3774866|3774866-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271654
3774869|3774869-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271655
3774891|3774891-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904271703
3775202|3775202-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.3|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904271953
3775330|3775330-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200904272030
3775439|3775439-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904272049
3775679|3775679-b19f-3f77-b713-d32bba55d77f|pass|200904|stsc@refcnt.org ("Steven Schubiger")|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200904272127
3775715|3775715-b19f-3f77-b713-d32bba55d77f|pass|200904|vpit@cpan.org|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200904272130
3775831|3775831-b19f-3f77-b713-d32bba55d77f|pass|200904|chris@bingosnet.co.uk|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200904272049
3775998|3775998-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.6.2|freebsd|7.0-release|200904272220
3776161|3776161-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.32|amd64-freebsd|5.8.9|freebsd|7.0-release|200904272252
3776447|3776447-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904272316
3776963|3776963-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904280605
3777050|3777050-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200904280630
3777051|3777051-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200904280631
3777053|3777053-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200904280633
3777056|3777056-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200904280634
3777058|3777058-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|CPAN-FindDependencies|2.32|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904280635
3777198|3777198-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|CPAN-FindDependencies|2.32|amd64-freebsd|5.8.8|freebsd|7.0-release|200904280733
3777442|3777442-b19f-3f77-b713-d32bba55d77f|pass|200904|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.5|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200904280848
3777893|3777893-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904280902
3777894|3777894-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904280902
3777918|3777918-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckLib|0.5|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200904280904
3778066|3778066-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.32|i86pc-solaris-64int|5.10.0|solaris|2.11|200904281028
3778254|3778254-b19f-3f77-b713-d32bba55d77f|pass|200904|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-1-amd64|200904281706
3778307|3778307-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904281114
3778362|3778362-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200904281126
3778393|3778393-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904281132
3778404|3778404-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904281133
3778421|3778421-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckLib|0.5|IP35-irix-64int|5.8.8|irix|6.5|200904281138
3778434|3778434-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|Devel-CheckLib|0.5|alpha-netbsd|5.10.0|netbsd|4.0.1|200904280941
3778470|3778470-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200904281053
3778597|3778597-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200904281221
3778659|3778659-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904281232
3778665|3778665-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200904281234
3778723|3778723-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200904281241
3778728|3778728-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200904281242
3778820|3778820-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904281258
3778845|3778845-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200904281304
3778850|3778850-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200904281305
3778979|3778979-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200904281229
3778984|3778984-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200904281230
3778995|3778995-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200904281231
3779035|3779035-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904281335
3779045|3779045-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904281338
3779152|3779152-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904281358
3779265|3779265-b19f-3f77-b713-d32bba55d77f|pass|200904|carlos.arenas@gmail.com ("Carlos Arenas")|Devel-CheckOS|1.61|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200904270954
3779397|3779397-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200904281429
3779398|3779398-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.3|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281329
3779417|3779417-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281331
3779422|3779422-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281332
3779429|3779429-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200904281333
3779519|3779519-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904281446
3779698|3779698-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200904281518
3779737|3779737-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200904280824
3779839|3779839-b19f-3f77-b713-d32bba55d77f|fail|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.10.0|linux|2.6.18-92.el5|200904281536
3780093|3780093-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|CPAN-FindDependencies|2.32|alpha-netbsd|5.10.0|netbsd|4.0.1|200904281411
3780218|3780218-b19f-3f77-b713-d32bba55d77f|pass|200904|JOST@cpan.org ("Josts Smokehouse")|CPAN-FindDependencies|2.32|i86pc-solaris-64int|5.8.9|solaris|2.11|200904281623
3780258|3780258-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904281631
3780333|3780333-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904281640
3780350|3780350-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200904281643
3780720|3780720-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200904281745
3780767|3780767-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904281652
3780780|3780780-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904281753
3780929|3780929-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904281811
3781088|3781088-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904281838
3781112|3781112-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200904281842
3781409|3781409-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904281918
3781501|3781501-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200904281836
3781566|3781566-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200904281946
3781635|3781635-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200904282007
3781657|3781657-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904282013
3782039|3782039-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200904282213
3782162|3782162-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904282244
3782193|3782193-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200904282252
3782206|3782206-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200904282256
3782208|3782208-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200904282256
3782306|3782306-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200904282326
3782329|3782329-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200904282329
3782385|3782385-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Data-Compare|1.21|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200904282237
3782702|3782702-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200904290017
3782820|3782820-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200904290036
3782937|3782937-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200904290101
3783353|3783353-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290121
3783357|3783357-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290121
3783398|3783398-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200904290230
3783465|3783465-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904290245
3783547|3783547-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.5|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904290304
3783616|3783616-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckOS|1.61|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904290330
3783631|3783631-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200904290338
3784121|3784121-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290515
3784125|3784125-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200904290617
3784126|3784126-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200904290619
3784212|3784212-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200904290658
3784349|3784349-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290659
3784352|3784352-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290701
3784354|3784354-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290702
3784356|3784356-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200904290704
3784416|3784416-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200904290824
3784470|3784470-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-FindDependencies|2.32|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200904290848
3784508|3784508-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200904290913
3784584|3784584-b19f-3f77-b713-d32bba55d77f|pass|200904|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200904290940
3785780|3785780-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291413
3785781|3785781-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291414
3786349|3786349-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291658
3786374|3786374-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291245
3786375|3786375-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291245
3786752|3786752-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291829
3786757|3786757-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291831
3786762|3786762-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291832
3786765|3786765-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200904291833
3786800|3786800-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291830
3787023|3787023-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291943
3787025|3787025-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291945
3787027|3787027-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291945
3787035|3787035-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904291952
3787129|3787129-b19f-3f77-b713-d32bba55d77f|pass|200904|srezic@cpan.org|Devel-CheckOS|1.55|amd64-freebsd|5.6.2|freebsd|7.0-release|200904292203
3787388|3787388-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904292204
3787390|3787390-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904292204
3787668|3787668-b19f-3f77-b713-d32bba55d77f|pass|200904|stro@cpan.org|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200904300100
3788148|3788148-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300127
3788378|3788378-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Data-Compare|1.21|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200904300152
3788379|3788379-b19f-3f77-b713-d32bba55d77f|pass|200904|mw487.yahoo.com@gmail.com|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200904300152
3788528|3788528-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300343
3788530|3788530-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300346
3788531|3788531-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.6|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300347
3788533|3788533-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200904300348
3791366|3791366-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904301840
3791369|3791369-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904301841
3791933|3791933-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302047
3792051|3792051-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|CPAN-FindDependencies|2.32|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904302114
3792135|3792135-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904302127
3792166|3792166-b19f-3f77-b713-d32bba55d77f|pass|200904|andy@hexten.net|Number-Phone|1.7002|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200904302132
3792346|3792346-b19f-3f77-b713-d32bba55d77f|pass|200904|david@cantrell.org.uk|XML-DoubleEncodedEntities|1.0|alpha-netbsd|5.10.0|netbsd|4.0.1|200904302110
3792434|3792434-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200904302159
3792468|3792468-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Number-Phone|1.7002|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200905010036
3792530|3792530-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-Treo680MessagesDB|1.01|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200905010047
3792552|3792552-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302254
3792558|3792558-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302256
3792562|3792562-b19f-3f77-b713-d32bba55d77f|pass|200904|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200904302257
3793477|3793477-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.5|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905010115
3795838|3795838-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Number-Phone|1.7002|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905010627
3798266|3798266-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200905020231
3798425|3798425-b19f-3f77-b713-d32bba55d77f|pass|200904|pjacklam@cpan.org|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200904301235
3799256|3799256-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905021016
3799831|3799831-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905021209
3800315|3800315-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Compare|1.21|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905021953
3800316|3800316-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Devel-CheckOS|1.61|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905021954
3800592|3800592-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905021455
3801406|3801406-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905021748
3801492|3801492-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905021759
3802701|3802701-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905022301
3802702|3802702-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905022301
3803088|3803088-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.21|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905022257
3803091|3803091-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905022257
3803455|3803455-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905030112
3803632|3803632-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905030100
3803909|3803909-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.31|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905030248
3803912|3803912-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905030249
3804338|3804338-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.31|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905030332
3804343|3804343-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905030335
3804419|3804419-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Number-Phone|1.7002|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905031103
3804824|3804824-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-16-generic|200905030022
3805131|3805131-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux|5.10.0|linux|2.6.24-16-generic|200905030120
3806704|3806704-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.10.0|freebsd|7.0-release|200905031330
3808378|3808378-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200905032119
3809209|3809209-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905040631
3809639|3809639-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905040143
3810091|3810091-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200905040320
3811253|3811253-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux|5.8.9|linux|2.6.24-16-generic|200905040500
3811866|3811866-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.21|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041318
3811869|3811869-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041319
3812299|3812299-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041430
3812829|3812829-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905041555
3813276|3813276-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041126
3813585|3813585-b19f-3f77-b713-d32bba55d77f|pass|200905|robin@smidsrod.no ("Robin Smidsrd")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-19-server|200905041419
3813942|3813942-b19f-3f77-b713-d32bba55d77f|pass|200905|robin@smidsrod.no ("Robin Smidsrd")|Data-Compare|1.21|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.24-19-server|200905041419
3814105|3814105-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041432
3814111|3814111-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041433
3814617|3814617-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905041655
3815130|3815130-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.21|darwin-2level|5.10.0|darwin|8.11.0|200905050033
3815133|3815133-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.10.0|darwin|8.11.0|200905050034
3815377|3815377-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|darwin-2level|5.10.0|darwin|8.11.0|200905050255
3815752|3815752-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050349
3815894|3815894-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|darwin-2level|5.10.0|darwin|8.11.0|200905050518
3816195|3816195-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050121
3816199|3816199-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050121
3816200|3816200-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.6.2|linux|2.6.24-16-generic|200905050122
3816446|3816446-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200905050746
3818121|3818121-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905051139
3819847|3819847-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200905051643
3819849|3819849-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200905051644
3819850|3819850-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200905051644
3819852|3819852-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200905051644
3819854|3819854-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200905051644
3819856|3819856-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200905051644
3820757|3820757-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905051819
3820777|3820777-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905051924
3820784|3820784-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905051826
3820909|3820909-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200905051408
3821101|3821101-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.8.8|freebsd|7.0-release|200905052035
3821247|3821247-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.8.9|freebsd|7.0-release|200905052035
3821470|3821470-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.8.9|linux|2.6.24-16-generic|200905051558
3821645|3821645-b19f-3f77-b713-d32bba55d77f|pass|200905|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.2101|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200905052239
3821794|3821794-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.10.0|netbsd|5.0|200905052300
3821796|3821796-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.10.0|netbsd|5.0|200905052259
3821934|3821934-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051735
3821935|3821935-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051735
3821991|3821991-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051747
3822281|3822281-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd|5.10.0|netbsd|5.0|200905060019
3822495|3822495-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24-16-generic|200905051922
3822681|3822681-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Data-Compare|1.2101|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905051856
3822707|3822707-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|CPAN-FindDependencies|2.32|i386-netbsd|5.10.0|netbsd|5.0|200905060142
3823111|3823111-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.10.0|darwin|8.11.0|200905060219
3824164|3824164-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.2101|i86pc-solaris-64int|5.10.0|solaris|2.11|200905060920
3824202|3824202-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905060941
3824283|3824283-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200905061003
3824544|3824544-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905061050
3824621|3824621-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200905061002
3825050|3825050-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905061123
3825074|3825074-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905061128
3825318|3825318-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905061344
3825400|3825400-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|x86_64-linux|5.8.8|linux|2.6.5-7.276-smp|200905061358
3825446|3825446-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|i586-linux-thread-multi|5.8.8|linux|2.6.16|200905061403
3825468|3825468-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.3|linux|2.6.4|200905061406
3825486|3825486-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905061407
3825508|3825508-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|i586-linux-thread-multi|5.8.5|linux|2.6.8.1|200905061410
3825517|3825517-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Data-Compare|1.2101|i86pc-solaris-64int|5.8.9|solaris|2.11|200905061411
3825562|3825562-b19f-3f77-b713-d32bba55d77f|pass|200905|g.grigelionis@computer.org|Data-Compare|1.2101|i386-linux-thread-multi|5.8.0|linux|2.6.9-22.18.bz155725.elsmp|200905061417
3825962|3825962-b19f-3f77-b713-d32bba55d77f|pass|200905|vovkasm@gmail.com|Data-Compare|1.2101|amd64-freebsd|5.10.0|freebsd|6.2-release-p1|200905061552
3826072|3826072-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905061449
3826074|3826074-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905061449
3826152|3826152-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|IP35-irix-64int|5.8.8|irix|6.5|200905061602
3826166|3826166-b19f-3f77-b713-d32bba55d77f|pass|200905|hohokus@gmail.com|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905061004
3826290|3826290-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905061526
3826417|3826417-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905061550
3826546|3826546-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.10.0|netbsd|5.0|200905061704
3826563|3826563-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905061023
3827217|3827217-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Data-Compare|1.2101|alpha-netbsd|5.10.0|netbsd|4.0.1|200905061724
3827671|3827671-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905062109
3827931|3827931-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905062203
3828033|3828033-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.9|darwin|8.11.0|200905062134
3828035|3828035-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.9|darwin|8.11.0|200905062135
3828077|3828077-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200905062140
3828148|3828148-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200905070000
3828188|3828188-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905062306
3828298|3828298-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|9.2.2|200905062236
3828353|3828353-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905062243
3828363|3828363-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200905062244
3829152|3829152-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Data-Compare|1.2101|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905070209
3829982|3829982-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|CPAN-FindDependencies|2.32|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200905070854
3830653|3830653-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071034
3830742|3830742-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200905071217
3831100|3831100-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.8.9|netbsd|5.0|200905071346
3831101|3831101-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.8.9|netbsd|5.0|200905071346
3831175|3831175-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Devel-CheckLib|0.5|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071323
3831250|3831250-b19f-3f77-b713-d32bba55d77f|unknown|200905|chris@bingosnet.co.uk|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071349
3831510|3831510-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071456
3831525|3831525-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Hexdumper|2.01|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071459
3832947|3832947-b19f-3f77-b713-d32bba55d77f|unknown|200905|imacat@mail.imacat.idv.tw|Acme-Licence|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080400
3832948|3832948-b19f-3f77-b713-d32bba55d77f|unknown|200905|imacat@mail.imacat.idv.tw|Acme-Pony|1.1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080400
3832949|3832949-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080401
3832962|3832962-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|Bryar|3.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080404
3832972|3832972-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Compare|1.2101|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080407
3832976|3832976-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080408
3832977|3832977-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200905072207
3832980|3832980-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080408
3832982|3832982-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080409
3832989|3832989-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080410
3832991|3832991-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Class-CanBeA|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080410
3832998|3832998-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080412
3833012|3833012-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080419
3833014|3833014-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Hexdumper|2.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080419
3833016|3833016-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Data-Transactional|1.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080420
3833020|3833020-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080420
3833022|3833022-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|File-Overwrite|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080421
3833024|3833024-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080421
3833026|3833026-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|NestedMap|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080421
3833038|3833038-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Net-Random|2.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080423
3833043|3833043-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080424
3833046|3833046-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080424
3833049|3833049-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Palm-SMS|0.03|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080425
3833062|3833062-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080427
3833087|3833087-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080429
3833099|3833099-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Sort-MultipleFields|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080429
3833101|3833101-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080429
3833106|3833106-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080430
3833111|3833111-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Sub-WrapPackages|1.2|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080430
3833115|3833115-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080430
3833120|3833120-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080431
3833126|3833126-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Tie-STDOUT|1.0401|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080431
3833128|3833128-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080432
3833131|3833131-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080432
3833134|3833134-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080432
3833138|3833138-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|XML-Tiny|2.02|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080433
3833142|3833142-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905080433
3833917|3833917-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200905072351
3834657|3834657-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080150
3834658|3834658-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080151
3835537|3835537-b19f-3f77-b713-d32bba55d77f|pass|200905|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-16-generic|200905080005
3835831|3835831-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.8.9|netbsd|5.0|200905080644
3835855|3835855-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.8.9|darwin|8.11.0|200905080609
3837093|3837093-b19f-3f77-b713-d32bba55d77f|pass|200905|rbo@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.9|solaris|2.11|200905080929
3837100|3837100-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200905081029
3837610|3837610-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905080414
3837613|3837613-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905080414
3837805|3837805-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905080432
3837806|3837806-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905080432
3839415|3839415-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080729
3839555|3839555-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905080756
3840307|3840307-b19f-3f77-b713-d32bba55d77f|pass|200905|perl@galumph.com|Data-Compare|1.2101|darwin-thread-multi-64int-ld-2level|5.10.0|darwin|9.4.0|200905080844
3840803|3840803-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200905081721
3841304|3841304-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200905081846
3842518|3842518-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckLib|0.5|amd64-freebsd|5.6.2|freebsd|7.0-release|200905082312
3842564|3842564-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.6.2|freebsd|7.0-release|200905082323
3844038|3844038-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.6|darwin|8.11.0|200905090349
3844043|3844043-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.6|darwin|8.11.0|200905090350
3844277|3844277-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905090423
3844392|3844392-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905090347
3845155|3845155-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905090843
3845610|3845610-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200905091108
3845653|3845653-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905091119
3845692|3845692-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905091127
3845871|3845871-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905091203
3845896|3845896-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905091211
3845937|3845937-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905091221
3845972|3845972-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200905091229
3846010|3846010-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905091236
3846040|3846040-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905091244
3846042|3846042-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200905091245
3846132|3846132-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200905091301
3846230|3846230-b19f-3f77-b713-d32bba55d77f|pass|200905|Michael.Finken@rbs.com|Data-Compare|1.2101|sun4-solaris-thread-multi|5.8.9|solaris|2.8|200905071143
3846231|3846231-b19f-3f77-b713-d32bba55d77f|pass|200905|Michael.Finken@rbs.com|Devel-CheckOS|1.61|sun4-solaris-thread-multi|5.8.9|solaris|2.8|200905071151
3846475|3846475-b19f-3f77-b713-d32bba55d77f|pass|200905|pjacklam@cpan.org|Data-Compare|1.2101|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905072052
3846601|3846601-b19f-3f77-b713-d32bba55d77f|fail|200905|rlane10@wi.rr.com|CPAN-FindDependencies|2.32|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200905080144
3846660|3846660-b19f-3f77-b713-d32bba55d77f|pass|200905|rlane10@wi.rr.com|Data-Compare|1.2101|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5xen|200905080024
3846786|3846786-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan-testing@yorfeix.de ("yor_feix")|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905071553
3847214|3847214-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905091431
3847567|3847567-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200905091522
3847642|3847642-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905091531
3847897|3847897-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905091607
3847962|3847962-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905091613
3848116|3848116-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200905091624
3848503|3848503-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905091727
3848606|3848606-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905091744
3848749|3848749-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200905091809
3849492|3849492-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24.5-smp|200905092012
3849637|3849637-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.8.8|linux|2.6.18.3|200905092050
3850622|3850622-b19f-3f77-b713-d32bba55d77f|pass|200905|rafl@debian.org|Data-Compare|1.2101|i686-linux|5.10.0 patch 35117|linux|2.6.26|200905100223
3851730|3851730-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905100302
3851774|3851774-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905100313
3852002|3852002-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905100338
3852262|3852262-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905100417
3853665|3853665-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905101236
3853671|3853671-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905101237
3854722|3854722-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Data-Compare|1.2101|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905100830
3855295|3855295-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.8.6|darwin|8.11.0|200905102223
3855569|3855569-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905101855
3855634|3855634-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905101856
3855879|3855879-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905101902
3855946|3855946-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905101904
3858048|3858048-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Data-Compare|1.2101|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905110512
3858635|3858635-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905110649
3860091|3860091-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Data-Compare|1.2101|i686-linux|5.10.0 patch 32633|linux|2.6.18-4-486|200905111645
3860111|3860111-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckLib|0.5|i686-linux|5.10.0 patch 32633|linux|2.6.18-4-486|200905111648
3860902|3860902-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111419
3860933|3860933-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111419
3861309|3861309-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111418
3861313|3861313-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200905112059
3861333|3861333-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905112100
3861384|3861384-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111429
3862002|3862002-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200905112201
3862199|3862199-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905111710
3862234|3862234-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905111711
3862278|3862278-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905111712
3862352|3862352-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905111714
3862963|3862963-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905111703
3863142|3863142-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905120049
3865415|3865415-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.24.5-smp|200905121106
3865931|3865931-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121445
3865970|3865970-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905121503
3866432|3866432-b19f-3f77-b713-d32bba55d77f|pass|200905|klaus+cpanplus@worstofall.com|XML-Tiny|2.02|x86_64-linux|5.10.0|linux|2.6.26-2-amd64|200905112307
3866600|3866600-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121648
3866672|3866672-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905121707
3867298|3867298-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121243
3867367|3867367-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905121244
3867430|3867430-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.6|darwin|8.11.0|200905121814
3867688|3867688-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121300
3867833|3867833-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121302
3867891|3867891-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121303
3868034|3868034-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121244
3868356|3868356-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121303
3868361|3868361-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905121303
3868443|3868443-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905121243
3868567|3868567-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905121300
3871030|3871030-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.61|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905130330
3871670|3871670-b19f-3f77-b713-d32bba55d77f|pass|200905|carlos.arenas@gmail.com ("Carlos Arenas")|Data-Compare|1.2101|i686-linux-thread-multi|5.10.0|linux|2.6.25-arch|200905121109
3871692|3871692-b19f-3f77-b713-d32bba55d77f|pass|200905|feldt@nhn.ou.edu|Data-Compare|1.2101|sun4-solaris-thread-multi|5.8.8|solaris|2.8|200905121226
3872252|3872252-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905131201
3872925|3872925-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200905131418
3873301|3873301-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.8|darwin|8.11.0|200905131507
3873855|3873855-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905131652
3874469|3874469-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905131410
3874619|3874619-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905131408
3875271|3875271-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905131411
3876132|3876132-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140210
3876210|3876210-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140219
3876448|3876448-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140250
3876779|3876779-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905140328
3876804|3876804-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140331
3876981|3876981-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905140345
3877074|3877074-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140352
3877257|3877257-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140410
3877258|3877258-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140411
3877362|3877362-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140422
3877414|3877414-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905140438
3877416|3877416-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905140438
3877425|3877425-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905140442
3878463|3878463-b19f-3f77-b713-d32bba55d77f|pass|200905|kamensky@cpan.org ("Moshe Kamensky")|Data-Compare|1.2101|sun4-solaris|5.10.0|solaris|2.8|200905131225
3879203|3879203-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.9|darwin|8.11.0|200905141049
3880320|3880320-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckOS|1.61|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905140409
3880943|3880943-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905141715
3881666|3881666-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905142001
3882265|3882265-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Compare|1.2101|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905141320
3882267|3882267-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckOS|1.61|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905141320
3882980|3882980-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905150019
3883140|3883140-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905141850
3883335|3883335-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905141852
3883482|3883482-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905141855
3883501|3883501-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905141855
3883535|3883535-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905141855
3883537|3883537-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905141855
3883539|3883539-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905141855
3883692|3883692-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905141852
3883995|3883995-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|8.11.0|200905150130
3884008|3884008-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905150033
3885227|3885227-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905150541
3885426|3885426-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905150423
3887461|3887461-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905150634
3887713|3887713-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150637
3887855|3887855-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905150638
3887899|3887899-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150638
3888062|3888062-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905150635
3888540|3888540-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150638
3888600|3888600-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckLib|0.5|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905150204
3888996|3888996-b19f-3f77-b713-d32bba55d77f|fail|200905|wiml@hhhh.org ("Wim Lewis")|CPAN-FindDependencies|2.32|powerpc-netbsd-thread-multi|5.8.8|netbsd|4.0|200905150235
3889160|3889160-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905150638
3890023|3890023-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200905151545
3890319|3890319-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905150826
3892169|3892169-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905152241
3892171|3892171-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905152241
3892187|3892187-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.5|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905152243
3893299|3893299-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905160258
3893392|3893392-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.6|darwin|8.0|200905160516
3893393|3893393-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.6|darwin|8.0|200905160516
3893785|3893785-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905160411
3895555|3895555-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200905161150
3895659|3895659-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.8|darwin|8.11.0|200905161212
3896788|3896788-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200905161745
3896885|3896885-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.8|darwin|8.11.0|200905161810
3899197|3899197-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905170318
3899239|3899239-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905170323
3899385|3899385-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170340
3899597|3899597-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170418
3899616|3899616-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905170423
3899744|3899744-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170533
3901568|3901568-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170849
3901736|3901736-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170850
3902510|3902510-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905170849
3902754|3902754-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905170853
3903810|3903810-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|8.11.0|200905171913
3903814|3903814-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|darwin-2level|5.10.0|darwin|8.11.0|200905171913
3905748|3905748-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-2level|5.8.8|darwin|8.11.0|200905172206
3905792|3905792-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|darwin-2level|5.8.8|darwin|8.11.0|200905172324
3905794|3905794-b19f-3f77-b713-d32bba55d77f|pass|200905|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|darwin-2level|5.8.8|darwin|8.11.0|200905172325
3906054|3906054-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905171815
3906970|3906970-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180205
3906972|3906972-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905180205
3907796|3907796-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905180339
3910154|3910154-b19f-3f77-b713-d32bba55d77f|fail|200905|DCOLLINS@cpan.org|Bryar|3.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180739
3910597|3910597-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905180742
3911090|3911090-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905181353
3912678|3912678-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckLib|0.5|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905180926
3912774|3912774-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckLib|0.5|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905180937
3912968|3912968-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|CPAN-FindDependencies|2.32|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905181003
3912977|3912977-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905181004
3912993|3912993-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.10.0|freebsd|7.0-release|200905181900
3914278|3914278-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905182139
3915712|3915712-b19f-3f77-b713-d32bba55d77f|pass|200905|greg@ie-entertainment.com|Number-Phone|1.7002|i386-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200905190111
3918395|3918395-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905190739
3922256|3922256-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200905200604
3923626|3923626-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905201215
3925267|3925267-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200905201549
3925269|3925269-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905201550
3925270|3925270-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200905201550
3925276|3925276-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.26-1-amd64|200905201549
3925278|3925278-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905201550
3925279|3925279-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200905201549
3925282|3925282-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200905201549
3925284|3925284-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200905201550
3925287|3925287-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200905201550
3925288|3925288-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckLib|0.6|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200905201550
3926043|3926043-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905201821
3926195|3926195-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.8.8|freebsd|7.0-release|200905201843
3926207|3926207-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.8.9|freebsd|7.0-release|200905201843
3926255|3926255-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905201855
3926260|3926260-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905201855
3926301|3926301-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905201855
3926309|3926309-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905201855
3926349|3926349-b19f-3f77-b713-d32bba55d77f|fail|200905|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Devel-CheckLib|0.6|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200905210212
3927224|3927224-b19f-3f77-b713-d32bba55d77f|pass|200905|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.6|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200905202240
3927536|3927536-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210821
3927537|3927537-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210822
3927602|3927602-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210845
3927655|3927655-b19f-3f77-b713-d32bba55d77f|pass|200905|chris@bingosnet.co.uk|Devel-CheckLib|0.6|i386-netbsd-thread-multi-64int|5.8.8|netbsd|3.1|200905210001
3927702|3927702-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905210009
3930716|3930716-b19f-3f77-b713-d32bba55d77f|pass|200905|imacat@mail.imacat.idv.tw|Devel-CheckLib|0.6|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905211947
3931297|3931297-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905211335
3931371|3931371-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905211342
3931388|3931388-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905211343
3931429|3931429-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905211347
3931632|3931632-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905211406
3932334|3932334-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|IP35-irix-64int|5.8.8|irix|6.5|200905211604
3932445|3932445-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905210919
3933523|3933523-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220344
3933614|3933614-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905211900
3933643|3933643-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905211904
3934778|3934778-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905220810
3935179|3935179-b19f-3f77-b713-d32bba55d77f|pass|200905|david@cantrell.org.uk|Devel-CheckLib|0.6|alpha-netbsd|5.10.0|netbsd|4.0.1|200905220006
3938115|3938115-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200905221125
3938234|3938234-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221943
3938256|3938256-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221945
3938262|3938262-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905221946
3938458|3938458-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200905221223
3938461|3938461-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905222024
3938864|3938864-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200905221259
3939137|3939137-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200905221335
3939243|3939243-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200905221354
3939522|3939522-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200905221434
3939563|3939563-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905221335
3939622|3939622-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200905221448
3939738|3939738-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905221508
3940204|3940204-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230027
3941123|3941123-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905221735
3941189|3941189-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.6|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200905221145
3941639|3941639-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230357
3941641|3941641-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230358
3941642|3941642-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230358
3941779|3941779-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200905221923
3942045|3942045-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200905222137
3942342|3942342-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905230653
3943144|3943144-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905230040
3944102|3944102-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905230302
3944728|3944728-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905230433
3944815|3944815-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905231451
3945760|3945760-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905232013
3945825|3945825-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905232042
3946896|3946896-b19f-3f77-b713-d32bba55d77f|pass|200905|rbo@cpan.org|Devel-CheckLib|0.6|i86pc-solaris|5.8.9|solaris|2.11|200905231646
3947217|3947217-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-netbsd-thread-multi-64int|5.10.0|netbsd|3.1|200905231618
3947452|3947452-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckOS|1.61|i686-linux|5.8.8|linux|2.4.27-2-386|200905231922
3947614|3947614-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|File-Overwrite|1.1|i686-linux|5.8.8|linux|2.4.27-2-386|200905231954
3947767|3947767-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.10.0|darwin|8.11.0|200905231819
3948401|3948401-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-SMS|0.03|i686-linux|5.8.8|linux|2.4.27-2-386|200905232253
3948791|3948791-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905232224
3948813|3948813-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200905232227
3949841|3949841-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240102
3949982|3949982-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200905240207
3950088|3950088-b19f-3f77-b713-d32bba55d77f|pass|200905|wiml@hhhh.org ("Wim Lewis")|Devel-CheckLib|0.6|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200905240126
3950261|3950261-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240142
3950486|3950486-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200905240223
3950687|3950687-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200905240426
3951877|3951877-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905240427
3952325|3952325-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-dragonfly-64int|5.10.0|dragonfly|2.0.0-release|200905241455
3952328|3952328-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.4.27-2-386|200905240628
3952344|3952344-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.4.27-2-386|200905240636
3952453|3952453-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.4.27-2-386|200905240701
3952511|3952511-b19f-3f77-b713-d32bba55d77f|pass|200905|mw487.yahoo.com@gmail.com|Devel-CheckLib|0.6|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905240944
3953078|3953078-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckLib|0.6|armv5tejl-linux|5.10.0|linux|2.6.17.14|200905241945
3953266|3953266-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200905241909
3953486|3953486-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200905242001
3953672|3953672-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200905242024
3953722|3953722-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200905242032
3953754|3953754-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Number-Phone|1.7002|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241138
3953938|3953938-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200905242105
3954098|3954098-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|File-Overwrite|1.1|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241227
3954103|3954103-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241228
3954111|3954111-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241228
3954159|3954159-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905241234
3954699|3954699-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905242217
3955185|3955185-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.6|i86pc-solaris-64int|5.10.0|solaris|2.11|200905250042
3955619|3955619-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250031
3955905|3955905-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|File-Overwrite|1.1|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250057
3955907|3955907-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Hexdumper|2.01|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250057
3955909|3955909-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250057
3955933|3955933-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905250101
3956048|3956048-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905250225
3956252|3956252-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250305
3957235|3957235-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.10.0|linux|2.6.18-92.el5|200905250831
3957520|3957520-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200905250916
3957715|3957715-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905250823
3957939|3957939-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200905251031
3957957|3957957-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905250930
3958002|3958002-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200905251043
3958219|3958219-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905251120
3958335|3958335-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200905251150
3958478|3958478-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200905251218
3958767|3958767-b19f-3f77-b713-d32bba55d77f|pass|200905|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.6|i86pc-solaris-64int|5.8.9|solaris|2.11|200905251230
3959198|3959198-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Tie-STDOUT|1.0401|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905251349
3960221|3960221-b19f-3f77-b713-d32bba55d77f|pass|200905|vpit@cpan.org|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200905252113
3960390|3960390-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200905251912
3960539|3960539-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200905251513
3962550|3962550-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.8.6|darwin|8.11.0|200905252356
3965875|3965875-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.10.0|freebsd|7.0-release|200905261205
3966727|3966727-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckLib|0.6|i686-linux|5.8.9|linux|2.6.26-2-686|200905261824
3968082|3968082-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-ParseDistribution|1.1|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261024
3968092|3968092-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-ParseDistribution|1.1|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261025
3968515|3968515-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Data-Compare|1.2101|i686-linux|5.8.9|linux|2.6.26-2-686|200905262307
3969871|3969871-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905261614
3970073|3970073-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|XML-Tiny-DOM|1.0|darwin-thread-multi-2level|5.10.0|darwin|9.1.0|200905262208
3970201|3970201-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905262216
3970785|3970785-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905261800
3970934|3970934-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-ProjectGutenberg|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261541
3970936|3970936-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|XML-Tiny|2.02|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261541
3970938|3970938-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|XML-Tiny-DOM|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261541
3971071|3971071-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-ProjectGutenberg|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261550
3971075|3971075-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|XML-Tiny|2.02|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261550
3971076|3971076-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|XML-Tiny-DOM|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905261550
3971674|3971674-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905270115
3971991|3971991-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200905270327
3972414|3972414-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905270243
3973221|3973221-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905270710
3974511|3974511-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200905271220
3974512|3974512-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200905271220
3974716|3974716-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905270628
3974999|3974999-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200905271309
3975011|3975011-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|alpha-linux-thread-multi|5.8.8|linux|2.6.18-5-alpha-generic|200905271212
3975338|3975338-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200905271406
3975400|3975400-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-FindDependencies|2.32|i686-linux|5.8.9|linux|2.6.26-2-686|200905271024
3975401|3975401-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|CPAN-ParseDistribution|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200905271024
3975848|3975848-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200905271536
3976253|3976253-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200905271657
3976401|3976401-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.8|freebsd|6.4-release|200905270931
3977908|3977908-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200905271951
3978979|3978979-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|File-Overwrite|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200905271655
3978981|3978981-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Data-Hexdumper|2.01|i686-linux|5.8.9|linux|2.6.26-2-686|200905271656
3978983|3978983-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Palm-Treo680MessagesDB|1.01|i686-linux|5.8.9|linux|2.6.26-2-686|200905271656
3979017|3979017-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Palm-ProjectGutenberg|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905271734
3979020|3979020-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|XML-Tiny|2.02|i686-linux|5.8.9|linux|2.6.26-2-686|200905271734
3979021|3979021-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|XML-Tiny-DOM|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905271734
3979028|3979028-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.8.8|darwin|8.11.0|200905272138
3979302|3979302-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|XML-DoubleEncodedEntities|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905271700
3979873|3979873-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Devel-CheckOS|1.61|i686-linux|5.8.9|linux|2.6.26-2-686|200905271507
3981894|3981894-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Tie-STDOUT|1.0401|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280049
3982598|3982598-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905282034
3983062|3983062-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Tie-STDOUT|1.0401|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905280359
3983205|3983205-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Number-Phone|1.7002|i686-linux|5.8.9|linux|2.6.26-2-686|200905281629
3983344|3983344-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Tie-STDOUT|1.0401|i686-linux|5.8.9|linux|2.6.26-2-686|200905281634
3983422|3983422-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200905281215
3983946|3983946-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905281707
3984043|3984043-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905282148
3984149|3984149-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905282153
3984548|3984548-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|File-Find-Rule-Permissions|2.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905281742
3984562|3984562-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Class-DBI-ClassGenerator|1.02|i686-linux|5.8.9|linux|2.6.26-2-686|200905281742
3984915|3984915-b19f-3f77-b713-d32bba55d77f|fail|200905|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282232
3985574|3985574-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@rail.org.ua|Bryar|3.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905281833
3985825|3985825-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Palm-SMS|0.03|i686-linux|5.8.9|linux|2.6.26-2-686|200905281851
3985970|3985970-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-SMS|0.03|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905282335
3987353|3987353-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905281706
3988264|3988264-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Devel-CheckLib|0.6|i686-linux|5.8.8|linux|2.4.27-2-386|200905282049
3988417|3988417-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905281918
3989560|3989560-b19f-3f77-b713-d32bba55d77f|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200905282354
3989568|3989568-b19f-3f77-b713-d32bba55d77f|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200905282355
3989571|3989571-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200905282355
3989572|3989572-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200905282356
3989574|3989574-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200905282356
3990031|3990031-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905290037
3990082|3990082-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905290057
3990807|3990807-b19f-3f77-b713-d32bba55d77f|fail|200905|taro-nishino@wine.ocn.ne.jp ("Taro Nishino")|Bryar|3.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200905291154
3991125|3991125-b19f-3f77-b713-d32bba55d77f|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.24-1-amd64|200905290549
3991126|3991126-b19f-3f77-b713-d32bba55d77f|fail|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200905290549
3991246|3991246-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200905290549
3991253|3991253-b19f-3f77-b713-d32bba55d77f|pass|200905|andreas.koenig.gmwojprw@franz.ak.mind.de|Bryar|3.1|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200905290549
3991583|3991583-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905290557
3991834|3991834-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200905290756
3991926|3991926-b19f-3f77-b713-d32bba55d77f|pass|200905|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200905290756
3992757|3992757-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Bryar|3.1|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905290228
3992912|3992912-b19f-3f77-b713-d32bba55d77f|fail|200905|stro@cpan.org|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905290241
3993559|3993559-b19f-3f77-b713-d32bba55d77f|fail|200905|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200905291309
3993797|3993797-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Sort-MultipleFields|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905291225
3994359|3994359-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|DBIx-Class-SingletonRows|0.11|i686-linux|5.8.9|linux|2.6.26-2-686|200905291332
3994449|3994449-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.8.9|freebsd|6.4-release|200905291345
3994539|3994539-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Data-Transactional|1.02|i686-linux|5.8.9|linux|2.6.26-2-686|200905291345
3994589|3994589-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPU-Emulator-Memory|1.1001|i686-linux|5.8.9|linux|2.6.26-2-686|200905291349
3994590|3994590-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|CPU-Emulator-Z80|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905291349
3994595|3994595-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905291356
3994722|3994722-b19f-3f77-b713-d32bba55d77f|fail|200905|JOST@cpan.org ("Josts Smokehouse")|Bryar|3.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200905291506
3994987|3994987-b19f-3f77-b713-d32bba55d77f|fail|200905|imacat@mail.imacat.idv.tw|Bryar|3.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200905292159
3995908|3995908-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300347
3995915|3995915-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300349
3995917|3995917-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300350
3996155|3996155-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905300447
3996165|3996165-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200905291955
3996341|3996341-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Bryar|3.1|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905292019
3996596|3996596-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200905292119
3997084|3997084-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200905292253
3997096|3997096-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200905292153
3997099|3997099-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200905292253
3997101|3997101-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200905292253
3997184|3997184-b19f-3f77-b713-d32bba55d77f|fail|200905|david@cantrell.org.uk|Bryar|3.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200905291712
3997908|3997908-b19f-3f77-b713-d32bba55d77f|fail|200905|bingos@cpan.org|Bryar|3.1|i386-freebsd|5.10.0|freebsd|6.4-release|200905300219
3998783|3998783-b19f-3f77-b713-d32bba55d77f|fail|200905|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301407
3998904|3998904-b19f-3f77-b713-d32bba55d77f|fail|200905|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200905301428
3999037|3999037-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Bryar|3.1|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200905300555
4000121|4000121-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905300232
4000627|4000627-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905300226
4001072|4001072-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905301917
4001125|4001125-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905300137
4001649|4001649-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905302148
4002805|4002805-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905302344
4002899|4002899-b19f-3f77-b713-d32bba55d77f|fail|200905|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.10.0|freebsd|7.0-release|200905301546
4003256|4003256-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310010
4003265|4003265-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310011
4003268|4003268-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310011
4005304|4005304-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905310250
4005777|4005777-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301333
4005881|4005881-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301340
4005950|4005950-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301042
4005957|4005957-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301042
4006119|4006119-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301333
4008247|4008247-b19f-3f77-b713-d32bba55d77f|fail|200905|mw487.yahoo.com@gmail.com|Bryar|3.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200905301541
4009276|4009276-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|File-Find-Rule-Permissions|2.0|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301521
4009283|4009283-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301821
4009291|4009291-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|File-Find-Rule-Permissions|2.0|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301521
4009296|4009296-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301822
4009317|4009317-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301824
4009342|4009342-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200905301827
4009351|4009351-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200905301827
4009385|4009385-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905301830
4009704|4009704-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301622
4009714|4009714-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905301622
4010371|4010371-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311033
4010784|4010784-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905310158
4012260|4012260-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd|5.10.0|freebsd|6.4-release|200905310442
4012729|4012729-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200905310448
4012956|4012956-b19f-3f77-b713-d32bba55d77f|pass|200905|rbo@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.10.0|solaris|2.11|200905310735
4013380|4013380-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311629
4013417|4013417-b19f-3f77-b713-d32bba55d77f|pass|200905|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200905311643
4013821|4013821-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd|5.10.0|freebsd|6.4-release|200905310831
4013828|4013828-b19f-3f77-b713-d32bba55d77f|pass|200905|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd|5.10.0|freebsd|6.4-release|200905310832
4014333|4014333-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905310441
4014385|4014385-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-SMS|0.03|x86_64-linux|5.10.0|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310201
4014390|4014390-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@cpan.org|Palm-SMS|0.03|x86_64-linux|5.8.9|linux|2.6.24.5-xeon-aufs20081006-grsec|200905310201
4014604|4014604-b19f-3f77-b713-d32bba55d77f|fail|200905|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200905310547
4015699|4015699-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905311413
4015704|4015704-b19f-3f77-b713-d32bba55d77f|pass|200905|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200905311414
4015847|4015847-b19f-3f77-b713-d32bba55d77f|pass|200905|angryxpeh@gmail.com|Net-Random|2.0|i686-linux|5.8.9|linux|2.6.26-2-686|200905311817
4016104|4016104-b19f-3f77-b713-d32bba55d77f|pass|200905|stro@rail.org.ua|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.8.9|linux|2.6.26-2-686|200905311841
4018412|4018412-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200905312041
4018415|4018415-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200905312042
4018625|4018625-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Devel-CheckLib|0.6|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200905312118
4018635|4018635-b19f-3f77-b713-d32bba55d77f|pass|200905|andy@hexten.net|Devel-CheckOS|1.61|i686-linux-thread-multi|5.10.0|linux|2.6.20-16-server|200905312118
4019337|4019337-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Palm-SMS|0.03|i686-linux-thread-multi-64int-ld|5.8.9|linux|2.6.28-11-generic|200906010755
4019599|4019599-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905311818
4019613|4019613-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200905311818
4019880|4019880-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905311818
4019975|4019975-b19f-3f77-b713-d32bba55d77f|pass|200905|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200905311818
4020116|4020116-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200906010020
4020384|4020384-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906010001
4020468|4020468-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906010011
4022257|4022257-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200906010824
4022258|4022258-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.8.9|darwin|8.11.0|200906010825
4023320|4023320-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011123
4023333|4023333-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011124
4023338|4023338-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011125
4023444|4023444-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906011140
4023447|4023447-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906011141
4023828|4023828-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906011254
4023836|4023836-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906011254
4024227|4024227-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011339
4025018|4025018-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906010949
4025027|4025027-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906010949
4025434|4025434-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200906011520
4025448|4025448-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200906011521
4025790|4025790-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906010949
4025799|4025799-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906010949
4026013|4026013-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906011553
4027417|4027417-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.10.0|darwin|8.11.0|200906011750
4027797|4027797-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906011344
4028316|4028316-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906011344
4028841|4028841-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011455
4029091|4029091-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Games-Dice-Advanced|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906012212
4029138|4029138-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011457
4029140|4029140-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906011457
4029816|4029816-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906012151
4029830|4029830-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Sub-WrapPackages|1.2|i686-linux|5.8.9|linux|2.6.26-2-686|200906012252
4030253|4030253-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200906012221
4030498|4030498-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906011455
4030818|4030818-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906012308
4032104|4032104-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906020014
4032230|4032230-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906011807
4032457|4032457-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906020038
4033019|4033019-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906020121
4033048|4033048-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906020123
4033246|4033246-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906020138
4033613|4033613-b19f-3f77-b713-d32bba55d77f|fail|200906|DCOLLINS@cpan.org|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020005
4033822|4033822-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200906020219
4033841|4033841-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200906020120
4034656|4034656-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020119
4034683|4034683-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020120
4034978|4034978-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906020341
4035010|4035010-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200906020242
4036502|4036502-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906020008
4036866|4036866-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906020106
4037766|4037766-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906020904
4038098|4038098-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Compare|1.2101|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906021009
4038406|4038406-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200906021105
4038411|4038411-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200906021106
4039570|4039570-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906020621
4039591|4039591-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020621
4039593|4039593-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020621
4039672|4039672-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906021204
4040187|4040187-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020625
4040188|4040188-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020625
4040313|4040313-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906020627
4040314|4040314-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020627
4040315|4040315-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020627
4040612|4040612-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020628
4040616|4040616-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020629
4041724|4041724-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020636
4041728|4041728-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020636
4042015|4042015-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020638
4042018|4042018-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020638
4042251|4042251-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200906021544
4042337|4042337-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.0-release|200906021450
4042410|4042410-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906021456
4042573|4042573-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200906021605
4042619|4042619-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906021607
4042977|4042977-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020645
4042981|4042981-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020645
4042999|4042999-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020645
4043000|4043000-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020645
4043001|4043001-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020645
4043511|4043511-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020621
4043513|4043513-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020621
4043521|4043521-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020621
4043772|4043772-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020625
4044558|4044558-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020636
4044562|4044562-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020636
4044564|4044564-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200906021821
4044666|4044666-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020638
4044676|4044676-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020638
4044861|4044861-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200906021846
4044891|4044891-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906021845
4044969|4044969-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200906021856
4045029|4045029-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906021900
4045037|4045037-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906020645
4045039|4045039-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020645
4045049|4045049-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906020645
4045066|4045066-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906020645
4045160|4045160-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906021913
4045378|4045378-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.5|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906020627
4046395|4046395-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906022048
4046525|4046525-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021402
4046528|4046528-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021402
4046771|4046771-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021404
4047069|4047069-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021407
4047073|4047073-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021407
4047985|4047985-b19f-3f77-b713-d32bba55d77f|pass|200906|schwern@pobox.com|Data-Compare|1.2101|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200906021052
4047991|4047991-b19f-3f77-b713-d32bba55d77f|pass|200906|schwern@pobox.com|Devel-CheckOS|1.61|darwin-thread-multi-2level|5.10.0|darwin|8.11.1|200906021057
4048772|4048772-b19f-3f77-b713-d32bba55d77f|fail|200906|srezic@cpan.org|Bryar|3.1|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200906022339
4048819|4048819-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021422
4048820|4048820-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021422
4048934|4048934-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021423
4048937|4048937-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906021423
4049386|4049386-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.8.6|darwin|8.11.0|200906022347
4049532|4049532-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021422
4049989|4049989-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906021407
4050196|4050196-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Class-CanBeA|1.2|i686-linux|5.8.9|linux|2.6.26-2-686|200906021245
4050204|4050204-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906021402
4050276|4050276-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021425
4050439|4050439-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906021425
4050880|4050880-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906022358
4050996|4050996-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030008
4051133|4051133-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030017
4051694|4051694-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030055
4051725|4051725-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030058
4051751|4051751-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906030159
4051813|4051813-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030102
4051840|4051840-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030104
4052180|4052180-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030127
4052221|4052221-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030131
4052398|4052398-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030143
4052442|4052442-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030146
4052539|4052539-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030153
4052550|4052550-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906030354
4052574|4052574-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@cpan.org|Bryar|3.1|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906030456
4052611|4052611-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030159
4052705|4052705-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906030406
4054379|4054379-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906030020
4054443|4054443-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906030426
4054486|4054486-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.8.9|linux|2.6.28-11-generic|200906030530
4054528|4054528-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906030033
4054862|4054862-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030505
4055782|4055782-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030612
4056092|4056092-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030633
4057256|4057256-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906030846
4057732|4057732-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030815
4058071|4058071-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030840
4058848|4058848-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906030937
4058853|4058853-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906030937
4058877|4058877-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906030939
4060816|4060816-b19f-3f77-b713-d32bba55d77f|fail|200906|stsc@refcnt.org ("Steven Schubiger")|Bryar|3.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200906031359
4060950|4060950-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906031307
4061140|4061140-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906030820
4062046|4062046-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200906031532
4063069|4063069-b19f-3f77-b713-d32bba55d77f|pass|200906|bminton@integ.com (Brian Minton)|CPAN-ParseDistribution|1.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200906031051
4063532|4063532-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906031623
4063658|4063658-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906031132
4064360|4064360-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200906031828
4065150|4065150-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906031940
4065594|4065594-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906030642
4065744|4065744-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906031928
4066091|4066091-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906031901
4066473|4066473-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906032149
4066595|4066595-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.8.8|darwin|8.11.0|200906032107
4067174|4067174-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906032307
4068240|4068240-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906032234
4069722|4069722-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040023
4069762|4069762-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200906040227
4070061|4070061-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906040110
4070081|4070081-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1049-g5f1c709|linux|2.6.28-11-generic|200906040114
4070241|4070241-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200906040236
4071032|4071032-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906040634
4071178|4071178-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906040705
4071435|4071435-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200906040758
4071944|4071944-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040310
4071947|4071947-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040311
4071950|4071950-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040312
4072917|4072917-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906041032
4074002|4074002-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200906041313
4074158|4074158-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200906041324
4074628|4074628-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040645
4074668|4074668-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200906041305
4074681|4074681-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906040645
4074785|4074785-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906040813
4075624|4075624-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Bryar|3.1|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.0-release|200906041417
4076574|4076574-b19f-3f77-b713-d32bba55d77f|fail|200906|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.6.2|freebsd|7.0-release|200906041624
4076787|4076787-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041044
4076813|4076813-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041046
4076817|4076817-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041047
4076839|4076839-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-24-generic|200906041547
4076906|4076906-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906040716
4076907|4076907-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906040716
4078890|4078890-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906041958
4079026|4079026-b19f-3f77-b713-d32bba55d77f|pass|200906|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.6.2|freebsd|7.0-release|200906042009
4079101|4079101-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906040716
4079528|4079528-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906042054
4080041|4080041-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906041402
4080042|4080042-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041403
4080044|4080044-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041403
4080151|4080151-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041953
4080225|4080225-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041404
4080265|4080265-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906041405
4080268|4080268-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041405
4080298|4080298-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906041405
4080727|4080727-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906042045
4082647|4082647-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906042241
4082901|4082901-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Bryar|3.1|darwin-2level|5.8.9|darwin|8.11.0|200906042354
4083377|4083377-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906041403
4083393|4083393-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906041403
4083445|4083445-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200906050125
4083492|4083492-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906041929
4084374|4084374-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050048
4084661|4084661-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906050114
4084690|4084690-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906050116
4084891|4084891-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906050336
4085845|4085845-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906050339
4085850|4085850-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906050339
4085888|4085888-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050343
4085890|4085890-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050343
4085891|4085891-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906050343
4086354|4086354-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200906050649
4086975|4086975-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906050708
4087283|4087283-b19f-3f77-b713-d32bba55d77f|fail|200906|martin.evans@easysoft.com|Bryar|3.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200906050919
4088541|4088541-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906051551
4088634|4088634-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.10.0|darwin|8.11.0|200906051506
4089438|4089438-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906051250
4089807|4089807-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906051842
4090056|4090056-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906052004
4090371|4090371-b19f-3f77-b713-d32bba55d77f|fail|200906|vpit@cpan.org|Bryar|3.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.26.3-fuuka.profvince.com|200906052021
4090985|4090985-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|darwin-64int-2level|5.10.0|darwin|8.11.0|200906052002
4091042|4091042-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091064|4091064-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051407
4091090|4091090-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906051407
4092162|4092162-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Tie-Hash-Longest|1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906060217
4092166|4092166-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Statistics-ChiSquare|0.5|i686-linux|5.8.9|linux|2.6.26-2-686|200906060217
4092419|4092419-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906051416
4092650|4092650-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906051644
4093529|4093529-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|NestedMap|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200906060335
4095378|4095378-b19f-3f77-b713-d32bba55d77f|unknown|200906|stro@rail.org.ua|Acme-Licence|1.0|i686-linux|5.8.9|linux|2.6.26-2-686|200906060527
4096126|4096126-b19f-3f77-b713-d32bba55d77f|fail|200906|bingos@cpan.org|Bryar|3.1|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906060113
4096130|4096130-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060016
4096721|4096721-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060052
4097751|4097751-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060230
4098588|4098588-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060357
4099037|4099037-b19f-3f77-b713-d32bba55d77f|pass|200906|wiml@hhhh.org ("Wim Lewis")|Number-Phone|1.7002|powerpc-netbsd-thread-multi|5.10.0|netbsd|5.0_rc3|200906060448
4099403|4099403-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200906060743
4099462|4099462-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906060749
4099516|4099516-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060556
4099886|4099886-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060635
4100288|4100288-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906060714
4100537|4100537-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060743
4100598|4100598-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906060750
4100846|4100846-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060816
4101107|4101107-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906060849
4101805|4101805-b19f-3f77-b713-d32bba55d77f|unknown|200906|angryxpeh@gmail.com|Acme-Pony|1.1.2|i686-linux|5.8.9|linux|2.6.26-2-686|200906061603
4101861|4101861-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906061608
4101912|4101912-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux|5.8.9|linux|2.6.26-2-686|200906061613
4102520|4102520-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200906061251
4103536|4103536-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061417
4103574|4103574-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061419
4103771|4103771-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200906061428
4104632|4104632-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061401
4104755|4104755-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200906061401
4106121|4106121-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@rail.org.ua|Bryar|3.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906062026
4106719|4106719-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906061043
4107433|4107433-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.26-2-686|200906062144
4107804|4107804-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.26-2-686|200906062205
4107842|4107842-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Devel-CheckLib|0.6|i686-linux|5.10.0|linux|2.6.26-2-686|200906062206
4108975|4108975-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906060830
4109420|4109420-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906060833
4109422|4109422-b19f-3f77-b713-d32bba55d77f|pass|200906|DCOLLINS@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906060833
4110126|4110126-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.10.0|darwin|8.11.0|200906061933
4110635|4110635-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.32|i686-linux|5.10.0|linux|2.6.26-2-686|200906070126
4111202|4111202-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Number-Phone|1.7002|i686-linux|5.10.0|linux|2.6.26-2-686|200906070246
4112697|4112697-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.10.0|darwin|8.11.0|200906070221
4112832|4112832-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|File-Overwrite|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906070630
4112835|4112835-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.26-2-686|200906070631
4112838|4112838-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux|5.10.0|linux|2.6.26-2-686|200906070631
4112872|4112872-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906070633
4113208|4113208-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-ParseDistribution|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906070750
4113880|4113880-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071008
4113882|4113882-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|XML-Tiny|2.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906071008
4113884|4113884-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|XML-Tiny-DOM|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071008
4114361|4114361-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906070754
4114381|4114381-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.26-2-686|200906071139
4115341|4115341-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071344
4115696|4115696-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071428
4115758|4115758-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906071434
4116423|4116423-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@rail.org.ua|Bryar|3.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906071520
4116550|4116550-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.26-2-686|200906071530
4118608|4118608-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200906071549
4120363|4120363-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|7.1-release|200906071951
4120629|4120629-b19f-3f77-b713-d32bba55d77f|pass|200906|rafl@debian.org|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.28.7|200906072154
4122034|4122034-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906080700
4122125|4122125-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906080251
4123367|4123367-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906080459
4123425|4123425-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906080709
4124786|4124786-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.26-2-686|200906081751
4124934|4124934-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.26-2-686|200906081806
4124973|4124973-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.26-2-686|200906081810
4124974|4124974-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906081810
4125580|4125580-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-24-generic|200906081352
4125821|4125821-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Devel-CheckLib|0.6|i686-linux|5.10.0|linux|2.6.24-24-generic|200906081405
4125945|4125945-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Statistics-ChiSquare|0.5|i686-linux|5.10.0|linux|2.6.26-2-686|200906081908
4125947|4125947-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Tie-Hash-Longest|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906081908
4126379|4126379-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906081931
4129535|4129535-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.6|darwin|8.11.0|200906081842
4129916|4129916-b19f-3f77-b713-d32bba55d77f|pass|200906|bobtfisg@bobtfish.net|Data-Compare|1.2101|darwin-thread-multi-2level|5.8.6|darwin|8.0|200906071349
4132738|4132738-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906090455
4133350|4133350-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.26-2-686|200906090720
4133554|4133554-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906090743
4134173|4134173-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906090949
4134928|4134928-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906091245
4134936|4134936-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.8.8|freebsd|7.1-release|200906091246
4138534|4138534-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.7|darwin|8.11.0|200906100034
4138539|4138539-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.7|darwin|8.11.0|200906100034
4139866|4139866-b19f-3f77-b713-d32bba55d77f|pass|200906|ivan.wills@gmail.com ("Ivan Wills")|Sort-MultipleFields|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906101123
4142260|4142260-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906100755
4142536|4142536-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.26-2-686|200906100822
4143368|4143368-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906101014
4143371|4143371-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906101014
4144065|4144065-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.26-2-686|200906101046
4146931|4146931-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.7|darwin|8.11.0|200906101644
4149099|4149099-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0.1|200906110004
4149969|4149969-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906110654
4150797|4150797-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Data-Compare|1.2101|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906110553
4151237|4151237-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110554
4151238|4151238-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906110554
4151430|4151430-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Tie-Scalar-Decay|1.1.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906111127
4151723|4151723-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Tie-Hash-Rank|1.0.1|i686-linux|5.10.0|linux|2.6.26-2-686|200906111231
4151782|4151782-b19f-3f77-b713-d32bba55d77f|unknown|200906|stro@cpan.org|Acme-Pony|1.1.2|i686-linux|5.10.0|linux|2.6.26-2-686|200906111236
4152494|4152494-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110013
4152749|4152749-b19f-3f77-b713-d32bba55d77f|pass|200906|james@mastros.biz|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110155
4153926|4153926-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200906111355
4156958|4156958-b19f-3f77-b713-d32bba55d77f|pass|200906|angryxpeh@gmail.com|NestedMap|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906120028
4157429|4157429-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.32|i686-linux|5.8.8|linux|2.4.27-2-386|200906120425
4157545|4157545-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906120255
4157546|4157546-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906120255
4159052|4159052-b19f-3f77-b713-d32bba55d77f|unknown|200906|stro@cpan.org|Acme-Licence|1.0|i686-linux|5.10.0|linux|2.6.26-2-686|200906120700
4160654|4160654-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906121419
4161253|4161253-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0.1|200906121512
4161531|4161531-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-FindDependencies|2.32|i686-linux|5.10.0|linux|2.6.24-24-generic|200906121600
4162193|4162193-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121807
4162195|4162195-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906121807
4163284|4163284-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906110133
4163504|4163504-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|DBIx-Class-SingletonRows|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906111658
4163607|4163607-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|DBIx-Class-SingletonRows|0.11|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906120211
4163791|4163791-b19f-3f77-b713-d32bba55d77f|pass|200906|sscaffidi@cpan.org ("Stephen R. Scaffidi")|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906121503
4163792|4163792-b19f-3f77-b713-d32bba55d77f|pass|200906|sscaffidi@cpan.org ("Stephen R. Scaffidi")|CPAN-FindDependencies|2.32|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906121504
4164574|4164574-b19f-3f77-b713-d32bba55d77f|pass|200906|sscaffidi@cpan.org ("Stephen R. Scaffidi")|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906121503
4165500|4165500-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130241
4165501|4165501-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906130241
4165939|4165939-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|5.0|200906130512
4170391|4170391-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906132113
4170393|4170393-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906132113
4170746|4170746-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131432
4170748|4170748-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906131432
4171633|4171633-b19f-3f77-b713-d32bba55d77f|pass|200906|bernt.guldbrandtsen@agrsci.dk|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200906132206
4171848|4171848-b19f-3f77-b713-d32bba55d77f|pass|200906|bernt.guldbrandtsen@agrsci.dk|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-128.1.6.el5|200906132206
4172719|4172719-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.1|linux|2.6.28-11-generic|200906142000
4172767|4172767-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142003
4172769|4172769-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142003
4173110|4173110-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142024
4173152|4173152-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|Devel-CheckOS|1.61|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906142234
4173175|4173175-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142029
4173177|4173177-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.10.0|netbsd|5.0|200906142032
4173179|4173179-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142029
4173191|4173191-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.10.0|netbsd|5.0|200906142033
4173275|4173275-b19f-3f77-b713-d32bba55d77f|fail|200906|stro@cpan.org|CPAN-FindDependencies|2.32|armv5tejl-linux|5.10.0|linux|2.6.17.14|200906142244
4173343|4173343-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.2|linux|2.6.28-11-generic|200906142025
4173436|4173436-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.1|linux|2.6.28-11-generic|200906142000
4173510|4173510-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142053
4173550|4173550-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142059
4173699|4173699-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.3|linux|2.6.28-11-generic|200906142053
4173720|4173720-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142059
4173841|4173841-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142131
4173843|4173843-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.4|linux|2.6.28-11-generic|200906142131
4173885|4173885-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142135
4173887|4173887-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142135
4174106|4174106-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142155
4174108|4174108-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.5|linux|2.6.28-11-generic|200906142155
4174138|4174138-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906142158
4174140|4174140-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906142158
4175727|4175727-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.8|darwin|8.11.0|200906150113
4175728|4175728-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.8|darwin|8.11.0|200906150113
4175751|4175751-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0.1|200906150113
4177049|4177049-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.10.0|netbsd|5.0|200906150541
4179587|4179587-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906151315
4179588|4179588-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.6|linux|2.6.28-11-generic|200906151315
4180979|4180979-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151602
4180982|4180982-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151602
4181712|4181712-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151731
4181758|4181758-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.7|linux|2.6.28-11-generic|200906151731
4181803|4181803-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906151741
4181806|4181806-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906151742
4182364|4182364-b19f-3f77-b713-d32bba55d77f|pass|200906|gms8994@dp.cx|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906150905
4182740|4182740-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.8|darwin|8.11.0|200906151940
4184195|4184195-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906152312
4184267|4184267-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux|5.8.8|linux|2.6.28-11-generic|200906152312
4184285|4184285-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.8.9|linux|2.6.28-11-generic|200906152323
4184288|4184288-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.8.9|linux|2.6.28-11-generic|200906152323
4186269|4186269-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906160145
4186273|4186273-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906160145
4186711|4186711-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200906160453
4186840|4186840-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.8.9|netbsd|5.0|200906160407
4186841|4186841-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.8.9|netbsd|5.0|200906160408
4188764|4188764-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906160908
4188769|4188769-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906160909
4189089|4189089-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906160950
4189092|4189092-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906160950
4189524|4189524-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Number-Phone|1.7002|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161036
4191562|4191562-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.8.9|netbsd|5.0|200906161701
4191789|4191789-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|File-Overwrite|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161744
4191793|4191793-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Palm-Treo680MessagesDB|1.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161745
4191794|4191794-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-24-generic|200906161744
4194549|4194549-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.10.0|netbsd|4.0|200906170030
4194633|4194633-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200906170040
4194641|4194641-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200906170041
4194696|4194696-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.10.0|linux|2.4.26|200906170044
4196349|4196349-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.9|darwin|8.11.0|200906170635
4196352|4196352-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.9|darwin|8.11.0|200906170636
4197647|4197647-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-64int|5.10.0|netbsd|5.0|200906171123
4197984|4197984-b19f-3f77-b713-d32bba55d77f|pass|200906|brian@minton.name|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161527
4197987|4197987-b19f-3f77-b713-d32bba55d77f|pass|200906|brian@minton.name|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161527
4197989|4197989-b19f-3f77-b713-d32bba55d77f|pass|200906|brian@minton.name|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.29.4-dsa-dl380-oldxeon|200906161528
4198265|4198265-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906171347
4198848|4198848-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906171337
4199185|4199185-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906170856
4199315|4199315-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906170905
4199443|4199443-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906170914
4200321|4200321-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906171043
4200571|4200571-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906171111
4200944|4200944-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-64int|5.10.0|netbsd|5.0|200906171656
4200974|4200974-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|alpha-linux-thread-multi|5.10.0|linux|2.6.18-5-alpha-generic|200906171707
4202506|4202506-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172010
4202508|4202508-b19f-3f77-b713-d32bba55d77f|fail|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172010
4202822|4202822-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172052
4202826|4202826-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.6.2|linux|2.6.20-16-generic|200906172052
4203892|4203892-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906171949
4203964|4203964-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906180051
4204623|4204623-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-64int-2level|5.8.9|darwin|8.11.0|200906180223
4205084|4205084-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-64int|5.10.0|netbsd|5.0|200906180329
4207025|4207025-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|CPAN-ParseDistribution|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200906180902
4209007|4209007-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i386-linux-thread-multi|5.10.0|linux|2.6.29.4-167.fc11.i686.pae|200906181411
4209008|4209008-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i386-linux-thread-multi|5.10.0|linux|2.6.29.4-167.fc11.i686.pae|200906181411
4209542|4209542-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|XML-Tiny|2.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200906181403
4209543|4209543-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|XML-Tiny-DOM|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906181403
4209545|4209545-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Palm-ProjectGutenberg|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906181403
4210156|4210156-b19f-3f77-b713-d32bba55d77f|fail|200906|mithaldu@yahoo.de ("Christian Walde")|CPAN-FindDependencies|2.32|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906181229
4210565|4210565-b19f-3f77-b713-d32bba55d77f|pass|200906|mithaldu@yahoo.de ("Christian Walde")|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906181256
4210731|4210731-b19f-3f77-b713-d32bba55d77f|pass|200906|mithaldu@yahoo.de ("Christian Walde")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906181307
4211385|4211385-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd|5.8.9|netbsd|5.0|200906181939
4211656|4211656-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906182130
4211659|4211659-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906182130
4211768|4211768-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906182152
4211772|4211772-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906182153
4211979|4211979-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906182139
4212534|4212534-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|WWW-Facebook-Go-SGF|1.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906190108
4213195|4213195-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906190151
4213783|4213783-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd|5.8.9|netbsd|5.0|200906190335
4214392|4214392-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906190539
4215243|4215243-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.8|netbsd|4.0|200906190829
4215435|4215435-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Tie-STDOUT|1.0401|i686-linux|5.10.0|linux|2.6.24-24-generic|200906190910
4216500|4216500-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906190702
4216790|4216790-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd|5.8.9|netbsd|5.0|200906191232
4216871|4216871-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.21|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906191442
4216887|4216887-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@cpan.org|CPAN-FindDependencies|2.22|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200906191444
4217824|4217824-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191534
4217825|4217825-b19f-3f77-b713-d32bba55d77f|fail|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191534
4218587|4218587-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191712
4218588|4218588-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.6.2|linux|2.6.29.4-167.fc11.i686.pae|200906191712
4218685|4218685-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191726
4218686|4218686-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191726
4219213|4219213-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191842
4219214|4219214-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.8.1|linux|2.6.29.4-167.fc11.i686.pae|200906191843
4219360|4219360-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906191901
4219362|4219362-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906191901
4220310|4220310-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906192200
4220718|4220718-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906200000
4221040|4221040-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906200010
4221487|4221487-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906200238
4221697|4221697-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906200109
4221730|4221730-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906200203
4221876|4221876-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200906200345
4221929|4221929-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200906200358
4222308|4222308-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.8.7|darwin|8.11.0|200906200407
4222506|4222506-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906200541
4222674|4222674-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200906200611
4223752|4223752-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906200953
4224528|4224528-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906201152
4224762|4224762-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906201345
4224764|4224764-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.8.2|linux|2.6.29.4-167.fc11.i686.pae|200906201345
4225170|4225170-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201441
4225171|4225171-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201441
4225339|4225339-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|darwin-thread-multi-2level|5.8.9 patch 35104|darwin|9.7.0|200906201353
4225340|4225340-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|darwin-thread-multi-2level|5.8.9 patch 35104|darwin|9.7.0|200906201353
4225377|4225377-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.1|linux|2.6.24-19-server|200906201358
4225380|4225380-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.1|linux|2.6.24-19-server|200906201358
4225852|4225852-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Compare|1.2101|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201540
4226071|4226071-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|i686-linux|5.8.3|linux|2.6.29.4-167.fc11.i686.pae|200906201540
4226872|4226872-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Data-Hexdumper|2.01|i686-linux|5.8.4|linux|2.6.29.4-167.fc11.i686.pae|200906201732
4226873|4226873-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|i686-linux|5.8.4|linux|2.6.29.4-167.fc11.i686.pae|200906201732
4227643|4227643-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.8.9|netbsd|4.0|200906201752
4229584|4229584-b19f-3f77-b713-d32bba55d77f|fail|200906|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-19-server|200906210704
4230922|4230922-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906210051
4230924|4230924-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906210051
4230926|4230926-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906210051
4230930|4230930-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906210051
4231331|4231331-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi|5.10.0|netbsd|5.0|200906210158
4236105|4236105-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906210028
4236261|4236261-b19f-3f77-b713-d32bba55d77f|pass|200906|l.mai@web.de|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.22-gentoo-r9|200906202116
4236953|4236953-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Data-Compare|1.2101|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906210502
4238136|4238136-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|Devel-CheckOS|1.61|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906210547
4239172|4239172-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906210236
4240160|4240160-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906210329
4240345|4240345-b19f-3f77-b713-d32bba55d77f|fail|200906|dagolden@cpan.org (DAGOLDEN)|Bryar|3.1|i686-linux|5.10.0|linux|2.6.24-16-generic|200906210342
4243789|4243789-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906211707
4244449|4244449-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906211910
4244731|4244731-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200906212009
4247092|4247092-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906211910
4247684|4247684-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906211925
4247753|4247753-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906211927
4248013|4248013-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906211934
4248084|4248084-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200906220033
4251240|4251240-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906221453
4251743|4251743-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi|5.8.9|netbsd|5.0|200906221446
4251848|4251848-b19f-3f77-b713-d32bba55d77f|pass|200906|bejuryu@gmail.com|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906221834
4251867|4251867-b19f-3f77-b713-d32bba55d77f|pass|200906|bejuryu@gmail.com|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906221835
4253035|4253035-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|WWW-Facebook-Go-SGF|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906221800
4253639|4253639-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221356
4254403|4254403-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221502
4256563|4256563-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221508
4257060|4257060-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221400
4257241|4257241-b19f-3f77-b713-d32bba55d77f|pass|200906|trey+cpanplus@lopsa.org|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|9.6.0|200906220946
4257445|4257445-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221509
4257522|4257522-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221523
4258090|4258090-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221508
4258510|4258510-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906221945
4258677|4258677-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230017
4259126|4259126-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.3|200906230208
4259706|4259706-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230323
4259828|4259828-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230346
4260121|4260121-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230029
4260754|4260754-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Bryar|3.1|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906230909
4260840|4260840-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906230924
4261723|4261723-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221824
4262108|4262108-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221703
4262780|4262780-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221710
4262814|4262814-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221758
4262837|4262837-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221758
4263018|4263018-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906221724
4263139|4263139-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906221709
4263202|4263202-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906221741
4263433|4263433-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221826
4263546|4263546-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221749
4264057|4264057-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230613
4264061|4264061-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230615
4264063|4264063-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230615
4264204|4264204-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221703
4264452|4264452-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906221722
4264557|4264557-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906230650
4264650|4264650-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221826
4264887|4264887-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230717
4264898|4264898-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230719
4264901|4264901-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230719
4265231|4265231-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906221751
4265284|4265284-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906230803
4266018|4266018-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230941
4266029|4266029-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230943
4266032|4266032-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906230943
4266376|4266376-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906231033
4266560|4266560-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231042
4266635|4266635-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906231029
4266730|4266730-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231048
4267129|4267129-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231046
4267328|4267328-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231025
4267652|4267652-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231048
4268846|4268846-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231401
4268907|4268907-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231357
4269764|4269764-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231644
4270035|4270035-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906231732
4270206|4270206-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906231753
4270668|4270668-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906231030
4270705|4270705-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231852
4270712|4270712-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231853
4270714|4270714-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906231853
4271786|4271786-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231336
4271912|4271912-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|cygwin-thread-multi-64int|5.8.9|cygwin|1.5.25(0.15642)|200906240102
4272350|4272350-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906231053
4272389|4272389-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240030
4272401|4272401-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240031
4272402|4272402-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240031
4272938|4272938-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231400
4273258|4273258-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240123
4273274|4273274-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240123
4273278|4273278-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240123
4273573|4273573-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.6|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200906240422
4273577|4273577-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906240225
4273942|4273942-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240242
4274783|4274783-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240304
4274966|4274966-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906240308
4275950|4275950-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240334
4276002|4276002-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240335
4276588|4276588-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1257-g2b4f847|linux|2.6.30-020630rc7-generic|200906240354
4276661|4276661-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|cygwin-thread-multi-64int|5.8.9|cygwin|1.5.25(0.15642)|200906240456
4276759|4276759-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906240401
4277742|4277742-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906231053
4277792|4277792-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906231358
4278381|4278381-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|File-Find-Rule-Permissions|2.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200906241058
4278487|4278487-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Class-DBI-ClassGenerator|1.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200906241121
4278731|4278731-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906241207
4278732|4278732-b19f-3f77-b713-d32bba55d77f|pass|200906|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.28-11-generic|200906241207
4278977|4278977-b19f-3f77-b713-d32bba55d77f|pass|200906|chris@bingosnet.co.uk|Devel-CheckLib|0.6|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200906241237
4280366|4280366-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240818
4280769|4280769-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240828
4281761|4281761-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906240837
4281791|4281791-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906240837
4282381|4282381-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906241349
4282396|4282396-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906240906
4282398|4282398-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906240907
4284099|4284099-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906241636
4285516|4285516-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906241652
4286189|4286189-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906250013
4286216|4286216-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906250019
4286319|4286319-b19f-3f77-b713-d32bba55d77f|pass|200906|doug@peaches.acomp.usf.edu|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.1|200906250040
4287492|4287492-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906250259
4287740|4287740-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250305
4288027|4288027-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906250311
4288058|4288058-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906250312
4289441|4289441-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906250343
4289835|4289835-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906250352
4290999|4290999-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250016
4291126|4291126-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906250019
4291491|4291491-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.5100rc1@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250028
4293122|4293122-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906250020
4296701|4296701-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200906251355
4296795|4296795-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906251006
4296881|4296881-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906251018
4296912|4296912-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906251023
4297031|4297031-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906251036
4297041|4297041-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906251038
4297111|4297111-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906251053
4297443|4297443-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251104
4297772|4297772-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251111
4298474|4298474-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906251109
4298592|4298592-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251129
4299025|4299025-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251140
4299120|4299120-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.8.7|darwin|8.11.0|200906251643
4299798|4299798-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251058
4301056|4301056-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker4@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251211
4301842|4301842-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251240
4302977|4302977-b19f-3f77-b713-d32bba55d77f|fail|200906|cpan.dcollins.smoker1@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251214
4303660|4303660-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.8.7|darwin|8.11.0|200906251928
4303725|4303725-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.3|200906251910
4305765|4305765-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251721
4305830|4305830-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251724
4306034|4306034-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251729
4306186|4306186-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251734
4306212|4306212-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906251734
4306299|4306299-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906252136
4306305|4306305-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200906252136
4306889|4306889-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251752
4306961|4306961-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906251754
4307049|4307049-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906251757
4308517|4308517-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260053
4308559|4308559-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260054
4308574|4308574-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker7@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260055
4308598|4308598-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260055
4308628|4308628-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260056
4308703|4308703-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260058
4308752|4308752-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260059
4308756|4308756-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260059
4308825|4308825-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260101
4309027|4309027-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260105
4309070|4309070-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260106
4309291|4309291-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260111
4309385|4309385-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260113
4309484|4309484-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260116
4309506|4309506-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260116
4309588|4309588-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906260120
4309688|4309688-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200906260125
4309712|4309712-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906260126
4310162|4310162-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200906260355
4310902|4310902-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|XML-Tiny|2.02|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906260329
4312103|4312103-b19f-3f77-b713-d32bba55d77f|pass|200906|andreas.koenig.gmwojprw@franz.ak.mind.de|Devel-CheckOS|1.61|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200906260858
4312187|4312187-b19f-3f77-b713-d32bba55d77f|pass|200906|andreas.koenig.gmwojprw@franz.ak.mind.de|Data-Compare|1.2101|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200906260858
4312414|4312414-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200906260955
4312988|4312988-b19f-3f77-b713-d32bba55d77f|pass|200906|justin.d.hunter@gmail.com|DBIx-Class-SingletonRows|0.11|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200906260244
4313102|4313102-b19f-3f77-b713-d32bba55d77f|pass|200906|martin.evans@easysoft.com|Palm-SMS|0.03|i686-linux|5.10.0|linux|2.6.24-24-generic|200906261100
4313231|4313231-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200906261215
4317316|4317316-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262105
4317411|4317411-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262111
4317767|4317767-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906261938
4318103|4318103-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906262011
4318204|4318204-b19f-3f77-b713-d32bba55d77f|pass|200906|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200906262202
4318612|4318612-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|darwin-2level|5.8.8|darwin|8.11.0|200906262308
4318649|4318649-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|darwin-2level|5.8.8|darwin|8.11.0|200906262314
4318890|4318890-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262341
4318893|4318893-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|i686-linux-thread-multi|5.11.0|linux|2.6.29.1.20090403|200906262341
4320925|4320925-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200906270531
4322043|4322043-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd|5.10.0|midnightbsd|0.1.1-release|200906270659
4323204|4323204-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906271321
4323337|4323337-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906271228
4323458|4323458-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906271305
4325233|4325233-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906271921
4325267|4325267-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-ChiSquare|0.5|darwin-2level|5.10.0|darwin|8.11.0|200906271923
4325282|4325282-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906271924
4325329|4325329-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Statistics-SerialCorrelation|1.1|darwin-2level|5.10.0|darwin|8.11.0|200906271927
4327445|4327445-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906272346
4327446|4327446-b19f-3f77-b713-d32bba55d77f|pass|200906|ipenburg@xs4all.nl ("Roland van Ipenburg")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-1-686|200906272347
4328369|4328369-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906271939
4328370|4328370-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906271939
4328919|4328919-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906280042
4328923|4328923-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906280043
4329773|4329773-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.6|i686-linux|5.10.0|linux|2.6.24-16-generic|200906280143
4329964|4329964-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906280159
4329967|4329967-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.11.0|linux|2.6.28-11-generic|200906280159
4331145|4331145-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906280529
4331311|4331311-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906280620
4331561|4331561-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200906280801
4333266|4333266-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.3|200906281024
4335328|4335328-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280837
4336541|4336541-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280901
4336660|4336660-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906280851
4336958|4336958-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280909
4337848|4337848-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280911
4338126|4338126-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280913
4338141|4338141-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906280932
4339083|4339083-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906280951
4339162|4339162-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906280952
4340255|4340255-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906281002
4342508|4342508-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906281948
4342896|4342896-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906282027
4342971|4342971-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906281643
4342973|4342973-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.8.9 patch 35104|linux|2.6.28-11-generic|200906281643
4344688|4344688-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906281941
4344689|4344689-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux|5.10.0|linux|2.6.28-11-generic|200906281941
4345375|4345375-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.10.0|darwin|8.11.0|200906290204
4345739|4345739-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290403
4346014|4346014-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200906290511
4346179|4346179-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906290320
4346423|4346423-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906290326
4346878|4346878-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906290334
4349521|4349521-b19f-3f77-b713-d32bba55d77f|pass|200906|andy.situ@verizon.net|CPAN-FindDependencies|2.32|i686-linux-multi-64int-ld|5.10.0|linux|2.6.22.1.emp6|200906281800
4349522|4349522-b19f-3f77-b713-d32bba55d77f|pass|200906|andy.situ@verizon.net|Data-Compare|1.2101|i686-linux-multi-64int-ld|5.10.0|linux|2.6.22.1.emp6|200906281759
4349525|4349525-b19f-3f77-b713-d32bba55d77f|pass|200906|andy.situ@verizon.net|Devel-CheckOS|1.61|i686-linux-multi-64int-ld|5.10.0|linux|2.6.22.1.emp6|200906281759
4349745|4349745-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Data-Compare|1.2101|i386-freebsd|5.8.9|freebsd|7.2-release|200906291011
4350411|4350411-b19f-3f77-b713-d32bba55d77f|pass|200906|stro@rail.org.ua|Devel-CheckOS|1.61|i386-freebsd|5.8.9|freebsd|7.2-release|200906291031
4352487|4352487-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd|5.8.9|midnightbsd|0.1.1-release|200906291430
4352831|4352831-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200906291737
4353274|4353274-b19f-3f77-b713-d32bba55d77f|pass|200906|dagolden@cpan.org (DAGOLDEN)|Devel-CheckLib|0.6|i686-linux-thread-multi-64int-ld|5.10.0|linux|2.6.24-16-generic|200906291243
4353903|4353903-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291325
4354360|4354360-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906291335
4354548|4354548-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906291340
4355022|4355022-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906291338
4357835|4357835-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906291502
4358128|4358128-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906291510
4360983|4360983-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|File-Find-Rule-Permissions|2.0|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906300154
4362054|4362054-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300101
4362292|4362292-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker2@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300105
4362961|4362961-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|Class-DBI-ClassGenerator|1.02|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200906300315
4363024|4363024-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300117
4364456|4364456-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300141
4364718|4364718-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300145
4365178|4365178-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker6@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300152
4365433|4365433-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.smoker9@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906300155
4365685|4365685-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300159
4365787|4365787-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300201
4365888|4365888-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300202
4366244|4366244-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300209
4366891|4366891-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker1@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906300227
4367057|4367057-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker5@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300236
4367508|4367508-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200906300257
4367793|4367793-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906300316
4367830|4367830-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200906300319
4367833|4367833-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-11-generic|200906300319
4369373|4369373-b19f-3f77-b713-d32bba55d77f|pass|200906|autarch@urth.org|CPAN-FindDependencies|2.32|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906291109
4369545|4369545-b19f-3f77-b713-d32bba55d77f|pass|200906|autarch@urth.org|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.24-16-server|200906291109
4372180|4372180-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-11-generic|200906300902
4372181|4372181-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-11-generic|200906300902
4373312|4373312-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200906301509
4373520|4373520-b19f-3f77-b713-d32bba55d77f|pass|200906|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200906301546
4374719|4374719-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@sourcentral.org ("Oliver Paukstadt")|CPAN-ParseDistribution|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200906302243
4376265|4376265-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.5100rc1@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301835
4376353|4376353-b19f-3f77-b713-d32bba55d77f|unknown|200906|cpan.dcollins.589@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301837
4376962|4376962-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker4@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200906301855
4377580|4377580-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200906301923
4377586|4377586-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200906301923
4378278|4378278-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker3@gmail.com|NestedMap|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301933
4378756|4378756-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301941
4379397|4379397-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.589@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301934
4379510|4379510-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200906301950
4380054|4380054-b19f-3f77-b713-d32bba55d77f|pass|200906|cpan.dcollins.smoker8@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200906301958
4380734|4380734-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907010006
4381405|4381405-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010018
4381480|4381480-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010020
4381565|4381565-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010022
4381647|4381647-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907010025
4383139|4383139-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.11.0 patch GitLive-blead-1493-g9015f10|midnightbsd|0.1.1-release|200907010213
4386726|4386726-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907011232
4388882|4388882-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010847
4389365|4389365-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907010901
4389466|4389466-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907010904
4389471|4389471-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010904
4390559|4390559-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907010946
4392370|4392370-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011104
4393000|4393000-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011140
4393466|4393466-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907011756
4393696|4393696-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907011825
4396209|4396209-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011634
4396870|4396870-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907012307
4397365|4397365-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011731
4397629|4397629-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907011743
4397871|4397871-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907011754
4398048|4398048-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907011801
4398109|4398109-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907020012
4401123|4401123-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.4|200907020500
4401703|4401703-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907020018
4402079|4402079-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907020027
4402563|4402563-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907020036
4402662|4402662-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907020037
4402806|4402806-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker9@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907020040
4402923|4402923-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907020407
4403637|4403637-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907020442
4403753|4403753-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907020043
4404374|4404374-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907020958
4404515|4404515-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|darwin-64int-2level|5.8.6|darwin|8.11.0|200907020934
4404657|4404657-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|darwin-64int-2level|5.8.6|darwin|8.11.0|200907020957
4406914|4406914-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.10.0 patch GitLive-maint-5.10-1462-g178839f|midnightbsd|0.1.1-release|200907021521
4409879|4409879-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021809
4410317|4410317-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker8@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907021819
4410628|4410628-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021827
4410643|4410643-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907021828
4411768|4411768-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907021857
4411907|4411907-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021900
4412245|4412245-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907021910
4412634|4412634-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907021920
4412744|4412744-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021922
4412843|4412843-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907021925
4415915|4415915-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907030038
4415917|4415917-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907030038
4416234|4416234-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907030116
4416235|4416235-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907030116
4417709|4417709-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907030937
4417843|4417843-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907031004
4418646|4418646-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907031405
4418889|4418889-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907031508
4420028|4420028-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031242
4420069|4420069-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031243
4421365|4421365-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031320
4421418|4421418-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031322
4421628|4421628-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031327
4422176|4422176-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031339
4423312|4423312-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031403
4423782|4423782-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031412
4423788|4423788-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907031354
4424134|4424134-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907031419
4424754|4424754-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907031433
4425156|4425156-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907031440
4425531|4425531-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031447
4425633|4425633-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907031449
4428458|4428458-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.8|openbsd|4.4|200907040217
4428667|4428667-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907040152
4429095|4429095-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907040338
4430488|4430488-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907040435
4431380|4431380-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907040916
4431488|4431488-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907040920
4432357|4432357-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907040935
4432507|4432507-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907040954
4432711|4432711-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041002
4433267|4433267-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041017
4433416|4433416-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041021
4433817|4433817-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041033
4434299|4434299-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041044
4434377|4434377-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041046
4434431|4434431-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041047
4434822|4434822-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041057
4434830|4434830-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041057
4434913|4434913-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041100
4435053|4435053-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041105
4435178|4435178-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041108
4435781|4435781-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041120
4435915|4435915-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041122
4436030|4436030-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907041624
4436039|4436039-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907041624
4436679|4436679-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041135
4437524|4437524-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041137
4438203|4438203-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907041740
4438379|4438379-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907041822
4438574|4438574-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041408
4439125|4439125-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041535
4439128|4439128-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041536
4439130|4439130-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041536
4439187|4439187-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041545
4439750|4439750-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041609
4439907|4439907-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041612
4440590|4440590-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041628
4440681|4440681-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041631
4440764|4440764-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041632
4440938|4440938-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041635
4441532|4441532-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041645
4441593|4441593-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041647
4441686|4441686-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041648
4441764|4441764-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041650
4441769|4441769-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041650
4441773|4441773-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041650
4441847|4441847-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041651
4442730|4442730-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker3@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041708
4443279|4443279-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041717
4443318|4443318-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907041701
4443350|4443350-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041719
4443644|4443644-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker3@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907041725
4443691|4443691-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041710
4443782|4443782-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041728
4443798|4443798-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041729
4443801|4443801-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041729
4443914|4443914-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041731
4444062|4444062-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041733
4444372|4444372-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041739
4444450|4444450-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907041740
4445011|4445011-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041648
4445092|4445092-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041752
4445360|4445360-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907041757
4445659|4445659-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907041807
4445660|4445660-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907041750
4446902|4446902-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050121
4447563|4447563-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050339
4447570|4447570-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050345
4447713|4447713-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-thread-multi-64int|5.11.0|netbsd|5.0|200907050513
4448386|4448386-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907050232
4448827|4448827-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-11-generic|200907050340
4448992|4448992-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907050419
4449242|4449242-b19f-3f77-b713-d32bba55d77f|pass|200907|g.grigelionis@computer.org|Statistics-ChiSquare|0.5|i586-linux-thread-multi|5.8.8|linux|2.6.16|200907051047
4449314|4449314-b19f-3f77-b713-d32bba55d77f|pass|200907|g.grigelionis@computer.org|Statistics-SerialCorrelation|1.1|i586-linux-thread-multi|5.8.8|linux|2.6.16|200907051101
4449491|4449491-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907051055
4449593|4449593-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907051123
4450367|4450367-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907050821
4450490|4450490-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907050823
4450795|4450795-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050829
4450797|4450797-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907050829
4452009|4452009-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907050849
4452134|4452134-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050851
4452166|4452166-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050851
4453169|4453169-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100rc1@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050908
4453746|4453746-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050919
4453930|4453930-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050922
4455351|4455351-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050933
4455472|4455472-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907050850
4455672|4455672-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050946
4455713|4455713-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907050914
4456258|4456258-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051153
4456733|4456733-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051330
4457410|4457410-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051550
4457415|4457415-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051550
4457420|4457420-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051551
4457503|4457503-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051603
4457970|4457970-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051721
4458518|4458518-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907051827
4458753|4458753-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051905
4458758|4458758-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051905
4458760|4458760-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907051905
4459093|4459093-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.4|200907060055
4459198|4459198-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060002
4459235|4459235-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060003
4459339|4459339-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060005
4460017|4460017-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060016
4460587|4460587-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060029
4461399|4461399-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060049
4461543|4461543-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060052
4461809|4461809-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060056
4461834|4461834-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060057
4462295|4462295-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060106
4462608|4462608-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907060113
4462637|4462637-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907060113
4463158|4463158-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907060122
4463291|4463291-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907060125
4464302|4464302-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200907060515
4464346|4464346-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.10.0|netbsd|5.0|200907060547
4468253|4468253-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907060915
4468263|4468263-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907060915
4469069|4469069-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907061003
4469070|4469070-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907061003
4469126|4469126-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907061010
4469127|4469127-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907061010
4469467|4469467-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907061534
4469874|4469874-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061049
4469966|4469966-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061051
4470351|4470351-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061102
4470450|4470450-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907061604
4470476|4470476-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061106
4470995|4470995-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061117
4471341|4471341-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061125
4472031|4472031-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Sort-MultipleFields|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200907061640
4472273|4472273-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061145
4472707|4472707-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061154
4473025|4473025-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061201
4473161|4473161-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061205
4473415|4473415-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061211
4473727|4473727-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061219
4473890|4473890-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061223
4474028|4474028-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061227
4474347|4474347-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061236
4474377|4474377-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061236
4474653|4474653-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907061744
4474656|4474656-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061236
4474702|4474702-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061243
4474876|4474876-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061248
4475142|4475142-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061255
4475685|4475685-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907061811
4475690|4475690-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907061309
4475730|4475730-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061310
4476302|4476302-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907061325
4477826|4477826-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200907062057
4477829|4477829-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-686|200907062058
4478620|4478620-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061748
4480314|4480314-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061835
4480609|4480609-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061845
4480703|4480703-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907061849
4480818|4480818-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061852
4480991|4480991-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907061857
4481096|4481096-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-netbsd-64int|5.10.0 patch GitLive-maint-5.10-1501-gba4fcaa|netbsd|5.0|200907062358
4481331|4481331-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907061907
4483985|4483985-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907070132
4483987|4483987-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907070133
4484465|4484465-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907070209
4484469|4484469-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907070209
4484477|4484477-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907070210
4484480|4484480-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907070210
4487043|4487043-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907071123
4487631|4487631-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907071220
4488330|4488330-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907072218
4488334|4488334-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907072218
4488554|4488554-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|DBIx-Class-SingletonRows|0.11|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071340
4488987|4488987-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Data-Transactional|1.02|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071423
4489122|4489122-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPU-Emulator-Z80|1.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071446
4489123|4489123-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|CPU-Emulator-Memory|1.1001|i686-linux|5.10.0|linux|2.6.24-24-generic|200907071446
4490519|4490519-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker9@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907071128
4490722|4490722-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071134
4491338|4491338-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071153
4491648|4491648-b19f-3f77-b713-d32bba55d77f|pass|200907|ss5@renormalist.net|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.18-5-k7|200907071801
4491970|4491970-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071209
4492945|4492945-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907071230
4493945|4493945-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071302
4494100|4494100-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071305
4494147|4494147-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071307
4494266|4494266-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907071311
4494802|4494802-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Number-Phone|1.7002|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907071923
4495987|4495987-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.10.0|solaris|2.10|200907080107
4498496|4498496-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907080446
4498497|4498497-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907080447
4499852|4499852-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907080724
4500395|4500395-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907080837
4501519|4501519-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081054
4502199|4502199-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907081109
4502950|4502950-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907081129
4503359|4503359-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907081140
4503611|4503611-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907081148
4506273|4506273-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907081254
4506408|4506408-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081258
4506417|4506417-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081258
4507268|4507268-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907081323
4507538|4507538-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081340
4508097|4508097-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081507
4508098|4508098-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081508
4508099|4508099-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081508
4508152|4508152-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081515
4508318|4508318-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907081523
4508840|4508840-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081538
4509182|4509182-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907081547
4509326|4509326-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081556
4509599|4509599-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081645
4509603|4509603-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081645
4509604|4509604-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081645
4509824|4509824-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081715
4510040|4510040-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckLib|0.6|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907082302
4510454|4510454-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907081940
4511108|4511108-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907090141
4511135|4511135-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907090146
4512323|4512323-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907090210
4514270|4514270-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.5|200907091245
4514274|4514274-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.5|200907091246
4514313|4514313-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200907091210
4514318|4514318-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.4|solaris|2.10|200907091211
4516516|4516516-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907090859
4516862|4516862-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907092310
4516898|4516898-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907090910
4517749|4517749-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907090932
4518220|4518220-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907090943
4522360|4522360-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Data-Hexdumper|2.01|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091738
4522363|4522363-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Devel-CheckLib|0.6|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091739
4522945|4522945-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Data-Compare|1.2101|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091837
4523041|4523041-b19f-3f77-b713-d32bba55d77f|pass|200907|andy@hexten.net|Devel-CheckOS|1.61|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.26-2-amd64|200907091837
4523690|4523690-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckOS|1.61|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907100437
4524114|4524114-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@tenzobox.net ("Axel Bourgeois")|Data-Compare|1.2101|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907091837
4525669|4525669-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|File-Overwrite|1.1|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907100211
4525801|4525801-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907091913
4526017|4526017-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907091918
4526603|4526603-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|Palm-Treo680MessagesDB|1.01|armv5tejl-linux|5.10.0|linux|2.6.17.14|200907100229
4527882|4527882-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907091957
4528213|4528213-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907100003
4528724|4528724-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907100013
4529945|4529945-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907100034
4530269|4530269-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907100040
4531091|4531091-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907100131
4531093|4531093-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907100131
4531593|4531593-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907100232
4533438|4533438-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.10.0|openbsd|4.5|200907100801
4535117|4535117-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907100556
4535957|4535957-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907100714
4537957|4537957-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101013
4537994|4537994-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101014
4538036|4538036-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101014
4538061|4538061-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101015
4538757|4538757-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101030
4539556|4539556-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907101051
4539748|4539748-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|DBIx-Class-SingletonRows|0.1|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907101756
4539762|4539762-b19f-3f77-b713-d32bba55d77f|pass|200907|stro@cpan.org|DBIx-Class-SingletonRows|0.11|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200907101756
4540515|4540515-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907101114
4541436|4541436-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|Bryar|3.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101149
4541484|4541484-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101154
4542079|4542079-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101302
4542215|4542215-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101330
4542218|4542218-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101330
4542219|4542219-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101330
4543358|4543358-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Acme-Licence|1.0|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907101931
4543386|4543386-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907101430
4543404|4543404-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101431
4543480|4543480-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Acme-Pony|1.1.2|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907101934
4543559|4543559-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907101936
4545181|4545181-b19f-3f77-b713-d32bba55d77f|fail|200907|bingos@cpan.org|Bryar|3.1|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907102222
4545258|4545258-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101735
4545423|4545423-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907101810
4545446|4545446-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101816
4545854|4545854-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101943
4545855|4545855-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101943
4545857|4545857-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101944
4545902|4545902-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907101955
4546098|4546098-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110113
4546170|4546170-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907110133
4546199|4546199-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907110142
4546359|4546359-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110219
4546363|4546363-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110219
4546364|4546364-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110219
4546583|4546583-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110258
4547578|4547578-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907110029
4547708|4547708-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907110033
4548527|4548527-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110055
4549069|4549069-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907110104
4549215|4549215-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907110107
4549236|4549236-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110055
4550044|4550044-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907110123
4550155|4550155-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907110126
4550566|4550566-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907110135
4550796|4550796-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907110141
4551657|4551657-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907110206
4551871|4551871-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907110213
4552169|4552169-b19f-3f77-b713-d32bba55d77f|fail|200907|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111633
4552329|4552329-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110334
4552622|4552622-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907110440
4553175|4553175-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200907111006
4553390|4553390-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907111953
4553648|4553648-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110618
4553695|4553695-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907110626
4555617|4555617-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907111212
4557310|4557310-b19f-3f77-b713-d32bba55d77f|pass|200907|andy.situ@verizon.net|Data-Compare|1.2101|i686-linux-multi-64int|5.10.0|linux|2.6.24-24-generic|200907111450
4557311|4557311-b19f-3f77-b713-d32bba55d77f|pass|200907|andy.situ@verizon.net|Devel-CheckOS|1.61|i686-linux-multi-64int|5.10.0|linux|2.6.24-24-generic|200907111450
4557312|4557312-b19f-3f77-b713-d32bba55d77f|pass|200907|andy.situ@verizon.net|CPAN-FindDependencies|2.32|i686-linux-multi-64int|5.10.0|linux|2.6.24-24-generic|200907111452
4559554|4559554-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907111941
4559559|4559559-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.589@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907111941
4559561|4559561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907111941
4560221|4560221-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907120121
4562425|4562425-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907120050
4562775|4562775-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120101
4562847|4562847-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907120103
4563421|4563421-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker5@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907120119
4563690|4563690-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907120127
4564518|4564518-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris-thread-multi-64int|5.8.8|solaris|2.10|200907120300
4564797|4564797-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907120313
4564920|4564920-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907120526
4566493|4566493-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907120730
4568057|4568057-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130511
4568961|4568961-b19f-3f77-b713-d32bba55d77f|pass|200907|rlane10@wi.rr.com|Devel-CheckOS|1.61|darwin-2level-ld|5.10.0|darwin|8.11.0|200907121520
4568963|4568963-b19f-3f77-b713-d32bba55d77f|fail|200907|rlane10@wi.rr.com|CPAN-FindDependencies|2.32|darwin-2level-ld|5.10.0|darwin|8.11.0|200907121540
4568986|4568986-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907121749
4569163|4569163-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907121820
4569206|4569206-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907121825
4569213|4569213-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907121826
4569459|4569459-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130909
4569466|4569466-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130911
4569469|4569469-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130911
4569580|4569580-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907130931
4569849|4569849-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907130011
4569865|4569865-b19f-3f77-b713-d32bba55d77f|fail|200907|ivan.wills@gmail.com ("Ivan Wills")|Bryar|3.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131013
4569996|4569996-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|Data-Compare|1.2101|i86pc-solaris|5.10.0|solaris|2.10|200907130136
4569997|4569997-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|Devel-CheckOS|1.61|i86pc-solaris|5.10.0|solaris|2.10|200907130136
4570245|4570245-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd-thread-multi-64int|5.8.9|openbsd|4.5|200907130243
4570369|4570369-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130142
4570520|4570520-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130147
4570630|4570630-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907130151
4570637|4570637-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130151
4570858|4570858-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131158
4570999|4570999-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130203
4571219|4571219-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130210
4571562|4571562-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130222
4571742|4571742-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130228
4572029|4572029-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907130239
4572034|4572034-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130240
4572248|4572248-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130246
4572422|4572422-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130249
4573064|4573064-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130315
4573207|4573207-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130321
4573393|4573393-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130329
4573407|4573407-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907130330
4573561|4573561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907130341
4573697|4573697-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907130351
4573726|4573726-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.6|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131353
4573800|4573800-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131400
4573805|4573805-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131401
4573806|4573806-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131401
4574125|4574125-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907130055
4574285|4574285-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Transactional|1.02|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130132
4574405|4574405-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907131604
4574480|4574480-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130218
4574481|4574481-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907130219
4576087|4576087-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907130623
4577180|4577180-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-16-generic|200907130750
4577632|4577632-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200907130827
4579815|4579815-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131057
4581695|4581695-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131334
4582258|4582258-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200907131908
4582771|4582771-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131451
4582800|4582800-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131452
4582802|4582802-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131452
4582863|4582863-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Transactional|1.02|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131456
4583851|4583851-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131601
4583857|4583857-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907131601
4583981|4583981-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200907131612
4584863|4584863-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris-thread-multi-64int|5.8.9|solaris|2.10|200907132227
4585974|4585974-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907131849
4586880|4586880-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907131912
4587509|4587509-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907131930
4592037|4592037-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140049
4592306|4592306-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker9@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140054
4592512|4592512-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140058
4592516|4592516-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Compare|1.2101|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140058
4593018|4593018-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker2@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140108
4594236|4594236-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907140214
4594643|4594643-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100rc1@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140224
4594872|4594872-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140228
4594982|4594982-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Devel-CheckOS|1.61|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140232
4596367|4596367-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|XML-DoubleEncodedEntities|1.0|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140016
4597698|4597698-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140102
4598012|4598012-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker1@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907140115
4598708|4598708-b19f-3f77-b713-d32bba55d77f|pass|200907|dagolden@cpan.org (DAGOLDEN)|Data-Hexdumper|2.01|i686-linux|5.10.0|linux|2.6.24-16-generic|200907140134
4601456|4601456-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907140949
4602561|4602561-b19f-3f77-b713-d32bba55d77f|pass|200907|rlane10@wi.rr.com|XML-Tiny|2.02|darwin-2level-ld|5.10.0|darwin|8.11.0|200907131744
4602940|4602940-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907141207
4604012|4604012-b19f-3f77-b713-d32bba55d77f|pass|200907|rlane10@wi.rr.com|Data-Compare|1.2101|darwin-2level-ld|5.10.0|darwin|8.11.0|200907140017
4604872|4604872-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907141101
4607004|4607004-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141440
4607329|4607329-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141447
4607619|4607619-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907150455
4607683|4607683-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker1@gmail.com|Acme-Pony|1.1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141456
4607720|4607720-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141457
4608133|4608133-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907141508
4608570|4608570-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker2@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907141521
4609794|4609794-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907141613
4609870|4609870-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141618
4609992|4609992-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker8@gmail.com|Statistics-ChiSquare|0.5|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141626
4610487|4610487-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100rc1@gmail.com|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907141651
4610683|4610683-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907141704
4613112|4613112-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.10.0|solaris|2.10|200907150041
4613819|4613819-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150123
4614138|4614138-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150129
4614220|4614220-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150130
4614373|4614373-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150135
4614428|4614428-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.10.0|solaris|2.10|200907150229
4614510|4614510-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150139
4614822|4614822-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150147
4615657|4615657-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150203
4615833|4615833-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907151208
4616803|4616803-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907150231
4616912|4616912-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150234
4617048|4617048-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907150237
4617508|4617508-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907150252
4617761|4617761-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907150301
4617769|4617769-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907150301
4618251|4618251-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker8@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907150320
4618423|4618423-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907150327
4618835|4618835-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907150014
4619260|4619260-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd|5.10.0|openbsd|4.5|200907150624
4619512|4619512-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Number-Phone|1.7002|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907151559
4619590|4619590-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907150211
4621302|4621302-b19f-3f77-b713-d32bba55d77f|pass|200907|rlane10@wi.rr.com|CPAN-FindDependencies|2.32|darwin-2level-ld|5.10.0|darwin|8.11.0|200907150419
4621671|4621671-b19f-3f77-b713-d32bba55d77f|pass|200907|rlane10@wi.rr.com|Tie-STDOUT|1.0401|darwin-2level-ld|5.10.0|darwin|8.11.0|200907150313
4624249|4624249-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907151055
4624872|4624872-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.10.0|solaris|2.10|200907151641
4625368|4625368-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151203
4625837|4625837-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151218
4625969|4625969-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker9@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151223
4627715|4627715-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151317
4628368|4628368-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100rc1@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151335
4628526|4628526-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151339
4628665|4628665-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907151342
4628688|4628688-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907151343
4628794|4628794-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907151346
4628889|4628889-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151348
4629707|4629707-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151407
4630823|4630823-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907151434
4630984|4630984-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151438
4631460|4631460-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907151449
4632093|4632093-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907151505
4633617|4633617-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Data-Compare|1.2101|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907151433
4634323|4634323-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.10.0 patch 35117|linux|2.6.22-1-k7|200907160049
4634327|4634327-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200907160049
4634331|4634331-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.8.8|linux|2.6.22-1-k7|200907160050
4634337|4634337-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.8.6|linux|2.6.22-1-k7|200907160050
4634415|4634415-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|x86_64-linux|5.8.9|linux|2.6.26-1-amd64|200907160049
4634416|4634416-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200907160049
4634419|4634419-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.10.0|linux|2.6.22-1-k7|200907160049
4634422|4634422-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny|2.02|x86_64-linux-thread-multi-ld|5.8.7|linux|2.6.26-1-amd64|200907160049
4634425|4634425-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|i686-linux-64int|5.8.9 patch 35054|linux|2.6.22-1-k7|200907160049
4634429|4634429-b19f-3f77-b713-d32bba55d77f|pass|200907|andreas.koenig.gmwojprw@franz.ak.mind.de|XML-Tiny-DOM|1.1|x86_64-linux-ld|5.10.0|linux|2.6.26-1-amd64|200907160049
4634824|4634824-b19f-3f77-b713-d32bba55d77f|pass|200907|d@0x64.nl|XML-Tiny|2.02|x86_64-linux-gnu-thread-multi|5.10.0|linux|2.6.18-xen-3.1-1-amd64|200907160148
4634841|4634841-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|XML-Tiny|2.02|i86pc-solaris|5.10.0|solaris|2.10|200907160049
4634842|4634842-b19f-3f77-b713-d32bba55d77f|pass|200907|bob@randomness.org.uk ("bob walker")|XML-Tiny-DOM|1.1|i86pc-solaris|5.10.0|solaris|2.10|200907160049
4635870|4635870-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160216
4636206|4636206-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160224
4636248|4636248-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160225
4636328|4636328-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160227
4636370|4636370-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160229
4636463|4636463-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160230
4636486|4636486-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160231
4636491|4636491-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160231
4636498|4636498-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160231
4636504|4636504-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160232
4636816|4636816-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160239
4636978|4636978-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160243
4637219|4637219-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160248
4637232|4637232-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160248
4637370|4637370-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160252
4637559|4637559-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker6@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160256
4638074|4638074-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160309
4638138|4638138-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160311
4638165|4638165-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907160311
4638490|4638490-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160319
4638511|4638511-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160319
4638893|4638893-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907160326
4638928|4638928-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907160327
4639286|4639286-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160334
4639697|4639697-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907160341
4639780|4639780-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker9@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160343
4639837|4639837-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160344
4640761|4640761-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160001
4641105|4641105-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160007
4641254|4641254-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.589@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160011
4641365|4641365-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160013
4641432|4641432-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.5100rc1@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907160415
4641695|4641695-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907160020
4641896|4641896-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907160024
4641964|4641964-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907161432
4642113|4642113-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Class-CanBeA|1.2|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200907160701
4642584|4642584-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|XML-Tiny-DOM|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200907160819
4642769|4642769-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907160244
4642889|4642889-b19f-3f77-b713-d32bba55d77f|pass|200907|srezic@cpan.org|XML-Tiny-DOM|1.1|amd64-freebsd|5.8.8|freebsd|7.0-release|200907160819
4643151|4643151-b19f-3f77-b713-d32bba55d77f|pass|200907|rbo@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.10.0|solaris|2.11|200907160938
4643156|4643156-b19f-3f77-b713-d32bba55d77f|pass|200907|rbo@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.10.0|solaris|2.11|200907160938
4643181|4643181-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.1|i86pc-solaris-64int|5.8.9|solaris|2.11|200907160940
4643740|4643740-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907160437
4643788|4643788-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-FindDependencies|2.32|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907161842
4644442|4644442-b19f-3f77-b713-d32bba55d77f|pass|200907|JOST@cpan.org ("Josts Smokehouse")|XML-Tiny-DOM|1.1|i86pc-solaris-64int|5.10.0|solaris|2.11|200907161148
4644963|4644963-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sub-WrapPackages|1.2|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907160651
4645303|4645303-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny|2.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907162128
4645305|4645305-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-Tiny-DOM|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907162128
4645687|4645687-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161314
4645977|4645977-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.4|solaris|2.10|200907161337
4646029|4646029-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200907161354
4646032|4646032-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|alpha-linux-thread-multi|5.8.9|linux|2.6.18-5-alpha-generic|200907161354
4647482|4647482-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161648
4647484|4647484-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907161648
4648067|4648067-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.4|solaris|2.10|200907161740
4648068|4648068-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.4|solaris|2.10|200907161740
4648200|4648200-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Palm-TreoPhoneCallDB|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200907161803
4648524|4648524-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Overwrite|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170335
4648541|4648541-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Data-Hexdumper|2.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170337
4648543|4648543-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-Treo680MessagesDB|1.01|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170337
4648712|4648712-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170406
4648774|4648774-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170414
4648795|4648795-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|XML-DoubleEncodedEntities|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170416
4650105|4650105-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|CPAN-ParseDistribution|1.1|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907170713
4651682|4651682-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Palm-ProjectGutenberg|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907171043
4651954|4651954-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907170132
4652268|4652268-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170140
4652873|4652873-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170151
4653083|4653083-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-CanBeA|1.2|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907170154
4654658|4654658-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170221
4654844|4654844-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170224
4655268|4655268-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170231
4655618|4655618-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170237
4655837|4655837-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170241
4655918|4655918-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170242
4656529|4656529-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170253
4656980|4656980-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170300
4657149|4657149-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170303
4657261|4657261-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170305
4657302|4657302-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170306
4657775|4657775-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker3@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170314
4658482|4658482-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Games-Dice-Advanced|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907170719
4660328|4660328-b19f-3f77-b713-d32bba55d77f|pass|200907|mw487.yahoo.com@gmail.com|XML-Tiny|2.02|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200907170430
4660329|4660329-b19f-3f77-b713-d32bba55d77f|pass|200907|mw487.yahoo.com@gmail.com|XML-Tiny-DOM|1.1|cygwin-thread-multi-64int|5.8.8|cygwin|1.5.24(0.15642)|200907170430
4661398|4661398-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200907171253
4661401|4661401-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200907171253
4661415|4661415-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200907171255
4661431|4661431-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200907171257
4661464|4661464-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200907171300
4661533|4661533-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|IP35-irix-64int|5.8.8|irix|6.5|200907171407
4661564|4661564-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170808
4661958|4661958-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170814
4662192|4662192-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200907170718
4662804|4662804-b19f-3f77-b713-d32bba55d77f|pass|200907|david@cantrell.org.uk|XML-Tiny-DOM|1.1|alpha-netbsd|5.10.0|netbsd|4.0.1|200907171229
4663313|4663313-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170837
4663621|4663621-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170843
4663720|4663720-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170844
4664180|4664180-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170853
4664278|4664278-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone-UK-DetailedLocations|1.3|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171454
4664802|4664802-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907170904
4665344|4665344-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170917
4665388|4665388-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-DoubleEncodedEntities|1.0|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907171517
4665754|4665754-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170926
4665870|4665870-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907170929
4666228|4666228-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170938
4666307|4666307-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907170939
4666852|4666852-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907170952
4667124|4667124-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Net-Random|2.0|i686-linux|5.10.0|linux|2.6.24-24-generic|200907171458
4667249|4667249-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907171001
4667384|4667384-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907170958
4667385|4667385-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907171005
4667875|4667875-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907171011
4668443|4668443-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sub-WrapPackages|1.2|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907171645
4668869|4668869-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|XML-Tiny-DOM|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200907171632
4669009|4669009-b19f-3f77-b713-d32bba55d77f|pass|200907|mw487.yahoo.com@gmail.com|XML-Tiny-DOM|1.1|cygwin-thread-multi-64int|5.10.0 patch 34065|cygwin|1.5.25(0.15642)|200907171046
4669047|4669047-b19f-3f77-b713-d32bba55d77f|pass|200907|imacat@mail.imacat.idv.tw|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi-ld|5.10.0|linux|2.6.26-2-amd64|200907172349
4669741|4669741-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907171303
4670334|4670334-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Data-Compare|1.2101|darwin-2level|5.10.0|darwin|9.2.0|200907171125
4671283|4671283-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Acme-Scurvy-Whoreson-BilgeRat|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907171633
4671648|4671648-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907171716
4671927|4671927-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907172350
4671999|4671999-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.4|solaris|2.10|200907172251
4672619|4672619-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|OpenBSD.i386-openbsd|5.8.9|openbsd|4.5|200907180031
4674327|4674327-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180349
4674411|4674411-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180350
4674434|4674434-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180351
4674539|4674539-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180353
4674767|4674767-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180357
4675124|4675124-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180003
4675431|4675431-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180008
4675636|4675636-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180011
4675805|4675805-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180014
4676270|4676270-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180022
4676337|4676337-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180023
4676432|4676432-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180025
4676443|4676443-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180025
4676767|4676767-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180031
4677024|4677024-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180035
4677109|4677109-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker7@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180036
4677491|4677491-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907180043
4677604|4677604-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180045
4677657|4677657-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180046
4677709|4677709-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180047
4677826|4677826-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180049
4677839|4677839-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180049
4678039|4678039-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker7@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180052
4678294|4678294-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180057
4678300|4678300-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180057
4678463|4678463-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907180100
4679104|4679104-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907180111
4679221|4679221-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180112
4679505|4679505-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180117
4679661|4679661-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907180114
4680003|4680003-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907180126
4680011|4680011-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907180126
4680012|4680012-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907180126
4680459|4680459-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Statistics-SerialCorrelation|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907180202
4681097|4681097-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Devel-CheckLib|0.6|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907180052
4683638|4683638-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.5|solaris|2.10|200907181645
4683794|4683794-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181617
4684198|4684198-b19f-3f77-b713-d32bba55d77f|pass|200907|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200907181909
4684801|4684801-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907181501
4684816|4684816-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181904
4684817|4684817-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907181904
4685287|4685287-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.5|solaris|2.10|200907182056
4685289|4685289-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.5|solaris|2.10|200907182056
4686216|4686216-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.10.0|midnightbsd|0.1.1-release|200907182221
4687806|4687806-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190148
4688258|4688258-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190202
4689003|4689003-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sub-WrapPackages|1.2|x86_64-linux-thread-multi|5.10.0|linux|2.6.28-13-generic|200907190222
4689093|4689093-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker4@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190225
4689354|4689354-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190232
4689539|4689539-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200907190437
4690135|4690135-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190254
4690209|4690209-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190256
4690327|4690327-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190259
4690343|4690343-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190300
4691116|4691116-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190322
4691463|4691463-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190332
4691475|4691475-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190333
4691591|4691591-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200907190536
4691880|4691880-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200907190544
4692559|4692559-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190004
4692617|4692617-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190006
4692751|4692751-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190010
4692801|4692801-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200907190611
4693163|4693163-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200907190622
4693332|4693332-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190026
4693368|4693368-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190027
4693385|4693385-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190027
4693973|4693973-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190040
4694031|4694031-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190041
4694233|4694233-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200907190650
4694248|4694248-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200907190653
4694346|4694346-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200907190714
4694428|4694428-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200907190726
4694572|4694572-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200907190755
4696598|4696598-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907190729
4696871|4696871-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Tie-STDOUT|1.0401|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907192209
4697025|4697025-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Number-Phone|1.7002|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907190531
4697271|4697271-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190852
4697442|4697442-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190855
4697558|4697558-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190857
4697654|4697654-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190859
4698043|4698043-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190906
4698512|4698512-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190913
4698533|4698533-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200907191513
4698863|4698863-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190918
4699137|4699137-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190922
4699232|4699232-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907190924
4699628|4699628-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190923
4699810|4699810-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907190932
4699875|4699875-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190933
4699879|4699879-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190933
4700004|4700004-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.10.0|linux|2.6.18-92.el5|200907191535
4700076|4700076-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190936
4700385|4700385-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190940
4700454|4700454-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190941
4700870|4700870-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190948
4701167|4701167-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|XML-Tiny-DOM|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907190952
4701203|4701203-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907190953
4701471|4701471-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200907191557
4701504|4701504-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907190958
4701657|4701657-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191000
4701675|4701675-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907191000
4701711|4701711-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191001
4702499|4702499-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker4@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907191012
4702819|4702819-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907191018
4702871|4702871-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907191015
4703708|4703708-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907191837
4703769|4703769-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|WWW-Facebook-Go-SGF|1.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200249
4704419|4704419-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200907192050
4705001|4705001-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907191638
4705002|4705002-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907191638
4705243|4705243-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|File-Find-Rule-Permissions|2.0|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200704
4705297|4705297-b19f-3f77-b713-d32bba55d77f|pass|200907|ivan.wills@gmail.com ("Ivan Wills")|Class-DBI-ClassGenerator|1.02|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200907200716
4705526|4705526-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.5|solaris|2.10|200907192228
4705550|4705550-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-Hash-Longest|1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907191750
4705553|4705553-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Statistics-ChiSquare|0.5|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907191751
4706314|4706314-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200907200156
4706513|4706513-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200907200225
4707166|4707166-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200907200404
4707303|4707303-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907200223
4707357|4707357-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200907200430
4707437|4707437-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|File-Overwrite|1.1|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200243
4707453|4707453-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Palm-Treo680MessagesDB|1.01|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200247
4707625|4707625-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907200308
4708033|4708033-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200315
4708183|4708183-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200317
4708476|4708476-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200322
4708494|4708494-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907200322
4708730|4708730-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200326
4708755|4708755-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200327
4708867|4708867-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907200328
4708923|4708923-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907200329
4709124|4709124-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200333
4709294|4709294-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907200336
4709804|4709804-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|XML-DoubleEncodedEntities|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200352
4709942|4709942-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200907200614
4710017|4710017-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200907200624
4710203|4710203-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200907200652
4710308|4710308-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200907200710
4710422|4710422-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Class-CanBeA|1.2|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200907200732
4710706|4710706-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|NestedMap|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907200221
4710934|4710934-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200907200853
4711638|4711638-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200907201049
4711887|4711887-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200907201118
4712297|4712297-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200907201213
4713036|4713036-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Palm-ProjectGutenberg|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200517
4713051|4713051-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|XML-Tiny|2.02|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200519
4713053|4713053-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|XML-Tiny-DOM|1.0|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907200519
4713510|4713510-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907201528
4714122|4714122-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201409
4714157|4714157-b19f-3f77-b713-d32bba55d77f|pass|200907|smoretti@unil.ch|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.8|linux|2.6.18|200907201503
4714326|4714326-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907201106
4714607|4714607-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan@greerga.m-l.org ("George Greer")|Acme-Licence|1.0|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907201132
4714625|4714625-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907201734
4714723|4714723-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907201744
4714785|4714785-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.6|solaris|2.10|200907201628
4714791|4714791-b19f-3f77-b713-d32bba55d77f|pass|200907|smoretti@unil.ch|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.8.8|linux|2.6.22|200907201511
4715034|4715034-b19f-3f77-b713-d32bba55d77f|pass|200907|smoretti@unil.ch|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.8|linux|2.6.22|200907201456
4715230|4715230-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201614
4715231|4715231-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907201614
4715601|4715601-b19f-3f77-b713-d32bba55d77f|pass|200907|smoretti@unil.ch|Data-Compare|1.2101|x86_64-linux-thread-multi|5.8.8|linux|2.6.18|200907201502
4715947|4715947-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.6|solaris|2.10|200907201914
4715948|4715948-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.6|solaris|2.10|200907201914
4716136|4716136-b19f-3f77-b713-d32bba55d77f|pass|200907|justin.d.hunter@gmail.com|XML-Tiny-DOM|1.1|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200907201206
4716432|4716432-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201527
4716993|4716993-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201540
4717571|4717571-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201556
4717610|4717610-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201558
4718756|4718756-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201629
4718957|4718957-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907201634
4719752|4719752-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201653
4720131|4720131-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201703
4721277|4721277-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907201731
4721837|4721837-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907201744
4722317|4722317-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny|2.02|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907210005
4722318|4722318-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907210005
4722383|4722383-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200907210015
4722586|4722586-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-midnightbsd-64int|5.8.9|midnightbsd|0.1.1-release|200907202212
4722831|4722831-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan@greerga.m-l.org ("George Greer")|DBIx-Class-SingletonRows|0.11|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907201938
4723007|4723007-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.6|solaris|2.10|200907210047
4723011|4723011-b19f-3f77-b713-d32bba55d77f|pass|200907|jeff@zeroclue.com|Devel-CheckOS|1.61|OpenBSD.i386-openbsd|5.8.9|openbsd|4.4|200907210018
4723047|4723047-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.6|solaris|2.10|200907210047
4724039|4724039-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|XML-Tiny-DOM|1.1|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907210542
4724306|4724306-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907210041
4724307|4724307-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907210041
4724353|4724353-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan@greerga.m-l.org ("George Greer")|Acme-Pony|1.1.2|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907210058
4724408|4724408-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-Hash-Rank|1.0.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907210106
4724466|4724466-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-Scalar-Decay|1.1.1|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200907210115
4726820|4726820-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Number-Phone-UK-DetailedLocations|1.3|i686-linux|5.10.0|linux|2.6.24-24-generic|200907211436
4727205|4727205-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907211641
4727777|4727777-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907211740
4728842|4728842-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211652
4728996|4728996-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211656
4729264|4729264-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211703
4729664|4729664-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211713
4729798|4729798-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211717
4729813|4729813-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211711
4729857|4729857-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211719
4729942|4729942-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211721
4730085|4730085-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker8@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211726
4730251|4730251-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211730
4730584|4730584-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907212339
4730799|4730799-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211745
4730847|4730847-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211746
4731080|4731080-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211752
4731095|4731095-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211753
4731335|4731335-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907220001
4731476|4731476-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211805
4731484|4731484-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211805
4731603|4731603-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker9@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211809
4731685|4731685-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211812
4732050|4732050-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211826
4732155|4732155-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211832
4732316|4732316-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211837
4732353|4732353-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211838
4732472|4732472-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211844
4732595|4732595-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907211848
4733281|4733281-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907211904
4733717|4733717-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907211915
4733721|4733721-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907211915
4733867|4733867-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211917
4734326|4734326-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907211926
4735046|4735046-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907220258
4735049|4735049-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200907220259
4736094|4736094-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220341
4736223|4736223-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220343
4736259|4736259-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220344
4736492|4736492-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220348
4736767|4736767-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220353
4737561|4737561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220007
4737751|4737751-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907220637
4738756|4738756-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907221021
4738758|4738758-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200907221022
4739306|4739306-b19f-3f77-b713-d32bba55d77f|pass|200907|lists.perl.cpan-testers@csjewell.fastmail.us ("Curtis Jewell")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200907211532
4740469|4740469-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220831
4740653|4740653-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220840
4740953|4740953-b19f-3f77-b713-d32bba55d77f|pass|200907|lists.perl.cpan-testers@csjewell.fastmail.us ("Curtis Jewell")|Devel-CheckOS|1.61|MSWin32-x86-multi-thread|5.8.9|MSWin32|5.1|200907211527
4740997|4740997-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220854
4741094|4741094-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220858
4741246|4741246-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907220905
4741469|4741469-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907220915
4741479|4741479-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907220915
4741830|4741830-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221429
4741849|4741849-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.7|solaris|2.10|200907221406
4742430|4742430-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221553
4742432|4742432-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221553
4742565|4742565-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907221611
4743085|4743085-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.7|solaris|2.10|200907221650
4743087|4743087-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny-DOM|1.1|i86pc-solaris|5.8.7|solaris|2.10|200907221650
4744386|4744386-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.7|solaris|2.10|200907222028
4746636|4746636-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907230241
4747402|4747402-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907230255
4747480|4747480-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907230257
4749275|4749275-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Class-CanBeA|1.2|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200907231117
4749357|4749357-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200907231137
4749367|4749367-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Sort-MultipleFields|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907231139
4750418|4750418-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200907231350
4750433|4750433-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i386-netbsd-thread-multi-64int|5.6.2|netbsd|3.1|200907231350
4751010|4751010-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907231449
4752187|4752187-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Games-Dice-Advanced|1.1|i686-linux|5.10.0|linux|2.6.24-24-generic|200907231741
4753484|4753484-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-ProjectGutenberg|1.0|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907232226
4753687|4753687-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907232225
4757596|4757596-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Tie-STDOUT|1.0401|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200907240637
4758816|4758816-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|DBIx-Class-SingletonRows|0.11|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907241207
4759796|4759796-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Sub-WrapPackages|1.2|i686-linux|5.10.0|linux|2.6.24-24-generic|200907241418
4761089|4761089-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Data-Transactional|1.02|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907241927
4761641|4761641-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241553
4761907|4761907-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241558
4761962|4761962-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Acme-Licence|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242057
4762027|4762027-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Acme-Pony|1.1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242058
4762057|4762057-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242059
4762699|4762699-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241611
4763409|4763409-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241630
4763679|4763679-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241638
4764204|4764204-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241653
4764207|4764207-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241653
4764410|4764410-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241657
4764563|4764563-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Memory|1.1001|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907242300
4764585|4764585-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|CPU-Emulator-Z80|1.0|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200907242301
4765186|4765186-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241718
4765197|4765197-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241719
4765368|4765368-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-TreoPhoneCallDB|1.1|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200907242323
4765508|4765508-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241727
4766048|4766048-b19f-3f77-b713-d32bba55d77f|fail|200907|bingos@cpan.org|Bryar|3.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242241
4766195|4766195-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907241747
4766906|4766906-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907241806
4766918|4766918-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907241806
4767080|4767080-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Class-CanBeA|1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242340
4767090|4767090-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907242342
4767216|4767216-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-FindDependencies|2.32|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250006
4767222|4767222-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250007
4767242|4767242-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.8|solaris|2.10|200907250014
4767247|4767247-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.8|solaris|2.10|200907250015
4767253|4767253-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250014
4767259|4767259-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|CPU-Emulator-Z80|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250016
4767284|4767284-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Transactional|1.02|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250020
4767308|4767308-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Palm-SMS|0.03|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200907250127
4767321|4767321-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Hexdumper|2.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250033
4767455|4767455-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250110
4767658|4767658-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250150
4767670|4767670-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|File-Overwrite|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250152
4767716|4767716-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Games-Dice-Advanced|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250158
4768209|4768209-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|NestedMap|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250354
4768326|4768326-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Net-Random|2.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250423
4768447|4768447-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Number-Phone-UK-DetailedLocations|1.3|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250450
4768469|4768469-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250452
4768471|4768471-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Palm-SMS|0.03|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250452
4768477|4768477-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250453
4768479|4768479-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250453
4768725|4768725-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@sourcentral.org ("Oliver Paukstadt")|Number-Phone|1.7002|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200907250641
4768945|4768945-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Sort-MultipleFields|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250620
4768953|4768953-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Statistics-ChiSquare|0.5|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250621
4768963|4768963-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Statistics-SerialCorrelation|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250622
4768975|4768975-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Sub-WrapPackages|1.2|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250624
4769229|4769229-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Tie-Hash-Longest|1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250742
4769230|4769230-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Tie-Hash-Rank|1.0.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250743
4769240|4769240-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Tie-Scalar-Decay|1.1.1|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250744
4769245|4769245-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Tie-STDOUT|1.0401|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250745
4769310|4769310-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907250304
4769374|4769374-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250813
4769404|4769404-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200907250820
4772144|4772144-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.8|solaris|2.10|200907251628
4773792|4773792-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907251904
4775104|4775104-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-FindDependencies|2.32|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907260149
4775553|4775553-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907260419
4776129|4776129-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907260636
4776271|4776271-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907260710
4777981|4777981-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261352
4777992|4777992-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261353
4777994|4777994-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-Treo680MessagesDB|1.01|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261354
4778184|4778184-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907261507
4778222|4778222-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Games-Dice-Advanced|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907261530
4779160|4779160-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sub-WrapPackages|1.2|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907270040
4779458|4779458-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Acme-Scurvy-Whoreson-BilgeRat|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270135
4780487|4780487-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Sub-WrapPackages|1.2|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907270154
4780790|4780790-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270201
4781139|4781139-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907270207
4781555|4781555-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907270214
4782041|4782041-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Class-CanBeA|1.2|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270221
4782527|4782527-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270230
4782702|4782702-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|NestedMap|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907270235
4784721|4784721-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPAN-ParseDistribution|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907270007
4785258|4785258-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907270329
4785363|4785363-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.8.9|solaris|2.10|200907270827
4785631|4785631-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907270504
4787287|4787287-b19f-3f77-b713-d32bba55d77f|fail|200907|srezic@cpan.org|CPAN-ParseDistribution|1.1|amd64-freebsd|5.8.9|freebsd|7.0-release|200907271524
4787828|4787828-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Compare|1.2101|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907271030
4787829|4787829-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckOS|1.61|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907271031
4788787|4788787-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907271228
4789010|4789010-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271234
4789800|4789800-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271256
4789891|4789891-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907271258
4790105|4790105-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271302
4790747|4790747-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907271317
4790947|4790947-b19f-3f77-b713-d32bba55d77f|unknown|200907|cpan.dcollins.smoker4@gmail.com|Acme-Licence|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907271323
4792200|4792200-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker1@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907271353
4792737|4792737-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907271403
4793286|4793286-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907271415
4793847|4793847-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907271428
4795317|4795317-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-Tiny|2.02|i86pc-solaris|5.8.9|solaris|2.10|200907272153
4795937|4795937-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Find-Rule-Permissions|2.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907271919
4796030|4796030-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907271934
4796876|4796876-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.8.9|solaris|2.10|200907280301
4797142|4797142-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280347
4797551|4797551-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker6@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907280001
4797652|4797652-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker6@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280004
4798180|4798180-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907280023
4798837|4798837-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280044
4798876|4798876-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280045
4799411|4799411-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi-ld|0|linux|2.6.30-020630rc7-generic|200907280102
4801043|4801043-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Net-Random|2.0|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907280149
4801469|4801469-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Tie-Hash-Longest|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907280202
4805809|4805809-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny|2.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907280904
4805810|4805810-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-Tiny-DOM|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907280904
4807753|4807753-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.5100rc1@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281324
4807821|4807821-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281326
4808122|4808122-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281340
4808250|4808250-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281346
4808263|4808263-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281347
4808312|4808312-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281349
4808489|4808489-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281357
4808561|4808561-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker5@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281400
4808910|4808910-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Palm-Treo680MessagesDB|1.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281412
4809032|4809032-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281417
4809484|4809484-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281437
4809580|4809580-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281442
4809616|4809616-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Number-Phone|1.7002|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281444
4809766|4809766-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Data-Hexdumper|2.01|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281450
4809815|4809815-b19f-3f77-b713-d32bba55d77f|pass|200907|stsc@refcnt.org ("Steven Schubiger")|Data-Compare|1.2101|i386-netbsd|5.10.0|netbsd|netbsd|200907282118
4809923|4809923-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281456
4810049|4810049-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281502
4810368|4810368-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Games-Dice-Advanced|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907281517
4810746|4810746-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907281534
4810888|4810888-b19f-3f77-b713-d32bba55d77f|pass|200907|vpit@cpan.org|Data-Compare|1.2101|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200907282141
4810893|4810893-b19f-3f77-b713-d32bba55d77f|pass|200907|vpit@cpan.org|Devel-CheckOS|1.61|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200907282142
4810899|4810899-b19f-3f77-b713-d32bba55d77f|pass|200907|vpit@cpan.org|Devel-CheckLib|0.6|i686-linux-64int-ld|5.10.0|linux|2.6.27.4-chii.profvince.com|200907282142
4810946|4810946-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907281544
4811574|4811574-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi-ld|5.11.0 patch GitLive-blead-1437-g8bca5c8|linux|2.6.30-020630rc7-generic|200907281615
4811774|4811774-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907281625
4814578|4814578-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i86pc-solaris|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|solaris|2.10|200907290313
4819098|4819098-b19f-3f77-b713-d32bba55d77f|pass|200907|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckOS|1.61|i386-netbsd|5.10.0|netbsd|netbsd|200907291456
4820061|4820061-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.6|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907290956
4820448|4820448-b19f-3f77-b713-d32bba55d77f|pass|200907|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny|2.02|i386-netbsd|5.10.0|netbsd|netbsd|200907291654
4820449|4820449-b19f-3f77-b713-d32bba55d77f|pass|200907|stsc@refcnt.org ("Steven Schubiger")|XML-Tiny-DOM|1.1|i386-netbsd|5.10.0|netbsd|netbsd|200907291655
4823714|4823714-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Devel-CheckOS|1.61|i86pc-solaris|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|solaris|2.10|200907292003
4825395|4825395-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Number-Phone|1.7002|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907291932
4826793|4826793-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|File-Overwrite|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300348
4826798|4826798-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Hexdumper|2.01|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300349
4826874|4826874-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|XML-DoubleEncodedEntities|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300009
4827916|4827916-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|XML-DoubleEncodedEntities|1.0|darwin-thread-multi-64int-2level|5.11.0 patch GitLive-blead-1530-g9ef4351|darwin|8.11.0|200907300858
4828085|4828085-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-ProjectGutenberg|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300439
4828773|4828773-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Tie-STDOUT|1.0401|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907300553
4828809|4828809-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200907301101
4830093|4830093-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|WWW-Facebook-Go-SGF|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907301022
4830604|4830604-b19f-3f77-b713-d32bba55d77f|pass|200907|martin.evans@easysoft.com|Class-CanBeA|1.2|i686-linux|5.10.0|linux|2.6.24-24-generic|200907301722
4831139|4831139-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Class-DBI-ClassGenerator|1.02|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907301444
4831877|4831877-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301639
4832526|4832526-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907301658
4832602|4832602-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-TreoPhoneCallDB|1.1|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301700
4832848|4832848-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301702
4832941|4832941-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301712
4834489|4834489-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301755
4834573|4834573-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301758
4834631|4834631-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.589@gmail.com|CPU-Emulator-Z80|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301800
4835010|4835010-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker8@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301811
4835244|4835244-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker4@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301818
4835519|4835519-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301827
4835549|4835549-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Transactional|1.02|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907301828
4836427|4836427-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|DBIx-Class-SingletonRows|0.11|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907301903
4838604|4838604-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Palm-SMS|0.03|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200907310034
4839855|4839855-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|Data-Transactional|1.02|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907310542
4840095|4840095-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907310646
4840097|4840097-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200907310646
4840531|4840531-b19f-3f77-b713-d32bba55d77f|pass|200907|bingos@cpan.org|Data-Compare|1.2101|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200907311328
4842519|4842519-b19f-3f77-b713-d32bba55d77f|fail|200907|cpan.dcollins.smoker2@gmail.com|Bryar|3.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907311410
4844313|4844313-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.9|linux|2.6.28-11-generic|200907311536
4845009|4845009-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker3@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907311607
4845743|4845743-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker9@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200907311646
4846078|4846078-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200907311659
4847414|4847414-b19f-3f77-b713-d32bba55d77f|pass|200907|cpan.dcollins.5100rc1@gmail.com|Net-Random|2.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200907311757
4851358|4851358-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|XML-Tiny|2.02|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200908011250
4851715|4851715-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Data-Compare|1.2101|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908011425
4852452|4852452-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Sort-MultipleFields|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908011244
4853386|4853386-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.699_001|i686-linux-thread-multi|5.10.0|linux|2.6.18-14-ovz-686|200908020009
4853535|4853535-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckOS|1.61|i386-freebsd-thread-multi-64int|5.10.0|freebsd|6.4-release|200908012354
4854502|4854502-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker4@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020311
4854613|4854613-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan.dcollins.smoker9@gmail.com|Bryar|3.1|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020315
4854637|4854637-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker6@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020316
4854663|4854663-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Memory|1.1001|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908020317
4854672|4854672-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|CPU-Emulator-Z80|1.0|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908020317
4854788|4854788-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker6@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020322
4854794|4854794-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker2@gmail.com|File-Find-Rule-Permissions|2.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020322
4855483|4855483-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker5@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020349
4855884|4855884-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker8@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020011
4856011|4856011-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker2@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020017
4856136|4856136-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker3@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020024
4856821|4856821-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker2@gmail.com|CPAN-ParseDistribution|1.1|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020047
4857016|4857016-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker2@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020054
4857045|4857045-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.6.2|linux|2.6.18-92.1.18.el5|200908020656
4857064|4857064-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.6.2|linux|2.6.16.60-0.31-default|200908020657
4857190|4857190-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.6.2|linux|2.6.5-7.315-s390|200908020703
4857211|4857211-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.6.2|linux|2.6.27.19-5-default|200908020703
4857222|4857222-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker5@gmail.com|Palm-ProjectGutenberg|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020104
4857286|4857286-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi|5.6.2|linux|2.6.5-7.315-s390|200908020706
4857325|4857325-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.9|linux|2.6.16.60-0.31-default|200908020707
4857353|4857353-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi-perlio|5.6.2|linux|2.6.5-7.315-s390|200908020708
4858185|4858185-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.6.2|linux|2.6.16.60-0.31-default|200908020741
4858329|4858329-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.6.2|linux|2.6.18-92.1.18.el5|200908020746
4858505|4858505-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020152
4858543|4858543-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.6.2|linux|2.6.27.19-5-default|200908020753
4858638|4858638-b19f-3f77-b713-d32bba55d77f|fail|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi-perlio|5.6.2|linux|2.6.27.19-5-default|200908020756
4858662|4858662-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020157
4858721|4858721-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker9@gmail.com|Palm-SMS|0.03|i686-linux-thread-multi-ld|5.10.0|linux|2.6.28-11-generic|200908020159
4858855|4858855-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.8|linux|2.6.16.60-0.31-default|200908020803
4858882|4858882-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.10.0|linux|2.6.16.60-0.31-default|200908020803
4859017|4859017-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker5@gmail.com|Devel-CheckLib|0.699_001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908020208
4859047|4859047-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.8|linux|2.6.18-92.1.18.el5|200908020808
4859059|4859059-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.8|linux|2.6.18-92.1.18.el5|200908020809
4859061|4859061-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.9|linux|2.6.18-92.1.18.el5|200908020809
4859078|4859078-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.8|linux|2.6.16.60-0.31-default|200908020809
4859113|4859113-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.8|linux|2.6.27.19-5-default|200908020811
4859125|4859125-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.9|linux|2.6.16.60-0.31-default|200908020812
4859229|4859229-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.9|linux|2.6.18-92.1.18.el5|200908020816
4859281|4859281-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.8.8|linux|2.6.5-7.315-s390|200908020818
4859325|4859325-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.8|linux|2.6.27.19-5-default|200908020820
4859370|4859370-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckLib|0.699_001|i686-linux-thread-multi-64int|5.10.0|linux|2.6.28-11-generic|200908020721
4859378|4859378-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.10.0|linux|2.6.18-92.el5|200908020822
4859489|4859489-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.10.0|linux|2.6.16.60-0.31-default|200908020826
4859503|4859503-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.8.9|linux|2.6.5-7.315-s390|200908020826
4859523|4859523-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.10.0|linux|2.6.27.19-5-default|200908020827
4859561|4859561-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux|5.10.0|linux|2.6.5-7.315-s390|200908020828
4859580|4859580-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.10.0|linux|2.6.18-92.el5|200908020829
4859600|4859600-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.10.0|linux|2.6.27.19-5-default|200908020830
4859611|4859611-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi|5.10.0|linux|2.6.5-7.315-s390|200908020830
4859672|4859672-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390-linux-thread-multi|5.8.9|linux|2.6.5-7.315-s390|200908020833
4859778|4859778-b19f-3f77-b713-d32bba55d77f|pass|200908|rbo@cpan.org|Devel-CheckLib|0.699_001|i86pc-solaris|5.10.0|solaris|2.11|200908020837
4859785|4859785-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker5@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.9.5|linux|2.6.28-11-generic|200908020237
4860035|4860035-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker6@gmail.com|CPU-Emulator-Memory|1.1001|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908020248
4860130|4860130-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux|5.8.9|linux|2.6.27.19-5-default|200908020859
4860190|4860190-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.8.8|freebsd|7.0-release|200908020832
4860202|4860202-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@sourcentral.org ("Oliver Paukstadt")|Devel-CheckLib|0.699_001|s390x-linux-thread-multi|5.8.9|linux|2.6.27.19-5-default|200908020909
4860303|4860303-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.8.9|freebsd|7.0-release|200908020844
4860543|4860543-b19f-3f77-b713-d32bba55d77f|fail|200908|taro.nishino@gmail.com ("Taro Nishino")|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.8.8|MSWin32|5.0|200908020643
4860975|4860975-b19f-3f77-b713-d32bba55d77f|pass|200908|bob@randomness.org.uk ("bob walker")|Devel-CheckLib|0.699_001|i86pc-solaris|5.10.0|solaris|2.10|200908021022
4861652|4861652-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.10.0|freebsd|7.0-release|200908021238
4861742|4861742-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.8.9 patch 35104|linux|2.6.28-13-generic|200908020651
4863062|4863062-b19f-3f77-b713-d32bba55d77f|fail|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.6.2|linux|2.6.18-4-xen-amd64|200908021508
4863530|4863530-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Devel-CheckLib|0.6|i386-netbsd|5.10.0|netbsd|netbsd|200908021728
4863806|4863806-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Number-Phone|1.7002|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908021643
4863861|4863861-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|IP35-irix-64int|5.8.8|irix|6.5|200908021805
4864171|4864171-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|darwin-thread-multi-2level|5.10.0|darwin|8.10.1|200908021836
4864176|4864176-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|i386-freebsd-thread-multi|5.10.0|freebsd|6.2-release|200908021836
4864184|4864184-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908021338
4864795|4864795-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|sun4-solaris-thread-multi|5.10.0|solaris|2.9|200908021416
4865078|4865078-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.10.0|linux|2.6.18-4-xen-amd64|200908022104
4865325|4865325-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckOS|1.61|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908022138
4868519|4868519-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckLib|0.699_001|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908031005
4868550|4868550-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|x86_64-linux-thread-multi|5.8.9|linux|2.6.18-4-xen-amd64|200908031009
4869499|4869499-b19f-3f77-b713-d32bba55d77f|fail|200908|stro@cpan.org|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200908031336
4869590|4869590-b19f-3f77-b713-d32bba55d77f|pass|200908|jafelds@gmail.com|Data-Compare|1.2101|darwin-64int-ld-2level|5.10.0|darwin|9.6.0|200908030312
4869679|4869679-b19f-3f77-b713-d32bba55d77f|pass|200908|david@cantrell.org.uk|Devel-CheckLib|0.699_001|alpha-netbsd|5.10.0|netbsd|4.0.1|200908031045
4870075|4870075-b19f-3f77-b713-d32bba55d77f|fail|200908|stro@cpan.org|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.8.8|MSWin32|4.0|200908031415
4870093|4870093-b19f-3f77-b713-d32bba55d77f|fail|200908|stro@cpan.org|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.00|200908031417
4870114|4870114-b19f-3f77-b713-d32bba55d77f|pass|200908|stro@cpan.org|Devel-CheckLib|0.699_001|armv5tejl-linux|5.10.0|linux|2.6.17.14|200908031421
4870354|4870354-b19f-3f77-b713-d32bba55d77f|pass|200908|stro@cpan.org|Devel-CheckLib|0.699_001|armv5tejl-linux|5.8.8|linux|2.6.17.14|200908031450
4871800|4871800-b19f-3f77-b713-d32bba55d77f|pass|200908|jafelds@gmail.com|Devel-CheckOS|1.61|darwin-64int-ld-2level|5.10.0|darwin|9.6.0|200908030306
4872249|4872249-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckLib|0.6|darwin-2level|5.10.1 patch GitLive-maint-5.10-1655-g4197df1|darwin|8.11.0|200908031644
4873064|4873064-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|File-Overwrite|1.1|i386-netbsd|5.10.0|netbsd|netbsd|200908031942
4873068|4873068-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Data-Hexdumper|2.01|i386-netbsd|5.10.0|netbsd|netbsd|200908031944
4873109|4873109-b19f-3f77-b713-d32bba55d77f|pass|200908|lists.perl.cpan-testers@csjewell.fastmail.us (Curtis Jewell)|Devel-CheckLib|0.699_001|MSWin32-x86-multi-thread|5.10.0|MSWin32|5.1|200908030741
4873170|4873170-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd-thread-multi|5.10.0|freebsd|7.0-release|200908031927
4873962|4873962-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|XML-Tiny|2.02|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908032028
4874377|4874377-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200908031640
4874737|4874737-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Data-Compare|1.2101|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908032255
4874739|4874739-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckOS|1.61|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908032256
4874821|4874821-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|CPAN-ParseDistribution|1.1|i386-netbsd|5.10.0|netbsd|netbsd|200908040042
4875881|4875881-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Palm-ProjectGutenberg|1.0|i386-netbsd|5.10.0|netbsd|netbsd|200908040434
4876401|4876401-b19f-3f77-b713-d32bba55d77f|pass|200908|stsc@refcnt.org ("Steven Schubiger")|Tie-STDOUT|1.0401|i386-netbsd|5.10.0|netbsd|netbsd|200908040725
4877258|4877258-b19f-3f77-b713-d32bba55d77f|pass|200908|martin.evans@easysoft.com|Devel-CheckLib|0.699_001|i686-linux|5.10.0|linux|2.6.24-24-generic|200908040936
4877958|4877958-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Data-Compare|1.2101|i686-linux|5.10.1|linux|2.6.18-4-486|200908041200
4878602|4878602-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Palm-TreoPhoneCallDB|1.1|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908040651
4878646|4878646-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.10.1|freebsd|7.0-release|200908041253
4878769|4878769-b19f-3f77-b713-d32bba55d77f|fail|200908|srezic@cpan.org|Devel-CheckLib|0.699_001|amd64-freebsd|5.6.2|freebsd|7.0-release|200908041259
4880208|4880208-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Net-Random|2.0|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200908041021
4881714|4881714-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker9@gmail.com|Sort-MultipleFields|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041133
4882362|4882362-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker1@gmail.com|XML-DoubleEncodedEntities|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041204
4882379|4882379-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.589@gmail.com|Devel-CheckLib|0.6|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041204
4882585|4882585-b19f-3f77-b713-d32bba55d77f|pass|200908|justin.d.hunter@gmail.com|Devel-CheckLib|0.699_001|i386-linux-thread-multi|5.8.8|linux|2.6.18-128.1.1.el5|200908040917
4883175|4883175-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Data-Compare|1.2101|amd64-freebsd|5.10.1|freebsd|7.0-release|200908041713
4883344|4883344-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker8@gmail.com|Tie-STDOUT|1.0401|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041248
4883753|4883753-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker3@gmail.com|XML-Tiny-DOM|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041308
4883828|4883828-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker2@gmail.com|CPAN-FindDependencies|2.32|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041311
4883883|4883883-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker9@gmail.com|File-Overwrite|1.1|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041313
4884133|4884133-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker2@gmail.com|Data-Compare|1.2101|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041325
4885068|4885068-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.smoker3@gmail.com|Devel-CheckOS|1.61|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041418
4885149|4885149-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.589@gmail.com|Class-DBI-ClassGenerator|1.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041424
4885175|4885175-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.5100rc1@gmail.com|XML-Tiny|2.02|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041426
4885372|4885372-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan.dcollins.589@gmail.com|WWW-Facebook-Go-SGF|1.0|i686-linux-thread-multi|5.8.8|linux|2.6.28-11-generic|200908041436
4885605|4885605-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.10.1|linux|2.6.28-13-generic|200908041528
4885733|4885733-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckOS|1.61|amd64-freebsd|5.10.1|freebsd|7.0-release|200908042214
4886283|4886283-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|XML-Tiny|2.02|amd64-freebsd|5.10.1|freebsd|7.0-release|200908042328
4886309|4886309-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|XML-Tiny-DOM|1.1|amd64-freebsd|5.10.1|freebsd|7.0-release|200908042328
4887171|4887171-b19f-3f77-b713-d32bba55d77f|pass|200908|cpan@greerga.m-l.org ("George Greer")|Number-Phone-UK-DetailedLocations|1.3|x86_64-linux-thread-multi|5.11.0|linux|2.6.28-13-generic|200908050155
4888300|4888300-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Number-Phone|1.7002|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908050635
4890952|4890952-b19f-3f77-b713-d32bba55d77f|pass|200908|ivan.wills@gmail.com ("Ivan Wills")|Devel-CheckLib|0.699_001|i486-linux-gnu-thread-multi|5.10.0|linux|2.6.24-23-server|200908052139
4891402|4891402-b19f-3f77-b713-d32bba55d77f|fail|200908|srezic@cpan.org|Bryar|3.1|amd64-freebsd|5.10.1|freebsd|7.0-release|200908051440
4891664|4891664-b19f-3f77-b713-d32bba55d77f|pass|200908|bingos@cpan.org|Devel-CheckLib|0.6|i686-linux-thread-multi-64int|5.8.8|linux|2.6.28-11-generic|200908051427
4891879|4891879-b19f-3f77-b713-d32bba55d77f|pass|200908|JOST@cpan.org ("Josts Smokehouse")|Devel-CheckLib|0.699_001|i86pc-solaris-64int|5.8.9|solaris|2.11|200908051554
4891904|4891904-b19f-3f77-b713-d32bba55d77f|pass|200908|srezic@cpan.org|Devel-CheckLib|0.6|amd64-freebsd|5.10.1|freebsd|7.0-release|200908051556
18561|18561-b19f-3f77-b713-d32bba55d77f|cpan|200102|DCANTRELL|Data-Hexdumper|0.01||0|||200102091317
20873|20873-b19f-3f77-b713-d32bba55d77f|cpan|200104|DCANTRELL|Pony|1.00||0|||200104031524
20890|20890-b19f-3f77-b713-d32bba55d77f|cpan|200104|DCANTRELL|Pony|1.01||0|||200104041148
21135|21135-b19f-3f77-b713-d32bba55d77f|cpan|200104|DCANTRELL|Tie-Scalar-Decay|1.0||0|||200104101615
21176|21176-b19f-3f77-b713-d32bba55d77f|cpan|200104|DCANTRELL|Tie-Scalar-Decay|1.1||0|||200104111716
23445|23445-b19f-3f77-b713-d32bba55d77f|cpan|200105|DCANTRELL|Tie-Scalar-Decay|1.1.1||0|||200105220018
24582|24582-b19f-3f77-b713-d32bba55d77f|cpan|200106|DCANTRELL|Tie-Hash-Rank|1.0.1||0|||200106132203
24768|24768-b19f-3f77-b713-d32bba55d77f|cpan|200106|DCANTRELL|Acme-Pony|1.1.1||0|||200106201613
25258|25258-b19f-3f77-b713-d32bba55d77f|cpan|200107|DCANTRELL|Acme-Pony|1.1.2||0|||200107100907
25259|25259-b19f-3f77-b713-d32bba55d77f|cpan|200107|DCANTRELL|Tie-Hash-Transactional|1.0||0|||200107100910
60243|60243-b19f-3f77-b713-d32bba55d77f|cpan|200209|DCANTRELL|Acme-Licence|1.0||0|||200209191118
60385|60385-b19f-3f77-b713-d32bba55d77f|cpan|200209|DCANTRELL|Data-Hexdumper|1.0.1||0|||200209201431
94015|94015-b19f-3f77-b713-d32bba55d77f|cpan|200306|DCANTRELL|NestedMap|1.0||0|||200306261034
94177|94177-b19f-3f77-b713-d32bba55d77f|cpan|200306|DCANTRELL|File-Find-Rule-Permissions|1.0||0|||200306291337
95932|95932-b19f-3f77-b713-d32bba55d77f|cpan|200307|DCANTRELL|File-Find-Rule-Permissions|1.1||0|||200307222223
97851|97851-b19f-3f77-b713-d32bba55d77f|cpan|200308|DCANTRELL|Data-Hexdumper|1.1||0|||200308101502
99242|99242-b19f-3f77-b713-d32bba55d77f|cpan|200308|DCANTRELL|Tie-Hash-Longest|1.0||0|||200308251544
99550|99550-b19f-3f77-b713-d32bba55d77f|cpan|200308|DCANTRELL|Tie-Hash-Longest|1.0.reupload||0|||200308272113
99713|99713-b19f-3f77-b713-d32bba55d77f|cpan|200308|DCANTRELL|Tie-Hash-Longest|1.0.reupload-again-because-im-stupid||0|||200308282356
100435|100435-b19f-3f77-b713-d32bba55d77f|cpan|200309|DCANTRELL|Acme-Scurvy-Whoreson-BilgeRat|1.0||0|||200309030037
107861|107861-b19f-3f77-b713-d32bba55d77f|cpan|200310|DCANTRELL|Games-Dice-Advanced|1.0||0|||200310202350
108215|108215-b19f-3f77-b713-d32bba55d77f|cpan|200310|DCANTRELL|Net-Random|1.0||0|||200310222224
110131|110131-b19f-3f77-b713-d32bba55d77f|cpan|200311|DCANTRELL|Scalar-Properties|0.11||0|||200311042001
110714|110714-b19f-3f77-b713-d32bba55d77f|cpan|200311|DCANTRELL|Scalar-Properties|0.12||0|||200311091239
111596|111596-b19f-3f77-b713-d32bba55d77f|cpan|200311|DCANTRELL|Sub-WrapPackages|1.0||0|||200311152027
111637|111637-b19f-3f77-b713-d32bba55d77f|cpan|200311|DCANTRELL|Statistics-ChiSquare|0.5||0|||200311161610
111698|111698-b19f-3f77-b713-d32bba55d77f|cpan|200311|DCANTRELL|Tie-Hash-Longest|1.1||0|||200311172142
112068|112068-b19f-3f77-b713-d32bba55d77f|cpan|200311|DCANTRELL|Statistics-SerialCorrelation|1.0||0|||200311211137
115196|115196-b19f-3f77-b713-d32bba55d77f|cpan|200312|DCANTRELL|File-Find-Rule-Permissions|1.2||0|||200312172039
115791|115791-b19f-3f77-b713-d32bba55d77f|cpan|200312|DCANTRELL|Data-Compare|0.03||0|||200312231623
115797|115797-b19f-3f77-b713-d32bba55d77f|cpan|200312|DCANTRELL|Data-Compare|0.04||0|||200312231817
116341|116341-b19f-3f77-b713-d32bba55d77f|cpan|200312|DCANTRELL|Data-Compare|0.05||0|||200312302326
117173|117173-b19f-3f77-b713-d32bba55d77f|cpan|200401|DCANTRELL|Data-Compare|0.06||0|||200401070009
117320|117320-b19f-3f77-b713-d32bba55d77f|cpan|200401|DCANTRELL|Data-Compare|0.07||0|||200401072031
119293|119293-b19f-3f77-b713-d32bba55d77f|cpan|200401|DCANTRELL|Data-Compare|0.08||0|||200401201351
119721|119721-b19f-3f77-b713-d32bba55d77f|cpan|200401|DCANTRELL|Statistics-SerialCorrelation|1.1||0|||200401231925
123317|123317-b19f-3f77-b713-d32bba55d77f|cpan|200402|DCANTRELL|Data-Hexdumper|1.2||0|||200402201400
123723|123723-b19f-3f77-b713-d32bba55d77f|cpan|200402|DCANTRELL|Data-Compare|0.09||0|||200402232204
126975|126975-b19f-3f77-b713-d32bba55d77f|cpan|200403|DCANTRELL|Data-Compare|0.1||0|||200403131033
142433|142433-b19f-3f77-b713-d32bba55d77f|cpan|200406|DCANTRELL|Data-Compare|0.11||0|||200406022128
148195|148195-b19f-3f77-b713-d32bba55d77f|cpan|200407|DCANTRELL|Class-CanBeA|1.0||0|||200407102030
153997|153997-b19f-3f77-b713-d32bba55d77f|cpan|200408|DCANTRELL|Number-Phone|1.0||0|||200408181838
156490|156490-b19f-3f77-b713-d32bba55d77f|cpan|200409|DCANTRELL|Net-Random|1.1||0|||200409071010
158150|158150-b19f-3f77-b713-d32bba55d77f|cpan|200409|DCANTRELL|Number-Phone|1.1||0|||200409152348
159942|159942-b19f-3f77-b713-d32bba55d77f|cpan|200409|DCANTRELL|Number-Phone|1.2||0|||200409222118
162174|162174-b19f-3f77-b713-d32bba55d77f|cpan|200410|DCANTRELL|Number-Phone|1.2001||0|||200410132026
162938|162938-b19f-3f77-b713-d32bba55d77f|cpan|200410|DCANTRELL|Number-Phone|1.3||0|||200410202307
163369|163369-b19f-3f77-b713-d32bba55d77f|cpan|200410|DCANTRELL|Acme-Scurvy-Whoreson-BilgeRat|1.1||0|||200410252258
165706|165706-b19f-3f77-b713-d32bba55d77f|cpan|200411|DCANTRELL|Data-Transactional|0.1||0|||200411062305
166048|166048-b19f-3f77-b713-d32bba55d77f|cpan|200411|DCANTRELL|Data-Compare|0.12||0|||200411091935
166051|166051-b19f-3f77-b713-d32bba55d77f|cpan|200411|DCANTRELL|Data-Compare|0.13||0|||200411092006
166394|166394-b19f-3f77-b713-d32bba55d77f|cpan|200411|DCANTRELL|Number-Phone|1.3001||0|||200411110010
169396|169396-b19f-3f77-b713-d32bba55d77f|cpan|200411|DCANTRELL|Number-Phone|1.3002||0|||200411261231
171989|171989-b19f-3f77-b713-d32bba55d77f|cpan|200412|DCANTRELL|Number-Phone|1.3003||0|||200412052038
175156|175156-b19f-3f77-b713-d32bba55d77f|cpan|200412|DCANTRELL|Class-CanBeA|1.1||0|||200412210020
198416|198416-b19f-3f77-b713-d32bba55d77f|cpan|200504|DCANTRELL|Number-Phone|1.3004||0|||200504121820
208303|208303-b19f-3f77-b713-d32bba55d77f|cpan|200505|DCANTRELL|Number-Phone|1.4||0|||200505182054
219457|219457-b19f-3f77-b713-d32bba55d77f|cpan|200506|DCANTRELL|Number-Phone|1.4001||0|||200506280014
230200|230200-b19f-3f77-b713-d32bba55d77f|cpan|200508|DCANTRELL|Number-Phone|1.4002||0|||200508021533
236772|236772-b19f-3f77-b713-d32bba55d77f|cpan|200508|DCANTRELL|Number-Phone|1.4003||0|||200508240021
258043|258043-b19f-3f77-b713-d32bba55d77f|cpan|200510|DCANTRELL|Number-Phone|1.4004||0|||200510111715
259958|259958-b19f-3f77-b713-d32bba55d77f|cpan|200510|DCANTRELL|Number-Phone|1.5||0|||200510161535
275288|275288-b19f-3f77-b713-d32bba55d77f|cpan|200512|DCANTRELL|Net-Random|1.2||0|||200512132331
278484|278484-b19f-3f77-b713-d32bba55d77f|cpan|200512|DCANTRELL|Class-CanBeA|1.2||0|||200512272316
286390|286390-b19f-3f77-b713-d32bba55d77f|cpan|200601|DCANTRELL|File-Overwrite|1.0||0|||200601291736
326764|326764-b19f-3f77-b713-d32bba55d77f|cpan|200607|DCANTRELL|Tie-STDOUT|1.0||0|||200607032333
326767|326767-b19f-3f77-b713-d32bba55d77f|cpan|200607|DCANTRELL|Tie-STDOUT|1.01||0|||200607032355
327002|327002-b19f-3f77-b713-d32bba55d77f|cpan|200607|DCANTRELL|Tie-STDOUT|1.02||0|||200607051519
336599|336599-b19f-3f77-b713-d32bba55d77f|cpan|200607|DCANTRELL|Sub-WrapPackages|1.1||0|||200607260915
340156|340156-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Sub-WrapPackages|1.2||0|||200608021542
344363|344363-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone|1.51||0|||200608230005
344492|344492-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone|1.52||0|||200608232313
344495|344495-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone|1.53||0|||200608240021
344496|344496-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone-UK-DetailedLocations|1.0||0|||200608240022
344681|344681-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone|1.54||0|||200608241608
344682|344682-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone-UK-DetailedLocations|1.1||0|||200608241626
344739|344739-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone|1.55||0|||200608250215
344740|344740-b19f-3f77-b713-d32bba55d77f|cpan|200608|DCANTRELL|Number-Phone-UK-DetailedLocations|1.2||0|||200608250220
348326|348326-b19f-3f77-b713-d32bba55d77f|cpan|200609|DCANTRELL|Games-Dice-Advanced|1.1||0|||200609121951
367316|367316-b19f-3f77-b713-d32bba55d77f|cpan|200611|DCANTRELL|Data-Compare|0.14||0|||200611011650
385595|385595-b19f-3f77-b713-d32bba55d77f|cpan|200612|DCANTRELL|Number-Phone|1.56||0|||200612121318
402533|402533-b19f-3f77-b713-d32bba55d77f|cpan|200701|DCANTRELL|Bryar|3.0||0|||200701201555
402559|402559-b19f-3f77-b713-d32bba55d77f|cpan|200701|DCANTRELL|Net-Random|1.3||0|||200701210016
406096|406096-b19f-3f77-b713-d32bba55d77f|cpan|200701|DCANTRELL|XML-Tiny|1.0||0|||200701261523
407368|407368-b19f-3f77-b713-d32bba55d77f|cpan|200701|DCANTRELL|XML-Tiny|1.01||0|||200701300016
408160|408160-b19f-3f77-b713-d32bba55d77f|cpan|200701|DCANTRELL|XML-Tiny|1.02||0|||200701302356
409886|409886-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|XML-Tiny|1.03||0|||200702030348
413165|413165-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|XML-Tiny|1.04||0|||200702111521
420582|420582-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|Number-Phone|1.5601||0|||200702241446
421740|421740-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|Data-Compare|0.15||0|||200702252138
423896|423896-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|Data-Compare|0.16||0|||200702272131
423938|423938-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|XML-Tiny|1.05||0|||200702272218
424835|424835-b19f-3f77-b713-d32bba55d77f|cpan|200702|DCANTRELL|Net-Random|1.4||0|||200702282207
428341|428341-b19f-3f77-b713-d32bba55d77f|cpan|200703|DCANTRELL|XML-Tiny|1.06||0|||200703042341
435949|435949-b19f-3f77-b713-d32bba55d77f|cpan|200703|DCANTRELL|XML-DoubleEncodedEntities|1.0||0|||200703122133
437845|437845-b19f-3f77-b713-d32bba55d77f|cpan|200703|DCANTRELL|Number-Phone-UK-DetailedLocations|1.3||0|||200703142131
437846|437846-b19f-3f77-b713-d32bba55d77f|cpan|200703|DCANTRELL|Number-Phone|1.57||0|||200703142132
458866|458866-b19f-3f77-b713-d32bba55d77f|cpan|200704|DCANTRELL|Net-Random|2.0||0|||200704130117
500610|500610-b19f-3f77-b713-d32bba55d77f|cpan|200706|DCANTRELL|Number-Phone|1.58||0|||200706020101
550752|550752-b19f-3f77-b713-d32bba55d77f|cpan|200707|DCANTRELL|Palm-TreoPhoneCallDB|1||0|||200707291727
551374|551374-b19f-3f77-b713-d32bba55d77f|cpan|200707|DCANTRELL|Palm-TreoPhoneCallDB|1.1||0|||200707302337
558544|558544-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|Data-Compare|0.17||0|||200708071930
581761|581761-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|CPAN-FindDependencies|1.0||0|||200708180022
582757|582757-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|CPAN-FindDependencies|1.01||0|||200708190252
583200|583200-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|CPAN-FindDependencies|1.02||0|||200708191408
586612|586612-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|Data-Hexdumper|1.3||0|||200708210010
596782|596782-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|Tie-STDOUT|1.03||0|||200708281235
597396|597396-b19f-3f77-b713-d32bba55d77f|cpan|200708|DCANTRELL|Data-Transactional|1.0||0|||200708290007
663028|663028-b19f-3f77-b713-d32bba55d77f|cpan|200709|DCANTRELL|Devel-CheckOS|0.9||0|||200709301722
663314|663314-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckOS|0.91||0|||200710011851
663551|663551-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckOS|0.92||0|||200710012333
665669|665669-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckOS|1.0||0|||200710021803
666093|666093-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|File-Find-Rule-Permissions|1.3||0|||200710021957
671365|671365-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckOS|1.1||0|||200710051605
686172|686172-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-AssertLib|0.1||0|||200710141722
686287|686287-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckOS|1.2||0|||200710141814
695141|695141-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckLib|0.2||0|||200710181942
711234|711234-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|XML-Tiny|1.07||0|||200710241517
714488|714488-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|XML-Tiny|1.08||0|||200710251630
723790|723790-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|XML-Tiny|1.09||0|||200710291857
724374|724374-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|XML-Tiny|1.10||0|||200710292352
725966|725966-b19f-3f77-b713-d32bba55d77f|cpan|200710|DCANTRELL|Devel-CheckLib|0.3||0|||200710301630
731691|731691-b19f-3f77-b713-d32bba55d77f|cpan|200711|DCANTRELL|XML-Tiny|1.11||0|||200711011806
748640|748640-b19f-3f77-b713-d32bba55d77f|cpan|200711|DCANTRELL|Devel-CheckOS|1.3||0|||200711071912
749350|749350-b19f-3f77-b713-d32bba55d77f|cpan|200711|DCANTRELL|Devel-CheckOS|1.4||0|||200711072227
749367|749367-b19f-3f77-b713-d32bba55d77f|cpan|200711|DCANTRELL|Devel-CheckOS|1.41||0|||200711072232
749596|749596-b19f-3f77-b713-d32bba55d77f|cpan|200711|DCANTRELL|CPAN-FindDependencies|1.1||0|||200711080036
790843|790843-b19f-3f77-b713-d32bba55d77f|cpan|200711|DCANTRELL|Devel-CheckOS|1.42||0|||200711202144
829798|829798-b19f-3f77-b713-d32bba55d77f|cpan|200712|DCANTRELL|CPAN-FindDependencies|1.99_01||0|||200712031848
857128|857128-b19f-3f77-b713-d32bba55d77f|cpan|200712|DCANTRELL|CPAN-FindDependencies|2.0||0|||200712141554
958858|958858-b19f-3f77-b713-d32bba55d77f|cpan|200801|DCANTRELL|Data-Compare|1.18||0|||200801160015
1039463|1039463-b19f-3f77-b713-d32bba55d77f|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.0||0|||200802142218
1082170|1082170-b19f-3f77-b713-d32bba55d77f|cpan|200802|DCANTRELL|Number-Phone|1.581||0|||200802272246
1085089|1085089-b19f-3f77-b713-d32bba55d77f|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.1||0|||200802282147
1085746|1085746-b19f-3f77-b713-d32bba55d77f|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.001||0|||200802290019
1085778|1085778-b19f-3f77-b713-d32bba55d77f|cpan|200802|DCANTRELL|CPU-Emulator-Memory|1.1001||0|||200802290023
1107354|1107354-b19f-3f77-b713-d32bba55d77f|cpan|200803|DCANTRELL|Devel-CheckLib|0.4||0|||200803042253
1157349|1157349-b19f-3f77-b713-d32bba55d77f|cpan|200803|DCANTRELL|Devel-CheckLib|0.5||0|||200803122102
1157413|1157413-b19f-3f77-b713-d32bba55d77f|cpan|200803|DCANTRELL|Devel-CheckOS|1.43||0|||200803122114
1158266|1158266-b19f-3f77-b713-d32bba55d77f|cpan|200803|DCANTRELL|CPU-Emulator-Z80|0.9||0|||200803122349
1443831|1443831-b19f-3f77-b713-d32bba55d77f|cpan|200805|DCANTRELL|Data-Compare|1.19||0|||200805121742
1479315|1479315-b19f-3f77-b713-d32bba55d77f|cpan|200805|DCANTRELL|Data-Hexdumper|1.4||0|||200805181803
1533076|1533076-b19f-3f77-b713-d32bba55d77f|cpan|200805|DCANTRELL|Number-Phone|1.6||0|||200805280206
1689406|1689406-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.0||0|||200806132245
1689431|1689431-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|CPU-Emulator-Z80|1.0||0|||200806132246
1699403|1699403-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.01||0|||200806141928
1709294|1709294-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|Data-Transactional|1.01||0|||200806161655
1709323|1709323-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|Data-Transactional|1.02||0|||200806161708
1767508|1767508-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.02||0|||200806222327
1790577|1790577-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|DBIx-Class-SingletonRows|0.1||0|||200806251641
1792766|1792766-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|CPU-Z80-Assembler|1.03||0|||200806252102
1799251|1799251-b19f-3f77-b713-d32bba55d77f|cpan|200806|DCANTRELL|DBIx-Class-SingletonRows|0.11||0|||200806261933
1878761|1878761-b19f-3f77-b713-d32bba55d77f|cpan|200807|DCANTRELL|Palm-Treo680MessagesDB|1.0||0|||200807110042
1943448|1943448-b19f-3f77-b713-d32bba55d77f|cpan|200807|DCANTRELL|Sort-MultipleFields|0.001_01||0|||200807252348
1955427|1955427-b19f-3f77-b713-d32bba55d77f|cpan|200807|DCANTRELL|Sort-MultipleFields|1.0||0|||200807282355
2064291|2064291-b19f-3f77-b713-d32bba55d77f|cpan|200808|DCANTRELL|Data-Compare|1.20||0|||200808211630
2090369|2090369-b19f-3f77-b713-d32bba55d77f|cpan|200808|DCANTRELL|Data-Compare|1.200_500||0|||200808262250
2100400|2100400-b19f-3f77-b713-d32bba55d77f|cpan|200808|DCANTRELL|Class-DBI-ClassGenerator|1.0||0|||200808281915
2122413|2122413-b19f-3f77-b713-d32bba55d77f|cpan|200809|DCANTRELL|Data-Compare|1.21||0|||200809011832
2133359|2133359-b19f-3f77-b713-d32bba55d77f|cpan|200809|DCANTRELL|Class-DBI-ClassGenerator|1.01||0|||200809031834
2335260|2335260-b19f-3f77-b713-d32bba55d77f|cpan|200809|DCANTRELL|Devel-CheckOS|1.44||0|||200809291718
2473005|2473005-b19f-3f77-b713-d32bba55d77f|cpan|200810|DCANTRELL|Devel-CheckOS|1.45||0|||200810222158
2505985|2505985-b19f-3f77-b713-d32bba55d77f|cpan|200810|DCANTRELL|Devel-CheckOS|1.46||0|||200810272138
2556191|2556191-b19f-3f77-b713-d32bba55d77f|cpan|200811|DCANTRELL|Devel-CheckOS|1.49_01||0|||200811052352
2595943|2595943-b19f-3f77-b713-d32bba55d77f|cpan|200811|DCANTRELL|Devel-CheckOS|1.50||0|||200811120055
3041172|3041172-b19f-3f77-b713-d32bba55d77f|cpan|200901|DCANTRELL|Palm-SMS|0.03||0|||200901101720
3115655|3115655-b19f-3f77-b713-d32bba55d77f|cpan|200901|DCANTRELL|XML-Tiny|1.12||0|||200901221756
3250415|3250415-b19f-3f77-b713-d32bba55d77f|cpan|200902|DCANTRELL|Class-DBI-ClassGenerator|1.02||0|||200902101617
3261096|3261096-b19f-3f77-b713-d32bba55d77f|cpan|200902|DCANTRELL|File-Find-Rule-Permissions|2.0||0|||200902120000
3352076|3352076-b19f-3f77-b713-d32bba55d77f|cpan|200902|DCANTRELL|Number-Phone|1.7||0|||200902262116
3355848|3355848-b19f-3f77-b713-d32bba55d77f|cpan|200902|DCANTRELL|WWW-Facebook-Go-SGF|1.0||0|||200902272216
3374215|3374215-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|Data-Hexdumper|2.0||0|||200903030047
3379639|3379639-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|Data-Hexdumper|2.01||0|||200903032129
3380947|3380947-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|Number-Phone|1.7001||0|||200903040118
3510206|3510206-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|Tie-STDOUT|1.04||0|||200903182050
3510257|3510257-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|App-Rsnapshot|1.999_00001||0|||200903182101
3514629|3514629-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|Tie-STDOUT|1.0401||0|||200903191113
3543273|3543273-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|XML-Tiny|2.0||0|||200903222031
3543480|3543480-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|App-Rsnapshot|1.999_00002||0|||200903222104
3544677|3544677-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|XML-Tiny|2.01||0|||200903231919
3557350|3557350-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|XML-Tiny|2.02||0|||200903241615
3572078|3572078-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|XML-Tiny-DOM|1.0||0|||200903261822
3572458|3572458-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|Palm-ProjectGutenberg|1.0||0|||200903262148
3594727|3594727-b19f-3f77-b713-d32bba55d77f|cpan|200903|DCANTRELL|CPAN-ParseDistribution|1.0||0|||200903310100
3620843|3620843-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-ParseDistribution|1.1||0|||200904041245
3666403|3666403-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Palm-Treo680MessagesDB|1.01||0|||200904101646
3666523|3666523-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|File-Overwrite|1.1||0|||200904101715
3673312|3673312-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.1||0|||200904111938
3689350|3689350-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.51||0|||200904142157
3690126|3690126-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.2||0|||200904150108
3695760|3695760-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.21||0|||200904152031
3695763|3695763-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.52||0|||200904152031
3696161|3696161-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.22||0|||200904152143
3696921|3696921-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.53||0|||200904160008
3697653|3697653-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.54||0|||200904160211
3697679|3697679-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.55||0|||200904160215
3727292|3727292-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.3||0|||200904201753
3736322|3736322-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.6||0|||200904212139
3742215|3742215-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Number-Phone|1.7002||0|||200904222047
3754728|3754728-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.31||0|||200904241728
3761267|3761267-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|Devel-CheckOS|1.61||0|||200904251318
3774732|3774732-b19f-3f77-b713-d32bba55d77f|cpan|200904|DCANTRELL|CPAN-FindDependencies|2.32||0|||200904271731
3819841|3819841-b19f-3f77-b713-d32bba55d77f|cpan|200905|DCANTRELL|Data-Compare|1.2101||0|||200905051643
3925252|3925252-b19f-3f77-b713-d32bba55d77f|cpan|200905|DCANTRELL|Devel-CheckLib|0.6||0|||200905201547
3989559|3989559-b19f-3f77-b713-d32bba55d77f|cpan|200905|DCANTRELL|Bryar|3.1||0|||200905282352
4634312|4634312-b19f-3f77-b713-d32bba55d77f|cpan|200907|DCANTRELL|XML-Tiny-DOM|1.1||0|||200907160048
4852270|4852270-b19f-3f77-b713-d32bba55d77f|cpan|200908|DCANTRELL|Devel-CheckLib|0.699_001||0|||200908011730
